# This File GEN using nerdicons_gen.py

class Cod:

	# CHAR : 
	cod_account = "\ueb99"
	# CHAR : 
	cod_activate_breakpoints = "\uea97"
	# CHAR : 
	cod_add = "\uea60"
	# CHAR : 
	cod_archive = "\uea98"
	# CHAR : 
	cod_arrow_both = "\uea99"
	# CHAR : 
	cod_arrow_circle_down = "\uebfc"
	# CHAR : 
	cod_arrow_circle_left = "\uebfd"
	# CHAR : 
	cod_arrow_circle_right = "\uebfe"
	# CHAR : 
	cod_arrow_circle_up = "\uebff"
	# CHAR : 
	cod_arrow_down = "\uea9a"
	# CHAR : 
	cod_arrow_left = "\uea9b"
	# CHAR : 
	cod_arrow_right = "\uea9c"
	# CHAR : 
	cod_arrow_small_down = "\uea9d"
	# CHAR : 
	cod_arrow_small_left = "\uea9e"
	# CHAR : 
	cod_arrow_small_right = "\uea9f"
	# CHAR : 
	cod_arrow_small_up = "\ueaa0"
	# CHAR : 
	cod_arrow_swap = "\uebcb"
	# CHAR : 
	cod_arrow_up = "\ueaa1"
	# CHAR : 
	cod_azure = "\uebd8"
	# CHAR : 
	cod_azure_devops = "\uebe8"
	# CHAR : 
	cod_beaker = "\uea79"
	# CHAR : 
	cod_beaker_stop = "\uebe1"
	# CHAR : 
	cod_bell = "\ueaa2"
	# CHAR : 
	cod_bell_dot = "\ueb9a"
	# CHAR : 
	cod_bell_slash = "\uec08"
	# CHAR : 
	cod_bell_slash_dot = "\uec09"
	# CHAR : 
	cod_blank = "\uec03"
	# CHAR : 
	cod_bold = "\ueaa3"
	# CHAR : 
	cod_book = "\ueaa4"
	# CHAR : 
	cod_bookmark = "\ueaa5"
	# CHAR : 
	cod_bracket_dot = "\uebe5"
	# CHAR : 
	cod_bracket_error = "\uebe6"
	# CHAR : 
	cod_briefcase = "\ueaac"
	# CHAR : 
	cod_broadcast = "\ueaad"
	# CHAR : 
	cod_browser = "\ueaae"
	# CHAR : 
	cod_bug = "\ueaaf"
	# CHAR : 
	cod_calendar = "\ueab0"
	# CHAR : 
	cod_call_incoming = "\ueb92"
	# CHAR : 
	cod_call_outgoing = "\ueb93"
	# CHAR : 
	cod_case_sensitive = "\ueab1"
	# CHAR : 
	cod_check = "\ueab2"
	# CHAR : 
	cod_check_all = "\uebb1"
	# CHAR : 
	cod_checklist = "\ueab3"
	# CHAR : 
	cod_chevron_down = "\ueab4"
	# CHAR : 
	cod_chevron_left = "\ueab5"
	# CHAR : 
	cod_chevron_right = "\ueab6"
	# CHAR : 
	cod_chevron_up = "\ueab7"
	# CHAR : 
	cod_chip = "\uec19"
	# CHAR : 
	cod_chrome_close = "\ueab8"
	# CHAR : 
	cod_chrome_maximize = "\ueab9"
	# CHAR : 
	cod_chrome_minimize = "\ueaba"
	# CHAR : 
	cod_chrome_restore = "\ueabb"
	# CHAR : 
	cod_circle = "\ueabc"
	# CHAR : 
	cod_circle_filled = "\uea71"
	# CHAR : 
	cod_circle_large = "\uebb5"
	# CHAR : 
	cod_circle_large_filled = "\uebb4"
	# CHAR : 
	cod_circle_slash = "\ueabd"
	# CHAR : 
	cod_circle_small = "\uec07"
	# CHAR : 
	cod_circle_small_filled = "\ueb8a"
	# CHAR : 
	cod_circuit_board = "\ueabe"
	# CHAR : 
	cod_clear_all = "\ueabf"
	# CHAR : 
	cod_clippy = "\ueac0"
	# CHAR : 
	cod_close = "\uea76"
	# CHAR : 
	cod_close_all = "\ueac1"
	# CHAR : 
	cod_cloud = "\uebaa"
	# CHAR : 
	cod_cloud_download = "\ueac2"
	# CHAR : 
	cod_cloud_upload = "\ueac3"
	# CHAR : 
	cod_code = "\ueac4"
	# CHAR : 
	cod_coffee = "\uec15"
	# CHAR : 
	cod_collapse_all = "\ueac5"
	# CHAR : 
	cod_color_mode = "\ueac6"
	# CHAR : 
	cod_combine = "\uebb6"
	# CHAR : 
	cod_comment = "\uea6b"
	# CHAR : 
	cod_comment_discussion = "\ueac7"
	# CHAR : 
	cod_comment_draft = "\uec0e"
	# CHAR : 
	cod_comment_unresolved = "\uec0a"
	# CHAR : 
	cod_compass = "\uebd5"
	# CHAR : 
	cod_compass_active = "\uebd7"
	# CHAR : 
	cod_compass_dot = "\uebd6"
	# CHAR : 
	cod_copilot = "\uec1e"
	# CHAR : 
	cod_copy = "\uebcc"
	# CHAR : 
	cod_credit_card = "\ueac9"
	# CHAR : 
	cod_dash = "\ueacc"
	# CHAR : 
	cod_dashboard = "\ueacd"
	# CHAR : 
	cod_database = "\ueace"
	# CHAR : 
	cod_debug = "\uead8"
	# CHAR : 
	cod_debug_all = "\uebdc"
	# CHAR : 
	cod_debug_alt = "\ueb91"
	# CHAR : 
	cod_debug_alt_small = "\ueba8"
	# CHAR : 
	cod_debug_breakpoint_conditional = "\ueaa7"
	# CHAR : 
	cod_debug_breakpoint_conditional_unverified = "\ueaa6"
	# CHAR : 
	cod_debug_breakpoint_data = "\ueaa9"
	# CHAR : 
	cod_debug_breakpoint_data_unverified = "\ueaa8"
	# CHAR : 
	cod_debug_breakpoint_function = "\ueb88"
	# CHAR : 
	cod_debug_breakpoint_function_unverified = "\ueb87"
	# CHAR : 
	cod_debug_breakpoint_log = "\ueaab"
	# CHAR : 
	cod_debug_breakpoint_log_unverified = "\ueaaa"
	# CHAR : 
	cod_debug_breakpoint_unsupported = "\ueb8c"
	# CHAR : 
	cod_debug_console = "\ueb9b"
	# CHAR : 
	cod_debug_continue = "\ueacf"
	# CHAR : 
	cod_debug_continue_small = "\uebe0"
	# CHAR : 
	cod_debug_coverage = "\uebdd"
	# CHAR : 
	cod_debug_disconnect = "\uead0"
	# CHAR : 
	cod_debug_line_by_line = "\uebd0"
	# CHAR : 
	cod_debug_pause = "\uead1"
	# CHAR : 
	cod_debug_rerun = "\uebc0"
	# CHAR : 
	cod_debug_restart = "\uead2"
	# CHAR : 
	cod_debug_restart_frame = "\ueb90"
	# CHAR : 
	cod_debug_reverse_continue = "\ueb8e"
	# CHAR : 
	cod_debug_stackframe = "\ueb8b"
	# CHAR : 
	cod_debug_stackframe_active = "\ueb89"
	# CHAR : 
	cod_debug_start = "\uead3"
	# CHAR : 
	cod_debug_step_back = "\ueb8f"
	# CHAR : 
	cod_debug_step_into = "\uead4"
	# CHAR : 
	cod_debug_step_out = "\uead5"
	# CHAR : 
	cod_debug_step_over = "\uead6"
	# CHAR : 
	cod_debug_stop = "\uead7"
	# CHAR : 
	cod_desktop_download = "\uea78"
	# CHAR : 
	cod_device_camera = "\ueada"
	# CHAR : 
	cod_device_camera_video = "\uead9"
	# CHAR : 
	cod_device_mobile = "\ueadb"
	# CHAR : 
	cod_diff = "\ueae1"
	# CHAR : 
	cod_diff_added = "\ueadc"
	# CHAR : 
	cod_diff_ignored = "\ueadd"
	# CHAR : 
	cod_diff_modified = "\ueade"
	# CHAR : 
	cod_diff_removed = "\ueadf"
	# CHAR : 
	cod_diff_renamed = "\ueae0"
	# CHAR : 
	cod_discard = "\ueae2"
	# CHAR : 
	cod_edit = "\uea73"
	# CHAR : 
	cod_editor_layout = "\ueae3"
	# CHAR : 
	cod_ellipsis = "\uea7c"
	# CHAR : 
	cod_empty_window = "\ueae4"
	# CHAR : 
	cod_error = "\uea87"
	# CHAR : 
	cod_error_small = "\uebfb"
	# CHAR : 
	cod_exclude = "\ueae5"
	# CHAR : 
	cod_expand_all = "\ueb95"
	# CHAR : 
	cod_export = "\uebac"
	# CHAR : 
	cod_extensions = "\ueae6"
	# CHAR : 
	cod_eye = "\uea70"
	# CHAR : 
	cod_eye_closed = "\ueae7"
	# CHAR : 
	cod_feedback = "\ueb96"
	# CHAR : 
	cod_file = "\uea7b"
	# CHAR : 
	cod_file_binary = "\ueae8"
	# CHAR : 
	cod_file_code = "\ueae9"
	# CHAR : 
	cod_file_media = "\ueaea"
	# CHAR : 
	cod_file_pdf = "\ueaeb"
	# CHAR : 
	cod_file_submodule = "\ueaec"
	# CHAR : 
	cod_file_symlink_directory = "\ueaed"
	# CHAR : 
	cod_file_symlink_file = "\ueaee"
	# CHAR : 
	cod_file_zip = "\ueaef"
	# CHAR : 
	cod_files = "\ueaf0"
	# CHAR : 
	cod_filter = "\ueaf1"
	# CHAR : 
	cod_filter_filled = "\uebce"
	# CHAR : 
	cod_flame = "\ueaf2"
	# CHAR : 
	cod_fold = "\ueaf5"
	# CHAR : 
	cod_fold_down = "\ueaf3"
	# CHAR : 
	cod_fold_up = "\ueaf4"
	# CHAR : 
	cod_folder = "\uea83"
	# CHAR : 
	cod_folder_active = "\ueaf6"
	# CHAR : 
	cod_folder_library = "\uebdf"
	# CHAR : 
	cod_folder_opened = "\ueaf7"
	# CHAR : 
	cod_game = "\uec17"
	# CHAR : 
	cod_gear = "\ueaf8"
	# CHAR : 
	cod_gift = "\ueaf9"
	# CHAR : 
	cod_gist_secret = "\ueafa"
	# CHAR : 
	cod_git_commit = "\ueafc"
	# CHAR : 
	cod_git_compare = "\ueafd"
	# CHAR : 
	cod_git_fetch = "\uec1d"
	# CHAR : 
	cod_git_merge = "\ueafe"
	# CHAR : 
	cod_git_pull_request = "\uea64"
	# CHAR : 
	cod_git_pull_request_closed = "\uebda"
	# CHAR : 
	cod_git_pull_request_create = "\uebbc"
	# CHAR : 
	cod_git_pull_request_draft = "\uebdb"
	# CHAR : 
	cod_git_pull_request_go_to_changes = "\uec0b"
	# CHAR : 
	cod_git_pull_request_new_changes = "\uec0c"
	# CHAR : 
	cod_github = "\uea84"
	# CHAR : 
	cod_github_action = "\ueaff"
	# CHAR : 
	cod_github_alt = "\ueb00"
	# CHAR : 
	cod_github_inverted = "\ueba1"
	# CHAR : 
	cod_globe = "\ueb01"
	# CHAR : 
	cod_go_to_file = "\uea94"
	# CHAR : 
	cod_grabber = "\ueb02"
	# CHAR : 
	cod_graph = "\ueb03"
	# CHAR : 
	cod_graph_left = "\uebad"
	# CHAR : 
	cod_graph_line = "\uebe2"
	# CHAR : 
	cod_graph_scatter = "\uebe3"
	# CHAR : 
	cod_gripper = "\ueb04"
	# CHAR : 
	cod_group_by_ref_type = "\ueb97"
	# CHAR : 
	cod_heart = "\ueb05"
	# CHAR : 
	cod_heart_filled = "\uec04"
	# CHAR : 
	cod_history = "\uea82"
	# CHAR : 
	cod_home = "\ueb06"
	# CHAR : 
	cod_horizontal_rule = "\ueb07"
	# CHAR : 
	cod_hubot = "\ueb08"
	# CHAR : 
	cod_inbox = "\ueb09"
	# CHAR : 
	cod_indent = "\uebf9"
	# CHAR : 
	cod_info = "\uea74"
	# CHAR : 
	cod_insert = "\uec11"
	# CHAR : 
	cod_inspect = "\uebd1"
	# CHAR : 
	cod_issue_draft = "\uebd9"
	# CHAR : 
	cod_issue_reopened = "\ueb0b"
	# CHAR : 
	cod_issues = "\ueb0c"
	# CHAR : 
	cod_italic = "\ueb0d"
	# CHAR : 
	cod_jersey = "\ueb0e"
	# CHAR : 
	cod_json = "\ueb0f"
	# CHAR : 
	cod_kebab_vertical = "\ueb10"
	# CHAR : 
	cod_key = "\ueb11"
	# CHAR : 
	cod_law = "\ueb12"
	# CHAR : 
	cod_layers = "\uebd2"
	# CHAR : 
	cod_layers_active = "\uebd4"
	# CHAR : 
	cod_layers_dot = "\uebd3"
	# CHAR : 
	cod_layout = "\uebeb"
	# CHAR : 
	cod_layout_activitybar_left = "\uebec"
	# CHAR : 
	cod_layout_activitybar_right = "\uebed"
	# CHAR : 
	cod_layout_centered = "\uebf7"
	# CHAR : 
	cod_layout_menubar = "\uebf6"
	# CHAR : 
	cod_layout_panel = "\uebf2"
	# CHAR : 
	cod_layout_panel_center = "\uebef"
	# CHAR : 
	cod_layout_panel_justify = "\uebf0"
	# CHAR : 
	cod_layout_panel_left = "\uebee"
	# CHAR : 
	cod_layout_panel_off = "\uec01"
	# CHAR : 
	cod_layout_panel_right = "\uebf1"
	# CHAR : 
	cod_layout_sidebar_left = "\uebf3"
	# CHAR : 
	cod_layout_sidebar_left_off = "\uec02"
	# CHAR : 
	cod_layout_sidebar_right = "\uebf4"
	# CHAR : 
	cod_layout_sidebar_right_off = "\uec00"
	# CHAR : 
	cod_layout_statusbar = "\uebf5"
	# CHAR : 
	cod_library = "\ueb9c"
	# CHAR : 
	cod_lightbulb = "\uea61"
	# CHAR : 
	cod_lightbulb_autofix = "\ueb13"
	# CHAR : 
	cod_link = "\ueb15"
	# CHAR : 
	cod_link_external = "\ueb14"
	# CHAR : 
	cod_list_filter = "\ueb83"
	# CHAR : 
	cod_list_flat = "\ueb84"
	# CHAR : 
	cod_list_ordered = "\ueb16"
	# CHAR : 
	cod_list_selection = "\ueb85"
	# CHAR : 
	cod_list_tree = "\ueb86"
	# CHAR : 
	cod_list_unordered = "\ueb17"
	# CHAR : 
	cod_live_share = "\ueb18"
	# CHAR : 
	cod_loading = "\ueb19"
	# CHAR : 
	cod_location = "\ueb1a"
	# CHAR : 
	cod_lock = "\uea75"
	# CHAR : 
	cod_lock_small = "\uebe7"
	# CHAR : 
	cod_magnet = "\uebae"
	# CHAR : 
	cod_mail = "\ueb1c"
	# CHAR : 
	cod_mail_read = "\ueb1b"
	# CHAR : 
	cod_map = "\uec05"
	# CHAR : 
	cod_map_filled = "\uec06"
	# CHAR : 
	cod_markdown = "\ueb1d"
	# CHAR : 
	cod_megaphone = "\ueb1e"
	# CHAR : 
	cod_mention = "\ueb1f"
	# CHAR : 
	cod_menu = "\ueb94"
	# CHAR : 
	cod_merge = "\uebab"
	# CHAR : 
	cod_mic = "\uec12"
	# CHAR : 
	cod_mic_filled = "\uec1c"
	# CHAR : 
	cod_milestone = "\ueb20"
	# CHAR : 
	cod_mirror = "\uea69"
	# CHAR : 
	cod_mortar_board = "\ueb21"
	# CHAR : 
	cod_move = "\ueb22"
	# CHAR : 
	cod_multiple_windows = "\ueb23"
	# CHAR : 
	cod_music = "\uec1b"
	# CHAR : 
	cod_mute = "\ueb24"
	# CHAR : 
	cod_new_file = "\uea7f"
	# CHAR : 
	cod_new_folder = "\uea80"
	# CHAR : 
	cod_newline = "\uebea"
	# CHAR : 
	cod_no_newline = "\ueb25"
	# CHAR : 
	cod_note = "\ueb26"
	# CHAR : 
	cod_notebook = "\uebaf"
	# CHAR : 
	cod_notebook_template = "\uebbf"
	# CHAR : 
	cod_octoface = "\ueb27"
	# CHAR : 
	cod_open_preview = "\ueb28"
	# CHAR : 
	cod_organization = "\uea7e"
	# CHAR : 
	cod_output = "\ueb9d"
	# CHAR : 
	cod_package = "\ueb29"
	# CHAR : 
	cod_paintcan = "\ueb2a"
	# CHAR : 
	cod_pass = "\ueba4"
	# CHAR : 
	cod_pass_filled = "\uebb3"
	# CHAR : 
	cod_person = "\uea67"
	# CHAR : 
	cod_person_add = "\uebcd"
	# CHAR : 
	cod_piano = "\uec1a"
	# CHAR : 
	cod_pie_chart = "\uebe4"
	# CHAR : 
	cod_pin = "\ueb2b"
	# CHAR : 
	cod_pinned = "\ueba0"
	# CHAR : 
	cod_pinned_dirty = "\uebb2"
	# CHAR : 
	cod_play = "\ueb2c"
	# CHAR : 
	cod_play_circle = "\ueba6"
	# CHAR : 
	cod_plug = "\ueb2d"
	# CHAR : 
	cod_preserve_case = "\ueb2e"
	# CHAR : 
	cod_preview = "\ueb2f"
	# CHAR : 
	cod_primitive_square = "\uea72"
	# CHAR : 
	cod_project = "\ueb30"
	# CHAR : 
	cod_pulse = "\ueb31"
	# CHAR : 
	cod_question = "\ueb32"
	# CHAR : 
	cod_quote = "\ueb33"
	# CHAR : 
	cod_radio_tower = "\ueb34"
	# CHAR : 
	cod_reactions = "\ueb35"
	# CHAR : 
	cod_record = "\ueba7"
	# CHAR : 
	cod_record_keys = "\uea65"
	# CHAR : 
	cod_record_small = "\uebfa"
	# CHAR : 
	cod_redo = "\uebb0"
	# CHAR : 
	cod_references = "\ueb36"
	# CHAR : 
	cod_refresh = "\ueb37"
	# CHAR : 
	cod_regex = "\ueb38"
	# CHAR : 
	cod_remote = "\ueb3a"
	# CHAR : 
	cod_remote_explorer = "\ueb39"
	# CHAR : 
	cod_remove = "\ueb3b"
	# CHAR : 
	cod_replace = "\ueb3d"
	# CHAR : 
	cod_replace_all = "\ueb3c"
	# CHAR : 
	cod_reply = "\uea7d"
	# CHAR : 
	cod_repo = "\uea62"
	# CHAR : 
	cod_repo_clone = "\ueb3e"
	# CHAR : 
	cod_repo_force_push = "\ueb3f"
	# CHAR : 
	cod_repo_forked = "\uea63"
	# CHAR : 
	cod_repo_pull = "\ueb40"
	# CHAR : 
	cod_repo_push = "\ueb41"
	# CHAR : 
	cod_report = "\ueb42"
	# CHAR : 
	cod_request_changes = "\ueb43"
	# CHAR : 
	cod_rocket = "\ueb44"
	# CHAR : 
	cod_root_folder = "\ueb46"
	# CHAR : 
	cod_root_folder_opened = "\ueb45"
	# CHAR : 
	cod_rss = "\ueb47"
	# CHAR : 
	cod_ruby = "\ueb48"
	# CHAR : 
	cod_run_above = "\uebbd"
	# CHAR : 
	cod_run_all = "\ueb9e"
	# CHAR : 
	cod_run_below = "\uebbe"
	# CHAR : 
	cod_run_errors = "\uebde"
	# CHAR : 
	cod_save = "\ueb4b"
	# CHAR : 
	cod_save_all = "\ueb49"
	# CHAR : 
	cod_save_as = "\ueb4a"
	# CHAR : 
	cod_screen_full = "\ueb4c"
	# CHAR : 
	cod_screen_normal = "\ueb4d"
	# CHAR : 
	cod_search = "\uea6d"
	# CHAR : 
	cod_search_fuzzy = "\uec0d"
	# CHAR : 
	cod_search_stop = "\ueb4e"
	# CHAR : 
	cod_send = "\uec0f"
	# CHAR : 
	cod_server = "\ueb50"
	# CHAR : 
	cod_server_environment = "\ueba3"
	# CHAR : 
	cod_server_process = "\ueba2"
	# CHAR : 
	cod_settings = "\ueb52"
	# CHAR : 
	cod_settings_gear = "\ueb51"
	# CHAR : 
	cod_shield = "\ueb53"
	# CHAR : 
	cod_sign_in = "\uea6f"
	# CHAR : 
	cod_sign_out = "\uea6e"
	# CHAR : 
	cod_smiley = "\ueb54"
	# CHAR : 
	cod_snake = "\uec16"
	# CHAR : 
	cod_sort_precedence = "\ueb55"
	# CHAR : 
	cod_source_control = "\uea68"
	# CHAR : 
	cod_sparkle = "\uec10"
	# CHAR : 
	cod_split_horizontal = "\ueb56"
	# CHAR : 
	cod_split_vertical = "\ueb57"
	# CHAR : 
	cod_squirrel = "\ueb58"
	# CHAR : 
	cod_star_empty = "\uea6a"
	# CHAR : 
	cod_star_full = "\ueb59"
	# CHAR : 
	cod_star_half = "\ueb5a"
	# CHAR : 
	cod_stop_circle = "\ueba5"
	# CHAR : 
	cod_symbol_array = "\uea8a"
	# CHAR : 
	cod_symbol_boolean = "\uea8f"
	# CHAR : 
	cod_symbol_class = "\ueb5b"
	# CHAR : 
	cod_symbol_color = "\ueb5c"
	# CHAR : 
	cod_symbol_constant = "\ueb5d"
	# CHAR : 
	cod_symbol_enum = "\uea95"
	# CHAR : 
	cod_symbol_enum_member = "\ueb5e"
	# CHAR : 
	cod_symbol_event = "\uea86"
	# CHAR : 
	cod_symbol_field = "\ueb5f"
	# CHAR : 
	cod_symbol_file = "\ueb60"
	# CHAR : 
	cod_symbol_interface = "\ueb61"
	# CHAR : 
	cod_symbol_key = "\uea93"
	# CHAR : 
	cod_symbol_keyword = "\ueb62"
	# CHAR : 
	cod_symbol_method = "\uea8c"
	# CHAR : 
	cod_symbol_misc = "\ueb63"
	# CHAR : 
	cod_symbol_namespace = "\uea8b"
	# CHAR : 
	cod_symbol_numeric = "\uea90"
	# CHAR : 
	cod_symbol_operator = "\ueb64"
	# CHAR : 
	cod_symbol_parameter = "\uea92"
	# CHAR : 
	cod_symbol_property = "\ueb65"
	# CHAR : 
	cod_symbol_ruler = "\uea96"
	# CHAR : 
	cod_symbol_snippet = "\ueb66"
	# CHAR : 
	cod_symbol_string = "\ueb8d"
	# CHAR : 
	cod_symbol_structure = "\uea91"
	# CHAR : 
	cod_symbol_variable = "\uea88"
	# CHAR : 
	cod_sync = "\uea77"
	# CHAR : 
	cod_sync_ignored = "\ueb9f"
	# CHAR : 
	cod_table = "\uebb7"
	# CHAR : 
	cod_tag = "\uea66"
	# CHAR : 
	cod_target = "\uebf8"
	# CHAR : 
	cod_tasklist = "\ueb67"
	# CHAR : 
	cod_telescope = "\ueb68"
	# CHAR : 
	cod_terminal = "\uea85"
	# CHAR : 
	cod_terminal_bash = "\uebca"
	# CHAR : 
	cod_terminal_cmd = "\uebc4"
	# CHAR : 
	cod_terminal_debian = "\uebc5"
	# CHAR : 
	cod_terminal_linux = "\uebc6"
	# CHAR : 
	cod_terminal_powershell = "\uebc7"
	# CHAR : 
	cod_terminal_tmux = "\uebc8"
	# CHAR : 
	cod_terminal_ubuntu = "\uebc9"
	# CHAR : 
	cod_text_size = "\ueb69"
	# CHAR : 
	cod_three_bars = "\ueb6a"
	# CHAR : 
	cod_thumbsdown = "\ueb6b"
	# CHAR : 
	cod_thumbsdown_filled = "\uec13"
	# CHAR : 
	cod_thumbsup = "\ueb6c"
	# CHAR : 
	cod_thumbsup_filled = "\uec14"
	# CHAR : 
	cod_tools = "\ueb6d"
	# CHAR : 
	cod_trash = "\uea81"
	# CHAR : 
	cod_triangle_down = "\ueb6e"
	# CHAR : 
	cod_triangle_left = "\ueb6f"
	# CHAR : 
	cod_triangle_right = "\ueb70"
	# CHAR : 
	cod_triangle_up = "\ueb71"
	# CHAR : 
	cod_twitter = "\ueb72"
	# CHAR : 
	cod_type_hierarchy = "\uebb9"
	# CHAR : 
	cod_type_hierarchy_sub = "\uebba"
	# CHAR : 
	cod_type_hierarchy_super = "\uebbb"
	# CHAR : 
	cod_unfold = "\ueb73"
	# CHAR : 
	cod_ungroup_by_ref_type = "\ueb98"
	# CHAR : 
	cod_unlock = "\ueb74"
	# CHAR : 
	cod_unmute = "\ueb75"
	# CHAR : 
	cod_unverified = "\ueb76"
	# CHAR : 
	cod_variable_group = "\uebb8"
	# CHAR : 
	cod_verified = "\ueb77"
	# CHAR : 
	cod_verified_filled = "\uebe9"
	# CHAR : 
	cod_versions = "\ueb78"
	# CHAR : 
	cod_vm = "\uea7a"
	# CHAR : 
	cod_vm_active = "\ueb79"
	# CHAR : 
	cod_vm_connect = "\ueba9"
	# CHAR : 
	cod_vm_outline = "\ueb7a"
	# CHAR : 
	cod_vm_running = "\ueb7b"
	# CHAR : 
	cod_vr = "\uec18"
	# CHAR : 
	cod_wand = "\uebcf"
	# CHAR : 
	cod_warning = "\uea6c"
	# CHAR : 
	cod_watch = "\ueb7c"
	# CHAR : 
	cod_whitespace = "\ueb7d"
	# CHAR : 
	cod_whole_word = "\ueb7e"
	# CHAR : 
	cod_window = "\ueb7f"
	# CHAR : 
	cod_word_wrap = "\ueb80"
	# CHAR : 
	cod_workspace_trusted = "\uebc1"
	# CHAR : 
	cod_workspace_unknown = "\uebc3"
	# CHAR : 
	cod_workspace_untrusted = "\uebc2"
	# CHAR : 
	cod_zoom_in = "\ueb81"
	# CHAR : 
	cod_zoom_out = "\ueb82"