# This File GEN using nerdicons_gen.py

class Fae:

	# CHAR : 
	fae_apple_fruit = "\ue29e"
	# CHAR : 
	fae_atom = "\ue27f"
	# CHAR : 
	fae_bacteria = "\ue280"
	# CHAR : 
	fae_banana = "\ue281"
	# CHAR : 
	fae_bath = "\ue282"
	# CHAR : 
	fae_bed = "\ue283"
	# CHAR : 
	fae_benzene = "\ue284"
	# CHAR : 
	fae_bigger = "\ue285"
	# CHAR : 
	fae_biohazard = "\ue286"
	# CHAR : 
	fae_blogger_circle = "\ue287"
	# CHAR : 
	fae_blogger_square = "\ue288"
	# CHAR : 
	fae_bones = "\ue289"
	# CHAR : 
	fae_book_open = "\ue28a"
	# CHAR : 
	fae_book_open_o = "\ue28b"
	# CHAR : 
	fae_brain = "\ue28c"
	# CHAR : 
	fae_bread = "\ue28d"
	# CHAR : 
	fae_butterfly = "\ue28e"
	# CHAR : 
	fae_carot = "\ue28f"
	# CHAR : 
	fae_cc_by = "\ue290"
	# CHAR : 
	fae_cc_cc = "\ue291"
	# CHAR : 
	fae_cc_nc = "\ue292"
	# CHAR : 
	fae_cc_nc_eu = "\ue293"
	# CHAR : 
	fae_cc_nc_jp = "\ue294"
	# CHAR : 
	fae_cc_nd = "\ue295"
	# CHAR : 
	fae_cc_remix = "\ue296"
	# CHAR : 
	fae_cc_sa = "\ue297"
	# CHAR : 
	fae_cc_share = "\ue298"
	# CHAR : 
	fae_cc_zero = "\ue299"
	# CHAR : 
	fae_checklist_o = "\ue29a"
	# CHAR : 
	fae_cheese = "\ue264"
	# CHAR : 
	fae_cherry = "\ue29b"
	# CHAR : 
	fae_chess_bishop = "\ue29c"
	# CHAR : 
	fae_chess_horse = "\ue25f"
	# CHAR : 
	fae_chess_king = "\ue260"
	# CHAR : 
	fae_chess_pawn = "\ue261"
	# CHAR : 
	fae_chess_queen = "\ue262"
	# CHAR : 
	fae_chess_tower = "\ue263"
	# CHAR : 
	fae_chicken_thigh = "\ue29f"
	# CHAR : 
	fae_chilli = "\ue265"
	# CHAR : 
	fae_chip = "\ue266"
	# CHAR : 
	fae_cicling = "\ue267"
	# CHAR : 
	fae_cloud = "\ue268"
	# CHAR : 
	fae_cockroach = "\ue269"
	# CHAR : 
	fae_coffe_beans = "\ue26a"
	# CHAR : 
	fae_coins = "\ue26b"
	# CHAR : 
	fae_comb = "\ue26c"
	# CHAR : 
	fae_comet = "\ue26d"
	# CHAR : 
	fae_crown = "\ue26e"
	# CHAR : 
	fae_cup_coffe = "\ue26f"
	# CHAR : 
	fae_dice = "\ue270"
	# CHAR : 
	fae_disco = "\ue271"
	# CHAR : 
	fae_dna = "\ue272"
	# CHAR : 
	fae_donut = "\ue273"
	# CHAR : 
	fae_dress = "\ue274"
	# CHAR : 
	fae_drop = "\ue275"
	# CHAR : 
	fae_ello = "\ue276"
	# CHAR : 
	fae_envelope_open = "\ue277"
	# CHAR : 
	fae_envelope_open_o = "\ue278"
	# CHAR : 
	fae_equal = "\ue279"
	# CHAR : 
	fae_equal_bigger = "\ue27a"
	# CHAR : 
	fae_feedly = "\ue27b"
	# CHAR : 
	fae_file_export = "\ue27c"
	# CHAR : 
	fae_file_import = "\ue27d"
	# CHAR : 
	fae_fingerprint = "\ue23f"
	# CHAR : 
	fae_floppy = "\ue240"
	# CHAR : 
	fae_footprint = "\ue241"
	# CHAR : 
	fae_freecodecamp = "\ue242"
	# CHAR : 
	fae_galaxy = "\ue243"
	# CHAR : 
	fae_galery = "\ue244"
	# CHAR : 
	fae_gift_card = "\ue2a0"
	# CHAR : 
	fae_glass = "\ue245"
	# CHAR : 
	fae_google_drive = "\ue246"
	# CHAR : 
	fae_google_play = "\ue247"
	# CHAR : 
	fae_gps = "\ue248"
	# CHAR : 
	fae_grav = "\ue249"
	# CHAR : 
	fae_guitar = "\ue24a"
	# CHAR : 
	fae_gut = "\ue24b"
	# CHAR : 
	fae_halter = "\ue24c"
	# CHAR : 
	fae_hamburger = "\ue24d"
	# CHAR : 
	fae_hat = "\ue24e"
	# CHAR : 
	fae_hexagon = "\ue24f"
	# CHAR : 
	fae_high_heel = "\ue250"
	# CHAR : 
	fae_hotdog = "\ue251"
	# CHAR : 
	fae_ice_cream = "\ue252"
	# CHAR : 
	fae_id_card = "\ue253"
	# CHAR : 
	fae_imdb = "\ue254"
	# CHAR : 
	fae_infinity = "\ue255"
	# CHAR : 
	fae_injection = "\ue2a1"
	# CHAR : 
	fae_isle = "\ue2a2"
	# CHAR : 
	fae_java = "\ue256"
	# CHAR : 
	fae_layers = "\ue257"
	# CHAR : 
	fae_lips = "\ue258"
	# CHAR : 
	fae_lipstick = "\ue259"
	# CHAR : 
	fae_liver = "\ue25a"
	# CHAR : 
	fae_lollipop = "\ue2a3"
	# CHAR : 
	fae_loyalty_card = "\ue2a4"
	# CHAR : 
	fae_lung = "\ue25b"
	# CHAR : 
	fae_makeup_brushes = "\ue25c"
	# CHAR : 
	fae_maximize = "\ue25d"
	# CHAR : 
	fae_meat = "\ue2a5"
	# CHAR : 
	fae_medicine = "\ue221"
	# CHAR : 
	fae_microscope = "\ue222"
	# CHAR : 
	fae_milk_bottle = "\ue223"
	# CHAR : 
	fae_minimize = "\ue224"
	# CHAR : 
	fae_molecule = "\ue225"
	# CHAR : 
	fae_moon_cloud = "\ue226"
	# CHAR : 
	fae_mountains = "\ue2a6"
	# CHAR : 
	fae_mushroom = "\ue227"
	# CHAR : 
	fae_mustache = "\ue228"
	# CHAR : 
	fae_mysql = "\ue229"
	# CHAR : 
	fae_nintendo = "\ue22a"
	# CHAR : 
	fae_orange = "\ue2a7"
	# CHAR : 
	fae_palette_color = "\ue22b"
	# CHAR : 
	fae_peach = "\ue2a8"
	# CHAR : 
	fae_pear = "\ue2a9"
	# CHAR : 
	fae_pi = "\ue22c"
	# CHAR : 
	fae_pizza = "\ue22d"
	# CHAR : 
	fae_planet = "\ue22e"
	# CHAR : 
	fae_plant = "\ue22f"
	# CHAR : 
	fae_playstation = "\ue230"
	# CHAR : 
	fae_poison = "\ue231"
	# CHAR : 
	fae_popcorn = "\ue232"
	# CHAR : 
	fae_popsicle = "\ue233"
	# CHAR : 
	fae_pulse = "\ue234"
	# CHAR : 
	fae_python = "\ue235"
	# CHAR : 
	fae_quora_circle = "\ue236"
	# CHAR : 
	fae_quora_square = "\ue237"
	# CHAR : 
	fae_radioactive = "\ue238"
	# CHAR : 
	fae_raining = "\ue239"
	# CHAR : 
	fae_real_heart = "\ue23a"
	# CHAR : 
	fae_refrigerator = "\ue23b"
	# CHAR : 
	fae_restore = "\ue23c"
	# CHAR : 
	fae_ring = "\ue23d"
	# CHAR : 
	fae_ruby = "\ue23e"
	# CHAR : 
	fae_ruby_o = "\ue21e"
	# CHAR : 
	fae_ruler = "\ue21f"
	# CHAR : 
	fae_shirt = "\ue218"
	# CHAR : 
	fae_slash = "\ue216"
	# CHAR : 
	fae_smaller = "\ue200"
	# CHAR : 
	fae_snowing = "\ue201"
	# CHAR : 
	fae_soda = "\ue202"
	# CHAR : 
	fae_sofa = "\ue203"
	# CHAR : 
	fae_soup = "\ue204"
	# CHAR : 
	fae_spermatozoon = "\ue205"
	# CHAR : 
	fae_spin_double = "\ue206"
	# CHAR : 
	fae_stomach = "\ue207"
	# CHAR : 
	fae_storm = "\ue208"
	# CHAR : 
	fae_sun_cloud = "\ue21d"
	# CHAR : 
	fae_sushi = "\ue21a"
	# CHAR : 
	fae_tacos = "\ue219"
	# CHAR : 
	fae_telegram = "\ue217"
	# CHAR : 
	fae_telegram_circle = "\ue215"
	# CHAR : 
	fae_telescope = "\ue209"
	# CHAR : 
	fae_thermometer = "\ue20a"
	# CHAR : 
	fae_thermometer_high = "\ue20b"
	# CHAR : 
	fae_thermometer_low = "\ue20c"
	# CHAR : 
	fae_thin_close = "\ue20d"
	# CHAR : 
	fae_toilet = "\ue20e"
	# CHAR : 
	fae_tools = "\ue20f"
	# CHAR : 
	fae_tooth = "\ue210"
	# CHAR : 
	fae_tree = "\ue21c"
	# CHAR : 
	fae_triangle_ruler = "\ue21b"
	# CHAR : 
	fae_umbrella = "\ue220"
	# CHAR : 
	fae_uterus = "\ue211"
	# CHAR : 
	fae_virus = "\ue214"
	# CHAR : 
	fae_w3c = "\ue212"
	# CHAR : 
	fae_walking = "\ue213"
	# CHAR : 
	fae_wallet = "\ue25e"
	# CHAR : 
	fae_wind = "\ue27e"
	# CHAR : 
	fae_xbox = "\ue29d"