# This File GEN using nerdicons_gen.py

class Extra:

	# CHAR : 
	extra_progress_empty_left = "\uee00"
	# CHAR : 
	extra_progress_empty_mid = "\uee01"
	# CHAR : 
	extra_progress_empty_right = "\uee02"
	# CHAR : 
	extra_progress_full_left = "\uee03"
	# CHAR : 
	extra_progress_full_mid = "\uee04"
	# CHAR : 
	extra_progress_full_right = "\uee05"
	# CHAR : 
	extra_progress_spinner_1 = "\uee06"
	# CHAR : 
	extra_progress_spinner_2 = "\uee07"
	# CHAR : 
	extra_progress_spinner_3 = "\uee08"
	# CHAR : 
	extra_progress_spinner_4 = "\uee09"
	# CHAR : 
	extra_progress_spinner_5 = "\uee0a"
	# CHAR : 
	extra_progress_spinner_6 = "\uee0b"