# This File GEN using nerdicons_gen.py

class Iec:

	# CHAR : ⏻
	iec_power = "\u23fb"
	# CHAR : ⭘
	iec_power_off = "\u2b58"
	# CHAR : ⏽
	iec_power_on = "\u23fd"
	# CHAR : ⏾
	iec_sleep_mode = "\u23fe"
	# CHAR : ⏼
	iec_toggle_power = "\u23fc"