# This File GEN using nerdicons_gen.py

class Linux:

	# CHAR : 
	linux_almalinux = "\uf31d"
	# CHAR : 
	linux_alpine = "\uf300"
	# CHAR : 
	linux_aosc = "\uf301"
	# CHAR : 
	linux_apple = "\uf302"
	# CHAR : 
	linux_archcraft = "\uf345"
	# CHAR : 
	linux_archlabs = "\uf31e"
	# CHAR : 
	linux_archlinux = "\uf303"
	# CHAR : 
	linux_arcolinux = "\uf346"
	# CHAR : 
	linux_arduino = "\uf34b"
	# CHAR : 
	linux_artix = "\uf31f"
	# CHAR : 
	linux_awesome = "\uf354"
	# CHAR : 
	linux_biglinux = "\uf347"
	# CHAR : 
	linux_bspwm = "\uf355"
	# CHAR : 
	linux_budgie = "\uf320"
	# CHAR : 
	linux_centos = "\uf304"
	# CHAR : 
	linux_cinnamon = "\uf35f"
	# CHAR : 
	linux_codeberg = "\uf330"
	# CHAR : 
	linux_coreos = "\uf305"
	# CHAR : 
	linux_crystal = "\uf348"
	# CHAR : 
	linux_debian = "\uf306"
	# CHAR : 
	linux_deepin = "\uf321"
	# CHAR : 
	linux_devuan = "\uf307"
	# CHAR : 
	linux_docker = "\uf308"
	# CHAR : 
	linux_dwm = "\uf356"
	# CHAR : 
	linux_elementary = "\uf309"
	# CHAR : 
	linux_endeavour = "\uf322"
	# CHAR : 
	linux_enlightenment = "\uf357"
	# CHAR : 
	linux_fdroid = "\uf36a"
	# CHAR : 
	linux_fedora = "\uf30a"
	# CHAR : 
	linux_fedora_inverse = "\uf30b"
	# CHAR : 
	linux_ferris = "\uf323"
	# CHAR : 
	linux_flathub = "\uf324"
	# CHAR : 
	linux_fluxbox = "\uf358"
	# CHAR : 
	linux_forgejo = "\uf335"
	# CHAR : 
	linux_fosdem = "\uf36b"
	# CHAR : 
	linux_freebsd = "\uf30c"
	# CHAR : 
	linux_freecad = "\uf336"
	# CHAR : 
	linux_freedesktop = "\uf360"
	# CHAR : 
	linux_garuda = "\uf337"
	# CHAR : 
	linux_gentoo = "\uf30d"
	# CHAR : 
	linux_gimp = "\uf338"
	# CHAR : 
	linux_gitea = "\uf339"
	# CHAR : 
	linux_gnome = "\uf361"
	# CHAR : 
	linux_gnu_guix = "\uf325"
	# CHAR : 
	linux_gtk = "\uf362"
	# CHAR : 
	linux_hyperbola = "\uf33a"
	# CHAR : 
	linux_hyprland = "\uf359"
	# CHAR : 
	linux_i3 = "\uf35a"
	# CHAR : 
	linux_illumos = "\uf326"
	# CHAR : 
	linux_inkscape = "\uf33b"
	# CHAR : 
	linux_jwm = "\uf35b"
	# CHAR : 
	linux_kali_linux = "\uf327"
	# CHAR : 
	linux_kde = "\uf373"
	# CHAR : 
	linux_kde_neon = "\uf331"
	# CHAR : 
	linux_kde_plasma = "\uf332"
	# CHAR : 
	linux_kdenlive = "\uf33c"
	# CHAR : 
	linux_kicad = "\uf34c"
	# CHAR : 
	linux_krita = "\uf33d"
	# CHAR : 
	linux_kubuntu = "\uf333"
	# CHAR : 
	linux_kubuntu_inverse = "\uf334"
	# CHAR : 
	linux_leap = "\uf37e"
	# CHAR : 
	linux_libreoffice = "\uf376"
	# CHAR : 
	linux_libreofficebase = "\uf377"
	# CHAR : 
	linux_libreofficecalc = "\uf378"
	# CHAR : 
	linux_libreofficedraw = "\uf379"
	# CHAR : 
	linux_libreofficeimpress = "\uf37a"
	# CHAR : 
	linux_libreofficemath = "\uf37b"
	# CHAR : 
	linux_libreofficewriter = "\uf37c"
	# CHAR : 
	linux_linuxmint = "\uf30e"
	# CHAR : 
	linux_linuxmint_inverse = "\uf30f"
	# CHAR : 
	linux_locos = "\uf349"
	# CHAR : 
	linux_lxde = "\uf363"
	# CHAR : 
	linux_lxle = "\uf33e"
	# CHAR : 
	linux_lxqt = "\uf364"
	# CHAR : 
	linux_mageia = "\uf310"
	# CHAR : 
	linux_mandriva = "\uf311"
	# CHAR : 
	linux_manjaro = "\uf312"
	# CHAR : 
	linux_mate = "\uf365"
	# CHAR : 
	linux_mpv = "\uf36e"
	# CHAR : 
	linux_mxlinux = "\uf33f"
	# CHAR : 
	linux_neovim = "\uf36f"
	# CHAR : 
	linux_nixos = "\uf313"
	# CHAR : 
	linux_nobara = "\uf380"
	# CHAR : 
	linux_octoprint = "\uf34d"
	# CHAR : 
	linux_openbsd = "\uf328"
	# CHAR : 
	linux_openscad = "\uf34e"
	# CHAR : 
	linux_opensuse = "\uf314"
	# CHAR : 
	linux_osh = "\uf34f"
	# CHAR : 
	linux_oshwa = "\uf350"
	# CHAR : 
	linux_osi = "\uf36c"
	# CHAR : 
	linux_parabola = "\uf340"
	# CHAR : 
	linux_parrot = "\uf329"
	# CHAR : 
	linux_pop_os = "\uf32a"
	# CHAR : 
	linux_postmarketos = "\uf374"
	# CHAR : 
	linux_prusaslicer = "\uf351"
	# CHAR : 
	linux_puppy = "\uf341"
	# CHAR : 
	linux_qt = "\uf375"
	# CHAR : 
	linux_qtile = "\uf35c"
	# CHAR : 
	linux_qubesos = "\uf342"
	# CHAR : 
	linux_raspberry_pi = "\uf315"
	# CHAR : 
	linux_redhat = "\uf316"
	# CHAR : 
	linux_reprap = "\uf352"
	# CHAR : 
	linux_riscv = "\uf353"
	# CHAR : 
	linux_river = "\uf381"
	# CHAR : 
	linux_rocky_linux = "\uf32b"
	# CHAR : 
	linux_sabayon = "\uf317"
	# CHAR : 
	linux_slackware = "\uf318"
	# CHAR : 
	linux_slackware_inverse = "\uf319"
	# CHAR : 
	linux_snappy = "\uf32c"
	# CHAR : 
	linux_solus = "\uf32d"
	# CHAR : 
	linux_sway = "\uf35d"
	# CHAR : 
	linux_tails = "\uf343"
	# CHAR : 
	linux_thunderbird = "\uf370"
	# CHAR : 
	linux_tor = "\uf371"
	# CHAR : 
	linux_trisquel = "\uf344"
	# CHAR : 
	linux_tumbleweed = "\uf37d"
	# CHAR : 
	linux_tux = "\uf31a"
	# CHAR : 
	linux_typst = "\uf37f"
	# CHAR : 
	linux_ubuntu = "\uf31b"
	# CHAR : 
	linux_ubuntu_inverse = "\uf31c"
	# CHAR : 
	linux_vanilla = "\uf366"
	# CHAR : 
	linux_void = "\uf32e"
	# CHAR : 
	linux_vscodium = "\uf372"
	# CHAR : 
	linux_wayland = "\uf367"
	# CHAR : 
	linux_wikimedia = "\uf36d"
	# CHAR : 
	linux_xerolinux = "\uf34a"
	# CHAR : 
	linux_xfce = "\uf368"
	# CHAR : 
	linux_xmonad = "\uf35e"
	# CHAR : 
	linux_xorg = "\uf369"
	# CHAR : 
	linux_zorin = "\uf32f"