# This File GEN using nerdicons_gen.py

class Weather:

	# CHAR : 
	weather_alien = "\ue36e"
	# CHAR : 
	weather_aliens = "\ue345"
	# CHAR : 
	weather_barometer = "\ue372"
	# CHAR : 
	weather_celsius = "\ue339"
	# CHAR : 
	weather_cloud = "\ue33d"
	# CHAR : 
	weather_cloud_down = "\ue33a"
	# CHAR : 
	weather_cloud_refresh = "\ue33b"
	# CHAR : 
	weather_cloud_up = "\ue33c"
	# CHAR : 
	weather_cloudy = "\ue312"
	# CHAR : 
	weather_cloudy_gusts = "\ue310"
	# CHAR : 
	weather_cloudy_windy = "\ue311"
	# CHAR : 
	weather_day_cloudy = "\ue302"
	# CHAR : 
	weather_day_cloudy_gusts = "\ue300"
	# CHAR : 
	weather_day_cloudy_high = "\ue376"
	# CHAR : 
	weather_day_cloudy_windy = "\ue301"
	# CHAR : 
	weather_day_fog = "\ue303"
	# CHAR : 
	weather_day_hail = "\ue304"
	# CHAR : 
	weather_day_haze = "\ue3ae"
	# CHAR : 
	weather_day_light_wind = "\ue3bc"
	# CHAR : 
	weather_day_lightning = "\ue305"
	# CHAR : 
	weather_day_rain = "\ue308"
	# CHAR : 
	weather_day_rain_mix = "\ue306"
	# CHAR : 
	weather_day_rain_wind = "\ue307"
	# CHAR : 
	weather_day_showers = "\ue309"
	# CHAR : 
	weather_day_sleet = "\ue3aa"
	# CHAR : 
	weather_day_sleet_storm = "\ue362"
	# CHAR : 
	weather_day_snow = "\ue30a"
	# CHAR : 
	weather_day_snow_thunderstorm = "\ue365"
	# CHAR : 
	weather_day_snow_wind = "\ue35f"
	# CHAR : 
	weather_day_sprinkle = "\ue30b"
	# CHAR : 
	weather_day_storm_showers = "\ue30e"
	# CHAR : 
	weather_day_sunny = "\ue30d"
	# CHAR : 
	weather_day_sunny_overcast = "\ue30c"
	# CHAR : 
	weather_day_thunderstorm = "\ue30f"
	# CHAR : 
	weather_day_windy = "\ue37d"
	# CHAR : 
	weather_degrees = "\ue33e"
	# CHAR : 
	weather_direction_down = "\ue340"
	# CHAR : 
	weather_direction_down_left = "\ue33f"
	# CHAR : 
	weather_direction_down_right = "\ue380"
	# CHAR : 
	weather_direction_left = "\ue344"
	# CHAR : 
	weather_direction_right = "\ue349"
	# CHAR : 
	weather_direction_up = "\ue353"
	# CHAR : 
	weather_direction_up_left = "\ue37f"
	# CHAR : 
	weather_direction_up_right = "\ue352"
	# CHAR : 
	weather_dust = "\ue35d"
	# CHAR : 
	weather_earthquake = "\ue3be"
	# CHAR : 
	weather_fahrenheit = "\ue341"
	# CHAR : 
	weather_fire = "\ue3bf"
	# CHAR : 
	weather_flood = "\ue375"
	# CHAR : 
	weather_fog = "\ue313"
	# CHAR : 
	weather_gale_warning = "\ue3c5"
	# CHAR : 
	weather_hail = "\ue314"
	# CHAR : 
	weather_horizon = "\ue343"
	# CHAR : 
	weather_horizon_alt = "\ue342"
	# CHAR : 
	weather_hot = "\ue36b"
	# CHAR : 
	weather_humidity = "\ue373"
	# CHAR : 
	weather_hurricane = "\ue36c"
	# CHAR : 
	weather_hurricane_warning = "\ue3c7"
	# CHAR : 
	weather_lightning = "\ue315"
	# CHAR : 
	weather_lunar_eclipse = "\ue369"
	# CHAR : 
	weather_meteor = "\ue36a"
	# CHAR : 
	weather_moon_alt_first_quarter = "\ue3ce"
	# CHAR : 
	weather_moon_alt_full = "\ue3d5"
	# CHAR : 
	weather_moon_alt_new = "\ue3e3"
	# CHAR : 
	weather_moon_alt_third_quarter = "\ue3dc"
	# CHAR : 
	weather_moon_alt_waning_crescent_1 = "\ue3dd"
	# CHAR : 
	weather_moon_alt_waning_crescent_2 = "\ue3de"
	# CHAR : 
	weather_moon_alt_waning_crescent_3 = "\ue3df"
	# CHAR : 
	weather_moon_alt_waning_crescent_4 = "\ue3e0"
	# CHAR : 
	weather_moon_alt_waning_crescent_5 = "\ue3e1"
	# CHAR : 
	weather_moon_alt_waning_crescent_6 = "\ue3e2"
	# CHAR : 
	weather_moon_alt_waning_gibbous_1 = "\ue3d6"
	# CHAR : 
	weather_moon_alt_waning_gibbous_2 = "\ue3d7"
	# CHAR : 
	weather_moon_alt_waning_gibbous_3 = "\ue3d8"
	# CHAR : 
	weather_moon_alt_waning_gibbous_4 = "\ue3d9"
	# CHAR : 
	weather_moon_alt_waning_gibbous_5 = "\ue3da"
	# CHAR : 
	weather_moon_alt_waning_gibbous_6 = "\ue3db"
	# CHAR : 
	weather_moon_alt_waxing_crescent_1 = "\ue3c8"
	# CHAR : 
	weather_moon_alt_waxing_crescent_2 = "\ue3c9"
	# CHAR : 
	weather_moon_alt_waxing_crescent_3 = "\ue3ca"
	# CHAR : 
	weather_moon_alt_waxing_crescent_4 = "\ue3cb"
	# CHAR : 
	weather_moon_alt_waxing_crescent_5 = "\ue3cc"
	# CHAR : 
	weather_moon_alt_waxing_crescent_6 = "\ue3cd"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_1 = "\ue3cf"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_2 = "\ue3d0"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_3 = "\ue3d1"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_4 = "\ue3d2"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_5 = "\ue3d3"
	# CHAR : 
	weather_moon_alt_waxing_gibbous_6 = "\ue3d4"
	# CHAR : 
	weather_moon_first_quarter = "\ue394"
	# CHAR : 
	weather_moon_full = "\ue39b"
	# CHAR : 
	weather_moon_new = "\ue38d"
	# CHAR : 
	weather_moon_third_quarter = "\ue3a2"
	# CHAR : 
	weather_moon_waning_crescent_1 = "\ue3a3"
	# CHAR : 
	weather_moon_waning_crescent_2 = "\ue3a4"
	# CHAR : 
	weather_moon_waning_crescent_3 = "\ue3a5"
	# CHAR : 
	weather_moon_waning_crescent_4 = "\ue3a6"
	# CHAR : 
	weather_moon_waning_crescent_5 = "\ue3a7"
	# CHAR : 
	weather_moon_waning_crescent_6 = "\ue3a8"
	# CHAR : 
	weather_moon_waning_gibbous_1 = "\ue39c"
	# CHAR : 
	weather_moon_waning_gibbous_2 = "\ue39d"
	# CHAR : 
	weather_moon_waning_gibbous_3 = "\ue39e"
	# CHAR : 
	weather_moon_waning_gibbous_4 = "\ue39f"
	# CHAR : 
	weather_moon_waning_gibbous_5 = "\ue3a0"
	# CHAR : 
	weather_moon_waning_gibbous_6 = "\ue3a1"
	# CHAR : 
	weather_moon_waxing_crescent_1 = "\ue38e"
	# CHAR : 
	weather_moon_waxing_crescent_2 = "\ue38f"
	# CHAR : 
	weather_moon_waxing_crescent_3 = "\ue390"
	# CHAR : 
	weather_moon_waxing_crescent_4 = "\ue391"
	# CHAR : 
	weather_moon_waxing_crescent_5 = "\ue392"
	# CHAR : 
	weather_moon_waxing_crescent_6 = "\ue393"
	# CHAR : 
	weather_moon_waxing_gibbous_1 = "\ue395"
	# CHAR : 
	weather_moon_waxing_gibbous_2 = "\ue396"
	# CHAR : 
	weather_moon_waxing_gibbous_3 = "\ue397"
	# CHAR : 
	weather_moon_waxing_gibbous_4 = "\ue398"
	# CHAR : 
	weather_moon_waxing_gibbous_5 = "\ue399"
	# CHAR : 
	weather_moon_waxing_gibbous_6 = "\ue39a"
	# CHAR : 
	weather_moonrise = "\ue3c1"
	# CHAR : 
	weather_moonset = "\ue3c2"
	# CHAR : 
	weather_na = "\ue374"
	# CHAR : 
	weather_night_alt_cloudy = "\ue37e"
	# CHAR : 
	weather_night_alt_cloudy_gusts = "\ue31f"
	# CHAR : 
	weather_night_alt_cloudy_high = "\ue377"
	# CHAR : 
	weather_night_alt_cloudy_windy = "\ue320"
	# CHAR : 
	weather_night_alt_hail = "\ue321"
	# CHAR : 
	weather_night_alt_lightning = "\ue322"
	# CHAR : 
	weather_night_alt_partly_cloudy = "\ue379"
	# CHAR : 
	weather_night_alt_rain = "\ue325"
	# CHAR : 
	weather_night_alt_rain_mix = "\ue323"
	# CHAR : 
	weather_night_alt_rain_wind = "\ue324"
	# CHAR : 
	weather_night_alt_showers = "\ue326"
	# CHAR : 
	weather_night_alt_sleet = "\ue3ac"
	# CHAR : 
	weather_night_alt_sleet_storm = "\ue364"
	# CHAR : 
	weather_night_alt_snow = "\ue327"
	# CHAR : 
	weather_night_alt_snow_thunderstorm = "\ue367"
	# CHAR : 
	weather_night_alt_snow_wind = "\ue361"
	# CHAR : 
	weather_night_alt_sprinkle = "\ue328"
	# CHAR : 
	weather_night_alt_storm_showers = "\ue329"
	# CHAR : 
	weather_night_alt_thunderstorm = "\ue32a"
	# CHAR : 
	weather_night_clear = "\ue32b"
	# CHAR : 
	weather_night_cloudy = "\ue32e"
	# CHAR : 
	weather_night_cloudy_gusts = "\ue32c"
	# CHAR : 
	weather_night_cloudy_high = "\ue378"
	# CHAR : 
	weather_night_cloudy_windy = "\ue32d"
	# CHAR : 
	weather_night_fog = "\ue346"
	# CHAR : 
	weather_night_hail = "\ue32f"
	# CHAR : 
	weather_night_lightning = "\ue330"
	# CHAR : 
	weather_night_partly_cloudy = "\ue37b"
	# CHAR : 
	weather_night_rain = "\ue333"
	# CHAR : 
	weather_night_rain_mix = "\ue331"
	# CHAR : 
	weather_night_rain_wind = "\ue332"
	# CHAR : 
	weather_night_showers = "\ue334"
	# CHAR : 
	weather_night_sleet = "\ue3ab"
	# CHAR : 
	weather_night_sleet_storm = "\ue363"
	# CHAR : 
	weather_night_snow = "\ue335"
	# CHAR : 
	weather_night_snow_thunderstorm = "\ue366"
	# CHAR : 
	weather_night_snow_wind = "\ue360"
	# CHAR : 
	weather_night_sprinkle = "\ue336"
	# CHAR : 
	weather_night_storm_showers = "\ue337"
	# CHAR : 
	weather_night_thunderstorm = "\ue338"
	# CHAR : 
	weather_rain = "\ue318"
	# CHAR : 
	weather_rain_mix = "\ue316"
	# CHAR : 
	weather_rain_wind = "\ue317"
	# CHAR : 
	weather_raindrop = "\ue371"
	# CHAR : 
	weather_raindrops = "\ue34a"
	# CHAR : 
	weather_refresh = "\ue348"
	# CHAR : 
	weather_refresh_alt = "\ue347"
	# CHAR : 
	weather_sandstorm = "\ue37a"
	# CHAR : 
	weather_showers = "\ue319"
	# CHAR : 
	weather_sleet = "\ue3ad"
	# CHAR : 
	weather_small_craft_advisory = "\ue3c4"
	# CHAR : 
	weather_smog = "\ue36d"
	# CHAR : 
	weather_smoke = "\ue35c"
	# CHAR : 
	weather_snow = "\ue31a"
	# CHAR : 
	weather_snow_wind = "\ue35e"
	# CHAR : 
	weather_snowflake_cold = "\ue36f"
	# CHAR : 
	weather_solar_eclipse = "\ue368"
	# CHAR : 
	weather_sprinkle = "\ue31b"
	# CHAR : 
	weather_stars = "\ue370"
	# CHAR : 
	weather_storm_showers = "\ue31c"
	# CHAR : 
	weather_storm_warning = "\ue3c6"
	# CHAR : 
	weather_strong_wind = "\ue34b"
	# CHAR : 
	weather_sunrise = "\ue34c"
	# CHAR : 
	weather_sunset = "\ue34d"
	# CHAR : 
	weather_thermometer = "\ue350"
	# CHAR : 
	weather_thermometer_exterior = "\ue34e"
	# CHAR : 
	weather_thermometer_internal = "\ue34f"
	# CHAR : 
	weather_thunderstorm = "\ue31d"
	# CHAR : 
	weather_time_1 = "\ue382"
	# CHAR : 
	weather_time_10 = "\ue38b"
	# CHAR : 
	weather_time_11 = "\ue38c"
	# CHAR : 
	weather_time_12 = "\ue381"
	# CHAR : 
	weather_time_2 = "\ue383"
	# CHAR : 
	weather_time_3 = "\ue384"
	# CHAR : 
	weather_time_4 = "\ue385"
	# CHAR : 
	weather_time_5 = "\ue386"
	# CHAR : 
	weather_time_6 = "\ue387"
	# CHAR : 
	weather_time_7 = "\ue388"
	# CHAR : 
	weather_time_8 = "\ue389"
	# CHAR : 
	weather_time_9 = "\ue38a"
	# CHAR : 
	weather_tornado = "\ue351"
	# CHAR : 
	weather_train = "\ue3c3"
	# CHAR : 
	weather_tsunami = "\ue3bd"
	# CHAR : 
	weather_umbrella = "\ue37c"
	# CHAR : 
	weather_volcano = "\ue3c0"
	# CHAR : 
	weather_wind_beaufort_0 = "\ue3af"
	# CHAR : 
	weather_wind_beaufort_1 = "\ue3b0"
	# CHAR : 
	weather_wind_beaufort_10 = "\ue3b9"
	# CHAR : 
	weather_wind_beaufort_11 = "\ue3ba"
	# CHAR : 
	weather_wind_beaufort_12 = "\ue3bb"
	# CHAR : 
	weather_wind_beaufort_2 = "\ue3b1"
	# CHAR : 
	weather_wind_beaufort_3 = "\ue3b2"
	# CHAR : 
	weather_wind_beaufort_4 = "\ue3b3"
	# CHAR : 
	weather_wind_beaufort_5 = "\ue3b4"
	# CHAR : 
	weather_wind_beaufort_6 = "\ue3b5"
	# CHAR : 
	weather_wind_beaufort_7 = "\ue3b6"
	# CHAR : 
	weather_wind_beaufort_8 = "\ue3b7"
	# CHAR : 
	weather_wind_beaufort_9 = "\ue3b8"
	# CHAR : 
	weather_wind_direction = "\ue3a9"
	# CHAR : 
	weather_wind_east = "\ue35b"
	# CHAR : 
	weather_wind_north = "\ue35a"
	# CHAR : 
	weather_wind_north_east = "\ue359"
	# CHAR : 
	weather_wind_north_west = "\ue358"
	# CHAR : 
	weather_wind_south = "\ue357"
	# CHAR : 
	weather_wind_south_east = "\ue356"
	# CHAR : 
	weather_wind_south_west = "\ue355"
	# CHAR : 
	weather_wind_west = "\ue354"
	# CHAR : 
	weather_windy = "\ue31e"