# This File GEN using nerdicons_gen.py

class Seti:

	# CHAR : 
	seti_apple = "\ue635"
	# CHAR : 
	seti_argdown = "\ue636"
	# CHAR : 
	seti_asm = "\ue637"
	# CHAR : 
	seti_audio = "\ue638"
	# CHAR : 
	seti_babel = "\ue639"
	# CHAR : 
	seti_bazel = "\ue63a"
	# CHAR : 
	seti_bicep = "\ue63b"
	# CHAR : 
	seti_bower = "\ue61a"
	# CHAR : 
	seti_bsl = "\ue63c"
	# CHAR : 
	seti_c = "\ue649"
	# CHAR : 
	seti_c_sharp = "\ue648"
	# CHAR : 
	seti_cake = "\ue63e"
	# CHAR : 
	seti_cake_php = "\ue63d"
	# CHAR : 
	seti_checkbox = "\ue63f"
	# CHAR : 
	seti_checkbox_unchecked = "\ue640"
	# CHAR : 
	seti_cjsx = "\ue61b"
	# CHAR : 
	seti_clock = "\ue641"
	# CHAR : 
	seti_clojure = "\ue642"
	# CHAR : 
	seti_code_climate = "\ue643"
	# CHAR : 
	seti_code_search = "\ue644"
	# CHAR : 
	seti_coffee = "\ue61b"
	# CHAR : 
	seti_coldfusion = "\ue645"
	# CHAR : 
	seti_config = "\ue615"
	# CHAR : 
	seti_cpp = "\ue646"
	# CHAR : 
	seti_crystal = "\ue62f"
	# CHAR : 
	seti_crystal_embedded = "\ue647"
	# CHAR : 
	seti_css = "\ue614"
	# CHAR : 
	seti_csv = "\ue64a"
	# CHAR : 
	seti_cu = "\ue64b"
	# CHAR : 
	seti_d = "\ue651"
	# CHAR : 
	seti_dart = "\ue64c"
	# CHAR : 
	seti_db = "\ue64d"
	# CHAR : 
	seti_default = "\ue64e"
	# CHAR : 
	seti_deprecation_cop = "\ue64f"
	# CHAR : 
	seti_docker = "\ue650"
	# CHAR : 
	seti_editorconfig = "\ue652"
	# CHAR : 
	seti_ejs = "\ue618"
	# CHAR : 
	seti_elixir = "\ue62d"
	# CHAR : 
	seti_elixir_script = "\ue653"
	# CHAR : 
	seti_elm = "\ue62c"
	# CHAR : 
	seti_error = "\ue654"
	# CHAR : 
	seti_eslint = "\ue655"
	# CHAR : 
	seti_ethereum = "\ue656"
	# CHAR : 
	seti_f_sharp = "\ue65a"
	# CHAR : 
	seti_favicon = "\ue623"
	# CHAR : 
	seti_firebase = "\ue657"
	# CHAR : 
	seti_firefox = "\ue658"
	# CHAR : 
	seti_folder = "\ue613"
	# CHAR : 
	seti_font = "\ue659"
	# CHAR : 
	seti_git = "\ue65d"
	# CHAR : 
	seti_git_folder = "\ue65d"
	# CHAR : 
	seti_git_ignore = "\ue65d"
	# CHAR : 
	seti_github = "\ue65b"
	# CHAR : 
	seti_gitlab = "\ue65c"
	# CHAR : 
	seti_go = "\ue627"
	# CHAR : 
	seti_go2 = "\ue65e"
	# CHAR : 
	seti_godot = "\ue65f"
	# CHAR : 
	seti_gradle = "\ue660"
	# CHAR : 
	seti_grails = "\ue661"
	# CHAR : 
	seti_graphql = "\ue662"
	# CHAR : 
	seti_grunt = "\ue611"
	# CHAR : 
	seti_gulp = "\ue610"
	# CHAR : 
	seti_hacklang = "\ue663"
	# CHAR : 
	seti_haml = "\ue664"
	# CHAR : 
	seti_happenings = "\ue665"
	# CHAR : 
	seti_haskell = "\ue61f"
	# CHAR : 
	seti_haxe = "\ue666"
	# CHAR : 
	seti_heroku = "\ue607"
	# CHAR : 
	seti_hex = "\ue667"
	# CHAR : 
	seti_home = "\ue617"
	# CHAR : 
	seti_html = "\ue60e"
	# CHAR : 
	seti_ignored = "\ue668"
	# CHAR : 
	seti_illustrator = "\ue669"
	# CHAR : 
	seti_image = "\ue60d"
	# CHAR : 
	seti_info = "\ue66a"
	# CHAR : 
	seti_ionic = "\ue66b"
	# CHAR : 
	seti_jade = "\ue66c"
	# CHAR : 
	seti_java = "\ue66d"
	# CHAR : 
	seti_javascript = "\ue60c"
	# CHAR : 
	seti_jenkins = "\ue66e"
	# CHAR : 
	seti_jinja = "\ue66f"
	# CHAR : 
	seti_json = "\ue60b"
	# CHAR : 
	seti_julia = "\ue624"
	# CHAR : 
	seti_karma = "\ue622"
	# CHAR : 
	seti_kotlin = "\ue634"
	# CHAR : 
	seti_less = "\ue60b"
	# CHAR : 
	seti_license = "\ue60a"
	# CHAR : 
	seti_liquid = "\ue670"
	# CHAR : 
	seti_livescript = "\ue671"
	# CHAR : 
	seti_lock = "\ue672"
	# CHAR : 
	seti_lua = "\ue620"
	# CHAR : 
	seti_makefile = "\ue673"
	# CHAR : 
	seti_markdown = "\ue609"
	# CHAR : 
	seti_maven = "\ue674"
	# CHAR : 
	seti_mdo = "\ue675"
	# CHAR : 
	seti_mustache = "\ue60f"
	# CHAR : 
	seti_new_file = "\ue676"
	# CHAR : 
	seti_nim = "\ue677"
	# CHAR : 
	seti_notebook = "\ue678"
	# CHAR : 
	seti_npm = "\ue616"
	# CHAR : 
	seti_npm_ignored = "\ue616"
	# CHAR : 
	seti_nunjucks = "\ue679"
	# CHAR : 
	seti_ocaml = "\ue67a"
	# CHAR : 
	seti_odata = "\ue67b"
	# CHAR : 
	seti_pddl = "\ue67c"
	# CHAR : 
	seti_pdf = "\ue67d"
	# CHAR : 
	seti_perl = "\ue67e"
	# CHAR : 
	seti_photoshop = "\ue67f"
	# CHAR : 
	seti_php = "\ue608"
	# CHAR : 
	seti_pipeline = "\ue680"
	# CHAR : 
	seti_plan = "\ue681"
	# CHAR : 
	seti_platformio = "\ue682"
	# CHAR : 
	seti_play_arrow = "\ue602"
	# CHAR : 
	seti_powershell = "\ue683"
	# CHAR : 
	seti_prisma = "\ue684"
	# CHAR : 
	seti_project = "\ue601"
	# CHAR : 
	seti_prolog = "\ue685"
	# CHAR : 
	seti_pug = "\ue686"
	# CHAR : 
	seti_puppet = "\ue631"
	# CHAR : 
	seti_purescript = "\ue630"
	# CHAR : 
	seti_python = "\ue606"
	# CHAR : 
	seti_r = "\ue68a"
	# CHAR : 
	seti_rails = "\ue604"
	# CHAR : 
	seti_react = "\ue625"
	# CHAR : 
	seti_reasonml = "\ue687"
	# CHAR : 
	seti_rescript = "\ue688"
	# CHAR : 
	seti_rollup = "\ue689"
	# CHAR : 
	seti_ruby = "\ue605"
	# CHAR : 
	seti_rust = "\ue68b"
	# CHAR : 
	seti_salesforce = "\ue68c"
	# CHAR : 
	seti_sass = "\ue603"
	# CHAR : 
	seti_sbt = "\ue68d"
	# CHAR : 
	seti_scala = "\ue68e"
	# CHAR : 
	seti_search = "\ue68f"
	# CHAR : 
	seti_settings = "\ue690"
	# CHAR : 
	seti_shell = "\ue691"
	# CHAR : 
	seti_slim = "\ue692"
	# CHAR : 
	seti_smarty = "\ue693"
	# CHAR : 
	seti_spring = "\ue694"
	# CHAR : 
	seti_stylelint = "\ue695"
	# CHAR : 
	seti_stylus = "\ue600"
	# CHAR : 
	seti_sublime = "\ue696"
	# CHAR : 
	seti_svelte = "\ue697"
	# CHAR : 
	seti_svg = "\ue698"
	# CHAR : 
	seti_swift = "\ue699"
	# CHAR : 
	seti_terraform = "\ue69a"
	# CHAR : 
	seti_tex = "\ue69b"
	# CHAR : 
	seti_text = "\ue64e"
	# CHAR : 
	seti_time_cop = "\ue641"
	# CHAR : 
	seti_todo = "\ue69c"
	# CHAR : 
	seti_tsconfig = "\ue69d"
	# CHAR : 
	seti_twig = "\ue61c"
	# CHAR : 
	seti_typescript = "\ue628"
	# CHAR : 
	seti_vala = "\ue69e"
	# CHAR : 
	seti_video = "\ue69f"
	# CHAR : 
	seti_vue = "\ue6a0"
	# CHAR : 
	seti_wasm = "\ue6a1"
	# CHAR : 
	seti_wat = "\ue6a2"
	# CHAR : 
	seti_webpack = "\ue6a3"
	# CHAR : 
	seti_wgt = "\ue6a4"
	# CHAR : 
	seti_word = "\ue6a5"
	# CHAR : 
	seti_xls = "\ue6a6"
	# CHAR : 
	seti_xml = "\ue619"
	# CHAR : 
	seti_yarn = "\ue6a7"
	# CHAR : 
	seti_yml = "\ue6a8"
	# CHAR : 
	seti_zig = "\ue6a9"
	# CHAR : 
	seti_zip = "\ue6aa"