# This File GEN using nerdicons_gen.py

class Ple:

	# CHAR : 
	ple_backslash_separator = "\ue0b9"
	# CHAR : 
	ple_backslash_separator_redundant = "\ue0bf"
	# CHAR : 
	ple_column_number = "\ue0a3"
	# CHAR : 
	ple_current_column = "\ue0a3"
	# CHAR : 
	ple_flame_thick = "\ue0c0"
	# CHAR : 
	ple_flame_thick_mirrored = "\ue0c2"
	# CHAR : 
	ple_flame_thin = "\ue0c1"
	# CHAR : 
	ple_flame_thin_mirrored = "\ue0c3"
	# CHAR : 
	ple_forwardslash_separator = "\ue0bb"
	# CHAR : 
	ple_forwardslash_separator_redundant = "\ue0bd"
	# CHAR : 
	ple_honeycomb = "\ue0cc"
	# CHAR : 
	ple_honeycomb_outline = "\ue0cd"
	# CHAR : 
	ple_ice_waveform = "\ue0c8"
	# CHAR : 
	ple_ice_waveform_mirrored = "\ue0ca"
	# CHAR : 
	ple_left_half_circle_thick = "\ue0b6"
	# CHAR : 
	ple_left_half_circle_thin = "\ue0b7"
	# CHAR : 
	ple_left_hard_divider_inverse = "\ue0d7"
	# CHAR : 
	ple_lego_block_facing = "\ue0d0"
	# CHAR : 
	ple_lego_block_sideways = "\ue0d1"
	# CHAR : 
	ple_lego_separator = "\ue0ce"
	# CHAR : 
	ple_lego_separator_thin = "\ue0cf"
	# CHAR : 
	ple_lower_left_triangle = "\ue0b8"
	# CHAR : 
	ple_lower_right_triangle = "\ue0ba"
	# CHAR : 
	ple_pixelated_squares_big = "\ue0c6"
	# CHAR : 
	ple_pixelated_squares_big_mirrored = "\ue0c7"
	# CHAR : 
	ple_pixelated_squares_small = "\ue0c4"
	# CHAR : 
	ple_pixelated_squares_small_mirrored = "\ue0c5"
	# CHAR : 
	ple_right_half_circle_thick = "\ue0b4"
	# CHAR : 
	ple_right_half_circle_thin = "\ue0b5"
	# CHAR : 
	ple_right_hard_divider_inverse = "\ue0d6"
	# CHAR : 
	ple_trapezoid_top_bottom = "\ue0d2"
	# CHAR : 
	ple_trapezoid_top_bottom_mirrored = "\ue0d4"
	# CHAR : 
	ple_upper_left_triangle = "\ue0bc"
	# CHAR : 
	ple_upper_right_triangle = "\ue0be"