# This File GEN using nerdicons_gen.py

class Pl:

	# CHAR : 
	pl_branch = "\ue0a0"
	# CHAR : 
	pl_current_line = "\ue0a1"
	# CHAR : 
	pl_hostname = "\ue0a2"
	# CHAR : 
	pl_left_hard_divider = "\ue0b0"
	# CHAR : 
	pl_left_soft_divider = "\ue0b1"
	# CHAR : 
	pl_line_number = "\ue0a1"
	# CHAR : 
	pl_readonly = "\ue0a2"
	# CHAR : 
	pl_right_hard_divider = "\ue0b2"
	# CHAR : 
	pl_right_soft_divider = "\ue0b3"