# This File GEN using nerdicons_gen.py

class Pom:

	# CHAR : 
	pom_away = "\ue007"
	# CHAR : 
	pom_clean_code = "\ue000"
	# CHAR : 
	pom_external_interruption = "\ue00a"
	# CHAR : 
	pom_internal_interruption = "\ue009"
	# CHAR : 
	pom_long_pause = "\ue006"
	# CHAR : 
	pom_pair_programming = "\ue008"
	# CHAR : 
	pom_pomodoro_done = "\ue001"
	# CHAR : 
	pom_pomodoro_estimated = "\ue002"
	# CHAR : 
	pom_pomodoro_squashed = "\ue004"
	# CHAR : 
	pom_pomodoro_ticking = "\ue003"
	# CHAR : 
	pom_short_pause = "\ue005"