# This File GEN using nerdicons_gen.py

class Oct:

	# CHAR : 
	oct_accessibility = "\uf406"
	# CHAR : 
	oct_accessibility_inset = "\uf40b"
	# CHAR : 
	oct_alert = "\uf421"
	# CHAR : 
	oct_alert_fill = "\uf40c"
	# CHAR : 
	oct_apps = "\uf40e"
	# CHAR : 
	oct_archive = "\uf411"
	# CHAR : 
	oct_arrow_both = "\uf416"
	# CHAR : 
	oct_arrow_down = "\uf433"
	# CHAR : 
	oct_arrow_down_left = "\uf424"
	# CHAR : 
	oct_arrow_down_right = "\uf43e"
	# CHAR : 
	oct_arrow_left = "\uf434"
	# CHAR : 
	oct_arrow_right = "\uf432"
	# CHAR : 
	oct_arrow_switch = "\uf443"
	# CHAR : 
	oct_arrow_up = "\uf431"
	# CHAR : 
	oct_arrow_up_left = "\uf45c"
	# CHAR : 
	oct_arrow_up_right = "\uf46c"
	# CHAR : 
	oct_beaker = "\uf499"
	# CHAR : 
	oct_bell = "\uf49a"
	# CHAR : 
	oct_bell_fill = "\uf476"
	# CHAR : 
	oct_bell_slash = "\uf478"
	# CHAR : 
	oct_blocked = "\uf479"
	# CHAR : 
	oct_bold = "\uf49d"
	# CHAR : 
	oct_book = "\uf405"
	# CHAR : 
	oct_bookmark = "\uf461"
	# CHAR : 
	oct_bookmark_fill = "\uf47a"
	# CHAR : 
	oct_bookmark_slash = "\uf533"
	# CHAR : 
	oct_bookmark_slash_fill = "\uf493"
	# CHAR : 
	oct_briefcase = "\uf491"
	# CHAR : 
	oct_broadcast = "\uf43c"
	# CHAR : 
	oct_browser = "\uf488"
	# CHAR : 
	oct_bug = "\uf46f"
	# CHAR : 
	oct_cache = "\uf49b"
	# CHAR : 
	oct_calendar = "\uf455"
	# CHAR : 
	oct_check = "\uf42e"
	# CHAR : 
	oct_check_circle = "\uf49e"
	# CHAR : 
	oct_check_circle_fill = "\uf4a4"
	# CHAR : 
	oct_checkbox = "\uf4a7"
	# CHAR : 
	oct_checklist = "\uf45e"
	# CHAR : 
	oct_chevron_down = "\uf47c"
	# CHAR : 
	oct_chevron_left = "\uf47d"
	# CHAR : 
	oct_chevron_right = "\uf460"
	# CHAR : 
	oct_chevron_up = "\uf47b"
	# CHAR : 
	oct_circle = "\uf4aa"
	# CHAR : 
	oct_circle_slash = "\uf468"
	# CHAR : 
	oct_clock = "\uf43a"
	# CHAR : 
	oct_clock_fill = "\uf4ab"
	# CHAR : 
	oct_cloud = "\uf4ac"
	# CHAR : 
	oct_cloud_offline = "\uf4ad"
	# CHAR : 
	oct_code = "\uf44f"
	# CHAR : 
	oct_code_of_conduct = "\uf4ae"
	# CHAR : 
	oct_code_review = "\uf4af"
	# CHAR : 
	oct_code_square = "\uf4b0"
	# CHAR : 
	oct_codescan = "\uf4b1"
	# CHAR : 
	oct_codescan_checkmark = "\uf4b2"
	# CHAR : 
	oct_codespaces = "\uf4b3"
	# CHAR : 
	oct_columns = "\uf4b4"
	# CHAR : 
	oct_command_palette = "\uf4b5"
	# CHAR : 
	oct_comment = "\uf41f"
	# CHAR : 
	oct_comment_discussion = "\uf442"
	# CHAR : 
	oct_commit = "\uf4b6"
	# CHAR : 
	oct_container = "\uf4b7"
	# CHAR : 
	oct_copilot = "\uf4b8"
	# CHAR : 
	oct_copilot_error = "\uf4b9"
	# CHAR : 
	oct_copilot_warning = "\uf4ba"
	# CHAR : 
	oct_copy = "\uf4bb"
	# CHAR : 
	oct_cpu = "\uf4bc"
	# CHAR : 
	oct_credit_card = "\uf439"
	# CHAR : 
	oct_cross_reference = "\uf4bd"
	# CHAR : 
	oct_dash = "\uf48b"
	# CHAR : 
	oct_database = "\uf472"
	# CHAR : 
	oct_dependabot = "\uf4be"
	# CHAR : 
	oct_desktop_download = "\uf498"
	# CHAR : 
	oct_device_camera = "\uf446"
	# CHAR : 
	oct_device_camera_video = "\uf447"
	# CHAR : 
	oct_device_desktop = "\uf4a9"
	# CHAR : 
	oct_device_mobile = "\uf42c"
	# CHAR : 
	oct_diamond = "\uf4bf"
	# CHAR : 
	oct_diff = "\uf440"
	# CHAR : 
	oct_diff_added = "\uf457"
	# CHAR : 
	oct_diff_ignored = "\uf474"
	# CHAR : 
	oct_diff_modified = "\uf459"
	# CHAR : 
	oct_diff_removed = "\uf458"
	# CHAR : 
	oct_diff_renamed = "\uf45a"
	# CHAR : 
	oct_discussion_closed = "\uf4c0"
	# CHAR : 
	oct_discussion_duplicate = "\uf4c1"
	# CHAR : 
	oct_discussion_outdated = "\uf4c2"
	# CHAR : 
	oct_dot = "\uf4c3"
	# CHAR : 
	oct_dot_fill = "\uf444"
	# CHAR : 
	oct_download = "\uf409"
	# CHAR : 
	oct_duplicate = "\uf4c4"
	# CHAR : 
	oct_ellipsis = "\uf475"
	# CHAR : 
	oct_eye = "\uf441"
	# CHAR : 
	oct_eye_closed = "\uf4c5"
	# CHAR : 
	oct_feed_discussion = "\uf4c6"
	# CHAR : 
	oct_feed_forked = "\uf4c7"
	# CHAR : 
	oct_feed_heart = "\uf4c8"
	# CHAR : 
	oct_feed_merged = "\uf4c9"
	# CHAR : 
	oct_feed_person = "\uf4ca"
	# CHAR : 
	oct_feed_repo = "\uf4cb"
	# CHAR : 
	oct_feed_rocket = "\uf4cc"
	# CHAR : 
	oct_feed_star = "\uf4cd"
	# CHAR : 
	oct_feed_tag = "\uf4ce"
	# CHAR : 
	oct_feed_trophy = "\uf4cf"
	# CHAR : 
	oct_file = "\uf4a5"
	# CHAR : 
	oct_file_added = "\uf4d0"
	# CHAR : 
	oct_file_badge = "\uf4d1"
	# CHAR : 
	oct_file_binary = "\uf471"
	# CHAR : 
	oct_file_code = "\uf40d"
	# CHAR : 
	oct_file_diff = "\uf4d2"
	# CHAR : 
	oct_file_directory = "\uf413"
	# CHAR : 
	oct_file_directory_fill = "\uf4d3"
	# CHAR : 
	oct_file_directory_open_fill = "\uf4d4"
	# CHAR : 
	oct_file_media = "\uf40f"
	# CHAR : 
	oct_file_moved = "\uf4d5"
	# CHAR : 
	oct_file_removed = "\uf4d6"
	# CHAR : 
	oct_file_submodule = "\uf414"
	# CHAR : 
	oct_file_symlink_directory = "\uf482"
	# CHAR : 
	oct_file_symlink_file = "\uf481"
	# CHAR : 
	oct_file_zip = "\uf410"
	# CHAR : 
	oct_filter = "\uf4d7"
	# CHAR : 
	oct_fiscal_host = "\uf4d8"
	# CHAR : 
	oct_flame = "\uf490"
	# CHAR : 
	oct_fold = "\uf48c"
	# CHAR : 
	oct_fold_down = "\uf4d9"
	# CHAR : 
	oct_fold_up = "\uf4da"
	# CHAR : 
	oct_gear = "\uf423"
	# CHAR : 
	oct_gift = "\uf436"
	# CHAR : 
	oct_git_branch = "\uf418"
	# CHAR : 
	oct_git_commit = "\uf417"
	# CHAR : 
	oct_git_compare = "\uf47f"
	# CHAR : 
	oct_git_merge = "\uf419"
	# CHAR : 
	oct_git_merge_queue = "\uf4db"
	# CHAR : 
	oct_git_pull_request = "\uf407"
	# CHAR : 
	oct_git_pull_request_closed = "\uf4dc"
	# CHAR : 
	oct_git_pull_request_draft = "\uf4dd"
	# CHAR : 
	oct_globe = "\uf484"
	# CHAR : 
	oct_goal = "\uf4de"
	# CHAR : 
	oct_grabber = "\uf4a6"
	# CHAR : 
	oct_graph = "\uf437"
	# CHAR : 
	oct_hash = "\uf4df"
	# CHAR : 
	oct_heading = "\uf4e0"
	# CHAR : ♥
	oct_heart = "\u2665"
	# CHAR : 
	oct_heart_fill = "\uf4e1"
	# CHAR : 
	oct_history = "\uf464"
	# CHAR : 
	oct_home = "\uf46d"
	# CHAR : 
	oct_home_fill = "\uf4e2"
	# CHAR : 
	oct_horizontal_rule = "\uf45b"
	# CHAR : 
	oct_hourglass = "\uf4e3"
	# CHAR : 
	oct_hubot = "\uf477"
	# CHAR : 
	oct_id_badge = "\uf4e4"
	# CHAR : 
	oct_image = "\uf4e5"
	# CHAR : 
	oct_inbox = "\uf48d"
	# CHAR : 
	oct_infinity = "\uf4e6"
	# CHAR : 
	oct_info = "\uf449"
	# CHAR : 
	oct_issue_closed = "\uf41d"
	# CHAR : 
	oct_issue_draft = "\uf4e7"
	# CHAR : 
	oct_issue_opened = "\uf41b"
	# CHAR : 
	oct_issue_reopened = "\uf41c"
	# CHAR : 
	oct_issue_tracked_by = "\uf4e8"
	# CHAR : 
	oct_issue_tracks = "\uf4e9"
	# CHAR : 
	oct_italic = "\uf49f"
	# CHAR : 
	oct_iterations = "\uf4ea"
	# CHAR : 
	oct_kebab_horizontal = "\uf4eb"
	# CHAR : 
	oct_key = "\uf43d"
	# CHAR : 
	oct_key_asterisk = "\uf4ec"
	# CHAR : 
	oct_law = "\uf495"
	# CHAR : 
	oct_light_bulb = "\uf400"
	# CHAR : 
	oct_link = "\uf44c"
	# CHAR : 
	oct_link_external = "\uf465"
	# CHAR : 
	oct_list_ordered = "\uf452"
	# CHAR : 
	oct_list_unordered = "\uf451"
	# CHAR : 
	oct_location = "\uf450"
	# CHAR : 
	oct_lock = "\uf456"
	# CHAR : 
	oct_log = "\uf4ed"
	# CHAR : 
	oct_logo_gist = "\uf480"
	# CHAR : 
	oct_logo_github = "\uf470"
	# CHAR : 
	oct_mail = "\uf42f"
	# CHAR : 
	oct_mark_github = "\uf408"
	# CHAR : 
	oct_markdown = "\uf48a"
	# CHAR : 
	oct_megaphone = "\uf45f"
	# CHAR : 
	oct_mention = "\uf486"
	# CHAR : 
	oct_meter = "\uf463"
	# CHAR : 
	oct_milestone = "\uf45d"
	# CHAR : 
	oct_mirror = "\uf41a"
	# CHAR : 
	oct_moon = "\uf4ee"
	# CHAR : 
	oct_mortar_board = "\uf494"
	# CHAR : 
	oct_move_to_bottom = "\uf4ef"
	# CHAR : 
	oct_move_to_end = "\uf4f0"
	# CHAR : 
	oct_move_to_start = "\uf4f1"
	# CHAR : 
	oct_move_to_top = "\uf4f2"
	# CHAR : 
	oct_multi_select = "\uf4f3"
	# CHAR : 
	oct_mute = "\uf466"
	# CHAR : 
	oct_no_entry = "\uf4f4"
	# CHAR : 
	oct_north_star = "\uf4f5"
	# CHAR : 
	oct_note = "\uf4f6"
	# CHAR : 
	oct_number = "\uf4f7"
	# CHAR : 
	oct_organization = "\uf42b"
	# CHAR : 
	oct_package = "\uf487"
	# CHAR : 
	oct_package_dependencies = "\uf4f8"
	# CHAR : 
	oct_package_dependents = "\uf4f9"
	# CHAR : 
	oct_paintbrush = "\uf48f"
	# CHAR : 
	oct_paper_airplane = "\uf4fa"
	# CHAR : 
	oct_paperclip = "\uf4fb"
	# CHAR : 
	oct_passkey_fill = "\uf4fc"
	# CHAR : 
	oct_paste = "\uf429"
	# CHAR : 
	oct_pencil = "\uf448"
	# CHAR : 
	oct_people = "\uf4fd"
	# CHAR : 
	oct_person = "\uf415"
	# CHAR : 
	oct_person_add = "\uf4fe"
	# CHAR : 
	oct_person_fill = "\uf4ff"
	# CHAR : 
	oct_pin = "\uf435"
	# CHAR : 
	oct_play = "\uf500"
	# CHAR : 
	oct_plug = "\uf492"
	# CHAR : 
	oct_plus = "\uf44d"
	# CHAR : 
	oct_plus_circle = "\uf501"
	# CHAR : 
	oct_project = "\uf502"
	# CHAR : 
	oct_project_roadmap = "\uf503"
	# CHAR : 
	oct_project_symlink = "\uf504"
	# CHAR : 
	oct_project_template = "\uf505"
	# CHAR : 
	oct_pulse = "\uf469"
	# CHAR : 
	oct_question = "\uf420"
	# CHAR : 
	oct_quote = "\uf453"
	# CHAR : 
	oct_read = "\uf430"
	# CHAR : 
	oct_rel_file_path = "\uf506"
	# CHAR : 
	oct_reply = "\uf4a8"
	# CHAR : 
	oct_repo = "\uf401"
	# CHAR : 
	oct_repo_clone = "\uf43f"
	# CHAR : 
	oct_repo_deleted = "\uf507"
	# CHAR : 
	oct_repo_forked = "\uf402"
	# CHAR : 
	oct_repo_locked = "\uf508"
	# CHAR : 
	oct_repo_pull = "\uf404"
	# CHAR : 
	oct_repo_push = "\uf403"
	# CHAR : 
	oct_repo_template = "\uf509"
	# CHAR : 
	oct_report = "\uf50a"
	# CHAR : 
	oct_rocket = "\uf427"
	# CHAR : 
	oct_rows = "\uf50b"
	# CHAR : 
	oct_rss = "\uf428"
	# CHAR : 
	oct_ruby = "\uf43b"
	# CHAR : 
	oct_screen_full = "\uf50c"
	# CHAR : 
	oct_screen_normal = "\uf50d"
	# CHAR : 
	oct_search = "\uf422"
	# CHAR : 
	oct_server = "\uf473"
	# CHAR : 
	oct_share = "\uf50e"
	# CHAR : 
	oct_share_android = "\uf50f"
	# CHAR : 
	oct_shield = "\uf49c"
	# CHAR : 
	oct_shield_check = "\uf510"
	# CHAR : 
	oct_shield_lock = "\uf511"
	# CHAR : 
	oct_shield_slash = "\uf512"
	# CHAR : 
	oct_shield_x = "\uf513"
	# CHAR : 
	oct_sidebar_collapse = "\uf514"
	# CHAR : 
	oct_sidebar_expand = "\uf515"
	# CHAR : 
	oct_sign_in = "\uf42a"
	# CHAR : 
	oct_sign_out = "\uf426"
	# CHAR : 
	oct_single_select = "\uf516"
	# CHAR : 
	oct_skip = "\uf517"
	# CHAR : 
	oct_skip_fill = "\uf518"
	# CHAR : 
	oct_sliders = "\uf462"
	# CHAR : 
	oct_smiley = "\uf4a2"
	# CHAR : 
	oct_sort_asc = "\uf519"
	# CHAR : 
	oct_sort_desc = "\uf51a"
	# CHAR : 
	oct_sparkle_fill = "\uf51b"
	# CHAR : 
	oct_sponsor_tiers = "\uf51c"
	# CHAR : 
	oct_square = "\uf51d"
	# CHAR : 
	oct_square_fill = "\uf445"
	# CHAR : 
	oct_squirrel = "\uf483"
	# CHAR : 
	oct_stack = "\uf51e"
	# CHAR : 
	oct_star = "\uf41e"
	# CHAR : 
	oct_star_fill = "\uf51f"
	# CHAR : 
	oct_stop = "\uf46e"
	# CHAR : 
	oct_stopwatch = "\uf520"
	# CHAR : 
	oct_strikethrough = "\uf521"
	# CHAR : 
	oct_sun = "\uf522"
	# CHAR : 
	oct_sync = "\uf46a"
	# CHAR : 
	oct_tab = "\uf523"
	# CHAR : 
	oct_tab_external = "\uf524"
	# CHAR : 
	oct_table = "\uf525"
	# CHAR : 
	oct_tag = "\uf412"
	# CHAR : 
	oct_tasklist = "\uf4a0"
	# CHAR : 
	oct_telescope = "\uf46b"
	# CHAR : 
	oct_telescope_fill = "\uf526"
	# CHAR : 
	oct_terminal = "\uf489"
	# CHAR : 
	oct_three_bars = "\uf44e"
	# CHAR : 
	oct_thumbsdown = "\uf497"
	# CHAR : 
	oct_thumbsup = "\uf496"
	# CHAR : 
	oct_tools = "\uf425"
	# CHAR : 
	oct_trash = "\uf48e"
	# CHAR : 
	oct_triangle_down = "\uf44b"
	# CHAR : 
	oct_triangle_left = "\uf438"
	# CHAR : 
	oct_triangle_right = "\uf44a"
	# CHAR : 
	oct_triangle_up = "\uf47e"
	# CHAR : 
	oct_trophy = "\uf527"
	# CHAR : 
	oct_typography = "\uf528"
	# CHAR : 
	oct_unfold = "\uf42d"
	# CHAR : 
	oct_unlink = "\uf529"
	# CHAR : 
	oct_unlock = "\uf52a"
	# CHAR : 
	oct_unmute = "\uf485"
	# CHAR : 
	oct_unread = "\uf52b"
	# CHAR : 
	oct_unverified = "\uf4a3"
	# CHAR : 
	oct_upload = "\uf40a"
	# CHAR : 
	oct_verified = "\uf4a1"
	# CHAR : 
	oct_versions = "\uf454"
	# CHAR : 
	oct_video = "\uf52c"
	# CHAR : 
	oct_webhook = "\uf52d"
	# CHAR : 
	oct_workflow = "\uf52e"
	# CHAR : 
	oct_x = "\uf467"
	# CHAR : 
	oct_x_circle = "\uf52f"
	# CHAR : 
	oct_x_circle_fill = "\uf530"
	# CHAR : ⚡
	oct_zap = "\u26a1"
	# CHAR : 
	oct_zoom_in = "\uf531"
	# CHAR : 
	oct_zoom_out = "\uf532"