# This File GEN using nerdicons_gen.py

class Custom:

	# CHAR : 
	custom_ada = "\ue6b5"
	# CHAR : 
	custom_asm = "\ue6ab"
	# CHAR : 
	custom_astro = "\ue6b3"
	# CHAR : 
	custom_bazel = "\ue63a"
	# CHAR : 
	custom_c = "\ue61e"
	# CHAR : 
	custom_chuck = "\ue6b6"
	# CHAR : 
	custom_common_lisp = "\ue6b0"
	# CHAR : 
	custom_cpp = "\ue61d"
	# CHAR : 
	custom_crystal = "\ue62f"
	# CHAR : 
	custom_css = "\ue6b8"
	# CHAR : 
	custom_default = "\ue612"
	# CHAR : 
	custom_electron = "\ue62e"
	# CHAR : 
	custom_elixir = "\ue62d"
	# CHAR : 
	custom_elm = "\ue62c"
	# CHAR : 
	custom_emacs = "\ue632"
	# CHAR : 
	custom_fennel = "\ue6af"
	# CHAR : 
	custom_firebase = "\ue657"
	# CHAR : 
	custom_folder = "\ue5ff"
	# CHAR : 
	custom_folder_config = "\ue5fc"
	# CHAR : 
	custom_folder_git = "\ue5fb"
	# CHAR : 
	custom_folder_git_branch = "\ue5fb"
	# CHAR : 
	custom_folder_github = "\ue5fd"
	# CHAR : 
	custom_folder_npm = "\ue5fa"
	# CHAR : 
	custom_folder_oct = "\ue6ad"
	# CHAR : 
	custom_folder_open = "\ue5fe"
	# CHAR : 
	custom_go = "\ue626"
	# CHAR : 
	custom_home = "\ue617"
	# CHAR : 
	custom_kotlin = "\ue634"
	# CHAR : 
	custom_msdos = "\ue629"
	# CHAR : 
	custom_neovim = "\ue6ae"
	# CHAR : 
	custom_orgmode = "\ue633"
	# CHAR : 
	custom_play_arrow = "\ue602"
	# CHAR : 
	custom_prettier = "\ue6b4"
	# CHAR : 
	custom_puppet = "\ue631"
	# CHAR : 
	custom_purescript = "\ue630"
	# CHAR : 
	custom_ruby = "\ue605"
	# CHAR : 
	custom_scheme = "\ue6b1"
	# CHAR : 
	custom_toml = "\ue6b2"
	# CHAR : 
	custom_v_lang = "\ue6ac"
	# CHAR : 
	custom_vim = "\ue62b"
	# CHAR : 
	custom_vitruvian = "\ue6b7"
	# CHAR : 
	custom_windows = "\ue62a"