# This File GEN using nerdicons_gen.py

class Md:

	# CHAR : 󰇉
	md_ab_testing = "\uf01c9"
	# CHAR : 󱛠
	md_abacus = "\uf16e0"
	# CHAR : 󱌨
	md_abjad_arabic = "\uf1328"
	# CHAR : 󱌩
	md_abjad_hebrew = "\uf1329"
	# CHAR : 󱌪
	md_abugida_devanagari = "\uf132a"
	# CHAR : 󱌫
	md_abugida_thai = "\uf132b"
	# CHAR : 󰀃
	md_access_point = "\uf0003"
	# CHAR : 󱔸
	md_access_point_check = "\uf1538"
	# CHAR : 󱔹
	md_access_point_minus = "\uf1539"
	# CHAR : 󰀂
	md_access_point_network = "\uf0002"
	# CHAR : 󰯡
	md_access_point_network_off = "\uf0be1"
	# CHAR : 󱔑
	md_access_point_off = "\uf1511"
	# CHAR : 󱔺
	md_access_point_plus = "\uf153a"
	# CHAR : 󱔻
	md_access_point_remove = "\uf153b"
	# CHAR : 󰀄
	md_account = "\uf0004"
	# CHAR : 󰀅
	md_account_alert = "\uf0005"
	# CHAR : 󰭐
	md_account_alert_outline = "\uf0b50"
	# CHAR : 󱡨
	md_account_arrow_down = "\uf1868"
	# CHAR : 󱡩
	md_account_arrow_down_outline = "\uf1869"
	# CHAR : 󰭑
	md_account_arrow_left = "\uf0b51"
	# CHAR : 󰭒
	md_account_arrow_left_outline = "\uf0b52"
	# CHAR : 󰭓
	md_account_arrow_right = "\uf0b53"
	# CHAR : 󰭔
	md_account_arrow_right_outline = "\uf0b54"
	# CHAR : 󱡧
	md_account_arrow_up = "\uf1867"
	# CHAR : 󱡪
	md_account_arrow_up_outline = "\uf186a"
	# CHAR : 󰀆
	md_account_box = "\uf0006"
	# CHAR : 󰤴
	md_account_box_multiple = "\uf0934"
	# CHAR : 󱀊
	md_account_box_multiple_outline = "\uf100a"
	# CHAR : 󰀇
	md_account_box_outline = "\uf0007"
	# CHAR : 󱋟
	md_account_cancel = "\uf12df"
	# CHAR : 󱋠
	md_account_cancel_outline = "\uf12e0"
	# CHAR : 󱂗
	md_account_cash = "\uf1097"
	# CHAR : 󱂘
	md_account_cash_outline = "\uf1098"
	# CHAR : 󰀈
	md_account_check = "\uf0008"
	# CHAR : 󰯢
	md_account_check_outline = "\uf0be2"
	# CHAR : 󰪉
	md_account_child = "\uf0a89"
	# CHAR : 󰪊
	md_account_child_circle = "\uf0a8a"
	# CHAR : 󱃈
	md_account_child_outline = "\uf10c8"
	# CHAR : 󰀉
	md_account_circle = "\uf0009"
	# CHAR : 󰭕
	md_account_circle_outline = "\uf0b55"
	# CHAR : 󰭖
	md_account_clock = "\uf0b56"
	# CHAR : 󰭗
	md_account_clock_outline = "\uf0b57"
	# CHAR : 󱍰
	md_account_cog = "\uf1370"
	# CHAR : 󱍱
	md_account_cog_outline = "\uf1371"
	# CHAR : 󰀊
	md_account_convert = "\uf000a"
	# CHAR : 󱌁
	md_account_convert_outline = "\uf1301"
	# CHAR : 󰺛
	md_account_cowboy_hat = "\uf0e9b"
	# CHAR : 󱟳
	md_account_cowboy_hat_outline = "\uf17f3"
	# CHAR : 󰘱
	md_account_details = "\uf0631"
	# CHAR : 󱍲
	md_account_details_outline = "\uf1372"
	# CHAR : 󰚼
	md_account_edit = "\uf06bc"
	# CHAR : 󰿻
	md_account_edit_outline = "\uf0ffb"
	# CHAR : 󰐠
	md_account_eye = "\uf0420"
	# CHAR : 󱉻
	md_account_eye_outline = "\uf127b"
	# CHAR : 󰤶
	md_account_filter = "\uf0936"
	# CHAR : 󰾝
	md_account_filter_outline = "\uf0f9d"
	# CHAR : 󰡉
	md_account_group = "\uf0849"
	# CHAR : 󰭘
	md_account_group_outline = "\uf0b58"
	# CHAR : 󰖵
	md_account_hard_hat = "\uf05b5"
	# CHAR : 󱨟
	md_account_hard_hat_outline = "\uf1a1f"
	# CHAR : 󰢙
	md_account_heart = "\uf0899"
	# CHAR : 󰯣
	md_account_heart_outline = "\uf0be3"
	# CHAR : 󱠕
	md_account_injury = "\uf1815"
	# CHAR : 󱠖
	md_account_injury_outline = "\uf1816"
	# CHAR : 󰀋
	md_account_key = "\uf000b"
	# CHAR : 󰯤
	md_account_key_outline = "\uf0be4"
	# CHAR : 󱅞
	md_account_lock = "\uf115e"
	# CHAR : 󱥠
	md_account_lock_open = "\uf1960"
	# CHAR : 󱥡
	md_account_lock_open_outline = "\uf1961"
	# CHAR : 󱅟
	md_account_lock_outline = "\uf115f"
	# CHAR : 󰀍
	md_account_minus = "\uf000d"
	# CHAR : 󰫬
	md_account_minus_outline = "\uf0aec"
	# CHAR : 󰀎
	md_account_multiple = "\uf000e"
	# CHAR : 󰣅
	md_account_multiple_check = "\uf08c5"
	# CHAR : 󱇾
	md_account_multiple_check_outline = "\uf11fe"
	# CHAR : 󰗓
	md_account_multiple_minus = "\uf05d3"
	# CHAR : 󰯥
	md_account_multiple_minus_outline = "\uf0be5"
	# CHAR : 󰀏
	md_account_multiple_outline = "\uf000f"
	# CHAR : 󰀐
	md_account_multiple_plus = "\uf0010"
	# CHAR : 󰠀
	md_account_multiple_plus_outline = "\uf0800"
	# CHAR : 󱈊
	md_account_multiple_remove = "\uf120a"
	# CHAR : 󱈋
	md_account_multiple_remove_outline = "\uf120b"
	# CHAR : 󰠃
	md_account_music = "\uf0803"
	# CHAR : 󰳩
	md_account_music_outline = "\uf0ce9"
	# CHAR : 󰀑
	md_account_network = "\uf0011"
	# CHAR : 󰯦
	md_account_network_outline = "\uf0be6"
	# CHAR : 󰀒
	md_account_off = "\uf0012"
	# CHAR : 󰯧
	md_account_off_outline = "\uf0be7"
	# CHAR : 󰀓
	md_account_outline = "\uf0013"
	# CHAR : 󰀔
	md_account_plus = "\uf0014"
	# CHAR : 󰠁
	md_account_plus_outline = "\uf0801"
	# CHAR : 󰭙
	md_account_question = "\uf0b59"
	# CHAR : 󰭚
	md_account_question_outline = "\uf0b5a"
	# CHAR : 󱔫
	md_account_reactivate = "\uf152b"
	# CHAR : 󱔬
	md_account_reactivate_outline = "\uf152c"
	# CHAR : 󰀕
	md_account_remove = "\uf0015"
	# CHAR : 󰫭
	md_account_remove_outline = "\uf0aed"
	# CHAR : 󱨠
	md_account_school = "\uf1a20"
	# CHAR : 󱨡
	md_account_school_outline = "\uf1a21"
	# CHAR : 󰀖
	md_account_search = "\uf0016"
	# CHAR : 󰤵
	md_account_search_outline = "\uf0935"
	# CHAR : 󰘰
	md_account_settings = "\uf0630"
	# CHAR : 󱃉
	md_account_settings_outline = "\uf10c9"
	# CHAR : 󰀗
	md_account_star = "\uf0017"
	# CHAR : 󰯨
	md_account_star_outline = "\uf0be8"
	# CHAR : 󰪋
	md_account_supervisor = "\uf0a8b"
	# CHAR : 󰪌
	md_account_supervisor_circle = "\uf0a8c"
	# CHAR : 󱓬
	md_account_supervisor_circle_outline = "\uf14ec"
	# CHAR : 󱄭
	md_account_supervisor_outline = "\uf112d"
	# CHAR : 󰀙
	md_account_switch = "\uf0019"
	# CHAR : 󰓋
	md_account_switch_outline = "\uf04cb"
	# CHAR : 󱤛
	md_account_sync = "\uf191b"
	# CHAR : 󱤜
	md_account_sync_outline = "\uf191c"
	# CHAR : 󰳣
	md_account_tie = "\uf0ce3"
	# CHAR : 󱢘
	md_account_tie_hat = "\uf1898"
	# CHAR : 󱢙
	md_account_tie_hat_outline = "\uf1899"
	# CHAR : 󱃊
	md_account_tie_outline = "\uf10ca"
	# CHAR : 󱌈
	md_account_tie_voice = "\uf1308"
	# CHAR : 󱌊
	md_account_tie_voice_off = "\uf130a"
	# CHAR : 󱌋
	md_account_tie_voice_off_outline = "\uf130b"
	# CHAR : 󱌉
	md_account_tie_voice_outline = "\uf1309"
	# CHAR : 󱪌
	md_account_tie_woman = "\uf1a8c"
	# CHAR : 󰗋
	md_account_voice = "\uf05cb"
	# CHAR : 󰻔
	md_account_voice_off = "\uf0ed4"
	# CHAR : 󱢚
	md_account_wrench = "\uf189a"
	# CHAR : 󱢛
	md_account_wrench_outline = "\uf189b"
	# CHAR : 󰀚
	md_adjust = "\uf001a"
	# CHAR : 󱤪
	md_advertisements = "\uf192a"
	# CHAR : 󱤫
	md_advertisements_off = "\uf192b"
	# CHAR : 󰀛
	md_air_conditioner = "\uf001b"
	# CHAR : 󰵃
	md_air_filter = "\uf0d43"
	# CHAR : 󰶬
	md_air_horn = "\uf0dac"
	# CHAR : 󱂙
	md_air_humidifier = "\uf1099"
	# CHAR : 󱑦
	md_air_humidifier_off = "\uf1466"
	# CHAR : 󰵄
	md_air_purifier = "\uf0d44"
	# CHAR : 󰯩
	md_airbag = "\uf0be9"
	# CHAR : 󰀜
	md_airballoon = "\uf001c"
	# CHAR : 󱀋
	md_airballoon_outline = "\uf100b"
	# CHAR : 󰀝
	md_airplane = "\uf001d"
	# CHAR : 󱡺
	md_airplane_alert = "\uf187a"
	# CHAR : 󱡻
	md_airplane_check = "\uf187b"
	# CHAR : 󱡼
	md_airplane_clock = "\uf187c"
	# CHAR : 󱡽
	md_airplane_cog = "\uf187d"
	# CHAR : 󱡾
	md_airplane_edit = "\uf187e"
	# CHAR : 󰗔
	md_airplane_landing = "\uf05d4"
	# CHAR : 󱡿
	md_airplane_marker = "\uf187f"
	# CHAR : 󱢀
	md_airplane_minus = "\uf1880"
	# CHAR : 󰀞
	md_airplane_off = "\uf001e"
	# CHAR : 󱢁
	md_airplane_plus = "\uf1881"
	# CHAR : 󱢂
	md_airplane_remove = "\uf1882"
	# CHAR : 󱢃
	md_airplane_search = "\uf1883"
	# CHAR : 󱢄
	md_airplane_settings = "\uf1884"
	# CHAR : 󰗕
	md_airplane_takeoff = "\uf05d5"
	# CHAR : 󰡋
	md_airport = "\uf084b"
	# CHAR : 󰀠
	md_alarm = "\uf0020"
	# CHAR : 󰞎
	md_alarm_bell = "\uf078e"
	# CHAR : 󰀡
	md_alarm_check = "\uf0021"
	# CHAR : 󰞏
	md_alarm_light = "\uf078f"
	# CHAR : 󱜞
	md_alarm_light_off = "\uf171e"
	# CHAR : 󱜟
	md_alarm_light_off_outline = "\uf171f"
	# CHAR : 󰯪
	md_alarm_light_outline = "\uf0bea"
	# CHAR : 󰀢
	md_alarm_multiple = "\uf0022"
	# CHAR : 󰹱
	md_alarm_note = "\uf0e71"
	# CHAR : 󰹲
	md_alarm_note_off = "\uf0e72"
	# CHAR : 󰀣
	md_alarm_off = "\uf0023"
	# CHAR : 󱗄
	md_alarm_panel = "\uf15c4"
	# CHAR : 󱗅
	md_alarm_panel_outline = "\uf15c5"
	# CHAR : 󰀤
	md_alarm_plus = "\uf0024"
	# CHAR : 󰚎
	md_alarm_snooze = "\uf068e"
	# CHAR : 󰀥
	md_album = "\uf0025"
	# CHAR : 󰀦
	md_alert = "\uf0026"
	# CHAR : 󰀧
	md_alert_box = "\uf0027"
	# CHAR : 󰳤
	md_alert_box_outline = "\uf0ce4"
	# CHAR : 󰀨
	md_alert_circle = "\uf0028"
	# CHAR : 󱇭
	md_alert_circle_check = "\uf11ed"
	# CHAR : 󱇮
	md_alert_circle_check_outline = "\uf11ee"
	# CHAR : 󰗖
	md_alert_circle_outline = "\uf05d6"
	# CHAR : 󰚽
	md_alert_decagram = "\uf06bd"
	# CHAR : 󰳥
	md_alert_decagram_outline = "\uf0ce5"
	# CHAR : 󱒻
	md_alert_minus = "\uf14bb"
	# CHAR : 󱒾
	md_alert_minus_outline = "\uf14be"
	# CHAR : 󰀩
	md_alert_octagon = "\uf0029"
	# CHAR : 󰳦
	md_alert_octagon_outline = "\uf0ce6"
	# CHAR : 󰝧
	md_alert_octagram = "\uf0767"
	# CHAR : 󰳧
	md_alert_octagram_outline = "\uf0ce7"
	# CHAR : 󰀪
	md_alert_outline = "\uf002a"
	# CHAR : 󱒺
	md_alert_plus = "\uf14ba"
	# CHAR : 󱒽
	md_alert_plus_outline = "\uf14bd"
	# CHAR : 󱒼
	md_alert_remove = "\uf14bc"
	# CHAR : 󱒿
	md_alert_remove_outline = "\uf14bf"
	# CHAR : 󱇎
	md_alert_rhombus = "\uf11ce"
	# CHAR : 󱇏
	md_alert_rhombus_outline = "\uf11cf"
	# CHAR : 󰢚
	md_alien = "\uf089a"
	# CHAR : 󱃋
	md_alien_outline = "\uf10cb"
	# CHAR : 󱇃
	md_align_horizontal_center = "\uf11c3"
	# CHAR : 󱥢
	md_align_horizontal_distribute = "\uf1962"
	# CHAR : 󱇂
	md_align_horizontal_left = "\uf11c2"
	# CHAR : 󱇄
	md_align_horizontal_right = "\uf11c4"
	# CHAR : 󱇅
	md_align_vertical_bottom = "\uf11c5"
	# CHAR : 󱇆
	md_align_vertical_center = "\uf11c6"
	# CHAR : 󱥣
	md_align_vertical_distribute = "\uf1963"
	# CHAR : 󱇇
	md_align_vertical_top = "\uf11c7"
	# CHAR : 󰚾
	md_all_inclusive = "\uf06be"
	# CHAR : 󱢍
	md_all_inclusive_box = "\uf188d"
	# CHAR : 󱢎
	md_all_inclusive_box_outline = "\uf188e"
	# CHAR : 󱉘
	md_allergy = "\uf1258"
	# CHAR : 󰀫
	md_alpha = "\uf002b"
	# CHAR : 󰫮
	md_alpha_a = "\uf0aee"
	# CHAR : 󰬈
	md_alpha_a_box = "\uf0b08"
	# CHAR : 󰯫
	md_alpha_a_box_outline = "\uf0beb"
	# CHAR : 󰯬
	md_alpha_a_circle = "\uf0bec"
	# CHAR : 󰯭
	md_alpha_a_circle_outline = "\uf0bed"
	# CHAR : 󰫯
	md_alpha_b = "\uf0aef"
	# CHAR : 󰬉
	md_alpha_b_box = "\uf0b09"
	# CHAR : 󰯮
	md_alpha_b_box_outline = "\uf0bee"
	# CHAR : 󰯯
	md_alpha_b_circle = "\uf0bef"
	# CHAR : 󰯰
	md_alpha_b_circle_outline = "\uf0bf0"
	# CHAR : 󰫰
	md_alpha_c = "\uf0af0"
	# CHAR : 󰬊
	md_alpha_c_box = "\uf0b0a"
	# CHAR : 󰯱
	md_alpha_c_box_outline = "\uf0bf1"
	# CHAR : 󰯲
	md_alpha_c_circle = "\uf0bf2"
	# CHAR : 󰯳
	md_alpha_c_circle_outline = "\uf0bf3"
	# CHAR : 󰫱
	md_alpha_d = "\uf0af1"
	# CHAR : 󰬋
	md_alpha_d_box = "\uf0b0b"
	# CHAR : 󰯴
	md_alpha_d_box_outline = "\uf0bf4"
	# CHAR : 󰯵
	md_alpha_d_circle = "\uf0bf5"
	# CHAR : 󰯶
	md_alpha_d_circle_outline = "\uf0bf6"
	# CHAR : 󰫲
	md_alpha_e = "\uf0af2"
	# CHAR : 󰬌
	md_alpha_e_box = "\uf0b0c"
	# CHAR : 󰯷
	md_alpha_e_box_outline = "\uf0bf7"
	# CHAR : 󰯸
	md_alpha_e_circle = "\uf0bf8"
	# CHAR : 󰯹
	md_alpha_e_circle_outline = "\uf0bf9"
	# CHAR : 󰫳
	md_alpha_f = "\uf0af3"
	# CHAR : 󰬍
	md_alpha_f_box = "\uf0b0d"
	# CHAR : 󰯺
	md_alpha_f_box_outline = "\uf0bfa"
	# CHAR : 󰯻
	md_alpha_f_circle = "\uf0bfb"
	# CHAR : 󰯼
	md_alpha_f_circle_outline = "\uf0bfc"
	# CHAR : 󰫴
	md_alpha_g = "\uf0af4"
	# CHAR : 󰬎
	md_alpha_g_box = "\uf0b0e"
	# CHAR : 󰯽
	md_alpha_g_box_outline = "\uf0bfd"
	# CHAR : 󰯾
	md_alpha_g_circle = "\uf0bfe"
	# CHAR : 󰯿
	md_alpha_g_circle_outline = "\uf0bff"
	# CHAR : 󰫵
	md_alpha_h = "\uf0af5"
	# CHAR : 󰬏
	md_alpha_h_box = "\uf0b0f"
	# CHAR : 󰰀
	md_alpha_h_box_outline = "\uf0c00"
	# CHAR : 󰰁
	md_alpha_h_circle = "\uf0c01"
	# CHAR : 󰰂
	md_alpha_h_circle_outline = "\uf0c02"
	# CHAR : 󰫶
	md_alpha_i = "\uf0af6"
	# CHAR : 󰬐
	md_alpha_i_box = "\uf0b10"
	# CHAR : 󰰃
	md_alpha_i_box_outline = "\uf0c03"
	# CHAR : 󰰄
	md_alpha_i_circle = "\uf0c04"
	# CHAR : 󰰅
	md_alpha_i_circle_outline = "\uf0c05"
	# CHAR : 󰫷
	md_alpha_j = "\uf0af7"
	# CHAR : 󰬑
	md_alpha_j_box = "\uf0b11"
	# CHAR : 󰰆
	md_alpha_j_box_outline = "\uf0c06"
	# CHAR : 󰰇
	md_alpha_j_circle = "\uf0c07"
	# CHAR : 󰰈
	md_alpha_j_circle_outline = "\uf0c08"
	# CHAR : 󰫸
	md_alpha_k = "\uf0af8"
	# CHAR : 󰬒
	md_alpha_k_box = "\uf0b12"
	# CHAR : 󰰉
	md_alpha_k_box_outline = "\uf0c09"
	# CHAR : 󰰊
	md_alpha_k_circle = "\uf0c0a"
	# CHAR : 󰰋
	md_alpha_k_circle_outline = "\uf0c0b"
	# CHAR : 󰫹
	md_alpha_l = "\uf0af9"
	# CHAR : 󰬓
	md_alpha_l_box = "\uf0b13"
	# CHAR : 󰰌
	md_alpha_l_box_outline = "\uf0c0c"
	# CHAR : 󰰍
	md_alpha_l_circle = "\uf0c0d"
	# CHAR : 󰰎
	md_alpha_l_circle_outline = "\uf0c0e"
	# CHAR : 󰫺
	md_alpha_m = "\uf0afa"
	# CHAR : 󰬔
	md_alpha_m_box = "\uf0b14"
	# CHAR : 󰰏
	md_alpha_m_box_outline = "\uf0c0f"
	# CHAR : 󰰐
	md_alpha_m_circle = "\uf0c10"
	# CHAR : 󰰑
	md_alpha_m_circle_outline = "\uf0c11"
	# CHAR : 󰫻
	md_alpha_n = "\uf0afb"
	# CHAR : 󰬕
	md_alpha_n_box = "\uf0b15"
	# CHAR : 󰰒
	md_alpha_n_box_outline = "\uf0c12"
	# CHAR : 󰰓
	md_alpha_n_circle = "\uf0c13"
	# CHAR : 󰰔
	md_alpha_n_circle_outline = "\uf0c14"
	# CHAR : 󰫼
	md_alpha_o = "\uf0afc"
	# CHAR : 󰬖
	md_alpha_o_box = "\uf0b16"
	# CHAR : 󰰕
	md_alpha_o_box_outline = "\uf0c15"
	# CHAR : 󰰖
	md_alpha_o_circle = "\uf0c16"
	# CHAR : 󰰗
	md_alpha_o_circle_outline = "\uf0c17"
	# CHAR : 󰫽
	md_alpha_p = "\uf0afd"
	# CHAR : 󰬗
	md_alpha_p_box = "\uf0b17"
	# CHAR : 󰰘
	md_alpha_p_box_outline = "\uf0c18"
	# CHAR : 󰰙
	md_alpha_p_circle = "\uf0c19"
	# CHAR : 󰰚
	md_alpha_p_circle_outline = "\uf0c1a"
	# CHAR : 󰫾
	md_alpha_q = "\uf0afe"
	# CHAR : 󰬘
	md_alpha_q_box = "\uf0b18"
	# CHAR : 󰰛
	md_alpha_q_box_outline = "\uf0c1b"
	# CHAR : 󰰜
	md_alpha_q_circle = "\uf0c1c"
	# CHAR : 󰰝
	md_alpha_q_circle_outline = "\uf0c1d"
	# CHAR : 󰫿
	md_alpha_r = "\uf0aff"
	# CHAR : 󰬙
	md_alpha_r_box = "\uf0b19"
	# CHAR : 󰰞
	md_alpha_r_box_outline = "\uf0c1e"
	# CHAR : 󰰟
	md_alpha_r_circle = "\uf0c1f"
	# CHAR : 󰰠
	md_alpha_r_circle_outline = "\uf0c20"
	# CHAR : 󰬀
	md_alpha_s = "\uf0b00"
	# CHAR : 󰬚
	md_alpha_s_box = "\uf0b1a"
	# CHAR : 󰰡
	md_alpha_s_box_outline = "\uf0c21"
	# CHAR : 󰰢
	md_alpha_s_circle = "\uf0c22"
	# CHAR : 󰰣
	md_alpha_s_circle_outline = "\uf0c23"
	# CHAR : 󰬁
	md_alpha_t = "\uf0b01"
	# CHAR : 󰬛
	md_alpha_t_box = "\uf0b1b"
	# CHAR : 󰰤
	md_alpha_t_box_outline = "\uf0c24"
	# CHAR : 󰰥
	md_alpha_t_circle = "\uf0c25"
	# CHAR : 󰰦
	md_alpha_t_circle_outline = "\uf0c26"
	# CHAR : 󰬂
	md_alpha_u = "\uf0b02"
	# CHAR : 󰬜
	md_alpha_u_box = "\uf0b1c"
	# CHAR : 󰰧
	md_alpha_u_box_outline = "\uf0c27"
	# CHAR : 󰰨
	md_alpha_u_circle = "\uf0c28"
	# CHAR : 󰰩
	md_alpha_u_circle_outline = "\uf0c29"
	# CHAR : 󰬃
	md_alpha_v = "\uf0b03"
	# CHAR : 󰬝
	md_alpha_v_box = "\uf0b1d"
	# CHAR : 󰰪
	md_alpha_v_box_outline = "\uf0c2a"
	# CHAR : 󰰫
	md_alpha_v_circle = "\uf0c2b"
	# CHAR : 󰰬
	md_alpha_v_circle_outline = "\uf0c2c"
	# CHAR : 󰬄
	md_alpha_w = "\uf0b04"
	# CHAR : 󰬞
	md_alpha_w_box = "\uf0b1e"
	# CHAR : 󰰭
	md_alpha_w_box_outline = "\uf0c2d"
	# CHAR : 󰰮
	md_alpha_w_circle = "\uf0c2e"
	# CHAR : 󰰯
	md_alpha_w_circle_outline = "\uf0c2f"
	# CHAR : 󰬅
	md_alpha_x = "\uf0b05"
	# CHAR : 󰬟
	md_alpha_x_box = "\uf0b1f"
	# CHAR : 󰰰
	md_alpha_x_box_outline = "\uf0c30"
	# CHAR : 󰰱
	md_alpha_x_circle = "\uf0c31"
	# CHAR : 󰰲
	md_alpha_x_circle_outline = "\uf0c32"
	# CHAR : 󰬆
	md_alpha_y = "\uf0b06"
	# CHAR : 󰬠
	md_alpha_y_box = "\uf0b20"
	# CHAR : 󰰳
	md_alpha_y_box_outline = "\uf0c33"
	# CHAR : 󰰴
	md_alpha_y_circle = "\uf0c34"
	# CHAR : 󰰵
	md_alpha_y_circle_outline = "\uf0c35"
	# CHAR : 󰬇
	md_alpha_z = "\uf0b07"
	# CHAR : 󰬡
	md_alpha_z_box = "\uf0b21"
	# CHAR : 󰰶
	md_alpha_z_box_outline = "\uf0c36"
	# CHAR : 󰰷
	md_alpha_z_circle = "\uf0c37"
	# CHAR : 󰰸
	md_alpha_z_circle_outline = "\uf0c38"
	# CHAR : 󱌬
	md_alphabet_aurebesh = "\uf132c"
	# CHAR : 󱌭
	md_alphabet_cyrillic = "\uf132d"
	# CHAR : 󱌮
	md_alphabet_greek = "\uf132e"
	# CHAR : 󱌯
	md_alphabet_latin = "\uf132f"
	# CHAR : 󱌰
	md_alphabet_piqad = "\uf1330"
	# CHAR : 󱌷
	md_alphabet_tengwar = "\uf1337"
	# CHAR : 󰀬
	md_alphabetical = "\uf002c"
	# CHAR : 󱀌
	md_alphabetical_off = "\uf100c"
	# CHAR : 󱀍
	md_alphabetical_variant = "\uf100d"
	# CHAR : 󱀎
	md_alphabetical_variant_off = "\uf100e"
	# CHAR : 󰗗
	md_altimeter = "\uf05d7"
	# CHAR : 󰀯
	md_ambulance = "\uf002f"
	# CHAR : 󰳨
	md_ammunition = "\uf0ce8"
	# CHAR : 󰪍
	md_ampersand = "\uf0a8d"
	# CHAR : 󰀰
	md_amplifier = "\uf0030"
	# CHAR : 󱆵
	md_amplifier_off = "\uf11b5"
	# CHAR : 󰀱
	md_anchor = "\uf0031"
	# CHAR : 󰀲
	md_android = "\uf0032"
	# CHAR : 󰵅
	md_android_messages = "\uf0d45"
	# CHAR : 󰀴
	md_android_studio = "\uf0034"
	# CHAR : 󰤷
	md_angle_acute = "\uf0937"
	# CHAR : 󰤸
	md_angle_obtuse = "\uf0938"
	# CHAR : 󰤹
	md_angle_right = "\uf0939"
	# CHAR : 󰚲
	md_angular = "\uf06b2"
	# CHAR : 󰚿
	md_angularjs = "\uf06bf"
	# CHAR : 󰗘
	md_animation = "\uf05d8"
	# CHAR : 󰪏
	md_animation_outline = "\uf0a8f"
	# CHAR : 󰤺
	md_animation_play = "\uf093a"
	# CHAR : 󰪐
	md_animation_play_outline = "\uf0a90"
	# CHAR : 󱂚
	md_ansible = "\uf109a"
	# CHAR : 󱄙
	md_antenna = "\uf1119"
	# CHAR : 󰢛
	md_anvil = "\uf089b"
	# CHAR : 󱀏
	md_apache_kafka = "\uf100f"
	# CHAR : 󱂛
	md_api = "\uf109b"
	# CHAR : 󱉗
	md_api_off = "\uf1257"
	# CHAR : 󰀵
	md_apple = "\uf0035"
	# CHAR : 󰀶
	md_apple_finder = "\uf0036"
	# CHAR : 󰀸
	md_apple_icloud = "\uf0038"
	# CHAR : 󰀷
	md_apple_ios = "\uf0037"
	# CHAR : 󰘲
	md_apple_keyboard_caps = "\uf0632"
	# CHAR : 󰘳
	md_apple_keyboard_command = "\uf0633"
	# CHAR : 󰘴
	md_apple_keyboard_control = "\uf0634"
	# CHAR : 󰘵
	md_apple_keyboard_option = "\uf0635"
	# CHAR : 󰘶
	md_apple_keyboard_shift = "\uf0636"
	# CHAR : 󰀹
	md_apple_safari = "\uf0039"
	# CHAR : 󰣆
	md_application = "\uf08c6"
	# CHAR : 󱃵
	md_application_array = "\uf10f5"
	# CHAR : 󱃶
	md_application_array_outline = "\uf10f6"
	# CHAR : 󱃷
	md_application_braces = "\uf10f7"
	# CHAR : 󱃸
	md_application_braces_outline = "\uf10f8"
	# CHAR : 󰲋
	md_application_brackets = "\uf0c8b"
	# CHAR : 󰲌
	md_application_brackets_outline = "\uf0c8c"
	# CHAR : 󰙵
	md_application_cog = "\uf0675"
	# CHAR : 󱕷
	md_application_cog_outline = "\uf1577"
	# CHAR : 󰂮
	md_application_edit = "\uf00ae"
	# CHAR : 󰘙
	md_application_edit_outline = "\uf0619"
	# CHAR : 󰶭
	md_application_export = "\uf0dad"
	# CHAR : 󰶮
	md_application_import = "\uf0dae"
	# CHAR : 󰘔
	md_application_outline = "\uf0614"
	# CHAR : 󱃹
	md_application_parentheses = "\uf10f9"
	# CHAR : 󱃺
	md_application_parentheses_outline = "\uf10fa"
	# CHAR : 󰭠
	md_application_settings = "\uf0b60"
	# CHAR : 󱕕
	md_application_settings_outline = "\uf1555"
	# CHAR : 󱃻
	md_application_variable = "\uf10fb"
	# CHAR : 󱃼
	md_application_variable_outline = "\uf10fc"
	# CHAR : 󰾞
	md_approximately_equal = "\uf0f9e"
	# CHAR : 󰾟
	md_approximately_equal_box = "\uf0f9f"
	# CHAR : 󰀻
	md_apps = "\uf003b"
	# CHAR : 󰵆
	md_apps_box = "\uf0d46"
	# CHAR : 󰣇
	md_arch = "\uf08c7"
	# CHAR : 󰀼
	md_archive = "\uf003c"
	# CHAR : 󱓽
	md_archive_alert = "\uf14fd"
	# CHAR : 󱓾
	md_archive_alert_outline = "\uf14fe"
	# CHAR : 󱉙
	md_archive_arrow_down = "\uf1259"
	# CHAR : 󱉚
	md_archive_arrow_down_outline = "\uf125a"
	# CHAR : 󱉛
	md_archive_arrow_up = "\uf125b"
	# CHAR : 󱉜
	md_archive_arrow_up_outline = "\uf125c"
	# CHAR : 󱝋
	md_archive_cancel = "\uf174b"
	# CHAR : 󱝌
	md_archive_cancel_outline = "\uf174c"
	# CHAR : 󱝍
	md_archive_check = "\uf174d"
	# CHAR : 󱝎
	md_archive_check_outline = "\uf174e"
	# CHAR : 󱝏
	md_archive_clock = "\uf174f"
	# CHAR : 󱝐
	md_archive_clock_outline = "\uf1750"
	# CHAR : 󱝑
	md_archive_cog = "\uf1751"
	# CHAR : 󱝒
	md_archive_cog_outline = "\uf1752"
	# CHAR : 󱝓
	md_archive_edit = "\uf1753"
	# CHAR : 󱝔
	md_archive_edit_outline = "\uf1754"
	# CHAR : 󱝕
	md_archive_eye = "\uf1755"
	# CHAR : 󱝖
	md_archive_eye_outline = "\uf1756"
	# CHAR : 󱝗
	md_archive_lock = "\uf1757"
	# CHAR : 󱝘
	md_archive_lock_open = "\uf1758"
	# CHAR : 󱝙
	md_archive_lock_open_outline = "\uf1759"
	# CHAR : 󱝚
	md_archive_lock_outline = "\uf175a"
	# CHAR : 󱝛
	md_archive_marker = "\uf175b"
	# CHAR : 󱝜
	md_archive_marker_outline = "\uf175c"
	# CHAR : 󱝝
	md_archive_minus = "\uf175d"
	# CHAR : 󱝞
	md_archive_minus_outline = "\uf175e"
	# CHAR : 󱝟
	md_archive_music = "\uf175f"
	# CHAR : 󱝠
	md_archive_music_outline = "\uf1760"
	# CHAR : 󱝡
	md_archive_off = "\uf1761"
	# CHAR : 󱝢
	md_archive_off_outline = "\uf1762"
	# CHAR : 󱈎
	md_archive_outline = "\uf120e"
	# CHAR : 󱝣
	md_archive_plus = "\uf1763"
	# CHAR : 󱝤
	md_archive_plus_outline = "\uf1764"
	# CHAR : 󱝥
	md_archive_refresh = "\uf1765"
	# CHAR : 󱝦
	md_archive_refresh_outline = "\uf1766"
	# CHAR : 󱝧
	md_archive_remove = "\uf1767"
	# CHAR : 󱝨
	md_archive_remove_outline = "\uf1768"
	# CHAR : 󱝩
	md_archive_search = "\uf1769"
	# CHAR : 󱝪
	md_archive_search_outline = "\uf176a"
	# CHAR : 󱝫
	md_archive_settings = "\uf176b"
	# CHAR : 󱝬
	md_archive_settings_outline = "\uf176c"
	# CHAR : 󱝭
	md_archive_star = "\uf176d"
	# CHAR : 󱝮
	md_archive_star_outline = "\uf176e"
	# CHAR : 󱝯
	md_archive_sync = "\uf176f"
	# CHAR : 󱝰
	md_archive_sync_outline = "\uf1770"
	# CHAR : 󰿗
	md_arm_flex = "\uf0fd7"
	# CHAR : 󰿖
	md_arm_flex_outline = "\uf0fd6"
	# CHAR : 󰀽
	md_arrange_bring_forward = "\uf003d"
	# CHAR : 󰀾
	md_arrange_bring_to_front = "\uf003e"
	# CHAR : 󰀿
	md_arrange_send_backward = "\uf003f"
	# CHAR : 󰁀
	md_arrange_send_to_back = "\uf0040"
	# CHAR : 󰁁
	md_arrow_all = "\uf0041"
	# CHAR : 󰁂
	md_arrow_bottom_left = "\uf0042"
	# CHAR : 󱥤
	md_arrow_bottom_left_bold_box = "\uf1964"
	# CHAR : 󱥥
	md_arrow_bottom_left_bold_box_outline = "\uf1965"
	# CHAR : 󰦷
	md_arrow_bottom_left_bold_outline = "\uf09b7"
	# CHAR : 󰦸
	md_arrow_bottom_left_thick = "\uf09b8"
	# CHAR : 󱦶
	md_arrow_bottom_left_thin = "\uf19b6"
	# CHAR : 󱖖
	md_arrow_bottom_left_thin_circle_outline = "\uf1596"
	# CHAR : 󰁃
	md_arrow_bottom_right = "\uf0043"
	# CHAR : 󱥦
	md_arrow_bottom_right_bold_box = "\uf1966"
	# CHAR : 󱥧
	md_arrow_bottom_right_bold_box_outline = "\uf1967"
	# CHAR : 󰦹
	md_arrow_bottom_right_bold_outline = "\uf09b9"
	# CHAR : 󰦺
	md_arrow_bottom_right_thick = "\uf09ba"
	# CHAR : 󱦷
	md_arrow_bottom_right_thin = "\uf19b7"
	# CHAR : 󱖕
	md_arrow_bottom_right_thin_circle_outline = "\uf1595"
	# CHAR : 󰘕
	md_arrow_collapse = "\uf0615"
	# CHAR : 󰁄
	md_arrow_collapse_all = "\uf0044"
	# CHAR : 󰞒
	md_arrow_collapse_down = "\uf0792"
	# CHAR : 󰡌
	md_arrow_collapse_horizontal = "\uf084c"
	# CHAR : 󰞓
	md_arrow_collapse_left = "\uf0793"
	# CHAR : 󰞔
	md_arrow_collapse_right = "\uf0794"
	# CHAR : 󰞕
	md_arrow_collapse_up = "\uf0795"
	# CHAR : 󰡍
	md_arrow_collapse_vertical = "\uf084d"
	# CHAR : 󰦻
	md_arrow_decision = "\uf09bb"
	# CHAR : 󰦼
	md_arrow_decision_auto = "\uf09bc"
	# CHAR : 󰦽
	md_arrow_decision_auto_outline = "\uf09bd"
	# CHAR : 󰦾
	md_arrow_decision_outline = "\uf09be"
	# CHAR : 󰁅
	md_arrow_down = "\uf0045"
	# CHAR : 󰜮
	md_arrow_down_bold = "\uf072e"
	# CHAR : 󰜯
	md_arrow_down_bold_box = "\uf072f"
	# CHAR : 󰜰
	md_arrow_down_bold_box_outline = "\uf0730"
	# CHAR : 󰁇
	md_arrow_down_bold_circle = "\uf0047"
	# CHAR : 󰁈
	md_arrow_down_bold_circle_outline = "\uf0048"
	# CHAR : 󰁉
	md_arrow_down_bold_hexagon_outline = "\uf0049"
	# CHAR : 󰦿
	md_arrow_down_bold_outline = "\uf09bf"
	# CHAR : 󰛀
	md_arrow_down_box = "\uf06c0"
	# CHAR : 󰳛
	md_arrow_down_circle = "\uf0cdb"
	# CHAR : 󰳜
	md_arrow_down_circle_outline = "\uf0cdc"
	# CHAR : 󰁊
	md_arrow_down_drop_circle = "\uf004a"
	# CHAR : 󰁋
	md_arrow_down_drop_circle_outline = "\uf004b"
	# CHAR : 󱞡
	md_arrow_down_left = "\uf17a1"
	# CHAR : 󱞢
	md_arrow_down_left_bold = "\uf17a2"
	# CHAR : 󱞣
	md_arrow_down_right = "\uf17a3"
	# CHAR : 󱞤
	md_arrow_down_right_bold = "\uf17a4"
	# CHAR : 󰁆
	md_arrow_down_thick = "\uf0046"
	# CHAR : 󱦳
	md_arrow_down_thin = "\uf19b3"
	# CHAR : 󱖙
	md_arrow_down_thin_circle_outline = "\uf1599"
	# CHAR : 󰘖
	md_arrow_expand = "\uf0616"
	# CHAR : 󰁌
	md_arrow_expand_all = "\uf004c"
	# CHAR : 󰞖
	md_arrow_expand_down = "\uf0796"
	# CHAR : 󰡎
	md_arrow_expand_horizontal = "\uf084e"
	# CHAR : 󰞗
	md_arrow_expand_left = "\uf0797"
	# CHAR : 󰞘
	md_arrow_expand_right = "\uf0798"
	# CHAR : 󰞙
	md_arrow_expand_up = "\uf0799"
	# CHAR : 󰡏
	md_arrow_expand_vertical = "\uf084f"
	# CHAR : 󱅛
	md_arrow_horizontal_lock = "\uf115b"
	# CHAR : 󰁍
	md_arrow_left = "\uf004d"
	# CHAR : 󰜱
	md_arrow_left_bold = "\uf0731"
	# CHAR : 󰜲
	md_arrow_left_bold_box = "\uf0732"
	# CHAR : 󰜳
	md_arrow_left_bold_box_outline = "\uf0733"
	# CHAR : 󰁏
	md_arrow_left_bold_circle = "\uf004f"
	# CHAR : 󰁐
	md_arrow_left_bold_circle_outline = "\uf0050"
	# CHAR : 󰁑
	md_arrow_left_bold_hexagon_outline = "\uf0051"
	# CHAR : 󰧀
	md_arrow_left_bold_outline = "\uf09c0"
	# CHAR : 󱞥
	md_arrow_left_bottom = "\uf17a5"
	# CHAR : 󱞦
	md_arrow_left_bottom_bold = "\uf17a6"
	# CHAR : 󰛁
	md_arrow_left_box = "\uf06c1"
	# CHAR : 󰳝
	md_arrow_left_circle = "\uf0cdd"
	# CHAR : 󰳞
	md_arrow_left_circle_outline = "\uf0cde"
	# CHAR : 󰁒
	md_arrow_left_drop_circle = "\uf0052"
	# CHAR : 󰁓
	md_arrow_left_drop_circle_outline = "\uf0053"
	# CHAR : 󰹳
	md_arrow_left_right = "\uf0e73"
	# CHAR : 󰹴
	md_arrow_left_right_bold = "\uf0e74"
	# CHAR : 󰧁
	md_arrow_left_right_bold_outline = "\uf09c1"
	# CHAR : 󰁎
	md_arrow_left_thick = "\uf004e"
	# CHAR : 󱦱
	md_arrow_left_thin = "\uf19b1"
	# CHAR : 󱖚
	md_arrow_left_thin_circle_outline = "\uf159a"
	# CHAR : 󱞧
	md_arrow_left_top = "\uf17a7"
	# CHAR : 󱞨
	md_arrow_left_top_bold = "\uf17a8"
	# CHAR : 󱡀
	md_arrow_projectile = "\uf1840"
	# CHAR : 󱠿
	md_arrow_projectile_multiple = "\uf183f"
	# CHAR : 󰁔
	md_arrow_right = "\uf0054"
	# CHAR : 󰜴
	md_arrow_right_bold = "\uf0734"
	# CHAR : 󰜵
	md_arrow_right_bold_box = "\uf0735"
	# CHAR : 󰜶
	md_arrow_right_bold_box_outline = "\uf0736"
	# CHAR : 󰁖
	md_arrow_right_bold_circle = "\uf0056"
	# CHAR : 󰁗
	md_arrow_right_bold_circle_outline = "\uf0057"
	# CHAR : 󰁘
	md_arrow_right_bold_hexagon_outline = "\uf0058"
	# CHAR : 󰧂
	md_arrow_right_bold_outline = "\uf09c2"
	# CHAR : 󱞩
	md_arrow_right_bottom = "\uf17a9"
	# CHAR : 󱞪
	md_arrow_right_bottom_bold = "\uf17aa"
	# CHAR : 󰛂
	md_arrow_right_box = "\uf06c2"
	# CHAR : 󰳟
	md_arrow_right_circle = "\uf0cdf"
	# CHAR : 󰳠
	md_arrow_right_circle_outline = "\uf0ce0"
	# CHAR : 󰁙
	md_arrow_right_drop_circle = "\uf0059"
	# CHAR : 󰁚
	md_arrow_right_drop_circle_outline = "\uf005a"
	# CHAR : 󰁕
	md_arrow_right_thick = "\uf0055"
	# CHAR : 󱦰
	md_arrow_right_thin = "\uf19b0"
	# CHAR : 󱖘
	md_arrow_right_thin_circle_outline = "\uf1598"
	# CHAR : 󱞫
	md_arrow_right_top = "\uf17ab"
	# CHAR : 󱞬
	md_arrow_right_top_bold = "\uf17ac"
	# CHAR : 󰤻
	md_arrow_split_horizontal = "\uf093b"
	# CHAR : 󰤼
	md_arrow_split_vertical = "\uf093c"
	# CHAR : 󰁛
	md_arrow_top_left = "\uf005b"
	# CHAR : 󱥨
	md_arrow_top_left_bold_box = "\uf1968"
	# CHAR : 󱥩
	md_arrow_top_left_bold_box_outline = "\uf1969"
	# CHAR : 󰧃
	md_arrow_top_left_bold_outline = "\uf09c3"
	# CHAR : 󰹵
	md_arrow_top_left_bottom_right = "\uf0e75"
	# CHAR : 󰹶
	md_arrow_top_left_bottom_right_bold = "\uf0e76"
	# CHAR : 󰧄
	md_arrow_top_left_thick = "\uf09c4"
	# CHAR : 󱦵
	md_arrow_top_left_thin = "\uf19b5"
	# CHAR : 󱖓
	md_arrow_top_left_thin_circle_outline = "\uf1593"
	# CHAR : 󰁜
	md_arrow_top_right = "\uf005c"
	# CHAR : 󱥪
	md_arrow_top_right_bold_box = "\uf196a"
	# CHAR : 󱥫
	md_arrow_top_right_bold_box_outline = "\uf196b"
	# CHAR : 󰧅
	md_arrow_top_right_bold_outline = "\uf09c5"
	# CHAR : 󰹷
	md_arrow_top_right_bottom_left = "\uf0e77"
	# CHAR : 󰹸
	md_arrow_top_right_bottom_left_bold = "\uf0e78"
	# CHAR : 󰧆
	md_arrow_top_right_thick = "\uf09c6"
	# CHAR : 󱦴
	md_arrow_top_right_thin = "\uf19b4"
	# CHAR : 󱖔
	md_arrow_top_right_thin_circle_outline = "\uf1594"
	# CHAR : 󱞭
	md_arrow_u_down_left = "\uf17ad"
	# CHAR : 󱞮
	md_arrow_u_down_left_bold = "\uf17ae"
	# CHAR : 󱞯
	md_arrow_u_down_right = "\uf17af"
	# CHAR : 󱞰
	md_arrow_u_down_right_bold = "\uf17b0"
	# CHAR : 󱞱
	md_arrow_u_left_bottom = "\uf17b1"
	# CHAR : 󱞲
	md_arrow_u_left_bottom_bold = "\uf17b2"
	# CHAR : 󱞳
	md_arrow_u_left_top = "\uf17b3"
	# CHAR : 󱞴
	md_arrow_u_left_top_bold = "\uf17b4"
	# CHAR : 󱞵
	md_arrow_u_right_bottom = "\uf17b5"
	# CHAR : 󱞶
	md_arrow_u_right_bottom_bold = "\uf17b6"
	# CHAR : 󱞷
	md_arrow_u_right_top = "\uf17b7"
	# CHAR : 󱞸
	md_arrow_u_right_top_bold = "\uf17b8"
	# CHAR : 󱞹
	md_arrow_u_up_left = "\uf17b9"
	# CHAR : 󱞺
	md_arrow_u_up_left_bold = "\uf17ba"
	# CHAR : 󱞻
	md_arrow_u_up_right = "\uf17bb"
	# CHAR : 󱞼
	md_arrow_u_up_right_bold = "\uf17bc"
	# CHAR : 󰁝
	md_arrow_up = "\uf005d"
	# CHAR : 󰜷
	md_arrow_up_bold = "\uf0737"
	# CHAR : 󰜸
	md_arrow_up_bold_box = "\uf0738"
	# CHAR : 󰜹
	md_arrow_up_bold_box_outline = "\uf0739"
	# CHAR : 󰁟
	md_arrow_up_bold_circle = "\uf005f"
	# CHAR : 󰁠
	md_arrow_up_bold_circle_outline = "\uf0060"
	# CHAR : 󰁡
	md_arrow_up_bold_hexagon_outline = "\uf0061"
	# CHAR : 󰧇
	md_arrow_up_bold_outline = "\uf09c7"
	# CHAR : 󰛃
	md_arrow_up_box = "\uf06c3"
	# CHAR : 󰳡
	md_arrow_up_circle = "\uf0ce1"
	# CHAR : 󰳢
	md_arrow_up_circle_outline = "\uf0ce2"
	# CHAR : 󰹹
	md_arrow_up_down = "\uf0e79"
	# CHAR : 󰹺
	md_arrow_up_down_bold = "\uf0e7a"
	# CHAR : 󰧈
	md_arrow_up_down_bold_outline = "\uf09c8"
	# CHAR : 󰁢
	md_arrow_up_drop_circle = "\uf0062"
	# CHAR : 󰁣
	md_arrow_up_drop_circle_outline = "\uf0063"
	# CHAR : 󱞽
	md_arrow_up_left = "\uf17bd"
	# CHAR : 󱞾
	md_arrow_up_left_bold = "\uf17be"
	# CHAR : 󱞿
	md_arrow_up_right = "\uf17bf"
	# CHAR : 󱟀
	md_arrow_up_right_bold = "\uf17c0"
	# CHAR : 󰁞
	md_arrow_up_thick = "\uf005e"
	# CHAR : 󱦲
	md_arrow_up_thin = "\uf19b2"
	# CHAR : 󱖗
	md_arrow_up_thin_circle_outline = "\uf1597"
	# CHAR : 󱅜
	md_arrow_vertical_lock = "\uf115c"
	# CHAR : 󰭛
	md_artstation = "\uf0b5b"
	# CHAR : 󰨤
	md_aspect_ratio = "\uf0a24"
	# CHAR : 󰁤
	md_assistant = "\uf0064"
	# CHAR : 󰛄
	md_asterisk = "\uf06c4"
	# CHAR : 󱨧
	md_asterisk_circle_outline = "\uf1a27"
	# CHAR : 󰁥
	md_at = "\uf0065"
	# CHAR : 󰠄
	md_atlassian = "\uf0804"
	# CHAR : 󰵇
	md_atm = "\uf0d47"
	# CHAR : 󰝨
	md_atom = "\uf0768"
	# CHAR : 󰹻
	md_atom_variant = "\uf0e7b"
	# CHAR : 󰁦
	md_attachment = "\uf0066"
	# CHAR : 󱫁
	md_attachment_check = "\uf1ac1"
	# CHAR : 󱧄
	md_attachment_lock = "\uf19c4"
	# CHAR : 󱫂
	md_attachment_minus = "\uf1ac2"
	# CHAR : 󱫃
	md_attachment_off = "\uf1ac3"
	# CHAR : 󱫄
	md_attachment_plus = "\uf1ac4"
	# CHAR : 󱫅
	md_attachment_remove = "\uf1ac5"
	# CHAR : 󱡫
	md_audio_input_rca = "\uf186b"
	# CHAR : 󱡬
	md_audio_input_stereo_minijack = "\uf186c"
	# CHAR : 󱡭
	md_audio_input_xlr = "\uf186d"
	# CHAR : 󰤽
	md_audio_video = "\uf093d"
	# CHAR : 󱆶
	md_audio_video_off = "\uf11b6"
	# CHAR : 󰡐
	md_augmented_reality = "\uf0850"
	# CHAR : 󱍾
	md_auto_download = "\uf137e"
	# CHAR : 󰁨
	md_auto_fix = "\uf0068"
	# CHAR : 󰁩
	md_auto_upload = "\uf0069"
	# CHAR : 󰁪
	md_autorenew = "\uf006a"
	# CHAR : 󱧧
	md_autorenew_off = "\uf19e7"
	# CHAR : 󰁫
	md_av_timer = "\uf006b"
	# CHAR : 󰸏
	md_aws = "\uf0e0f"
	# CHAR : 󰣈
	md_axe = "\uf08c8"
	# CHAR : 󱡂
	md_axe_battle = "\uf1842"
	# CHAR : 󰵈
	md_axis = "\uf0d48"
	# CHAR : 󰵉
	md_axis_arrow = "\uf0d49"
	# CHAR : 󱐎
	md_axis_arrow_info = "\uf140e"
	# CHAR : 󰵊
	md_axis_arrow_lock = "\uf0d4a"
	# CHAR : 󰵋
	md_axis_lock = "\uf0d4b"
	# CHAR : 󰵌
	md_axis_x_arrow = "\uf0d4c"
	# CHAR : 󰵍
	md_axis_x_arrow_lock = "\uf0d4d"
	# CHAR : 󰵎
	md_axis_x_rotate_clockwise = "\uf0d4e"
	# CHAR : 󰵏
	md_axis_x_rotate_counterclockwise = "\uf0d4f"
	# CHAR : 󰵐
	md_axis_x_y_arrow_lock = "\uf0d50"
	# CHAR : 󰵑
	md_axis_y_arrow = "\uf0d51"
	# CHAR : 󰵒
	md_axis_y_arrow_lock = "\uf0d52"
	# CHAR : 󰵓
	md_axis_y_rotate_clockwise = "\uf0d53"
	# CHAR : 󰵔
	md_axis_y_rotate_counterclockwise = "\uf0d54"
	# CHAR : 󰵕
	md_axis_z_arrow = "\uf0d55"
	# CHAR : 󰵖
	md_axis_z_arrow_lock = "\uf0d56"
	# CHAR : 󰵗
	md_axis_z_rotate_clockwise = "\uf0d57"
	# CHAR : 󰵘
	md_axis_z_rotate_counterclockwise = "\uf0d58"
	# CHAR : 󰨥
	md_babel = "\uf0a25"
	# CHAR : 󰁬
	md_baby = "\uf006c"
	# CHAR : 󰼹
	md_baby_bottle = "\uf0f39"
	# CHAR : 󰼺
	md_baby_bottle_outline = "\uf0f3a"
	# CHAR : 󱏠
	md_baby_buggy = "\uf13e0"
	# CHAR : 󰚏
	md_baby_carriage = "\uf068f"
	# CHAR : 󰾠
	md_baby_carriage_off = "\uf0fa0"
	# CHAR : 󰹼
	md_baby_face = "\uf0e7c"
	# CHAR : 󰹽
	md_baby_face_outline = "\uf0e7d"
	# CHAR : 󰁭
	md_backburger = "\uf006d"
	# CHAR : 󰁮
	md_backspace = "\uf006e"
	# CHAR : 󰭜
	md_backspace_outline = "\uf0b5c"
	# CHAR : 󰹾
	md_backspace_reverse = "\uf0e7e"
	# CHAR : 󰹿
	md_backspace_reverse_outline = "\uf0e7f"
	# CHAR : 󰁯
	md_backup_restore = "\uf006f"
	# CHAR : 󰻕
	md_bacteria = "\uf0ed5"
	# CHAR : 󰻖
	md_bacteria_outline = "\uf0ed6"
	# CHAR : 󰶧
	md_badge_account = "\uf0da7"
	# CHAR : 󰶨
	md_badge_account_alert = "\uf0da8"
	# CHAR : 󰶩
	md_badge_account_alert_outline = "\uf0da9"
	# CHAR : 󰸍
	md_badge_account_horizontal = "\uf0e0d"
	# CHAR : 󰸎
	md_badge_account_horizontal_outline = "\uf0e0e"
	# CHAR : 󰶪
	md_badge_account_outline = "\uf0daa"
	# CHAR : 󰡑
	md_badminton = "\uf0851"
	# CHAR : 󰼻
	md_bag_carry_on = "\uf0f3b"
	# CHAR : 󰵥
	md_bag_carry_on_check = "\uf0d65"
	# CHAR : 󰼼
	md_bag_carry_on_off = "\uf0f3c"
	# CHAR : 󰼽
	md_bag_checked = "\uf0f3d"
	# CHAR : 󰸐
	md_bag_personal = "\uf0e10"
	# CHAR : 󰸑
	md_bag_personal_off = "\uf0e11"
	# CHAR : 󰸒
	md_bag_personal_off_outline = "\uf0e12"
	# CHAR : 󰸓
	md_bag_personal_outline = "\uf0e13"
	# CHAR : 󱖋
	md_bag_suitcase = "\uf158b"
	# CHAR : 󱖍
	md_bag_suitcase_off = "\uf158d"
	# CHAR : 󱖎
	md_bag_suitcase_off_outline = "\uf158e"
	# CHAR : 󱖌
	md_bag_suitcase_outline = "\uf158c"
	# CHAR : 󰼾
	md_baguette = "\uf0f3e"
	# CHAR : 󱠗
	md_balcony = "\uf1817"
	# CHAR : 󰨦
	md_balloon = "\uf0a26"
	# CHAR : 󰧉
	md_ballot = "\uf09c9"
	# CHAR : 󰧊
	md_ballot_outline = "\uf09ca"
	# CHAR : 󰰹
	md_ballot_recount = "\uf0c39"
	# CHAR : 󰰺
	md_ballot_recount_outline = "\uf0c3a"
	# CHAR : 󰶯
	md_bandage = "\uf0daf"
	# CHAR : 󰁰
	md_bank = "\uf0070"
	# CHAR : 󱙕
	md_bank_check = "\uf1655"
	# CHAR : 󰶰
	md_bank_minus = "\uf0db0"
	# CHAR : 󱙖
	md_bank_off = "\uf1656"
	# CHAR : 󱙗
	md_bank_off_outline = "\uf1657"
	# CHAR : 󰺀
	md_bank_outline = "\uf0e80"
	# CHAR : 󰶱
	md_bank_plus = "\uf0db1"
	# CHAR : 󰶲
	md_bank_remove = "\uf0db2"
	# CHAR : 󰨧
	md_bank_transfer = "\uf0a27"
	# CHAR : 󰨨
	md_bank_transfer_in = "\uf0a28"
	# CHAR : 󰨩
	md_bank_transfer_out = "\uf0a29"
	# CHAR : 󰁱
	md_barcode = "\uf0071"
	# CHAR : 󱈶
	md_barcode_off = "\uf1236"
	# CHAR : 󰁲
	md_barcode_scan = "\uf0072"
	# CHAR : 󰁳
	md_barley = "\uf0073"
	# CHAR : 󰭝
	md_barley_off = "\uf0b5d"
	# CHAR : 󰭞
	md_barn = "\uf0b5e"
	# CHAR : 󰁴
	md_barrel = "\uf0074"
	# CHAR : 󱨨
	md_barrel_outline = "\uf1a28"
	# CHAR : 󰡒
	md_baseball = "\uf0852"
	# CHAR : 󰡓
	md_baseball_bat = "\uf0853"
	# CHAR : 󱗬
	md_baseball_diamond = "\uf15ec"
	# CHAR : 󱗭
	md_baseball_diamond_outline = "\uf15ed"
	# CHAR : 󱆃
	md_bash = "\uf1183"
	# CHAR : 󰁶
	md_basket = "\uf0076"
	# CHAR : 󱣥
	md_basket_check = "\uf18e5"
	# CHAR : 󱣦
	md_basket_check_outline = "\uf18e6"
	# CHAR : 󰁷
	md_basket_fill = "\uf0077"
	# CHAR : 󱔣
	md_basket_minus = "\uf1523"
	# CHAR : 󱔤
	md_basket_minus_outline = "\uf1524"
	# CHAR : 󱔥
	md_basket_off = "\uf1525"
	# CHAR : 󱔦
	md_basket_off_outline = "\uf1526"
	# CHAR : 󱆁
	md_basket_outline = "\uf1181"
	# CHAR : 󱔧
	md_basket_plus = "\uf1527"
	# CHAR : 󱔨
	md_basket_plus_outline = "\uf1528"
	# CHAR : 󱔩
	md_basket_remove = "\uf1529"
	# CHAR : 󱔪
	md_basket_remove_outline = "\uf152a"
	# CHAR : 󰁸
	md_basket_unfill = "\uf0078"
	# CHAR : 󰠆
	md_basketball = "\uf0806"
	# CHAR : 󰰻
	md_basketball_hoop = "\uf0c3b"
	# CHAR : 󰰼
	md_basketball_hoop_outline = "\uf0c3c"
	# CHAR : 󰭟
	md_bat = "\uf0b5f"
	# CHAR : 󱠘
	md_bathtub = "\uf1818"
	# CHAR : 󱠙
	md_bathtub_outline = "\uf1819"
	# CHAR : 󰁹
	md_battery = "\uf0079"
	# CHAR : 󰁺
	md_battery_10 = "\uf007a"
	# CHAR : 󰤾
	md_battery_10_bluetooth = "\uf093e"
	# CHAR : 󰁻
	md_battery_20 = "\uf007b"
	# CHAR : 󰤿
	md_battery_20_bluetooth = "\uf093f"
	# CHAR : 󰁼
	md_battery_30 = "\uf007c"
	# CHAR : 󰥀
	md_battery_30_bluetooth = "\uf0940"
	# CHAR : 󰁽
	md_battery_40 = "\uf007d"
	# CHAR : 󰥁
	md_battery_40_bluetooth = "\uf0941"
	# CHAR : 󰁾
	md_battery_50 = "\uf007e"
	# CHAR : 󰥂
	md_battery_50_bluetooth = "\uf0942"
	# CHAR : 󰁿
	md_battery_60 = "\uf007f"
	# CHAR : 󰥃
	md_battery_60_bluetooth = "\uf0943"
	# CHAR : 󰂀
	md_battery_70 = "\uf0080"
	# CHAR : 󰥄
	md_battery_70_bluetooth = "\uf0944"
	# CHAR : 󰂁
	md_battery_80 = "\uf0081"
	# CHAR : 󰥅
	md_battery_80_bluetooth = "\uf0945"
	# CHAR : 󰂂
	md_battery_90 = "\uf0082"
	# CHAR : 󰥆
	md_battery_90_bluetooth = "\uf0946"
	# CHAR : 󰂃
	md_battery_alert = "\uf0083"
	# CHAR : 󰥇
	md_battery_alert_bluetooth = "\uf0947"
	# CHAR : 󱃌
	md_battery_alert_variant = "\uf10cc"
	# CHAR : 󱃍
	md_battery_alert_variant_outline = "\uf10cd"
	# CHAR : 󱟞
	md_battery_arrow_down = "\uf17de"
	# CHAR : 󱟟
	md_battery_arrow_down_outline = "\uf17df"
	# CHAR : 󱟠
	md_battery_arrow_up = "\uf17e0"
	# CHAR : 󱟡
	md_battery_arrow_up_outline = "\uf17e1"
	# CHAR : 󰥈
	md_battery_bluetooth = "\uf0948"
	# CHAR : 󰥉
	md_battery_bluetooth_variant = "\uf0949"
	# CHAR : 󰂄
	md_battery_charging = "\uf0084"
	# CHAR : 󰢜
	md_battery_charging_10 = "\uf089c"
	# CHAR : 󰂅
	md_battery_charging_100 = "\uf0085"
	# CHAR : 󰂆
	md_battery_charging_20 = "\uf0086"
	# CHAR : 󰂇
	md_battery_charging_30 = "\uf0087"
	# CHAR : 󰂈
	md_battery_charging_40 = "\uf0088"
	# CHAR : 󰢝
	md_battery_charging_50 = "\uf089d"
	# CHAR : 󰂉
	md_battery_charging_60 = "\uf0089"
	# CHAR : 󰢞
	md_battery_charging_70 = "\uf089e"
	# CHAR : 󰂊
	md_battery_charging_80 = "\uf008a"
	# CHAR : 󰂋
	md_battery_charging_90 = "\uf008b"
	# CHAR : 󱊦
	md_battery_charging_high = "\uf12a6"
	# CHAR : 󱊤
	md_battery_charging_low = "\uf12a4"
	# CHAR : 󱊥
	md_battery_charging_medium = "\uf12a5"
	# CHAR : 󰢟
	md_battery_charging_outline = "\uf089f"
	# CHAR : 󰠇
	md_battery_charging_wireless = "\uf0807"
	# CHAR : 󰠈
	md_battery_charging_wireless_10 = "\uf0808"
	# CHAR : 󰠉
	md_battery_charging_wireless_20 = "\uf0809"
	# CHAR : 󰠊
	md_battery_charging_wireless_30 = "\uf080a"
	# CHAR : 󰠋
	md_battery_charging_wireless_40 = "\uf080b"
	# CHAR : 󰠌
	md_battery_charging_wireless_50 = "\uf080c"
	# CHAR : 󰠍
	md_battery_charging_wireless_60 = "\uf080d"
	# CHAR : 󰠎
	md_battery_charging_wireless_70 = "\uf080e"
	# CHAR : 󰠏
	md_battery_charging_wireless_80 = "\uf080f"
	# CHAR : 󰠐
	md_battery_charging_wireless_90 = "\uf0810"
	# CHAR : 󰠑
	md_battery_charging_wireless_alert = "\uf0811"
	# CHAR : 󰠒
	md_battery_charging_wireless_outline = "\uf0812"
	# CHAR : 󱟢
	md_battery_check = "\uf17e2"
	# CHAR : 󱟣
	md_battery_check_outline = "\uf17e3"
	# CHAR : 󱧥
	md_battery_clock = "\uf19e5"
	# CHAR : 󱧦
	md_battery_clock_outline = "\uf19e6"
	# CHAR : 󱈏
	md_battery_heart = "\uf120f"
	# CHAR : 󱈐
	md_battery_heart_outline = "\uf1210"
	# CHAR : 󱈑
	md_battery_heart_variant = "\uf1211"
	# CHAR : 󱊣
	md_battery_high = "\uf12a3"
	# CHAR : 󱞜
	md_battery_lock = "\uf179c"
	# CHAR : 󱞝
	md_battery_lock_open = "\uf179d"
	# CHAR : 󱊡
	md_battery_low = "\uf12a1"
	# CHAR : 󱊢
	md_battery_medium = "\uf12a2"
	# CHAR : 󱟤
	md_battery_minus = "\uf17e4"
	# CHAR : 󱟥
	md_battery_minus_outline = "\uf17e5"
	# CHAR : 󰂌
	md_battery_minus_variant = "\uf008c"
	# CHAR : 󰂍
	md_battery_negative = "\uf008d"
	# CHAR : 󱉝
	md_battery_off = "\uf125d"
	# CHAR : 󱉞
	md_battery_off_outline = "\uf125e"
	# CHAR : 󰂎
	md_battery_outline = "\uf008e"
	# CHAR : 󱟦
	md_battery_plus = "\uf17e6"
	# CHAR : 󱟧
	md_battery_plus_outline = "\uf17e7"
	# CHAR : 󰂏
	md_battery_plus_variant = "\uf008f"
	# CHAR : 󰂐
	md_battery_positive = "\uf0090"
	# CHAR : 󱟨
	md_battery_remove = "\uf17e8"
	# CHAR : 󱟩
	md_battery_remove_outline = "\uf17e9"
	# CHAR : 󱠴
	md_battery_sync = "\uf1834"
	# CHAR : 󱠵
	md_battery_sync_outline = "\uf1835"
	# CHAR : 󰂑
	md_battery_unknown = "\uf0091"
	# CHAR : 󰥊
	md_battery_unknown_bluetooth = "\uf094a"
	# CHAR : 󰂒
	md_beach = "\uf0092"
	# CHAR : 󰳪
	md_beaker = "\uf0cea"
	# CHAR : 󱈩
	md_beaker_alert = "\uf1229"
	# CHAR : 󱈪
	md_beaker_alert_outline = "\uf122a"
	# CHAR : 󱈫
	md_beaker_check = "\uf122b"
	# CHAR : 󱈬
	md_beaker_check_outline = "\uf122c"
	# CHAR : 󱈭
	md_beaker_minus = "\uf122d"
	# CHAR : 󱈮
	md_beaker_minus_outline = "\uf122e"
	# CHAR : 󰚐
	md_beaker_outline = "\uf0690"
	# CHAR : 󱈯
	md_beaker_plus = "\uf122f"
	# CHAR : 󱈰
	md_beaker_plus_outline = "\uf1230"
	# CHAR : 󱈱
	md_beaker_question = "\uf1231"
	# CHAR : 󱈲
	md_beaker_question_outline = "\uf1232"
	# CHAR : 󱈳
	md_beaker_remove = "\uf1233"
	# CHAR : 󱈴
	md_beaker_remove_outline = "\uf1234"
	# CHAR : 󰋣
	md_bed = "\uf02e3"
	# CHAR : 󰿔
	md_bed_double = "\uf0fd4"
	# CHAR : 󰿓
	md_bed_double_outline = "\uf0fd3"
	# CHAR : 󰢠
	md_bed_empty = "\uf08a0"
	# CHAR : 󰿒
	md_bed_king = "\uf0fd2"
	# CHAR : 󰿑
	md_bed_king_outline = "\uf0fd1"
	# CHAR : 󰂙
	md_bed_outline = "\uf0099"
	# CHAR : 󰿐
	md_bed_queen = "\uf0fd0"
	# CHAR : 󰿛
	md_bed_queen_outline = "\uf0fdb"
	# CHAR : 󱁭
	md_bed_single = "\uf106d"
	# CHAR : 󱁮
	md_bed_single_outline = "\uf106e"
	# CHAR : 󰾡
	md_bee = "\uf0fa1"
	# CHAR : 󰾢
	md_bee_flower = "\uf0fa2"
	# CHAR : 󱏭
	md_beehive_off_outline = "\uf13ed"
	# CHAR : 󱃎
	md_beehive_outline = "\uf10ce"
	# CHAR : 󱓢
	md_beekeeper = "\uf14e2"
	# CHAR : 󰂘
	md_beer = "\uf0098"
	# CHAR : 󱌌
	md_beer_outline = "\uf130c"
	# CHAR : 󰂚
	md_bell = "\uf009a"
	# CHAR : 󰵙
	md_bell_alert = "\uf0d59"
	# CHAR : 󰺁
	md_bell_alert_outline = "\uf0e81"
	# CHAR : 󱅫
	md_bell_badge = "\uf116b"
	# CHAR : 󰅸
	md_bell_badge_outline = "\uf0178"
	# CHAR : 󱏧
	md_bell_cancel = "\uf13e7"
	# CHAR : 󱏨
	md_bell_cancel_outline = "\uf13e8"
	# CHAR : 󱇥
	md_bell_check = "\uf11e5"
	# CHAR : 󱇦
	md_bell_check_outline = "\uf11e6"
	# CHAR : 󰵚
	md_bell_circle = "\uf0d5a"
	# CHAR : 󰵛
	md_bell_circle_outline = "\uf0d5b"
	# CHAR : 󱨩
	md_bell_cog = "\uf1a29"
	# CHAR : 󱨪
	md_bell_cog_outline = "\uf1a2a"
	# CHAR : 󱏩
	md_bell_minus = "\uf13e9"
	# CHAR : 󱏪
	md_bell_minus_outline = "\uf13ea"
	# CHAR : 󰂛
	md_bell_off = "\uf009b"
	# CHAR : 󰪑
	md_bell_off_outline = "\uf0a91"
	# CHAR : 󰂜
	md_bell_outline = "\uf009c"
	# CHAR : 󰂝
	md_bell_plus = "\uf009d"
	# CHAR : 󰪒
	md_bell_plus_outline = "\uf0a92"
	# CHAR : 󱏫
	md_bell_remove = "\uf13eb"
	# CHAR : 󱏬
	md_bell_remove_outline = "\uf13ec"
	# CHAR : 󰂞
	md_bell_ring = "\uf009e"
	# CHAR : 󰂟
	md_bell_ring_outline = "\uf009f"
	# CHAR : 󰂠
	md_bell_sleep = "\uf00a0"
	# CHAR : 󰪓
	md_bell_sleep_outline = "\uf0a93"
	# CHAR : 󰂡
	md_beta = "\uf00a1"
	# CHAR : 󰧋
	md_betamax = "\uf09cb"
	# CHAR : 󰸔
	md_biathlon = "\uf0e14"
	# CHAR : 󱂜
	md_bicycle = "\uf109c"
	# CHAR : 󱈵
	md_bicycle_basket = "\uf1235"
	# CHAR : 󱢜
	md_bicycle_cargo = "\uf189c"
	# CHAR : 󱖴
	md_bicycle_electric = "\uf15b4"
	# CHAR : 󱗩
	md_bicycle_penny_farthing = "\uf15e9"
	# CHAR : 󰂣
	md_bike = "\uf00a3"
	# CHAR : 󱄟
	md_bike_fast = "\uf111f"
	# CHAR : 󱀐
	md_billboard = "\uf1010"
	# CHAR : 󰭡
	md_billiards = "\uf0b61"
	# CHAR : 󰭢
	md_billiards_rack = "\uf0b62"
	# CHAR : 󰂥
	md_binoculars = "\uf00a5"
	# CHAR : 󰂦
	md_bio = "\uf00a6"
	# CHAR : 󰂧
	md_biohazard = "\uf00a7"
	# CHAR : 󱗆
	md_bird = "\uf15c6"
	# CHAR : 󰂨
	md_bitbucket = "\uf00a8"
	# CHAR : 󰠓
	md_bitcoin = "\uf0813"
	# CHAR : 󰂩
	md_black_mesa = "\uf00a9"
	# CHAR : 󰳫
	md_blender = "\uf0ceb"
	# CHAR : 󱠚
	md_blender_outline = "\uf181a"
	# CHAR : 󰂫
	md_blender_software = "\uf00ab"
	# CHAR : 󰂬
	md_blinds = "\uf00ac"
	# CHAR : 󱨫
	md_blinds_horizontal = "\uf1a2b"
	# CHAR : 󱨬
	md_blinds_horizontal_closed = "\uf1a2c"
	# CHAR : 󱀑
	md_blinds_open = "\uf1011"
	# CHAR : 󱨭
	md_blinds_vertical = "\uf1a2d"
	# CHAR : 󱨮
	md_blinds_vertical_closed = "\uf1a2e"
	# CHAR : 󰂭
	md_block_helper = "\uf00ad"
	# CHAR : 󰳬
	md_blood_bag = "\uf0cec"
	# CHAR : 󰂯
	md_bluetooth = "\uf00af"
	# CHAR : 󰂰
	md_bluetooth_audio = "\uf00b0"
	# CHAR : 󰂱
	md_bluetooth_connect = "\uf00b1"
	# CHAR : 󰂲
	md_bluetooth_off = "\uf00b2"
	# CHAR : 󰂳
	md_bluetooth_settings = "\uf00b3"
	# CHAR : 󰂴
	md_bluetooth_transfer = "\uf00b4"
	# CHAR : 󰂵
	md_blur = "\uf00b5"
	# CHAR : 󰂶
	md_blur_linear = "\uf00b6"
	# CHAR : 󰂷
	md_blur_off = "\uf00b7"
	# CHAR : 󰂸
	md_blur_radial = "\uf00b8"
	# CHAR : 󰶳
	md_bolt = "\uf0db3"
	# CHAR : 󰚑
	md_bomb = "\uf0691"
	# CHAR : 󰛅
	md_bomb_off = "\uf06c5"
	# CHAR : 󰂹
	md_bone = "\uf00b9"
	# CHAR : 󱧠
	md_bone_off = "\uf19e0"
	# CHAR : 󰂺
	md_book = "\uf00ba"
	# CHAR : 󱎭
	md_book_account = "\uf13ad"
	# CHAR : 󱎮
	md_book_account_outline = "\uf13ae"
	# CHAR : 󱙼
	md_book_alert = "\uf167c"
	# CHAR : 󱙽
	md_book_alert_outline = "\uf167d"
	# CHAR : 󰘝
	md_book_alphabet = "\uf061d"
	# CHAR : 󱙾
	md_book_arrow_down = "\uf167e"
	# CHAR : 󱙿
	md_book_arrow_down_outline = "\uf167f"
	# CHAR : 󱚀
	md_book_arrow_left = "\uf1680"
	# CHAR : 󱚁
	md_book_arrow_left_outline = "\uf1681"
	# CHAR : 󱚂
	md_book_arrow_right = "\uf1682"
	# CHAR : 󱚃
	md_book_arrow_right_outline = "\uf1683"
	# CHAR : 󱚄
	md_book_arrow_up = "\uf1684"
	# CHAR : 󱚅
	md_book_arrow_up_outline = "\uf1685"
	# CHAR : 󱚆
	md_book_cancel = "\uf1686"
	# CHAR : 󱚇
	md_book_cancel_outline = "\uf1687"
	# CHAR : 󱓳
	md_book_check = "\uf14f3"
	# CHAR : 󱓴
	md_book_check_outline = "\uf14f4"
	# CHAR : 󱚈
	md_book_clock = "\uf1688"
	# CHAR : 󱚉
	md_book_clock_outline = "\uf1689"
	# CHAR : 󱚊
	md_book_cog = "\uf168a"
	# CHAR : 󱚋
	md_book_cog_outline = "\uf168b"
	# CHAR : 󰂢
	md_book_cross = "\uf00a2"
	# CHAR : 󱚌
	md_book_edit = "\uf168c"
	# CHAR : 󱚍
	md_book_edit_outline = "\uf168d"
	# CHAR : 󱛉
	md_book_education = "\uf16c9"
	# CHAR : 󱛊
	md_book_education_outline = "\uf16ca"
	# CHAR : 󱨝
	md_book_heart = "\uf1a1d"
	# CHAR : 󱨞
	md_book_heart_outline = "\uf1a1e"
	# CHAR : 󱁯
	md_book_information_variant = "\uf106f"
	# CHAR : 󰞚
	md_book_lock = "\uf079a"
	# CHAR : 󰞛
	md_book_lock_open = "\uf079b"
	# CHAR : 󱚎
	md_book_lock_open_outline = "\uf168e"
	# CHAR : 󱚏
	md_book_lock_outline = "\uf168f"
	# CHAR : 󱚐
	md_book_marker = "\uf1690"
	# CHAR : 󱚑
	md_book_marker_outline = "\uf1691"
	# CHAR : 󰗙
	md_book_minus = "\uf05d9"
	# CHAR : 󰪔
	md_book_minus_multiple = "\uf0a94"
	# CHAR : 󰤋
	md_book_minus_multiple_outline = "\uf090b"
	# CHAR : 󱚒
	md_book_minus_outline = "\uf1692"
	# CHAR : 󰂻
	md_book_multiple = "\uf00bb"
	# CHAR : 󰐶
	md_book_multiple_outline = "\uf0436"
	# CHAR : 󰁧
	md_book_music = "\uf0067"
	# CHAR : 󱚓
	md_book_music_outline = "\uf1693"
	# CHAR : 󱚔
	md_book_off = "\uf1694"
	# CHAR : 󱚕
	md_book_off_outline = "\uf1695"
	# CHAR : 󰂽
	md_book_open = "\uf00bd"
	# CHAR : 󰂾
	md_book_open_blank_variant = "\uf00be"
	# CHAR : 󰭣
	md_book_open_outline = "\uf0b63"
	# CHAR : 󰗚
	md_book_open_page_variant = "\uf05da"
	# CHAR : 󱗖
	md_book_open_page_variant_outline = "\uf15d6"
	# CHAR : 󱓷
	md_book_open_variant = "\uf14f7"
	# CHAR : 󰭤
	md_book_outline = "\uf0b64"
	# CHAR : 󰺂
	md_book_play = "\uf0e82"
	# CHAR : 󰺃
	md_book_play_outline = "\uf0e83"
	# CHAR : 󰗛
	md_book_plus = "\uf05db"
	# CHAR : 󰪕
	md_book_plus_multiple = "\uf0a95"
	# CHAR : 󰫞
	md_book_plus_multiple_outline = "\uf0ade"
	# CHAR : 󱚖
	md_book_plus_outline = "\uf1696"
	# CHAR : 󱚗
	md_book_refresh = "\uf1697"
	# CHAR : 󱚘
	md_book_refresh_outline = "\uf1698"
	# CHAR : 󰪗
	md_book_remove = "\uf0a97"
	# CHAR : 󰪖
	md_book_remove_multiple = "\uf0a96"
	# CHAR : 󰓊
	md_book_remove_multiple_outline = "\uf04ca"
	# CHAR : 󱚙
	md_book_remove_outline = "\uf1699"
	# CHAR : 󰺄
	md_book_search = "\uf0e84"
	# CHAR : 󰺅
	md_book_search_outline = "\uf0e85"
	# CHAR : 󱚚
	md_book_settings = "\uf169a"
	# CHAR : 󱚛
	md_book_settings_outline = "\uf169b"
	# CHAR : 󱚜
	md_book_sync = "\uf169c"
	# CHAR : 󱛈
	md_book_sync_outline = "\uf16c8"
	# CHAR : 󰂿
	md_book_variant = "\uf00bf"
	# CHAR : 󰂼
	md_book_variant_multiple = "\uf00bc"
	# CHAR : 󰃀
	md_bookmark = "\uf00c0"
	# CHAR : 󱥬
	md_bookmark_box_multiple = "\uf196c"
	# CHAR : 󱥭
	md_bookmark_box_multiple_outline = "\uf196d"
	# CHAR : 󰃁
	md_bookmark_check = "\uf00c1"
	# CHAR : 󱍻
	md_bookmark_check_outline = "\uf137b"
	# CHAR : 󰧌
	md_bookmark_minus = "\uf09cc"
	# CHAR : 󰧍
	md_bookmark_minus_outline = "\uf09cd"
	# CHAR : 󰸕
	md_bookmark_multiple = "\uf0e15"
	# CHAR : 󰸖
	md_bookmark_multiple_outline = "\uf0e16"
	# CHAR : 󰃂
	md_bookmark_music = "\uf00c2"
	# CHAR : 󱍹
	md_bookmark_music_outline = "\uf1379"
	# CHAR : 󰧎
	md_bookmark_off = "\uf09ce"
	# CHAR : 󰧏
	md_bookmark_off_outline = "\uf09cf"
	# CHAR : 󰃃
	md_bookmark_outline = "\uf00c3"
	# CHAR : 󰃅
	md_bookmark_plus = "\uf00c5"
	# CHAR : 󰃄
	md_bookmark_plus_outline = "\uf00c4"
	# CHAR : 󰃆
	md_bookmark_remove = "\uf00c6"
	# CHAR : 󱍺
	md_bookmark_remove_outline = "\uf137a"
	# CHAR : 󱉟
	md_bookshelf = "\uf125f"
	# CHAR : 󰺆
	md_boom_gate = "\uf0e86"
	# CHAR : 󰺇
	md_boom_gate_alert = "\uf0e87"
	# CHAR : 󰺈
	md_boom_gate_alert_outline = "\uf0e88"
	# CHAR : 󰺉
	md_boom_gate_arrow_down = "\uf0e89"
	# CHAR : 󰺊
	md_boom_gate_arrow_down_outline = "\uf0e8a"
	# CHAR : 󰺌
	md_boom_gate_arrow_up = "\uf0e8c"
	# CHAR : 󰺍
	md_boom_gate_arrow_up_outline = "\uf0e8d"
	# CHAR : 󰺋
	md_boom_gate_outline = "\uf0e8b"
	# CHAR : 󱟹
	md_boom_gate_up = "\uf17f9"
	# CHAR : 󱟺
	md_boom_gate_up_outline = "\uf17fa"
	# CHAR : 󰗜
	md_boombox = "\uf05dc"
	# CHAR : 󱃏
	md_boomerang = "\uf10cf"
	# CHAR : 󰛆
	md_bootstrap = "\uf06c6"
	# CHAR : 󰃇
	md_border_all = "\uf00c7"
	# CHAR : 󰢡
	md_border_all_variant = "\uf08a1"
	# CHAR : 󰃈
	md_border_bottom = "\uf00c8"
	# CHAR : 󰢢
	md_border_bottom_variant = "\uf08a2"
	# CHAR : 󰃉
	md_border_color = "\uf00c9"
	# CHAR : 󰃊
	md_border_horizontal = "\uf00ca"
	# CHAR : 󰃋
	md_border_inside = "\uf00cb"
	# CHAR : 󰃌
	md_border_left = "\uf00cc"
	# CHAR : 󰢣
	md_border_left_variant = "\uf08a3"
	# CHAR : 󰃍
	md_border_none = "\uf00cd"
	# CHAR : 󰢤
	md_border_none_variant = "\uf08a4"
	# CHAR : 󰃎
	md_border_outside = "\uf00ce"
	# CHAR : 󰃏
	md_border_right = "\uf00cf"
	# CHAR : 󰢥
	md_border_right_variant = "\uf08a5"
	# CHAR : 󰃐
	md_border_style = "\uf00d0"
	# CHAR : 󰃑
	md_border_top = "\uf00d1"
	# CHAR : 󰢦
	md_border_top_variant = "\uf08a6"
	# CHAR : 󰃒
	md_border_vertical = "\uf00d2"
	# CHAR : 󱁰
	md_bottle_soda = "\uf1070"
	# CHAR : 󱁱
	md_bottle_soda_classic = "\uf1071"
	# CHAR : 󱍣
	md_bottle_soda_classic_outline = "\uf1363"
	# CHAR : 󱁲
	md_bottle_soda_outline = "\uf1072"
	# CHAR : 󱄮
	md_bottle_tonic = "\uf112e"
	# CHAR : 󱄯
	md_bottle_tonic_outline = "\uf112f"
	# CHAR : 󱄰
	md_bottle_tonic_plus = "\uf1130"
	# CHAR : 󱄱
	md_bottle_tonic_plus_outline = "\uf1131"
	# CHAR : 󱄲
	md_bottle_tonic_skull = "\uf1132"
	# CHAR : 󱄳
	md_bottle_tonic_skull_outline = "\uf1133"
	# CHAR : 󰡔
	md_bottle_wine = "\uf0854"
	# CHAR : 󱌐
	md_bottle_wine_outline = "\uf1310"
	# CHAR : 󱡁
	md_bow_arrow = "\uf1841"
	# CHAR : 󰙸
	md_bow_tie = "\uf0678"
	# CHAR : 󰊎
	md_bowl = "\uf028e"
	# CHAR : 󰘗
	md_bowl_mix = "\uf0617"
	# CHAR : 󰋤
	md_bowl_mix_outline = "\uf02e4"
	# CHAR : 󰊩
	md_bowl_outline = "\uf02a9"
	# CHAR : 󰃓
	md_bowling = "\uf00d3"
	# CHAR : 󰃔
	md_box = "\uf00d4"
	# CHAR : 󰃕
	md_box_cutter = "\uf00d5"
	# CHAR : 󰭊
	md_box_cutter_off = "\uf0b4a"
	# CHAR : 󰘷
	md_box_shadow = "\uf0637"
	# CHAR : 󰭥
	md_boxing_glove = "\uf0b65"
	# CHAR : 󰧐
	md_braille = "\uf09d0"
	# CHAR : 󰧑
	md_brain = "\uf09d1"
	# CHAR : 󰳮
	md_bread_slice = "\uf0cee"
	# CHAR : 󰳯
	md_bread_slice_outline = "\uf0cef"
	# CHAR : 󰘘
	md_bridge = "\uf0618"
	# CHAR : 󰃖
	md_briefcase = "\uf00d6"
	# CHAR : 󰳰
	md_briefcase_account = "\uf0cf0"
	# CHAR : 󰳱
	md_briefcase_account_outline = "\uf0cf1"
	# CHAR : 󱪍
	md_briefcase_arrow_left_right = "\uf1a8d"
	# CHAR : 󱪎
	md_briefcase_arrow_left_right_outline = "\uf1a8e"
	# CHAR : 󱪏
	md_briefcase_arrow_up_down = "\uf1a8f"
	# CHAR : 󱪐
	md_briefcase_arrow_up_down_outline = "\uf1a90"
	# CHAR : 󰃗
	md_briefcase_check = "\uf00d7"
	# CHAR : 󱌞
	md_briefcase_check_outline = "\uf131e"
	# CHAR : 󱃐
	md_briefcase_clock = "\uf10d0"
	# CHAR : 󱃑
	md_briefcase_clock_outline = "\uf10d1"
	# CHAR : 󰃘
	md_briefcase_download = "\uf00d8"
	# CHAR : 󰰽
	md_briefcase_download_outline = "\uf0c3d"
	# CHAR : 󰪘
	md_briefcase_edit = "\uf0a98"
	# CHAR : 󰰾
	md_briefcase_edit_outline = "\uf0c3e"
	# CHAR : 󱟙
	md_briefcase_eye = "\uf17d9"
	# CHAR : 󱟚
	md_briefcase_eye_outline = "\uf17da"
	# CHAR : 󰨪
	md_briefcase_minus = "\uf0a2a"
	# CHAR : 󰰿
	md_briefcase_minus_outline = "\uf0c3f"
	# CHAR : 󱙘
	md_briefcase_off = "\uf1658"
	# CHAR : 󱙙
	md_briefcase_off_outline = "\uf1659"
	# CHAR : 󰠔
	md_briefcase_outline = "\uf0814"
	# CHAR : 󰨫
	md_briefcase_plus = "\uf0a2b"
	# CHAR : 󰱀
	md_briefcase_plus_outline = "\uf0c40"
	# CHAR : 󰨬
	md_briefcase_remove = "\uf0a2c"
	# CHAR : 󰱁
	md_briefcase_remove_outline = "\uf0c41"
	# CHAR : 󰨭
	md_briefcase_search = "\uf0a2d"
	# CHAR : 󰱂
	md_briefcase_search_outline = "\uf0c42"
	# CHAR : 󰃙
	md_briefcase_upload = "\uf00d9"
	# CHAR : 󰱃
	md_briefcase_upload_outline = "\uf0c43"
	# CHAR : 󱒔
	md_briefcase_variant = "\uf1494"
	# CHAR : 󱙚
	md_briefcase_variant_off = "\uf165a"
	# CHAR : 󱙛
	md_briefcase_variant_off_outline = "\uf165b"
	# CHAR : 󱒕
	md_briefcase_variant_outline = "\uf1495"
	# CHAR : 󰃚
	md_brightness_1 = "\uf00da"
	# CHAR : 󰃛
	md_brightness_2 = "\uf00db"
	# CHAR : 󰃜
	md_brightness_3 = "\uf00dc"
	# CHAR : 󰃝
	md_brightness_4 = "\uf00dd"
	# CHAR : 󰃞
	md_brightness_5 = "\uf00de"
	# CHAR : 󰃟
	md_brightness_6 = "\uf00df"
	# CHAR : 󰃠
	md_brightness_7 = "\uf00e0"
	# CHAR : 󰃡
	md_brightness_auto = "\uf00e1"
	# CHAR : 󰳲
	md_brightness_percent = "\uf0cf2"
	# CHAR : 󱜠
	md_broadcast = "\uf1720"
	# CHAR : 󱜡
	md_broadcast_off = "\uf1721"
	# CHAR : 󰃢
	md_broom = "\uf00e2"
	# CHAR : 󰃣
	md_brush = "\uf00e3"
	# CHAR : 󱝱
	md_brush_off = "\uf1771"
	# CHAR : 󱨍
	md_brush_outline = "\uf1a0d"
	# CHAR : 󱠓
	md_brush_variant = "\uf1813"
	# CHAR : 󱐕
	md_bucket = "\uf1415"
	# CHAR : 󱐖
	md_bucket_outline = "\uf1416"
	# CHAR : 󰕸
	md_buffet = "\uf0578"
	# CHAR : 󰃤
	md_bug = "\uf00e4"
	# CHAR : 󰨮
	md_bug_check = "\uf0a2e"
	# CHAR : 󰨯
	md_bug_check_outline = "\uf0a2f"
	# CHAR : 󰨰
	md_bug_outline = "\uf0a30"
	# CHAR : 󰶴
	md_bugle = "\uf0db4"
	# CHAR : 󱨯
	md_bulkhead_light = "\uf1a2f"
	# CHAR : 󰬢
	md_bulldozer = "\uf0b22"
	# CHAR : 󰳳
	md_bullet = "\uf0cf3"
	# CHAR : 󰃥
	md_bulletin_board = "\uf00e5"
	# CHAR : 󰃦
	md_bullhorn = "\uf00e6"
	# CHAR : 󰬣
	md_bullhorn_outline = "\uf0b23"
	# CHAR : 󱥮
	md_bullhorn_variant = "\uf196e"
	# CHAR : 󱥯
	md_bullhorn_variant_outline = "\uf196f"
	# CHAR : 󰗝
	md_bullseye = "\uf05dd"
	# CHAR : 󰣉
	md_bullseye_arrow = "\uf08c9"
	# CHAR : 󱋧
	md_bulma = "\uf12e7"
	# CHAR : 󱌂
	md_bunk_bed = "\uf1302"
	# CHAR : 󰂗
	md_bunk_bed_outline = "\uf0097"
	# CHAR : 󰃧
	md_bus = "\uf00e7"
	# CHAR : 󰪙
	md_bus_alert = "\uf0a99"
	# CHAR : 󰞜
	md_bus_articulated_end = "\uf079c"
	# CHAR : 󰞝
	md_bus_articulated_front = "\uf079d"
	# CHAR : 󰣊
	md_bus_clock = "\uf08ca"
	# CHAR : 󰞞
	md_bus_double_decker = "\uf079e"
	# CHAR : 󱤝
	md_bus_electric = "\uf191d"
	# CHAR : 󱈒
	md_bus_marker = "\uf1212"
	# CHAR : 󰼿
	md_bus_multiple = "\uf0f3f"
	# CHAR : 󰞟
	md_bus_school = "\uf079f"
	# CHAR : 󰞠
	md_bus_side = "\uf07a0"
	# CHAR : 󱀒
	md_bus_stop = "\uf1012"
	# CHAR : 󱀓
	md_bus_stop_covered = "\uf1013"
	# CHAR : 󱀔
	md_bus_stop_uncovered = "\uf1014"
	# CHAR : 󱖉
	md_butterfly = "\uf1589"
	# CHAR : 󱖊
	md_butterfly_outline = "\uf158a"
	# CHAR : 󱢌
	md_cabin_a_frame = "\uf188c"
	# CHAR : 󱎔
	md_cable_data = "\uf1394"
	# CHAR : 󰃨
	md_cached = "\uf00e8"
	# CHAR : 󰶵
	md_cactus = "\uf0db5"
	# CHAR : 󰃩
	md_cake = "\uf00e9"
	# CHAR : 󰃪
	md_cake_layered = "\uf00ea"
	# CHAR : 󰃫
	md_cake_variant = "\uf00eb"
	# CHAR : 󱟰
	md_cake_variant_outline = "\uf17f0"
	# CHAR : 󰃬
	md_calculator = "\uf00ec"
	# CHAR : 󰪚
	md_calculator_variant = "\uf0a9a"
	# CHAR : 󱖦
	md_calculator_variant_outline = "\uf15a6"
	# CHAR : 󰃭
	md_calendar = "\uf00ed"
	# CHAR : 󰻗
	md_calendar_account = "\uf0ed7"
	# CHAR : 󰻘
	md_calendar_account_outline = "\uf0ed8"
	# CHAR : 󰨱
	md_calendar_alert = "\uf0a31"
	# CHAR : 󱄴
	md_calendar_arrow_left = "\uf1134"
	# CHAR : 󱄵
	md_calendar_arrow_right = "\uf1135"
	# CHAR : 󰃮
	md_calendar_blank = "\uf00ee"
	# CHAR : 󱁳
	md_calendar_blank_multiple = "\uf1073"
	# CHAR : 󰭦
	md_calendar_blank_outline = "\uf0b66"
	# CHAR : 󰃯
	md_calendar_check = "\uf00ef"
	# CHAR : 󰱄
	md_calendar_check_outline = "\uf0c44"
	# CHAR : 󰃰
	md_calendar_clock = "\uf00f0"
	# CHAR : 󱛡
	md_calendar_clock_outline = "\uf16e1"
	# CHAR : 󱢝
	md_calendar_collapse_horizontal = "\uf189d"
	# CHAR : 󱕻
	md_calendar_cursor = "\uf157b"
	# CHAR : 󰢧
	md_calendar_edit = "\uf08a7"
	# CHAR : 󱙬
	md_calendar_end = "\uf166c"
	# CHAR : 󱢞
	md_calendar_expand_horizontal = "\uf189e"
	# CHAR : 󰬤
	md_calendar_export = "\uf0b24"
	# CHAR : 󰧒
	md_calendar_heart = "\uf09d2"
	# CHAR : 󰬥
	md_calendar_import = "\uf0b25"
	# CHAR : 󱙁
	md_calendar_lock = "\uf1641"
	# CHAR : 󱙂
	md_calendar_lock_outline = "\uf1642"
	# CHAR : 󰵜
	md_calendar_minus = "\uf0d5c"
	# CHAR : 󰸗
	md_calendar_month = "\uf0e17"
	# CHAR : 󰸘
	md_calendar_month_outline = "\uf0e18"
	# CHAR : 󰃱
	md_calendar_multiple = "\uf00f1"
	# CHAR : 󰃲
	md_calendar_multiple_check = "\uf00f2"
	# CHAR : 󰨲
	md_calendar_multiselect = "\uf0a32"
	# CHAR : 󰭧
	md_calendar_outline = "\uf0b67"
	# CHAR : 󰃳
	md_calendar_plus = "\uf00f3"
	# CHAR : 󰚒
	md_calendar_question = "\uf0692"
	# CHAR : 󰙹
	md_calendar_range = "\uf0679"
	# CHAR : 󰭨
	md_calendar_range_outline = "\uf0b68"
	# CHAR : 󰇡
	md_calendar_refresh = "\uf01e1"
	# CHAR : 󰈃
	md_calendar_refresh_outline = "\uf0203"
	# CHAR : 󰃴
	md_calendar_remove = "\uf00f4"
	# CHAR : 󰱅
	md_calendar_remove_outline = "\uf0c45"
	# CHAR : 󰥌
	md_calendar_search = "\uf094c"
	# CHAR : 󰧓
	md_calendar_star = "\uf09d3"
	# CHAR : 󱙭
	md_calendar_start = "\uf166d"
	# CHAR : 󰺎
	md_calendar_sync = "\uf0e8e"
	# CHAR : 󰺏
	md_calendar_sync_outline = "\uf0e8f"
	# CHAR : 󰃵
	md_calendar_text = "\uf00f5"
	# CHAR : 󰱆
	md_calendar_text_outline = "\uf0c46"
	# CHAR : 󰃶
	md_calendar_today = "\uf00f6"
	# CHAR : 󱨰
	md_calendar_today_outline = "\uf1a30"
	# CHAR : 󰨳
	md_calendar_week = "\uf0a33"
	# CHAR : 󰨴
	md_calendar_week_begin = "\uf0a34"
	# CHAR : 󱨱
	md_calendar_week_begin_outline = "\uf1a31"
	# CHAR : 󱨲
	md_calendar_week_end = "\uf1a32"
	# CHAR : 󱨳
	md_calendar_week_end_outline = "\uf1a33"
	# CHAR : 󱨴
	md_calendar_week_outline = "\uf1a34"
	# CHAR : 󰻙
	md_calendar_weekend = "\uf0ed9"
	# CHAR : 󰻚
	md_calendar_weekend_outline = "\uf0eda"
	# CHAR : 󰃷
	md_call_made = "\uf00f7"
	# CHAR : 󰃸
	md_call_merge = "\uf00f8"
	# CHAR : 󰃹
	md_call_missed = "\uf00f9"
	# CHAR : 󰃺
	md_call_received = "\uf00fa"
	# CHAR : 󰃻
	md_call_split = "\uf00fb"
	# CHAR : 󰃼
	md_camcorder = "\uf00fc"
	# CHAR : 󰃿
	md_camcorder_off = "\uf00ff"
	# CHAR : 󰄀
	md_camera = "\uf0100"
	# CHAR : 󰣋
	md_camera_account = "\uf08cb"
	# CHAR : 󰚓
	md_camera_burst = "\uf0693"
	# CHAR : 󰭩
	md_camera_control = "\uf0b69"
	# CHAR : 󱡱
	md_camera_document = "\uf1871"
	# CHAR : 󱡲
	md_camera_document_off = "\uf1872"
	# CHAR : 󰄁
	md_camera_enhance = "\uf0101"
	# CHAR : 󰭪
	md_camera_enhance_outline = "\uf0b6a"
	# CHAR : 󱗙
	md_camera_flip = "\uf15d9"
	# CHAR : 󱗚
	md_camera_flip_outline = "\uf15da"
	# CHAR : 󰄂
	md_camera_front = "\uf0102"
	# CHAR : 󰄃
	md_camera_front_variant = "\uf0103"
	# CHAR : 󰞡
	md_camera_gopro = "\uf07a1"
	# CHAR : 󰣌
	md_camera_image = "\uf08cc"
	# CHAR : 󰄄
	md_camera_iris = "\uf0104"
	# CHAR : 󱨔
	md_camera_lock = "\uf1a14"
	# CHAR : 󱨕
	md_camera_lock_outline = "\uf1a15"
	# CHAR : 󱦧
	md_camera_marker = "\uf19a7"
	# CHAR : 󱦨
	md_camera_marker_outline = "\uf19a8"
	# CHAR : 󰞢
	md_camera_metering_center = "\uf07a2"
	# CHAR : 󰞣
	md_camera_metering_matrix = "\uf07a3"
	# CHAR : 󰞤
	md_camera_metering_partial = "\uf07a4"
	# CHAR : 󰞥
	md_camera_metering_spot = "\uf07a5"
	# CHAR : 󰗟
	md_camera_off = "\uf05df"
	# CHAR : 󱦿
	md_camera_off_outline = "\uf19bf"
	# CHAR : 󰵝
	md_camera_outline = "\uf0d5d"
	# CHAR : 󰄅
	md_camera_party_mode = "\uf0105"
	# CHAR : 󰻛
	md_camera_plus = "\uf0edb"
	# CHAR : 󰻜
	md_camera_plus_outline = "\uf0edc"
	# CHAR : 󰄆
	md_camera_rear = "\uf0106"
	# CHAR : 󰄇
	md_camera_rear_variant = "\uf0107"
	# CHAR : 󰸙
	md_camera_retake = "\uf0e19"
	# CHAR : 󰸚
	md_camera_retake_outline = "\uf0e1a"
	# CHAR : 󰄈
	md_camera_switch = "\uf0108"
	# CHAR : 󰡊
	md_camera_switch_outline = "\uf084a"
	# CHAR : 󰄉
	md_camera_timer = "\uf0109"
	# CHAR : 󰶶
	md_camera_wireless = "\uf0db6"
	# CHAR : 󰶷
	md_camera_wireless_outline = "\uf0db7"
	# CHAR : 󰻝
	md_campfire = "\uf0edd"
	# CHAR : 󰜺
	md_cancel = "\uf073a"
	# CHAR : 󱟒
	md_candelabra = "\uf17d2"
	# CHAR : 󱟓
	md_candelabra_fire = "\uf17d3"
	# CHAR : 󰗢
	md_candle = "\uf05e2"
	# CHAR : 󱥰
	md_candy = "\uf1970"
	# CHAR : 󱥱
	md_candy_off = "\uf1971"
	# CHAR : 󱥲
	md_candy_off_outline = "\uf1972"
	# CHAR : 󱥳
	md_candy_outline = "\uf1973"
	# CHAR : 󰄊
	md_candycane = "\uf010a"
	# CHAR : 󰞦
	md_cannabis = "\uf07a6"
	# CHAR : 󱙮
	md_cannabis_off = "\uf166e"
	# CHAR : 󰪛
	md_caps_lock = "\uf0a9b"
	# CHAR : 󰄋
	md_car = "\uf010b"
	# CHAR : 󱀕
	md_car_2_plus = "\uf1015"
	# CHAR : 󱀖
	md_car_3_plus = "\uf1016"
	# CHAR : 󱎲
	md_car_arrow_left = "\uf13b2"
	# CHAR : 󱎳
	md_car_arrow_right = "\uf13b3"
	# CHAR : 󰸛
	md_car_back = "\uf0e1b"
	# CHAR : 󰄌
	md_car_battery = "\uf010c"
	# CHAR : 󰱇
	md_car_brake_abs = "\uf0c47"
	# CHAR : 󰱈
	md_car_brake_alert = "\uf0c48"
	# CHAR : 󱤉
	md_car_brake_fluid_level = "\uf1909"
	# CHAR : 󰵞
	md_car_brake_hold = "\uf0d5e"
	# CHAR : 󱤊
	md_car_brake_low_pressure = "\uf190a"
	# CHAR : 󰵟
	md_car_brake_parking = "\uf0d5f"
	# CHAR : 󱀗
	md_car_brake_retarder = "\uf1017"
	# CHAR : 󱤋
	md_car_brake_temperature = "\uf190b"
	# CHAR : 󱤌
	md_car_brake_worn_linings = "\uf190c"
	# CHAR : 󰾣
	md_car_child_seat = "\uf0fa3"
	# CHAR : 󱥴
	md_car_clock = "\uf1974"
	# CHAR : 󱀘
	md_car_clutch = "\uf1018"
	# CHAR : 󱏌
	md_car_cog = "\uf13cc"
	# CHAR : 󰄍
	md_car_connected = "\uf010d"
	# CHAR : 󰞧
	md_car_convertible = "\uf07a7"
	# CHAR : 󱀙
	md_car_coolant_level = "\uf1019"
	# CHAR : 󰵠
	md_car_cruise_control = "\uf0d60"
	# CHAR : 󰵡
	md_car_defrost_front = "\uf0d61"
	# CHAR : 󰵢
	md_car_defrost_rear = "\uf0d62"
	# CHAR : 󰭫
	md_car_door = "\uf0b6b"
	# CHAR : 󱂝
	md_car_door_lock = "\uf109d"
	# CHAR : 󰭬
	md_car_electric = "\uf0b6c"
	# CHAR : 󱖵
	md_car_electric_outline = "\uf15b5"
	# CHAR : 󱘏
	md_car_emergency = "\uf160f"
	# CHAR : 󰱉
	md_car_esp = "\uf0c49"
	# CHAR : 󰞨
	md_car_estate = "\uf07a8"
	# CHAR : 󰞩
	md_car_hatchback = "\uf07a9"
	# CHAR : 󱆾
	md_car_info = "\uf11be"
	# CHAR : 󰭭
	md_car_key = "\uf0b6d"
	# CHAR : 󱔭
	md_car_lifted_pickup = "\uf152d"
	# CHAR : 󱤍
	md_car_light_alert = "\uf190d"
	# CHAR : 󰱊
	md_car_light_dimmed = "\uf0c4a"
	# CHAR : 󰱋
	md_car_light_fog = "\uf0c4b"
	# CHAR : 󰱌
	md_car_light_high = "\uf0c4c"
	# CHAR : 󰣍
	md_car_limousine = "\uf08cd"
	# CHAR : 󰭮
	md_car_multiple = "\uf0b6e"
	# CHAR : 󰸜
	md_car_off = "\uf0e1c"
	# CHAR : 󱓭
	md_car_outline = "\uf14ed"
	# CHAR : 󰵣
	md_car_parking_lights = "\uf0d63"
	# CHAR : 󰞪
	md_car_pickup = "\uf07aa"
	# CHAR : 󰾤
	md_car_seat = "\uf0fa4"
	# CHAR : 󰾥
	md_car_seat_cooler = "\uf0fa5"
	# CHAR : 󰾦
	md_car_seat_heater = "\uf0fa6"
	# CHAR : 󱡹
	md_car_select = "\uf1879"
	# CHAR : 󱏍
	md_car_settings = "\uf13cd"
	# CHAR : 󰽀
	md_car_shift_pattern = "\uf0f40"
	# CHAR : 󰞫
	md_car_side = "\uf07ab"
	# CHAR : 󱤎
	md_car_speed_limiter = "\uf190e"
	# CHAR : 󰞬
	md_car_sports = "\uf07ac"
	# CHAR : 󰱍
	md_car_tire_alert = "\uf0c4d"
	# CHAR : 󰵤
	md_car_traction_control = "\uf0d64"
	# CHAR : 󱀚
	md_car_turbocharger = "\uf101a"
	# CHAR : 󰄎
	md_car_wash = "\uf010e"
	# CHAR : 󱀛
	md_car_windshield = "\uf101b"
	# CHAR : 󱀜
	md_car_windshield_outline = "\uf101c"
	# CHAR : 󱡸
	md_car_wireless = "\uf1878"
	# CHAR : 󱠔
	md_car_wrench = "\uf1814"
	# CHAR : 󱓀
	md_carabiner = "\uf14c0"
	# CHAR : 󰞭
	md_caravan = "\uf07ad"
	# CHAR : 󰭯
	md_card = "\uf0b6f"
	# CHAR : 󰗒
	md_card_account_details = "\uf05d2"
	# CHAR : 󰶫
	md_card_account_details_outline = "\uf0dab"
	# CHAR : 󰊣
	md_card_account_details_star = "\uf02a3"
	# CHAR : 󰛛
	md_card_account_details_star_outline = "\uf06db"
	# CHAR : 󰆎
	md_card_account_mail = "\uf018e"
	# CHAR : 󰺘
	md_card_account_mail_outline = "\uf0e98"
	# CHAR : 󰺙
	md_card_account_phone = "\uf0e99"
	# CHAR : 󰺚
	md_card_account_phone_outline = "\uf0e9a"
	# CHAR : 󰭰
	md_card_bulleted = "\uf0b70"
	# CHAR : 󰭱
	md_card_bulleted_off = "\uf0b71"
	# CHAR : 󰭲
	md_card_bulleted_off_outline = "\uf0b72"
	# CHAR : 󰭳
	md_card_bulleted_outline = "\uf0b73"
	# CHAR : 󰭴
	md_card_bulleted_settings = "\uf0b74"
	# CHAR : 󰭵
	md_card_bulleted_settings_outline = "\uf0b75"
	# CHAR : 󱘀
	md_card_minus = "\uf1600"
	# CHAR : 󱘁
	md_card_minus_outline = "\uf1601"
	# CHAR : 󱟱
	md_card_multiple = "\uf17f1"
	# CHAR : 󱟲
	md_card_multiple_outline = "\uf17f2"
	# CHAR : 󱘂
	md_card_off = "\uf1602"
	# CHAR : 󱘃
	md_card_off_outline = "\uf1603"
	# CHAR : 󰭶
	md_card_outline = "\uf0b76"
	# CHAR : 󱇿
	md_card_plus = "\uf11ff"
	# CHAR : 󱈀
	md_card_plus_outline = "\uf1200"
	# CHAR : 󱘄
	md_card_remove = "\uf1604"
	# CHAR : 󱘅
	md_card_remove_outline = "\uf1605"
	# CHAR : 󱁴
	md_card_search = "\uf1074"
	# CHAR : 󱁵
	md_card_search_outline = "\uf1075"
	# CHAR : 󰭷
	md_card_text = "\uf0b77"
	# CHAR : 󰭸
	md_card_text_outline = "\uf0b78"
	# CHAR : 󰘸
	md_cards = "\uf0638"
	# CHAR : 󰣎
	md_cards_club = "\uf08ce"
	# CHAR : 󱢟
	md_cards_club_outline = "\uf189f"
	# CHAR : 󰣏
	md_cards_diamond = "\uf08cf"
	# CHAR : 󱀝
	md_cards_diamond_outline = "\uf101d"
	# CHAR : 󰘹
	md_cards_outline = "\uf0639"
	# CHAR : 󱢡
	md_cards_playing = "\uf18a1"
	# CHAR : 󱢢
	md_cards_playing_club = "\uf18a2"
	# CHAR : 󱢣
	md_cards_playing_club_multiple = "\uf18a3"
	# CHAR : 󱢤
	md_cards_playing_club_multiple_outline = "\uf18a4"
	# CHAR : 󱢥
	md_cards_playing_club_outline = "\uf18a5"
	# CHAR : 󱢦
	md_cards_playing_diamond = "\uf18a6"
	# CHAR : 󱢧
	md_cards_playing_diamond_multiple = "\uf18a7"
	# CHAR : 󱢨
	md_cards_playing_diamond_multiple_outline = "\uf18a8"
	# CHAR : 󱢩
	md_cards_playing_diamond_outline = "\uf18a9"
	# CHAR : 󱢪
	md_cards_playing_heart = "\uf18aa"
	# CHAR : 󱢫
	md_cards_playing_heart_multiple = "\uf18ab"
	# CHAR : 󱢬
	md_cards_playing_heart_multiple_outline = "\uf18ac"
	# CHAR : 󱢭
	md_cards_playing_heart_outline = "\uf18ad"
	# CHAR : 󰘺
	md_cards_playing_outline = "\uf063a"
	# CHAR : 󱢮
	md_cards_playing_spade = "\uf18ae"
	# CHAR : 󱢯
	md_cards_playing_spade_multiple = "\uf18af"
	# CHAR : 󱢰
	md_cards_playing_spade_multiple_outline = "\uf18b0"
	# CHAR : 󱢱
	md_cards_playing_spade_outline = "\uf18b1"
	# CHAR : 󰣑
	md_cards_spade = "\uf08d1"
	# CHAR : 󱢲
	md_cards_spade_outline = "\uf18b2"
	# CHAR : 󰛇
	md_cards_variant = "\uf06c7"
	# CHAR : 󰄏
	md_carrot = "\uf010f"
	# CHAR : 󰄐
	md_cart = "\uf0110"
	# CHAR : 󰵦
	md_cart_arrow_down = "\uf0d66"
	# CHAR : 󰱎
	md_cart_arrow_right = "\uf0c4e"
	# CHAR : 󰵧
	md_cart_arrow_up = "\uf0d67"
	# CHAR : 󱗪
	md_cart_check = "\uf15ea"
	# CHAR : 󱣠
	md_cart_heart = "\uf18e0"
	# CHAR : 󰵨
	md_cart_minus = "\uf0d68"
	# CHAR : 󰙫
	md_cart_off = "\uf066b"
	# CHAR : 󰄑
	md_cart_outline = "\uf0111"
	# CHAR : 󰄒
	md_cart_plus = "\uf0112"
	# CHAR : 󰵩
	md_cart_remove = "\uf0d69"
	# CHAR : 󱗫
	md_cart_variant = "\uf15eb"
	# CHAR : 󰄓
	md_case_sensitive_alt = "\uf0113"
	# CHAR : 󰄔
	md_cash = "\uf0114"
	# CHAR : 󰄕
	md_cash_100 = "\uf0115"
	# CHAR : 󱓮
	md_cash_check = "\uf14ee"
	# CHAR : 󱪑
	md_cash_clock = "\uf1a91"
	# CHAR : 󱡜
	md_cash_fast = "\uf185c"
	# CHAR : 󱓪
	md_cash_lock = "\uf14ea"
	# CHAR : 󱓫
	md_cash_lock_open = "\uf14eb"
	# CHAR : 󰶸
	md_cash_marker = "\uf0db8"
	# CHAR : 󱉠
	md_cash_minus = "\uf1260"
	# CHAR : 󰄖
	md_cash_multiple = "\uf0116"
	# CHAR : 󱉡
	md_cash_plus = "\uf1261"
	# CHAR : 󰪜
	md_cash_refund = "\uf0a9c"
	# CHAR : 󰳴
	md_cash_register = "\uf0cf4"
	# CHAR : 󱉢
	md_cash_remove = "\uf1262"
	# CHAR : 󱪒
	md_cash_sync = "\uf1a92"
	# CHAR : 󰧔
	md_cassette = "\uf09d4"
	# CHAR : 󰄘
	md_cast = "\uf0118"
	# CHAR : 󱀞
	md_cast_audio = "\uf101e"
	# CHAR : 󱝉
	md_cast_audio_variant = "\uf1749"
	# CHAR : 󰄙
	md_cast_connected = "\uf0119"
	# CHAR : 󰸝
	md_cast_education = "\uf0e1d"
	# CHAR : 󰞊
	md_cast_off = "\uf078a"
	# CHAR : 󰀟
	md_cast_variant = "\uf001f"
	# CHAR : 󰄚
	md_castle = "\uf011a"
	# CHAR : 󰄛
	md_cat = "\uf011b"
	# CHAR : 󰞮
	md_cctv = "\uf07ae"
	# CHAR : 󱡟
	md_cctv_off = "\uf185f"
	# CHAR : 󱞗
	md_ceiling_fan = "\uf1797"
	# CHAR : 󱞘
	md_ceiling_fan_light = "\uf1798"
	# CHAR : 󰝩
	md_ceiling_light = "\uf0769"
	# CHAR : 󱣝
	md_ceiling_light_multiple = "\uf18dd"
	# CHAR : 󱣞
	md_ceiling_light_multiple_outline = "\uf18de"
	# CHAR : 󱟇
	md_ceiling_light_outline = "\uf17c7"
	# CHAR : 󰄜
	md_cellphone = "\uf011c"
	# CHAR : 󰧕
	md_cellphone_arrow_down = "\uf09d5"
	# CHAR : 󱧅
	md_cellphone_arrow_down_variant = "\uf19c5"
	# CHAR : 󰄞
	md_cellphone_basic = "\uf011e"
	# CHAR : 󱎗
	md_cellphone_charging = "\uf1397"
	# CHAR : 󱟽
	md_cellphone_check = "\uf17fd"
	# CHAR : 󰥑
	md_cellphone_cog = "\uf0951"
	# CHAR : 󰄟
	md_cellphone_dock = "\uf011f"
	# CHAR : 󰽁
	md_cellphone_information = "\uf0f41"
	# CHAR : 󰥎
	md_cellphone_key = "\uf094e"
	# CHAR : 󰄡
	md_cellphone_link = "\uf0121"
	# CHAR : 󰄢
	md_cellphone_link_off = "\uf0122"
	# CHAR : 󰥏
	md_cellphone_lock = "\uf094f"
	# CHAR : 󱠺
	md_cellphone_marker = "\uf183a"
	# CHAR : 󰣓
	md_cellphone_message = "\uf08d3"
	# CHAR : 󱃒
	md_cellphone_message_off = "\uf10d2"
	# CHAR : 󰺐
	md_cellphone_nfc = "\uf0e90"
	# CHAR : 󱋘
	md_cellphone_nfc_off = "\uf12d8"
	# CHAR : 󰥐
	md_cellphone_off = "\uf0950"
	# CHAR : 󱀟
	md_cellphone_play = "\uf101f"
	# CHAR : 󰥍
	md_cellphone_remove = "\uf094d"
	# CHAR : 󰨵
	md_cellphone_screenshot = "\uf0a35"
	# CHAR : 󰄣
	md_cellphone_settings = "\uf0123"
	# CHAR : 󰥒
	md_cellphone_sound = "\uf0952"
	# CHAR : 󰣒
	md_cellphone_text = "\uf08d2"
	# CHAR : 󰠕
	md_cellphone_wireless = "\uf0815"
	# CHAR : 󱄚
	md_centos = "\uf111a"
	# CHAR : 󰄤
	md_certificate = "\uf0124"
	# CHAR : 󱆈
	md_certificate_outline = "\uf1188"
	# CHAR : 󰽈
	md_chair_rolling = "\uf0f48"
	# CHAR : 󰄥
	md_chair_school = "\uf0125"
	# CHAR : 󱞓
	md_chandelier = "\uf1793"
	# CHAR : 󰱏
	md_charity = "\uf0c4f"
	# CHAR : 󰄦
	md_chart_arc = "\uf0126"
	# CHAR : 󰄧
	md_chart_areaspline = "\uf0127"
	# CHAR : 󰺑
	md_chart_areaspline_variant = "\uf0e91"
	# CHAR : 󰄨
	md_chart_bar = "\uf0128"
	# CHAR : 󰝪
	md_chart_bar_stacked = "\uf076a"
	# CHAR : 󰱐
	md_chart_bell_curve = "\uf0c50"
	# CHAR : 󰾧
	md_chart_bell_curve_cumulative = "\uf0fa7"
	# CHAR : 󱕍
	md_chart_box = "\uf154d"
	# CHAR : 󱕎
	md_chart_box_outline = "\uf154e"
	# CHAR : 󱕏
	md_chart_box_plus_outline = "\uf154f"
	# CHAR : 󰗣
	md_chart_bubble = "\uf05e3"
	# CHAR : 󰞯
	md_chart_donut = "\uf07af"
	# CHAR : 󰞰
	md_chart_donut_variant = "\uf07b0"
	# CHAR : 󰙬
	md_chart_gantt = "\uf066c"
	# CHAR : 󰄩
	md_chart_histogram = "\uf0129"
	# CHAR : 󰄪
	md_chart_line = "\uf012a"
	# CHAR : 󰝫
	md_chart_line_stacked = "\uf076b"
	# CHAR : 󰞱
	md_chart_line_variant = "\uf07b1"
	# CHAR : 󰣔
	md_chart_multiline = "\uf08d4"
	# CHAR : 󱈓
	md_chart_multiple = "\uf1213"
	# CHAR : 󰄫
	md_chart_pie = "\uf012b"
	# CHAR : 󱎀
	md_chart_ppf = "\uf1380"
	# CHAR : 󱇟
	md_chart_sankey = "\uf11df"
	# CHAR : 󱇠
	md_chart_sankey_variant = "\uf11e0"
	# CHAR : 󰺒
	md_chart_scatter_plot = "\uf0e92"
	# CHAR : 󰙭
	md_chart_scatter_plot_hexbin = "\uf066d"
	# CHAR : 󰙮
	md_chart_timeline = "\uf066e"
	# CHAR : 󰺓
	md_chart_timeline_variant = "\uf0e93"
	# CHAR : 󱖶
	md_chart_timeline_variant_shimmer = "\uf15b6"
	# CHAR : 󰺔
	md_chart_tree = "\uf0e94"
	# CHAR : 󱤘
	md_chart_waterfall = "\uf1918"
	# CHAR : 󰭹
	md_chat = "\uf0b79"
	# CHAR : 󰭺
	md_chat_alert = "\uf0b7a"
	# CHAR : 󱋉
	md_chat_alert_outline = "\uf12c9"
	# CHAR : 󱐐
	md_chat_minus = "\uf1410"
	# CHAR : 󱐓
	md_chat_minus_outline = "\uf1413"
	# CHAR : 󰻞
	md_chat_outline = "\uf0ede"
	# CHAR : 󱐏
	md_chat_plus = "\uf140f"
	# CHAR : 󱐒
	md_chat_plus_outline = "\uf1412"
	# CHAR : 󰭻
	md_chat_processing = "\uf0b7b"
	# CHAR : 󱋊
	md_chat_processing_outline = "\uf12ca"
	# CHAR : 󱜸
	md_chat_question = "\uf1738"
	# CHAR : 󱜹
	md_chat_question_outline = "\uf1739"
	# CHAR : 󱐑
	md_chat_remove = "\uf1411"
	# CHAR : 󱐔
	md_chat_remove_outline = "\uf1414"
	# CHAR : 󱋑
	md_chat_sleep = "\uf12d1"
	# CHAR : 󱋒
	md_chat_sleep_outline = "\uf12d2"
	# CHAR : 󰄬
	md_check = "\uf012c"
	# CHAR : 󰄭
	md_check_all = "\uf012d"
	# CHAR : 󰸞
	md_check_bold = "\uf0e1e"
	# CHAR : 󰗠
	md_check_circle = "\uf05e0"
	# CHAR : 󰗡
	md_check_circle_outline = "\uf05e1"
	# CHAR : 󰞑
	md_check_decagram = "\uf0791"
	# CHAR : 󱝀
	md_check_decagram_outline = "\uf1740"
	# CHAR : 󰱓
	md_check_network = "\uf0c53"
	# CHAR : 󰱔
	md_check_network_outline = "\uf0c54"
	# CHAR : 󰡕
	md_check_outline = "\uf0855"
	# CHAR : 󰸟
	md_check_underline = "\uf0e1f"
	# CHAR : 󰸠
	md_check_underline_circle = "\uf0e20"
	# CHAR : 󰸡
	md_check_underline_circle_outline = "\uf0e21"
	# CHAR : 󰪝
	md_checkbook = "\uf0a9d"
	# CHAR : 󰄮
	md_checkbox_blank = "\uf012e"
	# CHAR : 󱅶
	md_checkbox_blank_badge = "\uf1176"
	# CHAR : 󰄗
	md_checkbox_blank_badge_outline = "\uf0117"
	# CHAR : 󰄯
	md_checkbox_blank_circle = "\uf012f"
	# CHAR : 󰄰
	md_checkbox_blank_circle_outline = "\uf0130"
	# CHAR : 󱋬
	md_checkbox_blank_off = "\uf12ec"
	# CHAR : 󱋭
	md_checkbox_blank_off_outline = "\uf12ed"
	# CHAR : 󰄱
	md_checkbox_blank_outline = "\uf0131"
	# CHAR : 󰡖
	md_checkbox_intermediate = "\uf0856"
	# CHAR : 󰄲
	md_checkbox_marked = "\uf0132"
	# CHAR : 󰄳
	md_checkbox_marked_circle = "\uf0133"
	# CHAR : 󰄴
	md_checkbox_marked_circle_outline = "\uf0134"
	# CHAR : 󱤧
	md_checkbox_marked_circle_plus_outline = "\uf1927"
	# CHAR : 󰄵
	md_checkbox_marked_outline = "\uf0135"
	# CHAR : 󰄶
	md_checkbox_multiple_blank = "\uf0136"
	# CHAR : 󰘻
	md_checkbox_multiple_blank_circle = "\uf063b"
	# CHAR : 󰘼
	md_checkbox_multiple_blank_circle_outline = "\uf063c"
	# CHAR : 󰄷
	md_checkbox_multiple_blank_outline = "\uf0137"
	# CHAR : 󰄸
	md_checkbox_multiple_marked = "\uf0138"
	# CHAR : 󰘽
	md_checkbox_multiple_marked_circle = "\uf063d"
	# CHAR : 󰘾
	md_checkbox_multiple_marked_circle_outline = "\uf063e"
	# CHAR : 󰄹
	md_checkbox_multiple_marked_outline = "\uf0139"
	# CHAR : 󰱑
	md_checkbox_multiple_outline = "\uf0c51"
	# CHAR : 󰱒
	md_checkbox_outline = "\uf0c52"
	# CHAR : 󰄺
	md_checkerboard = "\uf013a"
	# CHAR : 󱈂
	md_checkerboard_minus = "\uf1202"
	# CHAR : 󱈁
	md_checkerboard_plus = "\uf1201"
	# CHAR : 󱈃
	md_checkerboard_remove = "\uf1203"
	# CHAR : 󱊹
	md_cheese = "\uf12b9"
	# CHAR : 󱏮
	md_cheese_off = "\uf13ee"
	# CHAR : 󰭼
	md_chef_hat = "\uf0b7c"
	# CHAR : 󰄻
	md_chemical_weapon = "\uf013b"
	# CHAR : 󰡜
	md_chess_bishop = "\uf085c"
	# CHAR : 󰡗
	md_chess_king = "\uf0857"
	# CHAR : 󰡘
	md_chess_knight = "\uf0858"
	# CHAR : 󰡙
	md_chess_pawn = "\uf0859"
	# CHAR : 󰡚
	md_chess_queen = "\uf085a"
	# CHAR : 󰡛
	md_chess_rook = "\uf085b"
	# CHAR : 󰄼
	md_chevron_double_down = "\uf013c"
	# CHAR : 󰄽
	md_chevron_double_left = "\uf013d"
	# CHAR : 󰄾
	md_chevron_double_right = "\uf013e"
	# CHAR : 󰄿
	md_chevron_double_up = "\uf013f"
	# CHAR : 󰅀
	md_chevron_down = "\uf0140"
	# CHAR : 󰧖
	md_chevron_down_box = "\uf09d6"
	# CHAR : 󰧗
	md_chevron_down_box_outline = "\uf09d7"
	# CHAR : 󰬦
	md_chevron_down_circle = "\uf0b26"
	# CHAR : 󰬧
	md_chevron_down_circle_outline = "\uf0b27"
	# CHAR : 󰅁
	md_chevron_left = "\uf0141"
	# CHAR : 󰧘
	md_chevron_left_box = "\uf09d8"
	# CHAR : 󰧙
	md_chevron_left_box_outline = "\uf09d9"
	# CHAR : 󰬨
	md_chevron_left_circle = "\uf0b28"
	# CHAR : 󰬩
	md_chevron_left_circle_outline = "\uf0b29"
	# CHAR : 󰅂
	md_chevron_right = "\uf0142"
	# CHAR : 󰧚
	md_chevron_right_box = "\uf09da"
	# CHAR : 󰧛
	md_chevron_right_box_outline = "\uf09db"
	# CHAR : 󰬪
	md_chevron_right_circle = "\uf0b2a"
	# CHAR : 󰬫
	md_chevron_right_circle_outline = "\uf0b2b"
	# CHAR : 󰶹
	md_chevron_triple_down = "\uf0db9"
	# CHAR : 󰶺
	md_chevron_triple_left = "\uf0dba"
	# CHAR : 󰶻
	md_chevron_triple_right = "\uf0dbb"
	# CHAR : 󰶼
	md_chevron_triple_up = "\uf0dbc"
	# CHAR : 󰅃
	md_chevron_up = "\uf0143"
	# CHAR : 󰧜
	md_chevron_up_box = "\uf09dc"
	# CHAR : 󰧝
	md_chevron_up_box_outline = "\uf09dd"
	# CHAR : 󰬬
	md_chevron_up_circle = "\uf0b2c"
	# CHAR : 󰬭
	md_chevron_up_circle_outline = "\uf0b2d"
	# CHAR : 󱟪
	md_chili_alert = "\uf17ea"
	# CHAR : 󱟫
	md_chili_alert_outline = "\uf17eb"
	# CHAR : 󰞲
	md_chili_hot = "\uf07b2"
	# CHAR : 󱟬
	md_chili_hot_outline = "\uf17ec"
	# CHAR : 󰞳
	md_chili_medium = "\uf07b3"
	# CHAR : 󱟭
	md_chili_medium_outline = "\uf17ed"
	# CHAR : 󰞴
	md_chili_mild = "\uf07b4"
	# CHAR : 󱟮
	md_chili_mild_outline = "\uf17ee"
	# CHAR : 󱑧
	md_chili_off = "\uf1467"
	# CHAR : 󱟯
	md_chili_off_outline = "\uf17ef"
	# CHAR : 󰘚
	md_chip = "\uf061a"
	# CHAR : 󰅄
	md_church = "\uf0144"
	# CHAR : 󱆉
	md_cigar = "\uf1189"
	# CHAR : 󱐛
	md_cigar_off = "\uf141b"
	# CHAR : 󱗜
	md_circle_box = "\uf15dc"
	# CHAR : 󱗝
	md_circle_box_outline = "\uf15dd"
	# CHAR : 󰺕
	md_circle_double = "\uf0e95"
	# CHAR : 󰣕
	md_circle_edit_outline = "\uf08d5"
	# CHAR : 󰺖
	md_circle_expand = "\uf0e96"
	# CHAR : 󱎕
	md_circle_half = "\uf1395"
	# CHAR : 󱎖
	md_circle_half_full = "\uf1396"
	# CHAR : 󰧞
	md_circle_medium = "\uf09de"
	# CHAR : 󰬸
	md_circle_multiple = "\uf0b38"
	# CHAR : 󰚕
	md_circle_multiple_outline = "\uf0695"
	# CHAR : 󱃓
	md_circle_off_outline = "\uf10d3"
	# CHAR : 󱡓
	md_circle_opacity = "\uf1853"
	# CHAR : 󰪞
	md_circle_slice_1 = "\uf0a9e"
	# CHAR : 󰪟
	md_circle_slice_2 = "\uf0a9f"
	# CHAR : 󰪠
	md_circle_slice_3 = "\uf0aa0"
	# CHAR : 󰪡
	md_circle_slice_4 = "\uf0aa1"
	# CHAR : 󰪢
	md_circle_slice_5 = "\uf0aa2"
	# CHAR : 󰪣
	md_circle_slice_6 = "\uf0aa3"
	# CHAR : 󰪤
	md_circle_slice_7 = "\uf0aa4"
	# CHAR : 󰪥
	md_circle_slice_8 = "\uf0aa5"
	# CHAR : 󰧟
	md_circle_small = "\uf09df"
	# CHAR : 󰸢
	md_circular_saw = "\uf0e22"
	# CHAR : 󰅆
	md_city = "\uf0146"
	# CHAR : 󰨶
	md_city_variant = "\uf0a36"
	# CHAR : 󰨷
	md_city_variant_outline = "\uf0a37"
	# CHAR : 󰅇
	md_clipboard = "\uf0147"
	# CHAR : 󰅈
	md_clipboard_account = "\uf0148"
	# CHAR : 󰱕
	md_clipboard_account_outline = "\uf0c55"
	# CHAR : 󰅉
	md_clipboard_alert = "\uf0149"
	# CHAR : 󰳷
	md_clipboard_alert_outline = "\uf0cf7"
	# CHAR : 󰅊
	md_clipboard_arrow_down = "\uf014a"
	# CHAR : 󰱖
	md_clipboard_arrow_down_outline = "\uf0c56"
	# CHAR : 󰅋
	md_clipboard_arrow_left = "\uf014b"
	# CHAR : 󰳸
	md_clipboard_arrow_left_outline = "\uf0cf8"
	# CHAR : 󰳹
	md_clipboard_arrow_right = "\uf0cf9"
	# CHAR : 󰳺
	md_clipboard_arrow_right_outline = "\uf0cfa"
	# CHAR : 󰱗
	md_clipboard_arrow_up = "\uf0c57"
	# CHAR : 󰱘
	md_clipboard_arrow_up_outline = "\uf0c58"
	# CHAR : 󰅎
	md_clipboard_check = "\uf014e"
	# CHAR : 󱉣
	md_clipboard_check_multiple = "\uf1263"
	# CHAR : 󱉤
	md_clipboard_check_multiple_outline = "\uf1264"
	# CHAR : 󰢨
	md_clipboard_check_outline = "\uf08a8"
	# CHAR : 󱛢
	md_clipboard_clock = "\uf16e2"
	# CHAR : 󱛣
	md_clipboard_clock_outline = "\uf16e3"
	# CHAR : 󱓥
	md_clipboard_edit = "\uf14e5"
	# CHAR : 󱓦
	md_clipboard_edit_outline = "\uf14e6"
	# CHAR : 󱉥
	md_clipboard_file = "\uf1265"
	# CHAR : 󱉦
	md_clipboard_file_outline = "\uf1266"
	# CHAR : 󰛈
	md_clipboard_flow = "\uf06c8"
	# CHAR : 󱄗
	md_clipboard_flow_outline = "\uf1117"
	# CHAR : 󱃔
	md_clipboard_list = "\uf10d4"
	# CHAR : 󱃕
	md_clipboard_list_outline = "\uf10d5"
	# CHAR : 󱘘
	md_clipboard_minus = "\uf1618"
	# CHAR : 󱘙
	md_clipboard_minus_outline = "\uf1619"
	# CHAR : 󱉧
	md_clipboard_multiple = "\uf1267"
	# CHAR : 󱉨
	md_clipboard_multiple_outline = "\uf1268"
	# CHAR : 󱘚
	md_clipboard_off = "\uf161a"
	# CHAR : 󱘛
	md_clipboard_off_outline = "\uf161b"
	# CHAR : 󰅌
	md_clipboard_outline = "\uf014c"
	# CHAR : 󰱙
	md_clipboard_play = "\uf0c59"
	# CHAR : 󱉩
	md_clipboard_play_multiple = "\uf1269"
	# CHAR : 󱉪
	md_clipboard_play_multiple_outline = "\uf126a"
	# CHAR : 󰱚
	md_clipboard_play_outline = "\uf0c5a"
	# CHAR : 󰝑
	md_clipboard_plus = "\uf0751"
	# CHAR : 󱌟
	md_clipboard_plus_outline = "\uf131f"
	# CHAR : 󰡝
	md_clipboard_pulse = "\uf085d"
	# CHAR : 󰡞
	md_clipboard_pulse_outline = "\uf085e"
	# CHAR : 󱘜
	md_clipboard_remove = "\uf161c"
	# CHAR : 󱘝
	md_clipboard_remove_outline = "\uf161d"
	# CHAR : 󱘞
	md_clipboard_search = "\uf161e"
	# CHAR : 󱘟
	md_clipboard_search_outline = "\uf161f"
	# CHAR : 󰅍
	md_clipboard_text = "\uf014d"
	# CHAR : 󱣹
	md_clipboard_text_clock = "\uf18f9"
	# CHAR : 󱣺
	md_clipboard_text_clock_outline = "\uf18fa"
	# CHAR : 󱉫
	md_clipboard_text_multiple = "\uf126b"
	# CHAR : 󱉬
	md_clipboard_text_multiple_outline = "\uf126c"
	# CHAR : 󱘠
	md_clipboard_text_off = "\uf1620"
	# CHAR : 󱘡
	md_clipboard_text_off_outline = "\uf1621"
	# CHAR : 󰨸
	md_clipboard_text_outline = "\uf0a38"
	# CHAR : 󰱛
	md_clipboard_text_play = "\uf0c5b"
	# CHAR : 󰱜
	md_clipboard_text_play_outline = "\uf0c5c"
	# CHAR : 󱘢
	md_clipboard_text_search = "\uf1622"
	# CHAR : 󱘣
	md_clipboard_text_search_outline = "\uf1623"
	# CHAR : 󰅏
	md_clippy = "\uf014f"
	# CHAR : 󰥔
	md_clock = "\uf0954"
	# CHAR : 󰥕
	md_clock_alert = "\uf0955"
	# CHAR : 󰗎
	md_clock_alert_outline = "\uf05ce"
	# CHAR : 󰾨
	md_clock_check = "\uf0fa8"
	# CHAR : 󰾩
	md_clock_check_outline = "\uf0fa9"
	# CHAR : 󰺗
	md_clock_digital = "\uf0e97"
	# CHAR : 󱦺
	md_clock_edit = "\uf19ba"
	# CHAR : 󱦻
	md_clock_edit_outline = "\uf19bb"
	# CHAR : 󰅑
	md_clock_end = "\uf0151"
	# CHAR : 󰅒
	md_clock_fast = "\uf0152"
	# CHAR : 󰅓
	md_clock_in = "\uf0153"
	# CHAR : 󱡣
	md_clock_minus = "\uf1863"
	# CHAR : 󱡤
	md_clock_minus_outline = "\uf1864"
	# CHAR : 󰅔
	md_clock_out = "\uf0154"
	# CHAR : 󰅐
	md_clock_outline = "\uf0150"
	# CHAR : 󱡡
	md_clock_plus = "\uf1861"
	# CHAR : 󱡢
	md_clock_plus_outline = "\uf1862"
	# CHAR : 󱡥
	md_clock_remove = "\uf1865"
	# CHAR : 󱡦
	md_clock_remove_outline = "\uf1866"
	# CHAR : 󰅕
	md_clock_start = "\uf0155"
	# CHAR : 󱑆
	md_clock_time_eight = "\uf1446"
	# CHAR : 󱑒
	md_clock_time_eight_outline = "\uf1452"
	# CHAR : 󱑉
	md_clock_time_eleven = "\uf1449"
	# CHAR : 󱑕
	md_clock_time_eleven_outline = "\uf1455"
	# CHAR : 󱑃
	md_clock_time_five = "\uf1443"
	# CHAR : 󱑏
	md_clock_time_five_outline = "\uf144f"
	# CHAR : 󱑂
	md_clock_time_four = "\uf1442"
	# CHAR : 󱑎
	md_clock_time_four_outline = "\uf144e"
	# CHAR : 󱑇
	md_clock_time_nine = "\uf1447"
	# CHAR : 󱑓
	md_clock_time_nine_outline = "\uf1453"
	# CHAR : 󱐿
	md_clock_time_one = "\uf143f"
	# CHAR : 󱑋
	md_clock_time_one_outline = "\uf144b"
	# CHAR : 󱑅
	md_clock_time_seven = "\uf1445"
	# CHAR : 󱑑
	md_clock_time_seven_outline = "\uf1451"
	# CHAR : 󱑄
	md_clock_time_six = "\uf1444"
	# CHAR : 󱑐
	md_clock_time_six_outline = "\uf1450"
	# CHAR : 󱑈
	md_clock_time_ten = "\uf1448"
	# CHAR : 󱑔
	md_clock_time_ten_outline = "\uf1454"
	# CHAR : 󱑁
	md_clock_time_three = "\uf1441"
	# CHAR : 󱑍
	md_clock_time_three_outline = "\uf144d"
	# CHAR : 󱑊
	md_clock_time_twelve = "\uf144a"
	# CHAR : 󱑖
	md_clock_time_twelve_outline = "\uf1456"
	# CHAR : 󱑀
	md_clock_time_two = "\uf1440"
	# CHAR : 󱑌
	md_clock_time_two_outline = "\uf144c"
	# CHAR : 󰅖
	md_close = "\uf0156"
	# CHAR : 󰅗
	md_close_box = "\uf0157"
	# CHAR : 󰱝
	md_close_box_multiple = "\uf0c5d"
	# CHAR : 󰱞
	md_close_box_multiple_outline = "\uf0c5e"
	# CHAR : 󰅘
	md_close_box_outline = "\uf0158"
	# CHAR : 󰅙
	md_close_circle = "\uf0159"
	# CHAR : 󰘪
	md_close_circle_multiple = "\uf062a"
	# CHAR : 󰢃
	md_close_circle_multiple_outline = "\uf0883"
	# CHAR : 󰅚
	md_close_circle_outline = "\uf015a"
	# CHAR : 󰅛
	md_close_network = "\uf015b"
	# CHAR : 󰱟
	md_close_network_outline = "\uf0c5f"
	# CHAR : 󰅜
	md_close_octagon = "\uf015c"
	# CHAR : 󰅝
	md_close_octagon_outline = "\uf015d"
	# CHAR : 󰛉
	md_close_outline = "\uf06c9"
	# CHAR : 󱎘
	md_close_thick = "\uf1398"
	# CHAR : 󰅞
	md_closed_caption = "\uf015e"
	# CHAR : 󰶽
	md_closed_caption_outline = "\uf0dbd"
	# CHAR : 󰅟
	md_cloud = "\uf015f"
	# CHAR : 󰧠
	md_cloud_alert = "\uf09e0"
	# CHAR : 󰞵
	md_cloud_braces = "\uf07b5"
	# CHAR : 󰅠
	md_cloud_check = "\uf0160"
	# CHAR : 󱋌
	md_cloud_check_outline = "\uf12cc"
	# CHAR : 󰅡
	md_cloud_circle = "\uf0161"
	# CHAR : 󰅢
	md_cloud_download = "\uf0162"
	# CHAR : 󰭽
	md_cloud_download_outline = "\uf0b7d"
	# CHAR : 󱇱
	md_cloud_lock = "\uf11f1"
	# CHAR : 󱇲
	md_cloud_lock_outline = "\uf11f2"
	# CHAR : 󰅤
	md_cloud_off_outline = "\uf0164"
	# CHAR : 󰅣
	md_cloud_outline = "\uf0163"
	# CHAR : 󱨵
	md_cloud_percent = "\uf1a35"
	# CHAR : 󱨶
	md_cloud_percent_outline = "\uf1a36"
	# CHAR : 󰅥
	md_cloud_print = "\uf0165"
	# CHAR : 󰅦
	md_cloud_print_outline = "\uf0166"
	# CHAR : 󰨹
	md_cloud_question = "\uf0a39"
	# CHAR : 󰔪
	md_cloud_refresh = "\uf052a"
	# CHAR : 󰥖
	md_cloud_search = "\uf0956"
	# CHAR : 󰥗
	md_cloud_search_outline = "\uf0957"
	# CHAR : 󰘿
	md_cloud_sync = "\uf063f"
	# CHAR : 󱋖
	md_cloud_sync_outline = "\uf12d6"
	# CHAR : 󰞶
	md_cloud_tags = "\uf07b6"
	# CHAR : 󰅧
	md_cloud_upload = "\uf0167"
	# CHAR : 󰭾
	md_cloud_upload_outline = "\uf0b7e"
	# CHAR : 󰠖
	md_clover = "\uf0816"
	# CHAR : 󱀠
	md_coach_lamp = "\uf1020"
	# CHAR : 󱨷
	md_coach_lamp_variant = "\uf1a37"
	# CHAR : 󱂞
	md_coat_rack = "\uf109e"
	# CHAR : 󰅨
	md_code_array = "\uf0168"
	# CHAR : 󰅩
	md_code_braces = "\uf0169"
	# CHAR : 󱃖
	md_code_braces_box = "\uf10d6"
	# CHAR : 󰅪
	md_code_brackets = "\uf016a"
	# CHAR : 󰅫
	md_code_equal = "\uf016b"
	# CHAR : 󰅬
	md_code_greater_than = "\uf016c"
	# CHAR : 󰅭
	md_code_greater_than_or_equal = "\uf016d"
	# CHAR : 󰘦
	md_code_json = "\uf0626"
	# CHAR : 󰅮
	md_code_less_than = "\uf016e"
	# CHAR : 󰅯
	md_code_less_than_or_equal = "\uf016f"
	# CHAR : 󰅰
	md_code_not_equal = "\uf0170"
	# CHAR : 󰅱
	md_code_not_equal_variant = "\uf0171"
	# CHAR : 󰅲
	md_code_parentheses = "\uf0172"
	# CHAR : 󱃗
	md_code_parentheses_box = "\uf10d7"
	# CHAR : 󰅳
	md_code_string = "\uf0173"
	# CHAR : 󰅴
	md_code_tags = "\uf0174"
	# CHAR : 󰚔
	md_code_tags_check = "\uf0694"
	# CHAR : 󰅵
	md_codepen = "\uf0175"
	# CHAR : 󰅶
	md_coffee = "\uf0176"
	# CHAR : 󱂟
	md_coffee_maker = "\uf109f"
	# CHAR : 󱤱
	md_coffee_maker_check = "\uf1931"
	# CHAR : 󱤲
	md_coffee_maker_check_outline = "\uf1932"
	# CHAR : 󱠛
	md_coffee_maker_outline = "\uf181b"
	# CHAR : 󰾪
	md_coffee_off = "\uf0faa"
	# CHAR : 󰾫
	md_coffee_off_outline = "\uf0fab"
	# CHAR : 󰛊
	md_coffee_outline = "\uf06ca"
	# CHAR : 󰅷
	md_coffee_to_go = "\uf0177"
	# CHAR : 󱌎
	md_coffee_to_go_outline = "\uf130e"
	# CHAR : 󰭿
	md_coffin = "\uf0b7f"
	# CHAR : 󰒓
	md_cog = "\uf0493"
	# CHAR : 󰒔
	md_cog_box = "\uf0494"
	# CHAR : 󱇝
	md_cog_clockwise = "\uf11dd"
	# CHAR : 󱇞
	md_cog_counterclockwise = "\uf11de"
	# CHAR : 󱏎
	md_cog_off = "\uf13ce"
	# CHAR : 󱏏
	md_cog_off_outline = "\uf13cf"
	# CHAR : 󰢻
	md_cog_outline = "\uf08bb"
	# CHAR : 󱤳
	md_cog_pause = "\uf1933"
	# CHAR : 󱤴
	md_cog_pause_outline = "\uf1934"
	# CHAR : 󱤵
	md_cog_play = "\uf1935"
	# CHAR : 󱤶
	md_cog_play_outline = "\uf1936"
	# CHAR : 󱑞
	md_cog_refresh = "\uf145e"
	# CHAR : 󱑟
	md_cog_refresh_outline = "\uf145f"
	# CHAR : 󱤷
	md_cog_stop = "\uf1937"
	# CHAR : 󱤸
	md_cog_stop_outline = "\uf1938"
	# CHAR : 󱑠
	md_cog_sync = "\uf1460"
	# CHAR : 󱑡
	md_cog_sync_outline = "\uf1461"
	# CHAR : 󱁛
	md_cog_transfer = "\uf105b"
	# CHAR : 󱁜
	md_cog_transfer_outline = "\uf105c"
	# CHAR : 󰣖
	md_cogs = "\uf08d6"
	# CHAR : 󰙀
	md_collage = "\uf0640"
	# CHAR : 󰪦
	md_collapse_all = "\uf0aa6"
	# CHAR : 󰪧
	md_collapse_all_outline = "\uf0aa7"
	# CHAR : 󰅹
	md_color_helper = "\uf0179"
	# CHAR : 󰸣
	md_comma = "\uf0e23"
	# CHAR : 󰸫
	md_comma_box = "\uf0e2b"
	# CHAR : 󰸤
	md_comma_box_outline = "\uf0e24"
	# CHAR : 󰸥
	md_comma_circle = "\uf0e25"
	# CHAR : 󰸦
	md_comma_circle_outline = "\uf0e26"
	# CHAR : 󰅺
	md_comment = "\uf017a"
	# CHAR : 󰅻
	md_comment_account = "\uf017b"
	# CHAR : 󰅼
	md_comment_account_outline = "\uf017c"
	# CHAR : 󰅽
	md_comment_alert = "\uf017d"
	# CHAR : 󰅾
	md_comment_alert_outline = "\uf017e"
	# CHAR : 󰧡
	md_comment_arrow_left = "\uf09e1"
	# CHAR : 󰧢
	md_comment_arrow_left_outline = "\uf09e2"
	# CHAR : 󰧣
	md_comment_arrow_right = "\uf09e3"
	# CHAR : 󰧤
	md_comment_arrow_right_outline = "\uf09e4"
	# CHAR : 󱖮
	md_comment_bookmark = "\uf15ae"
	# CHAR : 󱖯
	md_comment_bookmark_outline = "\uf15af"
	# CHAR : 󰅿
	md_comment_check = "\uf017f"
	# CHAR : 󰆀
	md_comment_check_outline = "\uf0180"
	# CHAR : 󱆿
	md_comment_edit = "\uf11bf"
	# CHAR : 󱋄
	md_comment_edit_outline = "\uf12c4"
	# CHAR : 󰨺
	md_comment_eye = "\uf0a3a"
	# CHAR : 󰨻
	md_comment_eye_outline = "\uf0a3b"
	# CHAR : 󱖰
	md_comment_flash = "\uf15b0"
	# CHAR : 󱖱
	md_comment_flash_outline = "\uf15b1"
	# CHAR : 󱗟
	md_comment_minus = "\uf15df"
	# CHAR : 󱗠
	md_comment_minus_outline = "\uf15e0"
	# CHAR : 󰡟
	md_comment_multiple = "\uf085f"
	# CHAR : 󰆁
	md_comment_multiple_outline = "\uf0181"
	# CHAR : 󱗡
	md_comment_off = "\uf15e1"
	# CHAR : 󱗢
	md_comment_off_outline = "\uf15e2"
	# CHAR : 󰆂
	md_comment_outline = "\uf0182"
	# CHAR : 󰧥
	md_comment_plus = "\uf09e5"
	# CHAR : 󰆃
	md_comment_plus_outline = "\uf0183"
	# CHAR : 󰆄
	md_comment_processing = "\uf0184"
	# CHAR : 󰆅
	md_comment_processing_outline = "\uf0185"
	# CHAR : 󰠗
	md_comment_question = "\uf0817"
	# CHAR : 󰆆
	md_comment_question_outline = "\uf0186"
	# CHAR : 󱀡
	md_comment_quote = "\uf1021"
	# CHAR : 󱀢
	md_comment_quote_outline = "\uf1022"
	# CHAR : 󰗞
	md_comment_remove = "\uf05de"
	# CHAR : 󰆇
	md_comment_remove_outline = "\uf0187"
	# CHAR : 󰨼
	md_comment_search = "\uf0a3c"
	# CHAR : 󰨽
	md_comment_search_outline = "\uf0a3d"
	# CHAR : 󰆈
	md_comment_text = "\uf0188"
	# CHAR : 󰡠
	md_comment_text_multiple = "\uf0860"
	# CHAR : 󰡡
	md_comment_text_multiple_outline = "\uf0861"
	# CHAR : 󰆉
	md_comment_text_outline = "\uf0189"
	# CHAR : 󰆊
	md_compare = "\uf018a"
	# CHAR : 󱒒
	md_compare_horizontal = "\uf1492"
	# CHAR : 󱢳
	md_compare_remove = "\uf18b3"
	# CHAR : 󱒓
	md_compare_vertical = "\uf1493"
	# CHAR : 󰆋
	md_compass = "\uf018b"
	# CHAR : 󰮀
	md_compass_off = "\uf0b80"
	# CHAR : 󰮁
	md_compass_off_outline = "\uf0b81"
	# CHAR : 󰆌
	md_compass_outline = "\uf018c"
	# CHAR : 󱎂
	md_compass_rose = "\uf1382"
	# CHAR : 󱨸
	md_compost = "\uf1a38"
	# CHAR : 󱥌
	md_cone = "\uf194c"
	# CHAR : 󱥍
	md_cone_off = "\uf194d"
	# CHAR : 󱘖
	md_connection = "\uf1616"
	# CHAR : 󰆍
	md_console = "\uf018d"
	# CHAR : 󰞷
	md_console_line = "\uf07b7"
	# CHAR : 󰢩
	md_console_network = "\uf08a9"
	# CHAR : 󰱠
	md_console_network_outline = "\uf0c60"
	# CHAR : 󱃘
	md_consolidate = "\uf10d8"
	# CHAR : 󰵪
	md_contactless_payment = "\uf0d6a"
	# CHAR : 󰌡
	md_contactless_payment_circle = "\uf0321"
	# CHAR : 󰐈
	md_contactless_payment_circle_outline = "\uf0408"
	# CHAR : 󰛋
	md_contacts = "\uf06cb"
	# CHAR : 󰖸
	md_contacts_outline = "\uf05b8"
	# CHAR : 󰨾
	md_contain = "\uf0a3e"
	# CHAR : 󰨿
	md_contain_end = "\uf0a3f"
	# CHAR : 󰩀
	md_contain_start = "\uf0a40"
	# CHAR : 󰆏
	md_content_copy = "\uf018f"
	# CHAR : 󰆐
	md_content_cut = "\uf0190"
	# CHAR : 󰆑
	md_content_duplicate = "\uf0191"
	# CHAR : 󰆒
	md_content_paste = "\uf0192"
	# CHAR : 󰆓
	md_content_save = "\uf0193"
	# CHAR : 󰽂
	md_content_save_alert = "\uf0f42"
	# CHAR : 󰽃
	md_content_save_alert_outline = "\uf0f43"
	# CHAR : 󰆔
	md_content_save_all = "\uf0194"
	# CHAR : 󰽄
	md_content_save_all_outline = "\uf0f44"
	# CHAR : 󱣪
	md_content_save_check = "\uf18ea"
	# CHAR : 󱣫
	md_content_save_check_outline = "\uf18eb"
	# CHAR : 󱑛
	md_content_save_cog = "\uf145b"
	# CHAR : 󱑜
	md_content_save_cog_outline = "\uf145c"
	# CHAR : 󰳻
	md_content_save_edit = "\uf0cfb"
	# CHAR : 󰳼
	md_content_save_edit_outline = "\uf0cfc"
	# CHAR : 󰸧
	md_content_save_move = "\uf0e27"
	# CHAR : 󰸨
	md_content_save_move_outline = "\uf0e28"
	# CHAR : 󱙃
	md_content_save_off = "\uf1643"
	# CHAR : 󱙄
	md_content_save_off_outline = "\uf1644"
	# CHAR : 󰠘
	md_content_save_outline = "\uf0818"
	# CHAR : 󰘛
	md_content_save_settings = "\uf061b"
	# CHAR : 󰬮
	md_content_save_settings_outline = "\uf0b2e"
	# CHAR : 󰆕
	md_contrast = "\uf0195"
	# CHAR : 󰆖
	md_contrast_box = "\uf0196"
	# CHAR : 󰆗
	md_contrast_circle = "\uf0197"
	# CHAR : 󰮂
	md_controller_classic = "\uf0b82"
	# CHAR : 󰮃
	md_controller_classic_outline = "\uf0b83"
	# CHAR : 󰆘
	md_cookie = "\uf0198"
	# CHAR : 󱛐
	md_cookie_alert = "\uf16d0"
	# CHAR : 󱛑
	md_cookie_alert_outline = "\uf16d1"
	# CHAR : 󱛒
	md_cookie_check = "\uf16d2"
	# CHAR : 󱛓
	md_cookie_check_outline = "\uf16d3"
	# CHAR : 󱛤
	md_cookie_clock = "\uf16e4"
	# CHAR : 󱛥
	md_cookie_clock_outline = "\uf16e5"
	# CHAR : 󱛔
	md_cookie_cog = "\uf16d4"
	# CHAR : 󱛕
	md_cookie_cog_outline = "\uf16d5"
	# CHAR : 󱛦
	md_cookie_edit = "\uf16e6"
	# CHAR : 󱛧
	md_cookie_edit_outline = "\uf16e7"
	# CHAR : 󱛨
	md_cookie_lock = "\uf16e8"
	# CHAR : 󱛩
	md_cookie_lock_outline = "\uf16e9"
	# CHAR : 󱛚
	md_cookie_minus = "\uf16da"
	# CHAR : 󱛛
	md_cookie_minus_outline = "\uf16db"
	# CHAR : 󱛪
	md_cookie_off = "\uf16ea"
	# CHAR : 󱛫
	md_cookie_off_outline = "\uf16eb"
	# CHAR : 󱛞
	md_cookie_outline = "\uf16de"
	# CHAR : 󱛖
	md_cookie_plus = "\uf16d6"
	# CHAR : 󱛗
	md_cookie_plus_outline = "\uf16d7"
	# CHAR : 󱛬
	md_cookie_refresh = "\uf16ec"
	# CHAR : 󱛭
	md_cookie_refresh_outline = "\uf16ed"
	# CHAR : 󱛘
	md_cookie_remove = "\uf16d8"
	# CHAR : 󱛙
	md_cookie_remove_outline = "\uf16d9"
	# CHAR : 󱛜
	md_cookie_settings = "\uf16dc"
	# CHAR : 󱛝
	md_cookie_settings_outline = "\uf16dd"
	# CHAR : 󰏈
	md_coolant_temperature = "\uf03c8"
	# CHAR : 󱤹
	md_copyleft = "\uf1939"
	# CHAR : 󰗦
	md_copyright = "\uf05e6"
	# CHAR : 󰥘
	md_cordova = "\uf0958"
	# CHAR : 󰞸
	md_corn = "\uf07b8"
	# CHAR : 󱏯
	md_corn_off = "\uf13ef"
	# CHAR : 󱑹
	md_cosine_wave = "\uf1479"
	# CHAR : 󰆙
	md_counter = "\uf0199"
	# CHAR : 󱠜
	md_countertop = "\uf181c"
	# CHAR : 󱠝
	md_countertop_outline = "\uf181d"
	# CHAR : 󰆚
	md_cow = "\uf019a"
	# CHAR : 󱣼
	md_cow_off = "\uf18fc"
	# CHAR : 󰻟
	md_cpu_32_bit = "\uf0edf"
	# CHAR : 󰻠
	md_cpu_64_bit = "\uf0ee0"
	# CHAR : 󱦋
	md_cradle = "\uf198b"
	# CHAR : 󱦑
	md_cradle_outline = "\uf1991"
	# CHAR : 󰡢
	md_crane = "\uf0862"
	# CHAR : 󰙴
	md_creation = "\uf0674"
	# CHAR : 󰵫
	md_creative_commons = "\uf0d6b"
	# CHAR : 󰿯
	md_credit_card = "\uf0fef"
	# CHAR : 󱏐
	md_credit_card_check = "\uf13d0"
	# CHAR : 󱏑
	md_credit_card_check_outline = "\uf13d1"
	# CHAR : 󱤏
	md_credit_card_chip = "\uf190f"
	# CHAR : 󱤐
	md_credit_card_chip_outline = "\uf1910"
	# CHAR : 󰻡
	md_credit_card_clock = "\uf0ee1"
	# CHAR : 󰻢
	md_credit_card_clock_outline = "\uf0ee2"
	# CHAR : 󱟗
	md_credit_card_edit = "\uf17d7"
	# CHAR : 󱟘
	md_credit_card_edit_outline = "\uf17d8"
	# CHAR : 󱤑
	md_credit_card_fast = "\uf1911"
	# CHAR : 󱤒
	md_credit_card_fast_outline = "\uf1912"
	# CHAR : 󱣧
	md_credit_card_lock = "\uf18e7"
	# CHAR : 󱣨
	md_credit_card_lock_outline = "\uf18e8"
	# CHAR : 󰚨
	md_credit_card_marker = "\uf06a8"
	# CHAR : 󰶾
	md_credit_card_marker_outline = "\uf0dbe"
	# CHAR : 󰾬
	md_credit_card_minus = "\uf0fac"
	# CHAR : 󰾭
	md_credit_card_minus_outline = "\uf0fad"
	# CHAR : 󰿰
	md_credit_card_multiple = "\uf0ff0"
	# CHAR : 󰆜
	md_credit_card_multiple_outline = "\uf019c"
	# CHAR : 󰿱
	md_credit_card_off = "\uf0ff1"
	# CHAR : 󰗤
	md_credit_card_off_outline = "\uf05e4"
	# CHAR : 󰆛
	md_credit_card_outline = "\uf019b"
	# CHAR : 󰿲
	md_credit_card_plus = "\uf0ff2"
	# CHAR : 󰙶
	md_credit_card_plus_outline = "\uf0676"
	# CHAR : 󱙅
	md_credit_card_refresh = "\uf1645"
	# CHAR : 󱙆
	md_credit_card_refresh_outline = "\uf1646"
	# CHAR : 󰿳
	md_credit_card_refund = "\uf0ff3"
	# CHAR : 󰪨
	md_credit_card_refund_outline = "\uf0aa8"
	# CHAR : 󰾮
	md_credit_card_remove = "\uf0fae"
	# CHAR : 󰾯
	md_credit_card_remove_outline = "\uf0faf"
	# CHAR : 󰿴
	md_credit_card_scan = "\uf0ff4"
	# CHAR : 󰆝
	md_credit_card_scan_outline = "\uf019d"
	# CHAR : 󱙇
	md_credit_card_search = "\uf1647"
	# CHAR : 󱙈
	md_credit_card_search_outline = "\uf1648"
	# CHAR : 󰿵
	md_credit_card_settings = "\uf0ff5"
	# CHAR : 󰣗
	md_credit_card_settings_outline = "\uf08d7"
	# CHAR : 󱙉
	md_credit_card_sync = "\uf1649"
	# CHAR : 󱙊
	md_credit_card_sync_outline = "\uf164a"
	# CHAR : 󰠂
	md_credit_card_wireless = "\uf0802"
	# CHAR : 󰕺
	md_credit_card_wireless_off = "\uf057a"
	# CHAR : 󰕻
	md_credit_card_wireless_off_outline = "\uf057b"
	# CHAR : 󰵬
	md_credit_card_wireless_outline = "\uf0d6c"
	# CHAR : 󰵭
	md_cricket = "\uf0d6d"
	# CHAR : 󰆞
	md_crop = "\uf019e"
	# CHAR : 󰆟
	md_crop_free = "\uf019f"
	# CHAR : 󰆠
	md_crop_landscape = "\uf01a0"
	# CHAR : 󰆡
	md_crop_portrait = "\uf01a1"
	# CHAR : 󰚖
	md_crop_rotate = "\uf0696"
	# CHAR : 󰆢
	md_crop_square = "\uf01a2"
	# CHAR : 󰥓
	md_cross = "\uf0953"
	# CHAR : 󰳭
	md_cross_bolnisi = "\uf0ced"
	# CHAR : 󰳵
	md_cross_celtic = "\uf0cf5"
	# CHAR : 󰳶
	md_cross_outline = "\uf0cf6"
	# CHAR : 󰆣
	md_crosshairs = "\uf01a3"
	# CHAR : 󰆤
	md_crosshairs_gps = "\uf01a4"
	# CHAR : 󰽅
	md_crosshairs_off = "\uf0f45"
	# CHAR : 󱄶
	md_crosshairs_question = "\uf1136"
	# CHAR : 󱥵
	md_crowd = "\uf1975"
	# CHAR : 󰆥
	md_crown = "\uf01a5"
	# CHAR : 󱟜
	md_crown_circle = "\uf17dc"
	# CHAR : 󱟝
	md_crown_circle_outline = "\uf17dd"
	# CHAR : 󱇐
	md_crown_outline = "\uf11d0"
	# CHAR : 󰥙
	md_cryengine = "\uf0959"
	# CHAR : 󰬯
	md_crystal_ball = "\uf0b2f"
	# CHAR : 󰆦
	md_cube = "\uf01a6"
	# CHAR : 󱐜
	md_cube_off = "\uf141c"
	# CHAR : 󱐝
	md_cube_off_outline = "\uf141d"
	# CHAR : 󰆧
	md_cube_outline = "\uf01a7"
	# CHAR : 󰮄
	md_cube_scan = "\uf0b84"
	# CHAR : 󰆨
	md_cube_send = "\uf01a8"
	# CHAR : 󰆩
	md_cube_unfolded = "\uf01a9"
	# CHAR : 󰆪
	md_cup = "\uf01aa"
	# CHAR : 󰗥
	md_cup_off = "\uf05e5"
	# CHAR : 󱍽
	md_cup_off_outline = "\uf137d"
	# CHAR : 󱌏
	md_cup_outline = "\uf130f"
	# CHAR : 󰆫
	md_cup_water = "\uf01ab"
	# CHAR : 󰽆
	md_cupboard = "\uf0f46"
	# CHAR : 󰽇
	md_cupboard_outline = "\uf0f47"
	# CHAR : 󰥚
	md_cupcake = "\uf095a"
	# CHAR : 󰡣
	md_curling = "\uf0863"
	# CHAR : 󰡤
	md_currency_bdt = "\uf0864"
	# CHAR : 󰮅
	md_currency_brl = "\uf0b85"
	# CHAR : 󰆬
	md_currency_btc = "\uf01ac"
	# CHAR : 󰞺
	md_currency_cny = "\uf07ba"
	# CHAR : 󰞻
	md_currency_eth = "\uf07bb"
	# CHAR : 󰆭
	md_currency_eur = "\uf01ad"
	# CHAR : 󱌕
	md_currency_eur_off = "\uf1315"
	# CHAR : 󱨹
	md_currency_fra = "\uf1a39"
	# CHAR : 󰆮
	md_currency_gbp = "\uf01ae"
	# CHAR : 󰱡
	md_currency_ils = "\uf0c61"
	# CHAR : 󰆯
	md_currency_inr = "\uf01af"
	# CHAR : 󰞼
	md_currency_jpy = "\uf07bc"
	# CHAR : 󰞽
	md_currency_krw = "\uf07bd"
	# CHAR : 󰡥
	md_currency_kzt = "\uf0865"
	# CHAR : 󱔒
	md_currency_mnt = "\uf1512"
	# CHAR : 󰆰
	md_currency_ngn = "\uf01b0"
	# CHAR : 󰧦
	md_currency_php = "\uf09e6"
	# CHAR : 󰺜
	md_currency_rial = "\uf0e9c"
	# CHAR : 󰆱
	md_currency_rub = "\uf01b1"
	# CHAR : 󱥶
	md_currency_rupee = "\uf1976"
	# CHAR : 󰞾
	md_currency_sign = "\uf07be"
	# CHAR : 󰆲
	md_currency_try = "\uf01b2"
	# CHAR : 󰞿
	md_currency_twd = "\uf07bf"
	# CHAR : 󰇁
	md_currency_usd = "\uf01c1"
	# CHAR : 󰙺
	md_currency_usd_off = "\uf067a"
	# CHAR : 󱒀
	md_current_ac = "\uf1480"
	# CHAR : 󰥜
	md_current_dc = "\uf095c"
	# CHAR : 󰇀
	md_cursor_default = "\uf01c0"
	# CHAR : 󰳽
	md_cursor_default_click = "\uf0cfd"
	# CHAR : 󰳾
	md_cursor_default_click_outline = "\uf0cfe"
	# CHAR : 󱄧
	md_cursor_default_gesture = "\uf1127"
	# CHAR : 󱄨
	md_cursor_default_gesture_outline = "\uf1128"
	# CHAR : 󰆿
	md_cursor_default_outline = "\uf01bf"
	# CHAR : 󰆾
	md_cursor_move = "\uf01be"
	# CHAR : 󰆽
	md_cursor_pointer = "\uf01bd"
	# CHAR : 󰗧
	md_cursor_text = "\uf05e7"
	# CHAR : 󱡆
	md_curtains = "\uf1846"
	# CHAR : 󱡇
	md_curtains_closed = "\uf1847"
	# CHAR : 󱥎
	md_cylinder = "\uf194e"
	# CHAR : 󱥏
	md_cylinder_off = "\uf194f"
	# CHAR : 󱗻
	md_dance_ballroom = "\uf15fb"
	# CHAR : 󱕸
	md_dance_pole = "\uf1578"
	# CHAR : 󱔼
	md_data_matrix = "\uf153c"
	# CHAR : 󱔽
	md_data_matrix_edit = "\uf153d"
	# CHAR : 󱔾
	md_data_matrix_minus = "\uf153e"
	# CHAR : 󱔿
	md_data_matrix_plus = "\uf153f"
	# CHAR : 󱕀
	md_data_matrix_remove = "\uf1540"
	# CHAR : 󱕁
	md_data_matrix_scan = "\uf1541"
	# CHAR : 󰆼
	md_database = "\uf01bc"
	# CHAR : 󱘺
	md_database_alert = "\uf163a"
	# CHAR : 󱘤
	md_database_alert_outline = "\uf1624"
	# CHAR : 󱘻
	md_database_arrow_down = "\uf163b"
	# CHAR : 󱘥
	md_database_arrow_down_outline = "\uf1625"
	# CHAR : 󱘼
	md_database_arrow_left = "\uf163c"
	# CHAR : 󱘦
	md_database_arrow_left_outline = "\uf1626"
	# CHAR : 󱘽
	md_database_arrow_right = "\uf163d"
	# CHAR : 󱘧
	md_database_arrow_right_outline = "\uf1627"
	# CHAR : 󱘾
	md_database_arrow_up = "\uf163e"
	# CHAR : 󱘨
	md_database_arrow_up_outline = "\uf1628"
	# CHAR : 󰪩
	md_database_check = "\uf0aa9"
	# CHAR : 󱘩
	md_database_check_outline = "\uf1629"
	# CHAR : 󱘿
	md_database_clock = "\uf163f"
	# CHAR : 󱘪
	md_database_clock_outline = "\uf162a"
	# CHAR : 󱙋
	md_database_cog = "\uf164b"
	# CHAR : 󱙌
	md_database_cog_outline = "\uf164c"
	# CHAR : 󰮆
	md_database_edit = "\uf0b86"
	# CHAR : 󱘫
	md_database_edit_outline = "\uf162b"
	# CHAR : 󰥞
	md_database_export = "\uf095e"
	# CHAR : 󱘬
	md_database_export_outline = "\uf162c"
	# CHAR : 󱤟
	md_database_eye = "\uf191f"
	# CHAR : 󱤠
	md_database_eye_off = "\uf1920"
	# CHAR : 󱤡
	md_database_eye_off_outline = "\uf1921"
	# CHAR : 󱤢
	md_database_eye_outline = "\uf1922"
	# CHAR : 󰥝
	md_database_import = "\uf095d"
	# CHAR : 󱘭
	md_database_import_outline = "\uf162d"
	# CHAR : 󰪪
	md_database_lock = "\uf0aaa"
	# CHAR : 󱘮
	md_database_lock_outline = "\uf162e"
	# CHAR : 󱋶
	md_database_marker = "\uf12f6"
	# CHAR : 󱘯
	md_database_marker_outline = "\uf162f"
	# CHAR : 󰆻
	md_database_minus = "\uf01bb"
	# CHAR : 󱘰
	md_database_minus_outline = "\uf1630"
	# CHAR : 󱙀
	md_database_off = "\uf1640"
	# CHAR : 󱘱
	md_database_off_outline = "\uf1631"
	# CHAR : 󱘲
	md_database_outline = "\uf1632"
	# CHAR : 󰆺
	md_database_plus = "\uf01ba"
	# CHAR : 󱘳
	md_database_plus_outline = "\uf1633"
	# CHAR : 󰗂
	md_database_refresh = "\uf05c2"
	# CHAR : 󱘴
	md_database_refresh_outline = "\uf1634"
	# CHAR : 󰴀
	md_database_remove = "\uf0d00"
	# CHAR : 󱘵
	md_database_remove_outline = "\uf1635"
	# CHAR : 󰡦
	md_database_search = "\uf0866"
	# CHAR : 󱘶
	md_database_search_outline = "\uf1636"
	# CHAR : 󰴁
	md_database_settings = "\uf0d01"
	# CHAR : 󱘷
	md_database_settings_outline = "\uf1637"
	# CHAR : 󰳿
	md_database_sync = "\uf0cff"
	# CHAR : 󱘸
	md_database_sync_outline = "\uf1638"
	# CHAR : 󰣘
	md_death_star = "\uf08d8"
	# CHAR : 󰣙
	md_death_star_variant = "\uf08d9"
	# CHAR : 󰮇
	md_deathly_hallows = "\uf0b87"
	# CHAR : 󰣚
	md_debian = "\uf08da"
	# CHAR : 󰆹
	md_debug_step_into = "\uf01b9"
	# CHAR : 󰆸
	md_debug_step_out = "\uf01b8"
	# CHAR : 󰆷
	md_debug_step_over = "\uf01b7"
	# CHAR : 󰝬
	md_decagram = "\uf076c"
	# CHAR : 󰝭
	md_decagram_outline = "\uf076d"
	# CHAR : 󱂡
	md_decimal = "\uf10a1"
	# CHAR : 󱂢
	md_decimal_comma = "\uf10a2"
	# CHAR : 󱂣
	md_decimal_comma_decrease = "\uf10a3"
	# CHAR : 󱂤
	md_decimal_comma_increase = "\uf10a4"
	# CHAR : 󰆶
	md_decimal_decrease = "\uf01b6"
	# CHAR : 󰆵
	md_decimal_increase = "\uf01b5"
	# CHAR : 󰆴
	md_delete = "\uf01b4"
	# CHAR : 󱂥
	md_delete_alert = "\uf10a5"
	# CHAR : 󱂦
	md_delete_alert_outline = "\uf10a6"
	# CHAR : 󰚃
	md_delete_circle = "\uf0683"
	# CHAR : 󰮈
	md_delete_circle_outline = "\uf0b88"
	# CHAR : 󱕖
	md_delete_clock = "\uf1556"
	# CHAR : 󱕗
	md_delete_clock_outline = "\uf1557"
	# CHAR : 󰛌
	md_delete_empty = "\uf06cc"
	# CHAR : 󰺝
	md_delete_empty_outline = "\uf0e9d"
	# CHAR : 󰗨
	md_delete_forever = "\uf05e8"
	# CHAR : 󰮉
	md_delete_forever_outline = "\uf0b89"
	# CHAR : 󱂧
	md_delete_off = "\uf10a7"
	# CHAR : 󱂨
	md_delete_off_outline = "\uf10a8"
	# CHAR : 󰧧
	md_delete_outline = "\uf09e7"
	# CHAR : 󰠙
	md_delete_restore = "\uf0819"
	# CHAR : 󰗩
	md_delete_sweep = "\uf05e9"
	# CHAR : 󰱢
	md_delete_sweep_outline = "\uf0c62"
	# CHAR : 󰆳
	md_delete_variant = "\uf01b3"
	# CHAR : 󰇂
	md_delta = "\uf01c2"
	# CHAR : 󱈹
	md_desk = "\uf1239"
	# CHAR : 󰥟
	md_desk_lamp = "\uf095f"
	# CHAR : 󰇃
	md_deskphone = "\uf01c3"
	# CHAR : 󰟀
	md_desktop_classic = "\uf07c0"
	# CHAR : 󰇄
	md_desktop_mac = "\uf01c4"
	# CHAR : 󰧨
	md_desktop_mac_dashboard = "\uf09e8"
	# CHAR : 󰇅
	md_desktop_tower = "\uf01c5"
	# CHAR : 󰪫
	md_desktop_tower_monitor = "\uf0aab"
	# CHAR : 󰇆
	md_details = "\uf01c6"
	# CHAR : 󰵮
	md_dev_to = "\uf0d6e"
	# CHAR : 󰚗
	md_developer_board = "\uf0697"
	# CHAR : 󰇇
	md_deviantart = "\uf01c7"
	# CHAR : 󰾰
	md_devices = "\uf0fb0"
	# CHAR : 󰥋
	md_dharmachakra = "\uf094b"
	# CHAR : 󱄦
	md_diabetes = "\uf1126"
	# CHAR : 󰘜
	md_dialpad = "\uf061c"
	# CHAR : 󰱣
	md_diameter = "\uf0c63"
	# CHAR : 󰱤
	md_diameter_outline = "\uf0c64"
	# CHAR : 󰱥
	md_diameter_variant = "\uf0c65"
	# CHAR : 󰮊
	md_diamond = "\uf0b8a"
	# CHAR : 󰮋
	md_diamond_outline = "\uf0b8b"
	# CHAR : 󰇈
	md_diamond_stone = "\uf01c8"
	# CHAR : 󰇊
	md_dice_1 = "\uf01ca"
	# CHAR : 󱅊
	md_dice_1_outline = "\uf114a"
	# CHAR : 󰇋
	md_dice_2 = "\uf01cb"
	# CHAR : 󱅋
	md_dice_2_outline = "\uf114b"
	# CHAR : 󰇌
	md_dice_3 = "\uf01cc"
	# CHAR : 󱅌
	md_dice_3_outline = "\uf114c"
	# CHAR : 󰇍
	md_dice_4 = "\uf01cd"
	# CHAR : 󱅍
	md_dice_4_outline = "\uf114d"
	# CHAR : 󰇎
	md_dice_5 = "\uf01ce"
	# CHAR : 󱅎
	md_dice_5_outline = "\uf114e"
	# CHAR : 󰇏
	md_dice_6 = "\uf01cf"
	# CHAR : 󱅏
	md_dice_6_outline = "\uf114f"
	# CHAR : 󱅓
	md_dice_d10 = "\uf1153"
	# CHAR : 󰝯
	md_dice_d10_outline = "\uf076f"
	# CHAR : 󱅔
	md_dice_d12 = "\uf1154"
	# CHAR : 󰡧
	md_dice_d12_outline = "\uf0867"
	# CHAR : 󱅕
	md_dice_d20 = "\uf1155"
	# CHAR : 󰗪
	md_dice_d20_outline = "\uf05ea"
	# CHAR : 󱅐
	md_dice_d4 = "\uf1150"
	# CHAR : 󰗫
	md_dice_d4_outline = "\uf05eb"
	# CHAR : 󱅑
	md_dice_d6 = "\uf1151"
	# CHAR : 󰗭
	md_dice_d6_outline = "\uf05ed"
	# CHAR : 󱅒
	md_dice_d8 = "\uf1152"
	# CHAR : 󰗬
	md_dice_d8_outline = "\uf05ec"
	# CHAR : 󰝮
	md_dice_multiple = "\uf076e"
	# CHAR : 󱅖
	md_dice_multiple_outline = "\uf1156"
	# CHAR : 󱈷
	md_digital_ocean = "\uf1237"
	# CHAR : 󰟁
	md_dip_switch = "\uf07c1"
	# CHAR : 󰇐
	md_directions = "\uf01d0"
	# CHAR : 󰙁
	md_directions_fork = "\uf0641"
	# CHAR : 󰗮
	md_disc = "\uf05ee"
	# CHAR : 󰇑
	md_disc_alert = "\uf01d1"
	# CHAR : 󰥠
	md_disc_player = "\uf0960"
	# CHAR : 󰙯
	md_discord = "\uf066f"
	# CHAR : 󰪬
	md_dishwasher = "\uf0aac"
	# CHAR : 󱆸
	md_dishwasher_alert = "\uf11b8"
	# CHAR : 󱆹
	md_dishwasher_off = "\uf11b9"
	# CHAR : 󰇒
	md_disqus = "\uf01d2"
	# CHAR : 󱇉
	md_distribute_horizontal_center = "\uf11c9"
	# CHAR : 󱇈
	md_distribute_horizontal_left = "\uf11c8"
	# CHAR : 󱇊
	md_distribute_horizontal_right = "\uf11ca"
	# CHAR : 󱇋
	md_distribute_vertical_bottom = "\uf11cb"
	# CHAR : 󱇌
	md_distribute_vertical_center = "\uf11cc"
	# CHAR : 󱇍
	md_distribute_vertical_top = "\uf11cd"
	# CHAR : 󱡷
	md_diversify = "\uf1877"
	# CHAR : 󱥷
	md_diving = "\uf1977"
	# CHAR : 󰶿
	md_diving_flippers = "\uf0dbf"
	# CHAR : 󰷀
	md_diving_helmet = "\uf0dc0"
	# CHAR : 󰷁
	md_diving_scuba = "\uf0dc1"
	# CHAR : 󰷂
	md_diving_scuba_flag = "\uf0dc2"
	# CHAR : 󰷃
	md_diving_scuba_tank = "\uf0dc3"
	# CHAR : 󰷄
	md_diving_scuba_tank_multiple = "\uf0dc4"
	# CHAR : 󰷅
	md_diving_snorkel = "\uf0dc5"
	# CHAR : 󰇔
	md_division = "\uf01d4"
	# CHAR : 󰇕
	md_division_box = "\uf01d5"
	# CHAR : 󰩁
	md_dlna = "\uf0a41"
	# CHAR : 󰚄
	md_dna = "\uf0684"
	# CHAR : 󰇖
	md_dns = "\uf01d6"
	# CHAR : 󰮌
	md_dns_outline = "\uf0b8c"
	# CHAR : 󱂩
	md_dock_bottom = "\uf10a9"
	# CHAR : 󱂪
	md_dock_left = "\uf10aa"
	# CHAR : 󱂫
	md_dock_right = "\uf10ab"
	# CHAR : 󱔓
	md_dock_top = "\uf1513"
	# CHAR : 󱂬
	md_dock_window = "\uf10ac"
	# CHAR : 󰡨
	md_docker = "\uf0868"
	# CHAR : 󰩂
	md_doctor = "\uf0a42"
	# CHAR : 󰩃
	md_dog = "\uf0a43"
	# CHAR : 󰪭
	md_dog_service = "\uf0aad"
	# CHAR : 󰩄
	md_dog_side = "\uf0a44"
	# CHAR : 󱛮
	md_dog_side_off = "\uf16ee"
	# CHAR : 󰚳
	md_dolby = "\uf06b3"
	# CHAR : 󰺞
	md_dolly = "\uf0e9e"
	# CHAR : 󱢴
	md_dolphin = "\uf18b4"
	# CHAR : 󰇗
	md_domain = "\uf01d7"
	# CHAR : 󰵯
	md_domain_off = "\uf0d6f"
	# CHAR : 󱂭
	md_domain_plus = "\uf10ad"
	# CHAR : 󱂮
	md_domain_remove = "\uf10ae"
	# CHAR : 󱐞
	md_dome_light = "\uf141e"
	# CHAR : 󱀣
	md_domino_mask = "\uf1023"
	# CHAR : 󰟂
	md_donkey = "\uf07c2"
	# CHAR : 󰠚
	md_door = "\uf081a"
	# CHAR : 󰠛
	md_door_closed = "\uf081b"
	# CHAR : 󱂯
	md_door_closed_lock = "\uf10af"
	# CHAR : 󰠜
	md_door_open = "\uf081c"
	# CHAR : 󱠞
	md_door_sliding = "\uf181e"
	# CHAR : 󱠟
	md_door_sliding_lock = "\uf181f"
	# CHAR : 󱠠
	md_door_sliding_open = "\uf1820"
	# CHAR : 󱋦
	md_doorbell = "\uf12e6"
	# CHAR : 󰡩
	md_doorbell_video = "\uf0869"
	# CHAR : 󰪮
	md_dot_net = "\uf0aae"
	# CHAR : 󱥸
	md_dots_circle = "\uf1978"
	# CHAR : 󱗼
	md_dots_grid = "\uf15fc"
	# CHAR : 󱗿
	md_dots_hexagon = "\uf15ff"
	# CHAR : 󰇘
	md_dots_horizontal = "\uf01d8"
	# CHAR : 󰟃
	md_dots_horizontal_circle = "\uf07c3"
	# CHAR : 󰮍
	md_dots_horizontal_circle_outline = "\uf0b8d"
	# CHAR : 󱗽
	md_dots_square = "\uf15fd"
	# CHAR : 󱗾
	md_dots_triangle = "\uf15fe"
	# CHAR : 󰇙
	md_dots_vertical = "\uf01d9"
	# CHAR : 󰟄
	md_dots_vertical_circle = "\uf07c4"
	# CHAR : 󰮎
	md_dots_vertical_circle_outline = "\uf0b8e"
	# CHAR : 󰇚
	md_download = "\uf01da"
	# CHAR : 󱑢
	md_download_box = "\uf1462"
	# CHAR : 󱑣
	md_download_box_outline = "\uf1463"
	# CHAR : 󱑤
	md_download_circle = "\uf1464"
	# CHAR : 󱑥
	md_download_circle_outline = "\uf1465"
	# CHAR : 󱌠
	md_download_lock = "\uf1320"
	# CHAR : 󱌡
	md_download_lock_outline = "\uf1321"
	# CHAR : 󰧩
	md_download_multiple = "\uf09e9"
	# CHAR : 󰛴
	md_download_network = "\uf06f4"
	# CHAR : 󰱦
	md_download_network_outline = "\uf0c66"
	# CHAR : 󱂰
	md_download_off = "\uf10b0"
	# CHAR : 󱂱
	md_download_off_outline = "\uf10b1"
	# CHAR : 󰮏
	md_download_outline = "\uf0b8f"
	# CHAR : 󰇛
	md_drag = "\uf01db"
	# CHAR : 󰇜
	md_drag_horizontal = "\uf01dc"
	# CHAR : 󱋰
	md_drag_horizontal_variant = "\uf12f0"
	# CHAR : 󰮐
	md_drag_variant = "\uf0b90"
	# CHAR : 󰇝
	md_drag_vertical = "\uf01dd"
	# CHAR : 󱋱
	md_drag_vertical_variant = "\uf12f1"
	# CHAR : 󰴂
	md_drama_masks = "\uf0d02"
	# CHAR : 󰽉
	md_draw = "\uf0f49"
	# CHAR : 󱦹
	md_draw_pen = "\uf19b9"
	# CHAR : 󰇞
	md_drawing = "\uf01de"
	# CHAR : 󰇟
	md_drawing_box = "\uf01df"
	# CHAR : 󰽊
	md_dresser = "\uf0f4a"
	# CHAR : 󰽋
	md_dresser_outline = "\uf0f4b"
	# CHAR : 󰇢
	md_drone = "\uf01e2"
	# CHAR : 󰇣
	md_dropbox = "\uf01e3"
	# CHAR : 󰇤
	md_drupal = "\uf01e4"
	# CHAR : 󰇥
	md_duck = "\uf01e5"
	# CHAR : 󰇦
	md_dumbbell = "\uf01e6"
	# CHAR : 󰱧
	md_dump_truck = "\uf0c67"
	# CHAR : 󰟅
	md_ear_hearing = "\uf07c5"
	# CHAR : 󱫮
	md_ear_hearing_loop = "\uf1aee"
	# CHAR : 󰩅
	md_ear_hearing_off = "\uf0a45"
	# CHAR : 󱡏
	md_earbuds = "\uf184f"
	# CHAR : 󱡐
	md_earbuds_off = "\uf1850"
	# CHAR : 󱡑
	md_earbuds_off_outline = "\uf1851"
	# CHAR : 󱡒
	md_earbuds_outline = "\uf1852"
	# CHAR : 󰇧
	md_earth = "\uf01e7"
	# CHAR : 󱌑
	md_earth_arrow_right = "\uf1311"
	# CHAR : 󰛍
	md_earth_box = "\uf06cd"
	# CHAR : 󱐇
	md_earth_box_minus = "\uf1407"
	# CHAR : 󰛎
	md_earth_box_off = "\uf06ce"
	# CHAR : 󱐆
	md_earth_box_plus = "\uf1406"
	# CHAR : 󱐈
	md_earth_box_remove = "\uf1408"
	# CHAR : 󱐄
	md_earth_minus = "\uf1404"
	# CHAR : 󰇨
	md_earth_off = "\uf01e8"
	# CHAR : 󱐃
	md_earth_plus = "\uf1403"
	# CHAR : 󱐅
	md_earth_remove = "\uf1405"
	# CHAR : 󰪯
	md_egg = "\uf0aaf"
	# CHAR : 󰪰
	md_egg_easter = "\uf0ab0"
	# CHAR : 󱡊
	md_egg_fried = "\uf184a"
	# CHAR : 󱏰
	md_egg_off = "\uf13f0"
	# CHAR : 󱏱
	md_egg_off_outline = "\uf13f1"
	# CHAR : 󱏲
	md_egg_outline = "\uf13f2"
	# CHAR : 󱕫
	md_eiffel_tower = "\uf156b"
	# CHAR : 󰧪
	md_eight_track = "\uf09ea"
	# CHAR : 󰇪
	md_eject = "\uf01ea"
	# CHAR : 󰮑
	md_eject_outline = "\uf0b91"
	# CHAR : 󰺟
	md_electric_switch = "\uf0e9f"
	# CHAR : 󱃙
	md_electric_switch_closed = "\uf10d9"
	# CHAR : 󱀤
	md_electron_framework = "\uf1024"
	# CHAR : 󰟆
	md_elephant = "\uf07c6"
	# CHAR : 󰇫
	md_elevation_decline = "\uf01eb"
	# CHAR : 󰇬
	md_elevation_rise = "\uf01ec"
	# CHAR : 󰇭
	md_elevator = "\uf01ed"
	# CHAR : 󱋂
	md_elevator_down = "\uf12c2"
	# CHAR : 󱎁
	md_elevator_passenger = "\uf1381"
	# CHAR : 󱥹
	md_elevator_passenger_off = "\uf1979"
	# CHAR : 󱥺
	md_elevator_passenger_off_outline = "\uf197a"
	# CHAR : 󱥻
	md_elevator_passenger_outline = "\uf197b"
	# CHAR : 󱋁
	md_elevator_up = "\uf12c1"
	# CHAR : 󰺠
	md_ellipse = "\uf0ea0"
	# CHAR : 󰺡
	md_ellipse_outline = "\uf0ea1"
	# CHAR : 󰇮
	md_email = "\uf01ee"
	# CHAR : 󰛏
	md_email_alert = "\uf06cf"
	# CHAR : 󰵂
	md_email_alert_outline = "\uf0d42"
	# CHAR : 󰴃
	md_email_box = "\uf0d03"
	# CHAR : 󰪱
	md_email_check = "\uf0ab1"
	# CHAR : 󰪲
	md_email_check_outline = "\uf0ab2"
	# CHAR : 󰻣
	md_email_edit = "\uf0ee3"
	# CHAR : 󰻤
	md_email_edit_outline = "\uf0ee4"
	# CHAR : 󱡯
	md_email_fast = "\uf186f"
	# CHAR : 󱡰
	md_email_fast_outline = "\uf1870"
	# CHAR : 󰇱
	md_email_lock = "\uf01f1"
	# CHAR : 󰮒
	md_email_mark_as_unread = "\uf0b92"
	# CHAR : 󰻥
	md_email_minus = "\uf0ee5"
	# CHAR : 󰻦
	md_email_minus_outline = "\uf0ee6"
	# CHAR : 󰻧
	md_email_multiple = "\uf0ee7"
	# CHAR : 󰻨
	md_email_multiple_outline = "\uf0ee8"
	# CHAR : 󰾱
	md_email_newsletter = "\uf0fb1"
	# CHAR : 󱏣
	md_email_off = "\uf13e3"
	# CHAR : 󱏤
	md_email_off_outline = "\uf13e4"
	# CHAR : 󰇯
	md_email_open = "\uf01ef"
	# CHAR : 󰻩
	md_email_open_multiple = "\uf0ee9"
	# CHAR : 󰻪
	md_email_open_multiple_outline = "\uf0eea"
	# CHAR : 󰗯
	md_email_open_outline = "\uf05ef"
	# CHAR : 󰇰
	md_email_outline = "\uf01f0"
	# CHAR : 󰧫
	md_email_plus = "\uf09eb"
	# CHAR : 󰧬
	md_email_plus_outline = "\uf09ec"
	# CHAR : 󱃚
	md_email_receive = "\uf10da"
	# CHAR : 󱃛
	md_email_receive_outline = "\uf10db"
	# CHAR : 󱙡
	md_email_remove = "\uf1661"
	# CHAR : 󱙢
	md_email_remove_outline = "\uf1662"
	# CHAR : 󱥛
	md_email_seal = "\uf195b"
	# CHAR : 󱥜
	md_email_seal_outline = "\uf195c"
	# CHAR : 󰥡
	md_email_search = "\uf0961"
	# CHAR : 󰥢
	md_email_search_outline = "\uf0962"
	# CHAR : 󱃜
	md_email_send = "\uf10dc"
	# CHAR : 󱃝
	md_email_send_outline = "\uf10dd"
	# CHAR : 󱋇
	md_email_sync = "\uf12c7"
	# CHAR : 󱋈
	md_email_sync_outline = "\uf12c8"
	# CHAR : 󰗰
	md_email_variant = "\uf05f0"
	# CHAR : 󰬰
	md_ember = "\uf0b30"
	# CHAR : 󰚴
	md_emby = "\uf06b4"
	# CHAR : 󰱨
	md_emoticon = "\uf0c68"
	# CHAR : 󰱩
	md_emoticon_angry = "\uf0c69"
	# CHAR : 󰱪
	md_emoticon_angry_outline = "\uf0c6a"
	# CHAR : 󱃞
	md_emoticon_confused = "\uf10de"
	# CHAR : 󱃟
	md_emoticon_confused_outline = "\uf10df"
	# CHAR : 󰱫
	md_emoticon_cool = "\uf0c6b"
	# CHAR : 󰇳
	md_emoticon_cool_outline = "\uf01f3"
	# CHAR : 󰱬
	md_emoticon_cry = "\uf0c6c"
	# CHAR : 󰱭
	md_emoticon_cry_outline = "\uf0c6d"
	# CHAR : 󰱮
	md_emoticon_dead = "\uf0c6e"
	# CHAR : 󰚛
	md_emoticon_dead_outline = "\uf069b"
	# CHAR : 󰱯
	md_emoticon_devil = "\uf0c6f"
	# CHAR : 󰇴
	md_emoticon_devil_outline = "\uf01f4"
	# CHAR : 󰱰
	md_emoticon_excited = "\uf0c70"
	# CHAR : 󰚜
	md_emoticon_excited_outline = "\uf069c"
	# CHAR : 󰽌
	md_emoticon_frown = "\uf0f4c"
	# CHAR : 󰽍
	md_emoticon_frown_outline = "\uf0f4d"
	# CHAR : 󰱱
	md_emoticon_happy = "\uf0c71"
	# CHAR : 󰇵
	md_emoticon_happy_outline = "\uf01f5"
	# CHAR : 󰱲
	md_emoticon_kiss = "\uf0c72"
	# CHAR : 󰱳
	md_emoticon_kiss_outline = "\uf0c73"
	# CHAR : 󱈔
	md_emoticon_lol = "\uf1214"
	# CHAR : 󱈕
	md_emoticon_lol_outline = "\uf1215"
	# CHAR : 󰱴
	md_emoticon_neutral = "\uf0c74"
	# CHAR : 󰇶
	md_emoticon_neutral_outline = "\uf01f6"
	# CHAR : 󰇲
	md_emoticon_outline = "\uf01f2"
	# CHAR : 󰇷
	md_emoticon_poop = "\uf01f7"
	# CHAR : 󰱵
	md_emoticon_poop_outline = "\uf0c75"
	# CHAR : 󰱶
	md_emoticon_sad = "\uf0c76"
	# CHAR : 󰇸
	md_emoticon_sad_outline = "\uf01f8"
	# CHAR : 󱕼
	md_emoticon_sick = "\uf157c"
	# CHAR : 󱕽
	md_emoticon_sick_outline = "\uf157d"
	# CHAR : 󰇹
	md_emoticon_tongue = "\uf01f9"
	# CHAR : 󰱷
	md_emoticon_tongue_outline = "\uf0c77"
	# CHAR : 󰱸
	md_emoticon_wink = "\uf0c78"
	# CHAR : 󰱹
	md_emoticon_wink_outline = "\uf0c79"
	# CHAR : 󰇺
	md_engine = "\uf01fa"
	# CHAR : 󰩆
	md_engine_off = "\uf0a46"
	# CHAR : 󰩇
	md_engine_off_outline = "\uf0a47"
	# CHAR : 󰇻
	md_engine_outline = "\uf01fb"
	# CHAR : 󱃠
	md_epsilon = "\uf10e0"
	# CHAR : 󰇼
	md_equal = "\uf01fc"
	# CHAR : 󰇽
	md_equal_box = "\uf01fd"
	# CHAR : 󰺢
	md_equalizer = "\uf0ea2"
	# CHAR : 󰺣
	md_equalizer_outline = "\uf0ea3"
	# CHAR : 󰇾
	md_eraser = "\uf01fe"
	# CHAR : 󰙂
	md_eraser_variant = "\uf0642"
	# CHAR : 󰇿
	md_escalator = "\uf01ff"
	# CHAR : 󱎙
	md_escalator_box = "\uf1399"
	# CHAR : 󱋀
	md_escalator_down = "\uf12c0"
	# CHAR : 󱊿
	md_escalator_up = "\uf12bf"
	# CHAR : 󰱺
	md_eslint = "\uf0c7a"
	# CHAR : 󰪳
	md_et = "\uf0ab3"
	# CHAR : 󰡪
	md_ethereum = "\uf086a"
	# CHAR : 󰈀
	md_ethernet = "\uf0200"
	# CHAR : 󰈁
	md_ethernet_cable = "\uf0201"
	# CHAR : 󰈂
	md_ethernet_cable_off = "\uf0202"
	# CHAR : 󱔙
	md_ev_plug_ccs1 = "\uf1519"
	# CHAR : 󱔚
	md_ev_plug_ccs2 = "\uf151a"
	# CHAR : 󱔛
	md_ev_plug_chademo = "\uf151b"
	# CHAR : 󱔜
	md_ev_plug_tesla = "\uf151c"
	# CHAR : 󱔝
	md_ev_plug_type1 = "\uf151d"
	# CHAR : 󱔞
	md_ev_plug_type2 = "\uf151e"
	# CHAR : 󰗱
	md_ev_station = "\uf05f1"
	# CHAR : 󰈄
	md_evernote = "\uf0204"
	# CHAR : 󱀥
	md_excavator = "\uf1025"
	# CHAR : 󰈅
	md_exclamation = "\uf0205"
	# CHAR : 󱈸
	md_exclamation_thick = "\uf1238"
	# CHAR : 󰩈
	md_exit_run = "\uf0a48"
	# CHAR : 󰈆
	md_exit_to_app = "\uf0206"
	# CHAR : 󰪴
	md_expand_all = "\uf0ab4"
	# CHAR : 󰪵
	md_expand_all_outline = "\uf0ab5"
	# CHAR : 󰢮
	md_expansion_card = "\uf08ae"
	# CHAR : 󰾲
	md_expansion_card_variant = "\uf0fb2"
	# CHAR : 󰥣
	md_exponent = "\uf0963"
	# CHAR : 󰥤
	md_exponent_box = "\uf0964"
	# CHAR : 󰈇
	md_export = "\uf0207"
	# CHAR : 󰮓
	md_export_variant = "\uf0b93"
	# CHAR : 󰈈
	md_eye = "\uf0208"
	# CHAR : 󱣽
	md_eye_arrow_left = "\uf18fd"
	# CHAR : 󱣾
	md_eye_arrow_left_outline = "\uf18fe"
	# CHAR : 󱣿
	md_eye_arrow_right = "\uf18ff"
	# CHAR : 󱤀
	md_eye_arrow_right_outline = "\uf1900"
	# CHAR : 󰴄
	md_eye_check = "\uf0d04"
	# CHAR : 󰴅
	md_eye_check_outline = "\uf0d05"
	# CHAR : 󰮔
	md_eye_circle = "\uf0b94"
	# CHAR : 󰮕
	md_eye_circle_outline = "\uf0b95"
	# CHAR : 󱀦
	md_eye_minus = "\uf1026"
	# CHAR : 󱀧
	md_eye_minus_outline = "\uf1027"
	# CHAR : 󰈉
	md_eye_off = "\uf0209"
	# CHAR : 󰛑
	md_eye_off_outline = "\uf06d1"
	# CHAR : 󰛐
	md_eye_outline = "\uf06d0"
	# CHAR : 󰡫
	md_eye_plus = "\uf086b"
	# CHAR : 󰡬
	md_eye_plus_outline = "\uf086c"
	# CHAR : 󱥼
	md_eye_refresh = "\uf197c"
	# CHAR : 󱥽
	md_eye_refresh_outline = "\uf197d"
	# CHAR : 󱗣
	md_eye_remove = "\uf15e3"
	# CHAR : 󱗤
	md_eye_remove_outline = "\uf15e4"
	# CHAR : 󰡭
	md_eye_settings = "\uf086d"
	# CHAR : 󰡮
	md_eye_settings_outline = "\uf086e"
	# CHAR : 󰈊
	md_eyedropper = "\uf020a"
	# CHAR : 󱏝
	md_eyedropper_minus = "\uf13dd"
	# CHAR : 󱏟
	md_eyedropper_off = "\uf13df"
	# CHAR : 󱏜
	md_eyedropper_plus = "\uf13dc"
	# CHAR : 󱏞
	md_eyedropper_remove = "\uf13de"
	# CHAR : 󰈋
	md_eyedropper_variant = "\uf020b"
	# CHAR : 󰵰
	md_face_agent = "\uf0d70"
	# CHAR : 󰙃
	md_face_man = "\uf0643"
	# CHAR : 󰮖
	md_face_man_outline = "\uf0b96"
	# CHAR : 󰙄
	md_face_man_profile = "\uf0644"
	# CHAR : 󱗌
	md_face_man_shimmer = "\uf15cc"
	# CHAR : 󱗍
	md_face_man_shimmer_outline = "\uf15cd"
	# CHAR : 󱖆
	md_face_mask = "\uf1586"
	# CHAR : 󱖇
	md_face_mask_outline = "\uf1587"
	# CHAR : 󰱻
	md_face_recognition = "\uf0c7b"
	# CHAR : 󱁷
	md_face_woman = "\uf1077"
	# CHAR : 󱁸
	md_face_woman_outline = "\uf1078"
	# CHAR : 󱁶
	md_face_woman_profile = "\uf1076"
	# CHAR : 󱗎
	md_face_woman_shimmer = "\uf15ce"
	# CHAR : 󱗏
	md_face_woman_shimmer_outline = "\uf15cf"
	# CHAR : 󰈌
	md_facebook = "\uf020c"
	# CHAR : 󰟝
	md_facebook_gaming = "\uf07dd"
	# CHAR : 󰈎
	md_facebook_messenger = "\uf020e"
	# CHAR : 󰬱
	md_facebook_workplace = "\uf0b31"
	# CHAR : 󰈏
	md_factory = "\uf020f"
	# CHAR : 󱘎
	md_family_tree = "\uf160e"
	# CHAR : 󰈐
	md_fan = "\uf0210"
	# CHAR : 󱑬
	md_fan_alert = "\uf146c"
	# CHAR : 󱜝
	md_fan_auto = "\uf171d"
	# CHAR : 󱑭
	md_fan_chevron_down = "\uf146d"
	# CHAR : 󱑮
	md_fan_chevron_up = "\uf146e"
	# CHAR : 󱨺
	md_fan_clock = "\uf1a3a"
	# CHAR : 󱑰
	md_fan_minus = "\uf1470"
	# CHAR : 󰠝
	md_fan_off = "\uf081d"
	# CHAR : 󱑯
	md_fan_plus = "\uf146f"
	# CHAR : 󱑱
	md_fan_remove = "\uf1471"
	# CHAR : 󱑲
	md_fan_speed_1 = "\uf1472"
	# CHAR : 󱑳
	md_fan_speed_2 = "\uf1473"
	# CHAR : 󱑴
	md_fan_speed_3 = "\uf1474"
	# CHAR : 󰈑
	md_fast_forward = "\uf0211"
	# CHAR : 󰵱
	md_fast_forward_10 = "\uf0d71"
	# CHAR : 󱤺
	md_fast_forward_15 = "\uf193a"
	# CHAR : 󰴆
	md_fast_forward_30 = "\uf0d06"
	# CHAR : 󱇸
	md_fast_forward_5 = "\uf11f8"
	# CHAR : 󱘋
	md_fast_forward_60 = "\uf160b"
	# CHAR : 󰛒
	md_fast_forward_outline = "\uf06d2"
	# CHAR : 󰈒
	md_fax = "\uf0212"
	# CHAR : 󰛓
	md_feather = "\uf06d3"
	# CHAR : 󰩉
	md_feature_search = "\uf0a49"
	# CHAR : 󰩊
	md_feature_search_outline = "\uf0a4a"
	# CHAR : 󰣛
	md_fedora = "\uf08db"
	# CHAR : 󱞚
	md_fence = "\uf179a"
	# CHAR : 󱟶
	md_fence_electric = "\uf17f6"
	# CHAR : 󱓁
	md_fencing = "\uf14c1"
	# CHAR : 󰺤
	md_ferris_wheel = "\uf0ea4"
	# CHAR : 󰈓
	md_ferry = "\uf0213"
	# CHAR : 󰈔
	md_file = "\uf0214"
	# CHAR : 󰜻
	md_file_account = "\uf073b"
	# CHAR : 󱀨
	md_file_account_outline = "\uf1028"
	# CHAR : 󰩋
	md_file_alert = "\uf0a4b"
	# CHAR : 󰩌
	md_file_alert_outline = "\uf0a4c"
	# CHAR : 󱪓
	md_file_arrow_left_right = "\uf1a93"
	# CHAR : 󱪔
	md_file_arrow_left_right_outline = "\uf1a94"
	# CHAR : 󱪕
	md_file_arrow_up_down = "\uf1a95"
	# CHAR : 󱪖
	md_file_arrow_up_down_outline = "\uf1a96"
	# CHAR : 󰪶
	md_file_cabinet = "\uf0ab6"
	# CHAR : 󰻫
	md_file_cad = "\uf0eeb"
	# CHAR : 󰻬
	md_file_cad_box = "\uf0eec"
	# CHAR : 󰷆
	md_file_cancel = "\uf0dc6"
	# CHAR : 󰷇
	md_file_cancel_outline = "\uf0dc7"
	# CHAR : 󱆆
	md_file_certificate = "\uf1186"
	# CHAR : 󱆇
	md_file_certificate_outline = "\uf1187"
	# CHAR : 󰈕
	md_file_chart = "\uf0215"
	# CHAR : 󱧆
	md_file_chart_check = "\uf19c6"
	# CHAR : 󱧇
	md_file_chart_check_outline = "\uf19c7"
	# CHAR : 󱀩
	md_file_chart_outline = "\uf1029"
	# CHAR : 󰈖
	md_file_check = "\uf0216"
	# CHAR : 󰸩
	md_file_check_outline = "\uf0e29"
	# CHAR : 󱋡
	md_file_clock = "\uf12e1"
	# CHAR : 󱋢
	md_file_clock_outline = "\uf12e2"
	# CHAR : 󰈗
	md_file_cloud = "\uf0217"
	# CHAR : 󱀪
	md_file_cloud_outline = "\uf102a"
	# CHAR : 󰈮
	md_file_code = "\uf022e"
	# CHAR : 󱀫
	md_file_code_outline = "\uf102b"
	# CHAR : 󱁻
	md_file_cog = "\uf107b"
	# CHAR : 󱁼
	md_file_cog_outline = "\uf107c"
	# CHAR : 󰢪
	md_file_compare = "\uf08aa"
	# CHAR : 󰈘
	md_file_delimited = "\uf0218"
	# CHAR : 󰺥
	md_file_delimited_outline = "\uf0ea5"
	# CHAR : 󰈙
	md_file_document = "\uf0219"
	# CHAR : 󱪗
	md_file_document_alert = "\uf1a97"
	# CHAR : 󱪘
	md_file_document_alert_outline = "\uf1a98"
	# CHAR : 󱪙
	md_file_document_check = "\uf1a99"
	# CHAR : 󱪚
	md_file_document_check_outline = "\uf1a9a"
	# CHAR : 󰷈
	md_file_document_edit = "\uf0dc8"
	# CHAR : 󰷉
	md_file_document_edit_outline = "\uf0dc9"
	# CHAR : 󱪛
	md_file_document_minus = "\uf1a9b"
	# CHAR : 󱪜
	md_file_document_minus_outline = "\uf1a9c"
	# CHAR : 󱔗
	md_file_document_multiple = "\uf1517"
	# CHAR : 󱔘
	md_file_document_multiple_outline = "\uf1518"
	# CHAR : 󰧮
	md_file_document_outline = "\uf09ee"
	# CHAR : 󱪝
	md_file_document_plus = "\uf1a9d"
	# CHAR : 󱪞
	md_file_document_plus_outline = "\uf1a9e"
	# CHAR : 󱪟
	md_file_document_remove = "\uf1a9f"
	# CHAR : 󱪠
	md_file_document_remove_outline = "\uf1aa0"
	# CHAR : 󰥥
	md_file_download = "\uf0965"
	# CHAR : 󰥦
	md_file_download_outline = "\uf0966"
	# CHAR : 󱇧
	md_file_edit = "\uf11e7"
	# CHAR : 󱇨
	md_file_edit_outline = "\uf11e8"
	# CHAR : 󰈛
	md_file_excel = "\uf021b"
	# CHAR : 󰈜
	md_file_excel_box = "\uf021c"
	# CHAR : 󱀬
	md_file_excel_box_outline = "\uf102c"
	# CHAR : 󱀭
	md_file_excel_outline = "\uf102d"
	# CHAR : 󰈝
	md_file_export = "\uf021d"
	# CHAR : 󱀮
	md_file_export_outline = "\uf102e"
	# CHAR : 󰷊
	md_file_eye = "\uf0dca"
	# CHAR : 󰷋
	md_file_eye_outline = "\uf0dcb"
	# CHAR : 󰈞
	md_file_find = "\uf021e"
	# CHAR : 󰮗
	md_file_find_outline = "\uf0b97"
	# CHAR : 󰵸
	md_file_gif_box = "\uf0d78"
	# CHAR : 󰘓
	md_file_hidden = "\uf0613"
	# CHAR : 󰈟
	md_file_image = "\uf021f"
	# CHAR : 󱝲
	md_file_image_marker = "\uf1772"
	# CHAR : 󱝳
	md_file_image_marker_outline = "\uf1773"
	# CHAR : 󱤻
	md_file_image_minus = "\uf193b"
	# CHAR : 󱤼
	md_file_image_minus_outline = "\uf193c"
	# CHAR : 󰺰
	md_file_image_outline = "\uf0eb0"
	# CHAR : 󱤽
	md_file_image_plus = "\uf193d"
	# CHAR : 󱤾
	md_file_image_plus_outline = "\uf193e"
	# CHAR : 󱤿
	md_file_image_remove = "\uf193f"
	# CHAR : 󱥀
	md_file_image_remove_outline = "\uf1940"
	# CHAR : 󰈠
	md_file_import = "\uf0220"
	# CHAR : 󱀯
	md_file_import_outline = "\uf102f"
	# CHAR : 󰈥
	md_file_jpg_box = "\uf0225"
	# CHAR : 󱆄
	md_file_key = "\uf1184"
	# CHAR : 󱆅
	md_file_key_outline = "\uf1185"
	# CHAR : 󱅷
	md_file_link = "\uf1177"
	# CHAR : 󱅸
	md_file_link_outline = "\uf1178"
	# CHAR : 󰈡
	md_file_lock = "\uf0221"
	# CHAR : 󱧈
	md_file_lock_open = "\uf19c8"
	# CHAR : 󱧉
	md_file_lock_open_outline = "\uf19c9"
	# CHAR : 󱀰
	md_file_lock_outline = "\uf1030"
	# CHAR : 󱝴
	md_file_marker = "\uf1774"
	# CHAR : 󱝵
	md_file_marker_outline = "\uf1775"
	# CHAR : 󱪡
	md_file_minus = "\uf1aa1"
	# CHAR : 󱪢
	md_file_minus_outline = "\uf1aa2"
	# CHAR : 󰪹
	md_file_move = "\uf0ab9"
	# CHAR : 󱀱
	md_file_move_outline = "\uf1031"
	# CHAR : 󰈢
	md_file_multiple = "\uf0222"
	# CHAR : 󱀲
	md_file_multiple_outline = "\uf1032"
	# CHAR : 󰈣
	md_file_music = "\uf0223"
	# CHAR : 󰸪
	md_file_music_outline = "\uf0e2a"
	# CHAR : 󰈤
	md_file_outline = "\uf0224"
	# CHAR : 󰈦
	md_file_pdf_box = "\uf0226"
	# CHAR : 󰠞
	md_file_percent = "\uf081e"
	# CHAR : 󱀳
	md_file_percent_outline = "\uf1033"
	# CHAR : 󱅹
	md_file_phone = "\uf1179"
	# CHAR : 󱅺
	md_file_phone_outline = "\uf117a"
	# CHAR : 󰝒
	md_file_plus = "\uf0752"
	# CHAR : 󰻭
	md_file_plus_outline = "\uf0eed"
	# CHAR : 󰸭
	md_file_png_box = "\uf0e2d"
	# CHAR : 󰈧
	md_file_powerpoint = "\uf0227"
	# CHAR : 󰈨
	md_file_powerpoint_box = "\uf0228"
	# CHAR : 󱀴
	md_file_powerpoint_box_outline = "\uf1034"
	# CHAR : 󱀵
	md_file_powerpoint_outline = "\uf1035"
	# CHAR : 󰈩
	md_file_presentation_box = "\uf0229"
	# CHAR : 󰡯
	md_file_question = "\uf086f"
	# CHAR : 󱀶
	md_file_question_outline = "\uf1036"
	# CHAR : 󰤘
	md_file_refresh = "\uf0918"
	# CHAR : 󰕁
	md_file_refresh_outline = "\uf0541"
	# CHAR : 󰮘
	md_file_remove = "\uf0b98"
	# CHAR : 󱀷
	md_file_remove_outline = "\uf1037"
	# CHAR : 󰬲
	md_file_replace = "\uf0b32"
	# CHAR : 󰬳
	md_file_replace_outline = "\uf0b33"
	# CHAR : 󰙰
	md_file_restore = "\uf0670"
	# CHAR : 󱀸
	md_file_restore_outline = "\uf1038"
	# CHAR : 󱨻
	md_file_rotate_left = "\uf1a3b"
	# CHAR : 󱨼
	md_file_rotate_left_outline = "\uf1a3c"
	# CHAR : 󱨽
	md_file_rotate_right = "\uf1a3d"
	# CHAR : 󱨾
	md_file_rotate_right_outline = "\uf1a3e"
	# CHAR : 󰱼
	md_file_search = "\uf0c7c"
	# CHAR : 󰱽
	md_file_search_outline = "\uf0c7d"
	# CHAR : 󰈪
	md_file_send = "\uf022a"
	# CHAR : 󱀹
	md_file_send_outline = "\uf1039"
	# CHAR : 󱁹
	md_file_settings = "\uf1079"
	# CHAR : 󱁺
	md_file_settings_outline = "\uf107a"
	# CHAR : 󱧃
	md_file_sign = "\uf19c3"
	# CHAR : 󱀺
	md_file_star = "\uf103a"
	# CHAR : 󱀻
	md_file_star_outline = "\uf103b"
	# CHAR : 󰾴
	md_file_swap = "\uf0fb4"
	# CHAR : 󰾵
	md_file_swap_outline = "\uf0fb5"
	# CHAR : 󱈖
	md_file_sync = "\uf1216"
	# CHAR : 󱈗
	md_file_sync_outline = "\uf1217"
	# CHAR : 󰱾
	md_file_table = "\uf0c7e"
	# CHAR : 󱃡
	md_file_table_box = "\uf10e1"
	# CHAR : 󱃢
	md_file_table_box_multiple = "\uf10e2"
	# CHAR : 󱃣
	md_file_table_box_multiple_outline = "\uf10e3"
	# CHAR : 󱃤
	md_file_table_box_outline = "\uf10e4"
	# CHAR : 󰱿
	md_file_table_outline = "\uf0c7f"
	# CHAR : 󰙅
	md_file_tree = "\uf0645"
	# CHAR : 󱏒
	md_file_tree_outline = "\uf13d2"
	# CHAR : 󰣜
	md_file_undo = "\uf08dc"
	# CHAR : 󱀼
	md_file_undo_outline = "\uf103c"
	# CHAR : 󰩍
	md_file_upload = "\uf0a4d"
	# CHAR : 󰩎
	md_file_upload_outline = "\uf0a4e"
	# CHAR : 󰈫
	md_file_video = "\uf022b"
	# CHAR : 󰸬
	md_file_video_outline = "\uf0e2c"
	# CHAR : 󰈬
	md_file_word = "\uf022c"
	# CHAR : 󰈭
	md_file_word_box = "\uf022d"
	# CHAR : 󱀽
	md_file_word_box_outline = "\uf103d"
	# CHAR : 󱀾
	md_file_word_outline = "\uf103e"
	# CHAR : 󰈯
	md_film = "\uf022f"
	# CHAR : 󰈰
	md_filmstrip = "\uf0230"
	# CHAR : 󰌲
	md_filmstrip_box = "\uf0332"
	# CHAR : 󰴘
	md_filmstrip_box_multiple = "\uf0d18"
	# CHAR : 󰈱
	md_filmstrip_off = "\uf0231"
	# CHAR : 󰈲
	md_filter = "\uf0232"
	# CHAR : 󱣬
	md_filter_check = "\uf18ec"
	# CHAR : 󱣭
	md_filter_check_outline = "\uf18ed"
	# CHAR : 󱪣
	md_filter_cog = "\uf1aa3"
	# CHAR : 󱪤
	md_filter_cog_outline = "\uf1aa4"
	# CHAR : 󱃥
	md_filter_menu = "\uf10e5"
	# CHAR : 󱃦
	md_filter_menu_outline = "\uf10e6"
	# CHAR : 󰻮
	md_filter_minus = "\uf0eee"
	# CHAR : 󰻯
	md_filter_minus_outline = "\uf0eef"
	# CHAR : 󱨿
	md_filter_multiple = "\uf1a3f"
	# CHAR : 󱩀
	md_filter_multiple_outline = "\uf1a40"
	# CHAR : 󱓯
	md_filter_off = "\uf14ef"
	# CHAR : 󱓰
	md_filter_off_outline = "\uf14f0"
	# CHAR : 󰈳
	md_filter_outline = "\uf0233"
	# CHAR : 󰻰
	md_filter_plus = "\uf0ef0"
	# CHAR : 󰻱
	md_filter_plus_outline = "\uf0ef1"
	# CHAR : 󰈴
	md_filter_remove = "\uf0234"
	# CHAR : 󰈵
	md_filter_remove_outline = "\uf0235"
	# CHAR : 󱪥
	md_filter_settings = "\uf1aa5"
	# CHAR : 󱪦
	md_filter_settings_outline = "\uf1aa6"
	# CHAR : 󰈶
	md_filter_variant = "\uf0236"
	# CHAR : 󱄒
	md_filter_variant_minus = "\uf1112"
	# CHAR : 󱄓
	md_filter_variant_plus = "\uf1113"
	# CHAR : 󱀿
	md_filter_variant_remove = "\uf103f"
	# CHAR : 󰠟
	md_finance = "\uf081f"
	# CHAR : 󰛔
	md_find_replace = "\uf06d4"
	# CHAR : 󰈷
	md_fingerprint = "\uf0237"
	# CHAR : 󰺱
	md_fingerprint_off = "\uf0eb1"
	# CHAR : 󰈸
	md_fire = "\uf0238"
	# CHAR : 󱗗
	md_fire_alert = "\uf15d7"
	# CHAR : 󱠇
	md_fire_circle = "\uf1807"
	# CHAR : 󰻲
	md_fire_extinguisher = "\uf0ef2"
	# CHAR : 󱄷
	md_fire_hydrant = "\uf1137"
	# CHAR : 󱄸
	md_fire_hydrant_alert = "\uf1138"
	# CHAR : 󱄹
	md_fire_hydrant_off = "\uf1139"
	# CHAR : 󱜢
	md_fire_off = "\uf1722"
	# CHAR : 󰢫
	md_fire_truck = "\uf08ab"
	# CHAR : 󰥧
	md_firebase = "\uf0967"
	# CHAR : 󰈹
	md_firefox = "\uf0239"
	# CHAR : 󰸮
	md_fireplace = "\uf0e2e"
	# CHAR : 󰸯
	md_fireplace_off = "\uf0e2f"
	# CHAR : 󰖾
	md_firewire = "\uf05be"
	# CHAR : 󰸰
	md_firework = "\uf0e30"
	# CHAR : 󱜣
	md_firework_off = "\uf1723"
	# CHAR : 󰈺
	md_fish = "\uf023a"
	# CHAR : 󱏳
	md_fish_off = "\uf13f3"
	# CHAR : 󰻳
	md_fishbowl = "\uf0ef3"
	# CHAR : 󰻴
	md_fishbowl_outline = "\uf0ef4"
	# CHAR : 󰻵
	md_fit_to_page = "\uf0ef5"
	# CHAR : 󰻶
	md_fit_to_page_outline = "\uf0ef6"
	# CHAR : 󱣴
	md_fit_to_screen = "\uf18f4"
	# CHAR : 󱣵
	md_fit_to_screen_outline = "\uf18f5"
	# CHAR : 󰈻
	md_flag = "\uf023b"
	# CHAR : 󰈼
	md_flag_checkered = "\uf023c"
	# CHAR : 󰮙
	md_flag_minus = "\uf0b99"
	# CHAR : 󱂲
	md_flag_minus_outline = "\uf10b2"
	# CHAR : 󱣮
	md_flag_off = "\uf18ee"
	# CHAR : 󱣯
	md_flag_off_outline = "\uf18ef"
	# CHAR : 󰈽
	md_flag_outline = "\uf023d"
	# CHAR : 󰮚
	md_flag_plus = "\uf0b9a"
	# CHAR : 󱂳
	md_flag_plus_outline = "\uf10b3"
	# CHAR : 󰮛
	md_flag_remove = "\uf0b9b"
	# CHAR : 󱂴
	md_flag_remove_outline = "\uf10b4"
	# CHAR : 󰈿
	md_flag_triangle = "\uf023f"
	# CHAR : 󰉀
	md_flag_variant = "\uf0240"
	# CHAR : 󰈾
	md_flag_variant_outline = "\uf023e"
	# CHAR : 󰵲
	md_flare = "\uf0d72"
	# CHAR : 󰉁
	md_flash = "\uf0241"
	# CHAR : 󰻷
	md_flash_alert = "\uf0ef7"
	# CHAR : 󰻸
	md_flash_alert_outline = "\uf0ef8"
	# CHAR : 󰉂
	md_flash_auto = "\uf0242"
	# CHAR : 󰉃
	md_flash_off = "\uf0243"
	# CHAR : 󰛕
	md_flash_outline = "\uf06d5"
	# CHAR : 󰙻
	md_flash_red_eye = "\uf067b"
	# CHAR : 󰉄
	md_flashlight = "\uf0244"
	# CHAR : 󰉅
	md_flashlight_off = "\uf0245"
	# CHAR : 󰂓
	md_flask = "\uf0093"
	# CHAR : 󰂔
	md_flask_empty = "\uf0094"
	# CHAR : 󱈺
	md_flask_empty_minus = "\uf123a"
	# CHAR : 󱈻
	md_flask_empty_minus_outline = "\uf123b"
	# CHAR : 󱏴
	md_flask_empty_off = "\uf13f4"
	# CHAR : 󱏵
	md_flask_empty_off_outline = "\uf13f5"
	# CHAR : 󰂕
	md_flask_empty_outline = "\uf0095"
	# CHAR : 󱈼
	md_flask_empty_plus = "\uf123c"
	# CHAR : 󱈽
	md_flask_empty_plus_outline = "\uf123d"
	# CHAR : 󱈾
	md_flask_empty_remove = "\uf123e"
	# CHAR : 󱈿
	md_flask_empty_remove_outline = "\uf123f"
	# CHAR : 󱉀
	md_flask_minus = "\uf1240"
	# CHAR : 󱉁
	md_flask_minus_outline = "\uf1241"
	# CHAR : 󱏶
	md_flask_off = "\uf13f6"
	# CHAR : 󱏷
	md_flask_off_outline = "\uf13f7"
	# CHAR : 󰂖
	md_flask_outline = "\uf0096"
	# CHAR : 󱉂
	md_flask_plus = "\uf1242"
	# CHAR : 󱉃
	md_flask_plus_outline = "\uf1243"
	# CHAR : 󱉄
	md_flask_remove = "\uf1244"
	# CHAR : 󱉅
	md_flask_remove_outline = "\uf1245"
	# CHAR : 󱉋
	md_flask_round_bottom = "\uf124b"
	# CHAR : 󱉌
	md_flask_round_bottom_empty = "\uf124c"
	# CHAR : 󱉍
	md_flask_round_bottom_empty_outline = "\uf124d"
	# CHAR : 󱉎
	md_flask_round_bottom_outline = "\uf124e"
	# CHAR : 󱌃
	md_fleur_de_lis = "\uf1303"
	# CHAR : 󱃧
	md_flip_horizontal = "\uf10e7"
	# CHAR : 󰉇
	md_flip_to_back = "\uf0247"
	# CHAR : 󰉈
	md_flip_to_front = "\uf0248"
	# CHAR : 󱃨
	md_flip_vertical = "\uf10e8"
	# CHAR : 󰣝
	md_floor_lamp = "\uf08dd"
	# CHAR : 󱁀
	md_floor_lamp_dual = "\uf1040"
	# CHAR : 󱟎
	md_floor_lamp_dual_outline = "\uf17ce"
	# CHAR : 󱟈
	md_floor_lamp_outline = "\uf17c8"
	# CHAR : 󱝇
	md_floor_lamp_torchiere = "\uf1747"
	# CHAR : 󱟖
	md_floor_lamp_torchiere_outline = "\uf17d6"
	# CHAR : 󱁁
	md_floor_lamp_torchiere_variant = "\uf1041"
	# CHAR : 󱟏
	md_floor_lamp_torchiere_variant_outline = "\uf17cf"
	# CHAR : 󰠡
	md_floor_plan = "\uf0821"
	# CHAR : 󰉉
	md_floppy = "\uf0249"
	# CHAR : 󰧯
	md_floppy_variant = "\uf09ef"
	# CHAR : 󰉊
	md_flower = "\uf024a"
	# CHAR : 󰧰
	md_flower_outline = "\uf09f0"
	# CHAR : 󱢅
	md_flower_pollen = "\uf1885"
	# CHAR : 󱢆
	md_flower_pollen_outline = "\uf1886"
	# CHAR : 󰴈
	md_flower_poppy = "\uf0d08"
	# CHAR : 󰧱
	md_flower_tulip = "\uf09f1"
	# CHAR : 󰧲
	md_flower_tulip_outline = "\uf09f2"
	# CHAR : 󰽎
	md_focus_auto = "\uf0f4e"
	# CHAR : 󰽏
	md_focus_field = "\uf0f4f"
	# CHAR : 󰽐
	md_focus_field_horizontal = "\uf0f50"
	# CHAR : 󰽑
	md_focus_field_vertical = "\uf0f51"
	# CHAR : 󰉋
	md_folder = "\uf024b"
	# CHAR : 󰉌
	md_folder_account = "\uf024c"
	# CHAR : 󰮜
	md_folder_account_outline = "\uf0b9c"
	# CHAR : 󰷌
	md_folder_alert = "\uf0dcc"
	# CHAR : 󰷍
	md_folder_alert_outline = "\uf0dcd"
	# CHAR : 󱧨
	md_folder_arrow_down = "\uf19e8"
	# CHAR : 󱧩
	md_folder_arrow_down_outline = "\uf19e9"
	# CHAR : 󱧪
	md_folder_arrow_left = "\uf19ea"
	# CHAR : 󱧫
	md_folder_arrow_left_outline = "\uf19eb"
	# CHAR : 󱧬
	md_folder_arrow_left_right = "\uf19ec"
	# CHAR : 󱧭
	md_folder_arrow_left_right_outline = "\uf19ed"
	# CHAR : 󱧮
	md_folder_arrow_right = "\uf19ee"
	# CHAR : 󱧯
	md_folder_arrow_right_outline = "\uf19ef"
	# CHAR : 󱧰
	md_folder_arrow_up = "\uf19f0"
	# CHAR : 󱧱
	md_folder_arrow_up_down = "\uf19f1"
	# CHAR : 󱧲
	md_folder_arrow_up_down_outline = "\uf19f2"
	# CHAR : 󱧳
	md_folder_arrow_up_outline = "\uf19f3"
	# CHAR : 󱧴
	md_folder_cancel = "\uf19f4"
	# CHAR : 󱧵
	md_folder_cancel_outline = "\uf19f5"
	# CHAR : 󱥾
	md_folder_check = "\uf197e"
	# CHAR : 󱥿
	md_folder_check_outline = "\uf197f"
	# CHAR : 󰪺
	md_folder_clock = "\uf0aba"
	# CHAR : 󰪻
	md_folder_clock_outline = "\uf0abb"
	# CHAR : 󱁿
	md_folder_cog = "\uf107f"
	# CHAR : 󱂀
	md_folder_cog_outline = "\uf1080"
	# CHAR : 󰉍
	md_folder_download = "\uf024d"
	# CHAR : 󱃩
	md_folder_download_outline = "\uf10e9"
	# CHAR : 󰣞
	md_folder_edit = "\uf08de"
	# CHAR : 󰷎
	md_folder_edit_outline = "\uf0dce"
	# CHAR : 󱞊
	md_folder_eye = "\uf178a"
	# CHAR : 󱞋
	md_folder_eye_outline = "\uf178b"
	# CHAR : 󱧶
	md_folder_file = "\uf19f6"
	# CHAR : 󱧷
	md_folder_file_outline = "\uf19f7"
	# CHAR : 󰉎
	md_folder_google_drive = "\uf024e"
	# CHAR : 󱃪
	md_folder_heart = "\uf10ea"
	# CHAR : 󱃫
	md_folder_heart_outline = "\uf10eb"
	# CHAR : 󱞞
	md_folder_hidden = "\uf179e"
	# CHAR : 󱂵
	md_folder_home = "\uf10b5"
	# CHAR : 󱂶
	md_folder_home_outline = "\uf10b6"
	# CHAR : 󰉏
	md_folder_image = "\uf024f"
	# CHAR : 󱂷
	md_folder_information = "\uf10b7"
	# CHAR : 󱂸
	md_folder_information_outline = "\uf10b8"
	# CHAR : 󰢬
	md_folder_key = "\uf08ac"
	# CHAR : 󰢭
	md_folder_key_network = "\uf08ad"
	# CHAR : 󰲀
	md_folder_key_network_outline = "\uf0c80"
	# CHAR : 󱃬
	md_folder_key_outline = "\uf10ec"
	# CHAR : 󰉐
	md_folder_lock = "\uf0250"
	# CHAR : 󰉑
	md_folder_lock_open = "\uf0251"
	# CHAR : 󱪧
	md_folder_lock_open_outline = "\uf1aa7"
	# CHAR : 󱪨
	md_folder_lock_outline = "\uf1aa8"
	# CHAR : 󱉭
	md_folder_marker = "\uf126d"
	# CHAR : 󱉮
	md_folder_marker_outline = "\uf126e"
	# CHAR : 󰉒
	md_folder_move = "\uf0252"
	# CHAR : 󱉆
	md_folder_move_outline = "\uf1246"
	# CHAR : 󰉓
	md_folder_multiple = "\uf0253"
	# CHAR : 󰉔
	md_folder_multiple_image = "\uf0254"
	# CHAR : 󰉕
	md_folder_multiple_outline = "\uf0255"
	# CHAR : 󱑾
	md_folder_multiple_plus = "\uf147e"
	# CHAR : 󱑿
	md_folder_multiple_plus_outline = "\uf147f"
	# CHAR : 󱍙
	md_folder_music = "\uf1359"
	# CHAR : 󱍚
	md_folder_music_outline = "\uf135a"
	# CHAR : 󰡰
	md_folder_network = "\uf0870"
	# CHAR : 󰲁
	md_folder_network_outline = "\uf0c81"
	# CHAR : 󱧸
	md_folder_off = "\uf19f8"
	# CHAR : 󱧹
	md_folder_off_outline = "\uf19f9"
	# CHAR : 󰝰
	md_folder_open = "\uf0770"
	# CHAR : 󰷏
	md_folder_open_outline = "\uf0dcf"
	# CHAR : 󰉖
	md_folder_outline = "\uf0256"
	# CHAR : 󱧺
	md_folder_play = "\uf19fa"
	# CHAR : 󱧻
	md_folder_play_outline = "\uf19fb"
	# CHAR : 󰉗
	md_folder_plus = "\uf0257"
	# CHAR : 󰮝
	md_folder_plus_outline = "\uf0b9d"
	# CHAR : 󰴉
	md_folder_pound = "\uf0d09"
	# CHAR : 󰴊
	md_folder_pound_outline = "\uf0d0a"
	# CHAR : 󱧊
	md_folder_question = "\uf19ca"
	# CHAR : 󱧋
	md_folder_question_outline = "\uf19cb"
	# CHAR : 󰝉
	md_folder_refresh = "\uf0749"
	# CHAR : 󰕂
	md_folder_refresh_outline = "\uf0542"
	# CHAR : 󰉘
	md_folder_remove = "\uf0258"
	# CHAR : 󰮞
	md_folder_remove_outline = "\uf0b9e"
	# CHAR : 󰥨
	md_folder_search = "\uf0968"
	# CHAR : 󰥩
	md_folder_search_outline = "\uf0969"
	# CHAR : 󱁽
	md_folder_settings = "\uf107d"
	# CHAR : 󱁾
	md_folder_settings_outline = "\uf107e"
	# CHAR : 󰚝
	md_folder_star = "\uf069d"
	# CHAR : 󱏓
	md_folder_star_multiple = "\uf13d3"
	# CHAR : 󱏔
	md_folder_star_multiple_outline = "\uf13d4"
	# CHAR : 󰮟
	md_folder_star_outline = "\uf0b9f"
	# CHAR : 󰾶
	md_folder_swap = "\uf0fb6"
	# CHAR : 󰾷
	md_folder_swap_outline = "\uf0fb7"
	# CHAR : 󰴋
	md_folder_sync = "\uf0d0b"
	# CHAR : 󰴌
	md_folder_sync_outline = "\uf0d0c"
	# CHAR : 󱋣
	md_folder_table = "\uf12e3"
	# CHAR : 󱋤
	md_folder_table_outline = "\uf12e4"
	# CHAR : 󰲂
	md_folder_text = "\uf0c82"
	# CHAR : 󰲃
	md_folder_text_outline = "\uf0c83"
	# CHAR : 󰉙
	md_folder_upload = "\uf0259"
	# CHAR : 󱃭
	md_folder_upload_outline = "\uf10ed"
	# CHAR : 󱧼
	md_folder_wrench = "\uf19fc"
	# CHAR : 󱧽
	md_folder_wrench_outline = "\uf19fd"
	# CHAR : 󰛫
	md_folder_zip = "\uf06eb"
	# CHAR : 󰞹
	md_folder_zip_outline = "\uf07b9"
	# CHAR : 󰀺
	md_font_awesome = "\uf003a"
	# CHAR : 󰉚
	md_food = "\uf025a"
	# CHAR : 󰉛
	md_food_apple = "\uf025b"
	# CHAR : 󰲄
	md_food_apple_outline = "\uf0c84"
	# CHAR : 󰟈
	md_food_croissant = "\uf07c8"
	# CHAR : 󱐟
	md_food_drumstick = "\uf141f"
	# CHAR : 󱑨
	md_food_drumstick_off = "\uf1468"
	# CHAR : 󱑩
	md_food_drumstick_off_outline = "\uf1469"
	# CHAR : 󱐠
	md_food_drumstick_outline = "\uf1420"
	# CHAR : 󰗲
	md_food_fork_drink = "\uf05f2"
	# CHAR : 󱕲
	md_food_halal = "\uf1572"
	# CHAR : 󱡋
	md_food_hot_dog = "\uf184b"
	# CHAR : 󱕳
	md_food_kosher = "\uf1573"
	# CHAR : 󰗳
	md_food_off = "\uf05f3"
	# CHAR : 󱤕
	md_food_off_outline = "\uf1915"
	# CHAR : 󱤖
	md_food_outline = "\uf1916"
	# CHAR : 󱑪
	md_food_steak = "\uf146a"
	# CHAR : 󱑫
	md_food_steak_off = "\uf146b"
	# CHAR : 󱠶
	md_food_takeout_box = "\uf1836"
	# CHAR : 󱠷
	md_food_takeout_box_outline = "\uf1837"
	# CHAR : 󱜜
	md_food_turkey = "\uf171c"
	# CHAR : 󰉜
	md_food_variant = "\uf025c"
	# CHAR : 󱏥
	md_food_variant_off = "\uf13e5"
	# CHAR : 󰽒
	md_foot_print = "\uf0f52"
	# CHAR : 󰉝
	md_football = "\uf025d"
	# CHAR : 󰉞
	md_football_australian = "\uf025e"
	# CHAR : 󰉟
	md_football_helmet = "\uf025f"
	# CHAR : 󱢗
	md_forest = "\uf1897"
	# CHAR : 󰟉
	md_forklift = "\uf07c9"
	# CHAR : 󱐀
	md_form_dropdown = "\uf1400"
	# CHAR : 󱐁
	md_form_select = "\uf1401"
	# CHAR : 󱂕
	md_form_textarea = "\uf1095"
	# CHAR : 󰘎
	md_form_textbox = "\uf060e"
	# CHAR : 󱍝
	md_form_textbox_lock = "\uf135d"
	# CHAR : 󰟵
	md_form_textbox_password = "\uf07f5"
	# CHAR : 󰝓
	md_format_align_bottom = "\uf0753"
	# CHAR : 󰉠
	md_format_align_center = "\uf0260"
	# CHAR : 󰉡
	md_format_align_justify = "\uf0261"
	# CHAR : 󰉢
	md_format_align_left = "\uf0262"
	# CHAR : 󰝔
	md_format_align_middle = "\uf0754"
	# CHAR : 󰉣
	md_format_align_right = "\uf0263"
	# CHAR : 󰝕
	md_format_align_top = "\uf0755"
	# CHAR : 󰪼
	md_format_annotation_minus = "\uf0abc"
	# CHAR : 󰙆
	md_format_annotation_plus = "\uf0646"
	# CHAR : 󰉤
	md_format_bold = "\uf0264"
	# CHAR : 󰉥
	md_format_clear = "\uf0265"
	# CHAR : 󰉦
	md_format_color_fill = "\uf0266"
	# CHAR : 󰸱
	md_format_color_highlight = "\uf0e31"
	# CHAR : 󱌓
	md_format_color_marker_cancel = "\uf1313"
	# CHAR : 󰚞
	md_format_color_text = "\uf069e"
	# CHAR : 󰣟
	md_format_columns = "\uf08df"
	# CHAR : 󰉧
	md_format_float_center = "\uf0267"
	# CHAR : 󰉨
	md_format_float_left = "\uf0268"
	# CHAR : 󰉩
	md_format_float_none = "\uf0269"
	# CHAR : 󰉪
	md_format_float_right = "\uf026a"
	# CHAR : 󰛖
	md_format_font = "\uf06d6"
	# CHAR : 󰧳
	md_format_font_size_decrease = "\uf09f3"
	# CHAR : 󰧴
	md_format_font_size_increase = "\uf09f4"
	# CHAR : 󰉫
	md_format_header_1 = "\uf026b"
	# CHAR : 󰉬
	md_format_header_2 = "\uf026c"
	# CHAR : 󰉭
	md_format_header_3 = "\uf026d"
	# CHAR : 󰉮
	md_format_header_4 = "\uf026e"
	# CHAR : 󰉯
	md_format_header_5 = "\uf026f"
	# CHAR : 󰉰
	md_format_header_6 = "\uf0270"
	# CHAR : 󰉱
	md_format_header_decrease = "\uf0271"
	# CHAR : 󰉲
	md_format_header_equal = "\uf0272"
	# CHAR : 󰉳
	md_format_header_increase = "\uf0273"
	# CHAR : 󰉴
	md_format_header_pound = "\uf0274"
	# CHAR : 󰘞
	md_format_horizontal_align_center = "\uf061e"
	# CHAR : 󰘟
	md_format_horizontal_align_left = "\uf061f"
	# CHAR : 󰘠
	md_format_horizontal_align_right = "\uf0620"
	# CHAR : 󰉵
	md_format_indent_decrease = "\uf0275"
	# CHAR : 󰉶
	md_format_indent_increase = "\uf0276"
	# CHAR : 󰉷
	md_format_italic = "\uf0277"
	# CHAR : 󰬴
	md_format_letter_case = "\uf0b34"
	# CHAR : 󰬵
	md_format_letter_case_lower = "\uf0b35"
	# CHAR : 󰬶
	md_format_letter_case_upper = "\uf0b36"
	# CHAR : 󰾸
	md_format_letter_ends_with = "\uf0fb8"
	# CHAR : 󰾹
	md_format_letter_matches = "\uf0fb9"
	# CHAR : 󱥖
	md_format_letter_spacing = "\uf1956"
	# CHAR : 󰾺
	md_format_letter_starts_with = "\uf0fba"
	# CHAR : 󰉸
	md_format_line_spacing = "\uf0278"
	# CHAR : 󰗈
	md_format_line_style = "\uf05c8"
	# CHAR : 󰗉
	md_format_line_weight = "\uf05c9"
	# CHAR : 󰉹
	md_format_list_bulleted = "\uf0279"
	# CHAR : 󰷐
	md_format_list_bulleted_square = "\uf0dd0"
	# CHAR : 󰺲
	md_format_list_bulleted_triangle = "\uf0eb2"
	# CHAR : 󰉺
	md_format_list_bulleted_type = "\uf027a"
	# CHAR : 󰥪
	md_format_list_checkbox = "\uf096a"
	# CHAR : 󰝖
	md_format_list_checks = "\uf0756"
	# CHAR : 󱡠
	md_format_list_group = "\uf1860"
	# CHAR : 󰉻
	md_format_list_numbered = "\uf027b"
	# CHAR : 󰴍
	md_format_list_numbered_rtl = "\uf0d0d"
	# CHAR : 󱉯
	md_format_list_text = "\uf126f"
	# CHAR : 󰺳
	md_format_overline = "\uf0eb3"
	# CHAR : 󰛗
	md_format_page_break = "\uf06d7"
	# CHAR : 󱤗
	md_format_page_split = "\uf1917"
	# CHAR : 󰉼
	md_format_paint = "\uf027c"
	# CHAR : 󰉽
	md_format_paragraph = "\uf027d"
	# CHAR : 󰛘
	md_format_pilcrow = "\uf06d8"
	# CHAR : 󰉾
	md_format_quote_close = "\uf027e"
	# CHAR : 󱆨
	md_format_quote_close_outline = "\uf11a8"
	# CHAR : 󰝗
	md_format_quote_open = "\uf0757"
	# CHAR : 󱆧
	md_format_quote_open_outline = "\uf11a7"
	# CHAR : 󰚪
	md_format_rotate_90 = "\uf06aa"
	# CHAR : 󰚟
	md_format_section = "\uf069f"
	# CHAR : 󰉿
	md_format_size = "\uf027f"
	# CHAR : 󰊀
	md_format_strikethrough = "\uf0280"
	# CHAR : 󰊁
	md_format_strikethrough_variant = "\uf0281"
	# CHAR : 󰊂
	md_format_subscript = "\uf0282"
	# CHAR : 󰊃
	md_format_superscript = "\uf0283"
	# CHAR : 󰊄
	md_format_text = "\uf0284"
	# CHAR : 󰾻
	md_format_text_rotation_angle_down = "\uf0fbb"
	# CHAR : 󰾼
	md_format_text_rotation_angle_up = "\uf0fbc"
	# CHAR : 󰵳
	md_format_text_rotation_down = "\uf0d73"
	# CHAR : 󰾽
	md_format_text_rotation_down_vertical = "\uf0fbd"
	# CHAR : 󰵴
	md_format_text_rotation_none = "\uf0d74"
	# CHAR : 󰾾
	md_format_text_rotation_up = "\uf0fbe"
	# CHAR : 󰾿
	md_format_text_rotation_vertical = "\uf0fbf"
	# CHAR : 󰸲
	md_format_text_variant = "\uf0e32"
	# CHAR : 󱔏
	md_format_text_variant_outline = "\uf150f"
	# CHAR : 󰴎
	md_format_text_wrapping_clip = "\uf0d0e"
	# CHAR : 󰴏
	md_format_text_wrapping_overflow = "\uf0d0f"
	# CHAR : 󰴐
	md_format_text_wrapping_wrap = "\uf0d10"
	# CHAR : 󰴑
	md_format_textbox = "\uf0d11"
	# CHAR : 󰊅
	md_format_textdirection_l_to_r = "\uf0285"
	# CHAR : 󰊆
	md_format_textdirection_r_to_l = "\uf0286"
	# CHAR : 󰗴
	md_format_title = "\uf05f4"
	# CHAR : 󰊇
	md_format_underline = "\uf0287"
	# CHAR : 󱣩
	md_format_underline_wavy = "\uf18e9"
	# CHAR : 󰘡
	md_format_vertical_align_bottom = "\uf0621"
	# CHAR : 󰘢
	md_format_vertical_align_center = "\uf0622"
	# CHAR : 󰘣
	md_format_vertical_align_top = "\uf0623"
	# CHAR : 󰊈
	md_format_wrap_inline = "\uf0288"
	# CHAR : 󰊉
	md_format_wrap_square = "\uf0289"
	# CHAR : 󰊊
	md_format_wrap_tight = "\uf028a"
	# CHAR : 󰊋
	md_format_wrap_top_bottom = "\uf028b"
	# CHAR : 󰊌
	md_forum = "\uf028c"
	# CHAR : 󱪩
	md_forum_minus = "\uf1aa9"
	# CHAR : 󱪪
	md_forum_minus_outline = "\uf1aaa"
	# CHAR : 󰠢
	md_forum_outline = "\uf0822"
	# CHAR : 󱪫
	md_forum_plus = "\uf1aab"
	# CHAR : 󱪬
	md_forum_plus_outline = "\uf1aac"
	# CHAR : 󱪭
	md_forum_remove = "\uf1aad"
	# CHAR : 󱪮
	md_forum_remove_outline = "\uf1aae"
	# CHAR : 󰊍
	md_forward = "\uf028d"
	# CHAR : 󰵵
	md_forwardburger = "\uf0d75"
	# CHAR : 󰥫
	md_fountain = "\uf096b"
	# CHAR : 󰴒
	md_fountain_pen = "\uf0d12"
	# CHAR : 󰴓
	md_fountain_pen_tip = "\uf0d13"
	# CHAR : 󱦒
	md_fraction_one_half = "\uf1992"
	# CHAR : 󰣠
	md_freebsd = "\uf08e0"
	# CHAR : 󱥗
	md_french_fries = "\uf1957"
	# CHAR : 󰺴
	md_frequently_asked_questions = "\uf0eb4"
	# CHAR : 󰊐
	md_fridge = "\uf0290"
	# CHAR : 󱆱
	md_fridge_alert = "\uf11b1"
	# CHAR : 󱆲
	md_fridge_alert_outline = "\uf11b2"
	# CHAR : 󰊒
	md_fridge_bottom = "\uf0292"
	# CHAR : 󱗮
	md_fridge_industrial = "\uf15ee"
	# CHAR : 󱗯
	md_fridge_industrial_alert = "\uf15ef"
	# CHAR : 󱗰
	md_fridge_industrial_alert_outline = "\uf15f0"
	# CHAR : 󱗱
	md_fridge_industrial_off = "\uf15f1"
	# CHAR : 󱗲
	md_fridge_industrial_off_outline = "\uf15f2"
	# CHAR : 󱗳
	md_fridge_industrial_outline = "\uf15f3"
	# CHAR : 󱆯
	md_fridge_off = "\uf11af"
	# CHAR : 󱆰
	md_fridge_off_outline = "\uf11b0"
	# CHAR : 󰊏
	md_fridge_outline = "\uf028f"
	# CHAR : 󰊑
	md_fridge_top = "\uf0291"
	# CHAR : 󱗴
	md_fridge_variant = "\uf15f4"
	# CHAR : 󱗵
	md_fridge_variant_alert = "\uf15f5"
	# CHAR : 󱗶
	md_fridge_variant_alert_outline = "\uf15f6"
	# CHAR : 󱗷
	md_fridge_variant_off = "\uf15f7"
	# CHAR : 󱗸
	md_fridge_variant_off_outline = "\uf15f8"
	# CHAR : 󱗹
	md_fridge_variant_outline = "\uf15f9"
	# CHAR : 󱁂
	md_fruit_cherries = "\uf1042"
	# CHAR : 󱏸
	md_fruit_cherries_off = "\uf13f8"
	# CHAR : 󱁃
	md_fruit_citrus = "\uf1043"
	# CHAR : 󱏹
	md_fruit_citrus_off = "\uf13f9"
	# CHAR : 󱁄
	md_fruit_grapes = "\uf1044"
	# CHAR : 󱁅
	md_fruit_grapes_outline = "\uf1045"
	# CHAR : 󱨎
	md_fruit_pear = "\uf1a0e"
	# CHAR : 󱁆
	md_fruit_pineapple = "\uf1046"
	# CHAR : 󱁇
	md_fruit_watermelon = "\uf1047"
	# CHAR : 󰟊
	md_fuel = "\uf07ca"
	# CHAR : 󱢵
	md_fuel_cell = "\uf18b5"
	# CHAR : 󰊓
	md_fullscreen = "\uf0293"
	# CHAR : 󰊔
	md_fullscreen_exit = "\uf0294"
	# CHAR : 󰊕
	md_function = "\uf0295"
	# CHAR : 󰡱
	md_function_variant = "\uf0871"
	# CHAR : 󱂁
	md_furigana_horizontal = "\uf1081"
	# CHAR : 󱂂
	md_furigana_vertical = "\uf1082"
	# CHAR : 󰲅
	md_fuse = "\uf0c85"
	# CHAR : 󱐭
	md_fuse_alert = "\uf142d"
	# CHAR : 󰲆
	md_fuse_blade = "\uf0c86"
	# CHAR : 󱐬
	md_fuse_off = "\uf142c"
	# CHAR : 󰊖
	md_gamepad = "\uf0296"
	# CHAR : 󰸳
	md_gamepad_circle = "\uf0e33"
	# CHAR : 󰸴
	md_gamepad_circle_down = "\uf0e34"
	# CHAR : 󰸵
	md_gamepad_circle_left = "\uf0e35"
	# CHAR : 󰸶
	md_gamepad_circle_outline = "\uf0e36"
	# CHAR : 󰸷
	md_gamepad_circle_right = "\uf0e37"
	# CHAR : 󰸸
	md_gamepad_circle_up = "\uf0e38"
	# CHAR : 󰸹
	md_gamepad_down = "\uf0e39"
	# CHAR : 󰸺
	md_gamepad_left = "\uf0e3a"
	# CHAR : 󱤙
	md_gamepad_outline = "\uf1919"
	# CHAR : 󰸻
	md_gamepad_right = "\uf0e3b"
	# CHAR : 󰸼
	md_gamepad_round = "\uf0e3c"
	# CHAR : 󰸽
	md_gamepad_round_down = "\uf0e3d"
	# CHAR : 󰸾
	md_gamepad_round_left = "\uf0e3e"
	# CHAR : 󰸿
	md_gamepad_round_outline = "\uf0e3f"
	# CHAR : 󰹀
	md_gamepad_round_right = "\uf0e40"
	# CHAR : 󰹁
	md_gamepad_round_up = "\uf0e41"
	# CHAR : 󰺵
	md_gamepad_square = "\uf0eb5"
	# CHAR : 󰺶
	md_gamepad_square_outline = "\uf0eb6"
	# CHAR : 󰹂
	md_gamepad_up = "\uf0e42"
	# CHAR : 󰊗
	md_gamepad_variant = "\uf0297"
	# CHAR : 󰺷
	md_gamepad_variant_outline = "\uf0eb7"
	# CHAR : 󱃮
	md_gamma = "\uf10ee"
	# CHAR : 󰷑
	md_gantry_crane = "\uf0dd1"
	# CHAR : 󰛙
	md_garage = "\uf06d9"
	# CHAR : 󰡲
	md_garage_alert = "\uf0872"
	# CHAR : 󱋕
	md_garage_alert_variant = "\uf12d5"
	# CHAR : 󱟻
	md_garage_lock = "\uf17fb"
	# CHAR : 󰛚
	md_garage_open = "\uf06da"
	# CHAR : 󱋔
	md_garage_open_variant = "\uf12d4"
	# CHAR : 󱋓
	md_garage_variant = "\uf12d3"
	# CHAR : 󱟼
	md_garage_variant_lock = "\uf17fc"
	# CHAR : 󱨛
	md_gas_burner = "\uf1a1b"
	# CHAR : 󰙇
	md_gas_cylinder = "\uf0647"
	# CHAR : 󰊘
	md_gas_station = "\uf0298"
	# CHAR : 󱐉
	md_gas_station_off = "\uf1409"
	# CHAR : 󱐊
	md_gas_station_off_outline = "\uf140a"
	# CHAR : 󰺸
	md_gas_station_outline = "\uf0eb8"
	# CHAR : 󰊙
	md_gate = "\uf0299"
	# CHAR : 󱟸
	md_gate_alert = "\uf17f8"
	# CHAR : 󰣡
	md_gate_and = "\uf08e1"
	# CHAR : 󱟷
	md_gate_arrow_left = "\uf17f7"
	# CHAR : 󱅩
	md_gate_arrow_right = "\uf1169"
	# CHAR : 󰣢
	md_gate_nand = "\uf08e2"
	# CHAR : 󰣣
	md_gate_nor = "\uf08e3"
	# CHAR : 󰣤
	md_gate_not = "\uf08e4"
	# CHAR : 󱅪
	md_gate_open = "\uf116a"
	# CHAR : 󰣥
	md_gate_or = "\uf08e5"
	# CHAR : 󰣦
	md_gate_xnor = "\uf08e6"
	# CHAR : 󰣧
	md_gate_xor = "\uf08e7"
	# CHAR : 󰹃
	md_gatsby = "\uf0e43"
	# CHAR : 󰊚
	md_gauge = "\uf029a"
	# CHAR : 󰡳
	md_gauge_empty = "\uf0873"
	# CHAR : 󰡴
	md_gauge_full = "\uf0874"
	# CHAR : 󰡵
	md_gauge_low = "\uf0875"
	# CHAR : 󰊛
	md_gavel = "\uf029b"
	# CHAR : 󰊜
	md_gender_female = "\uf029c"
	# CHAR : 󰊝
	md_gender_male = "\uf029d"
	# CHAR : 󰊞
	md_gender_male_female = "\uf029e"
	# CHAR : 󱄿
	md_gender_male_female_variant = "\uf113f"
	# CHAR : 󱅀
	md_gender_non_binary = "\uf1140"
	# CHAR : 󰊟
	md_gender_transgender = "\uf029f"
	# CHAR : 󰣨
	md_gentoo = "\uf08e8"
	# CHAR : 󰟋
	md_gesture = "\uf07cb"
	# CHAR : 󰜼
	md_gesture_double_tap = "\uf073c"
	# CHAR : 󰪽
	md_gesture_pinch = "\uf0abd"
	# CHAR : 󰪾
	md_gesture_spread = "\uf0abe"
	# CHAR : 󰵶
	md_gesture_swipe = "\uf0d76"
	# CHAR : 󰜽
	md_gesture_swipe_down = "\uf073d"
	# CHAR : 󰪿
	md_gesture_swipe_horizontal = "\uf0abf"
	# CHAR : 󰜾
	md_gesture_swipe_left = "\uf073e"
	# CHAR : 󰜿
	md_gesture_swipe_right = "\uf073f"
	# CHAR : 󰝀
	md_gesture_swipe_up = "\uf0740"
	# CHAR : 󰫀
	md_gesture_swipe_vertical = "\uf0ac0"
	# CHAR : 󰝁
	md_gesture_tap = "\uf0741"
	# CHAR : 󱊩
	md_gesture_tap_box = "\uf12a9"
	# CHAR : 󱊨
	md_gesture_tap_button = "\uf12a8"
	# CHAR : 󰵷
	md_gesture_tap_hold = "\uf0d77"
	# CHAR : 󰝂
	md_gesture_two_double_tap = "\uf0742"
	# CHAR : 󰝃
	md_gesture_two_tap = "\uf0743"
	# CHAR : 󰊠
	md_ghost = "\uf02a0"
	# CHAR : 󰧵
	md_ghost_off = "\uf09f5"
	# CHAR : 󱙜
	md_ghost_off_outline = "\uf165c"
	# CHAR : 󱙝
	md_ghost_outline = "\uf165d"
	# CHAR : 󰹄
	md_gift = "\uf0e44"
	# CHAR : 󱛯
	md_gift_off = "\uf16ef"
	# CHAR : 󱛰
	md_gift_off_outline = "\uf16f0"
	# CHAR : 󱛱
	md_gift_open = "\uf16f1"
	# CHAR : 󱛲
	md_gift_open_outline = "\uf16f2"
	# CHAR : 󰊡
	md_gift_outline = "\uf02a1"
	# CHAR : 󰊢
	md_git = "\uf02a2"
	# CHAR : 󰊤
	md_github = "\uf02a4"
	# CHAR : 󰮠
	md_gitlab = "\uf0ba0"
	# CHAR : 󰍖
	md_glass_cocktail = "\uf0356"
	# CHAR : 󱗦
	md_glass_cocktail_off = "\uf15e6"
	# CHAR : 󰊥
	md_glass_flute = "\uf02a5"
	# CHAR : 󱡳
	md_glass_fragile = "\uf1873"
	# CHAR : 󰊦
	md_glass_mug = "\uf02a6"
	# CHAR : 󱗧
	md_glass_mug_off = "\uf15e7"
	# CHAR : 󱄖
	md_glass_mug_variant = "\uf1116"
	# CHAR : 󱗨
	md_glass_mug_variant_off = "\uf15e8"
	# CHAR : 󱌍
	md_glass_pint_outline = "\uf130d"
	# CHAR : 󰊧
	md_glass_stange = "\uf02a7"
	# CHAR : 󰊨
	md_glass_tulip = "\uf02a8"
	# CHAR : 󰡶
	md_glass_wine = "\uf0876"
	# CHAR : 󰊪
	md_glasses = "\uf02aa"
	# CHAR : 󱋗
	md_globe_light = "\uf12d7"
	# CHAR : 󰣩
	md_globe_model = "\uf08e9"
	# CHAR : 󰊫
	md_gmail = "\uf02ab"
	# CHAR : 󰊬
	md_gnome = "\uf02ac"
	# CHAR : 󰵹
	md_go_kart = "\uf0d79"
	# CHAR : 󰵺
	md_go_kart_track = "\uf0d7a"
	# CHAR : 󰮡
	md_gog = "\uf0ba1"
	# CHAR : 󱉏
	md_gold = "\uf124f"
	# CHAR : 󰠣
	md_golf = "\uf0823"
	# CHAR : 󱆤
	md_golf_cart = "\uf11a4"
	# CHAR : 󱂃
	md_golf_tee = "\uf1083"
	# CHAR : 󰚆
	md_gondola = "\uf0686"
	# CHAR : 󰵻
	md_goodreads = "\uf0d7b"
	# CHAR : 󰊭
	md_google = "\uf02ad"
	# CHAR : 󰲇
	md_google_ads = "\uf0c87"
	# CHAR : 󰟌
	md_google_analytics = "\uf07cc"
	# CHAR : 󰟍
	md_google_assistant = "\uf07cd"
	# CHAR : 󰊮
	md_google_cardboard = "\uf02ae"
	# CHAR : 󰊯
	md_google_chrome = "\uf02af"
	# CHAR : 󰊰
	md_google_circles = "\uf02b0"
	# CHAR : 󰊱
	md_google_circles_communities = "\uf02b1"
	# CHAR : 󰊲
	md_google_circles_extended = "\uf02b2"
	# CHAR : 󰊳
	md_google_circles_group = "\uf02b3"
	# CHAR : 󰋀
	md_google_classroom = "\uf02c0"
	# CHAR : 󱇶
	md_google_cloud = "\uf11f6"
	# CHAR : 󰊴
	md_google_controller = "\uf02b4"
	# CHAR : 󰊵
	md_google_controller_off = "\uf02b5"
	# CHAR : 󱍢
	md_google_downasaur = "\uf1362"
	# CHAR : 󰊶
	md_google_drive = "\uf02b6"
	# CHAR : 󰊷
	md_google_earth = "\uf02b7"
	# CHAR : 󰥬
	md_google_fit = "\uf096c"
	# CHAR : 󰊸
	md_google_glass = "\uf02b8"
	# CHAR : 󰋉
	md_google_hangouts = "\uf02c9"
	# CHAR : 󰠤
	md_google_home = "\uf0824"
	# CHAR : 󰛜
	md_google_keep = "\uf06dc"
	# CHAR : 󰧶
	md_google_lens = "\uf09f6"
	# CHAR : 󰗵
	md_google_maps = "\uf05f5"
	# CHAR : 󱁈
	md_google_my_business = "\uf1048"
	# CHAR : 󰊹
	md_google_nearby = "\uf02b9"
	# CHAR : 󰊼
	md_google_play = "\uf02bc"
	# CHAR : 󰊽
	md_google_plus = "\uf02bd"
	# CHAR : 󰺹
	md_google_podcast = "\uf0eb9"
	# CHAR : 󰧷
	md_google_spreadsheet = "\uf09f7"
	# CHAR : 󰲈
	md_google_street_view = "\uf0c88"
	# CHAR : 󰊿
	md_google_translate = "\uf02bf"
	# CHAR : 󱝊
	md_gradient_horizontal = "\uf174a"
	# CHAR : 󰚠
	md_gradient_vertical = "\uf06a0"
	# CHAR : 󰵼
	md_grain = "\uf0d7c"
	# CHAR : 󱁉
	md_graph = "\uf1049"
	# CHAR : 󱁊
	md_graph_outline = "\uf104a"
	# CHAR : 󰡷
	md_graphql = "\uf0877"
	# CHAR : 󱔐
	md_grass = "\uf1510"
	# CHAR : 󰮢
	md_grave_stone = "\uf0ba2"
	# CHAR : 󰙈
	md_grease_pencil = "\uf0648"
	# CHAR : 󰥭
	md_greater_than = "\uf096d"
	# CHAR : 󰥮
	md_greater_than_or_equal = "\uf096e"
	# CHAR : 󰀭
	md_greenhouse = "\uf002d"
	# CHAR : 󰋁
	md_grid = "\uf02c1"
	# CHAR : 󰝘
	md_grid_large = "\uf0758"
	# CHAR : 󰋂
	md_grid_off = "\uf02c2"
	# CHAR : 󰹅
	md_grill = "\uf0e45"
	# CHAR : 󱆊
	md_grill_outline = "\uf118a"
	# CHAR : 󰋃
	md_group = "\uf02c3"
	# CHAR : 󰝱
	md_guitar_acoustic = "\uf0771"
	# CHAR : 󰋄
	md_guitar_electric = "\uf02c4"
	# CHAR : 󰋅
	md_guitar_pick = "\uf02c5"
	# CHAR : 󰋆
	md_guitar_pick_outline = "\uf02c6"
	# CHAR : 󰠥
	md_guy_fawkes_mask = "\uf0825"
	# CHAR : 󱩁
	md_gymnastics = "\uf1a41"
	# CHAR : 󰫁
	md_hail = "\uf0ac1"
	# CHAR : 󱃯
	md_hair_dryer = "\uf10ef"
	# CHAR : 󱃰
	md_hair_dryer_outline = "\uf10f0"
	# CHAR : 󰮣
	md_halloween = "\uf0ba3"
	# CHAR : 󰚅
	md_hamburger = "\uf0685"
	# CHAR : 󱝶
	md_hamburger_check = "\uf1776"
	# CHAR : 󱝷
	md_hamburger_minus = "\uf1777"
	# CHAR : 󱝸
	md_hamburger_off = "\uf1778"
	# CHAR : 󱝹
	md_hamburger_plus = "\uf1779"
	# CHAR : 󱝺
	md_hamburger_remove = "\uf177a"
	# CHAR : 󰣪
	md_hammer = "\uf08ea"
	# CHAR : 󱌢
	md_hammer_screwdriver = "\uf1322"
	# CHAR : 󱢇
	md_hammer_sickle = "\uf1887"
	# CHAR : 󱌣
	md_hammer_wrench = "\uf1323"
	# CHAR : 󰹆
	md_hand_back_left = "\uf0e46"
	# CHAR : 󱠰
	md_hand_back_left_off = "\uf1830"
	# CHAR : 󱠲
	md_hand_back_left_off_outline = "\uf1832"
	# CHAR : 󱠬
	md_hand_back_left_outline = "\uf182c"
	# CHAR : 󰹇
	md_hand_back_right = "\uf0e47"
	# CHAR : 󱠱
	md_hand_back_right_off = "\uf1831"
	# CHAR : 󱠳
	md_hand_back_right_off_outline = "\uf1833"
	# CHAR : 󱠭
	md_hand_back_right_outline = "\uf182d"
	# CHAR : 󱥋
	md_hand_clap = "\uf194b"
	# CHAR : 󱩂
	md_hand_clap_off = "\uf1a42"
	# CHAR : 󱢏
	md_hand_coin = "\uf188f"
	# CHAR : 󱢐
	md_hand_coin_outline = "\uf1890"
	# CHAR : 󱢶
	md_hand_extended = "\uf18b6"
	# CHAR : 󱢷
	md_hand_extended_outline = "\uf18b7"
	# CHAR : 󱠫
	md_hand_front_left = "\uf182b"
	# CHAR : 󱠮
	md_hand_front_left_outline = "\uf182e"
	# CHAR : 󰩏
	md_hand_front_right = "\uf0a4f"
	# CHAR : 󱠯
	md_hand_front_right_outline = "\uf182f"
	# CHAR : 󱃱
	md_hand_heart = "\uf10f1"
	# CHAR : 󱕾
	md_hand_heart_outline = "\uf157e"
	# CHAR : 󰩐
	md_hand_okay = "\uf0a50"
	# CHAR : 󰩑
	md_hand_peace = "\uf0a51"
	# CHAR : 󰩒
	md_hand_peace_variant = "\uf0a52"
	# CHAR : 󰩓
	md_hand_pointing_down = "\uf0a53"
	# CHAR : 󰩔
	md_hand_pointing_left = "\uf0a54"
	# CHAR : 󰋇
	md_hand_pointing_right = "\uf02c7"
	# CHAR : 󰩕
	md_hand_pointing_up = "\uf0a55"
	# CHAR : 󰹈
	md_hand_saw = "\uf0e48"
	# CHAR : 󱕿
	md_hand_wash = "\uf157f"
	# CHAR : 󱖀
	md_hand_wash_outline = "\uf1580"
	# CHAR : 󱎟
	md_hand_water = "\uf139f"
	# CHAR : 󱠡
	md_hand_wave = "\uf1821"
	# CHAR : 󱠢
	md_hand_wave_outline = "\uf1822"
	# CHAR : 󰽓
	md_handball = "\uf0f53"
	# CHAR : 󱄾
	md_handcuffs = "\uf113e"
	# CHAR : 󰕹
	md_hands_pray = "\uf0579"
	# CHAR : 󱈘
	md_handshake = "\uf1218"
	# CHAR : 󱖡
	md_handshake_outline = "\uf15a1"
	# CHAR : 󰋈
	md_hanger = "\uf02c8"
	# CHAR : 󰥯
	md_hard_hat = "\uf096f"
	# CHAR : 󰋊
	md_harddisk = "\uf02ca"
	# CHAR : 󱁋
	md_harddisk_plus = "\uf104b"
	# CHAR : 󱁌
	md_harddisk_remove = "\uf104c"
	# CHAR : 󰮤
	md_hat_fedora = "\uf0ba4"
	# CHAR : 󰲉
	md_hazard_lights = "\uf0c89"
	# CHAR : 󰵽
	md_hdr = "\uf0d7d"
	# CHAR : 󰵾
	md_hdr_off = "\uf0d7e"
	# CHAR : 󱍞
	md_head = "\uf135e"
	# CHAR : 󱌸
	md_head_alert = "\uf1338"
	# CHAR : 󱌹
	md_head_alert_outline = "\uf1339"
	# CHAR : 󱌺
	md_head_check = "\uf133a"
	# CHAR : 󱌻
	md_head_check_outline = "\uf133b"
	# CHAR : 󱌼
	md_head_cog = "\uf133c"
	# CHAR : 󱌽
	md_head_cog_outline = "\uf133d"
	# CHAR : 󱌾
	md_head_dots_horizontal = "\uf133e"
	# CHAR : 󱌿
	md_head_dots_horizontal_outline = "\uf133f"
	# CHAR : 󱍀
	md_head_flash = "\uf1340"
	# CHAR : 󱍁
	md_head_flash_outline = "\uf1341"
	# CHAR : 󱍂
	md_head_heart = "\uf1342"
	# CHAR : 󱍃
	md_head_heart_outline = "\uf1343"
	# CHAR : 󱍄
	md_head_lightbulb = "\uf1344"
	# CHAR : 󱍅
	md_head_lightbulb_outline = "\uf1345"
	# CHAR : 󱍆
	md_head_minus = "\uf1346"
	# CHAR : 󱍇
	md_head_minus_outline = "\uf1347"
	# CHAR : 󱍟
	md_head_outline = "\uf135f"
	# CHAR : 󱍈
	md_head_plus = "\uf1348"
	# CHAR : 󱍉
	md_head_plus_outline = "\uf1349"
	# CHAR : 󱍊
	md_head_question = "\uf134a"
	# CHAR : 󱍋
	md_head_question_outline = "\uf134b"
	# CHAR : 󱍌
	md_head_remove = "\uf134c"
	# CHAR : 󱍍
	md_head_remove_outline = "\uf134d"
	# CHAR : 󱍎
	md_head_snowflake = "\uf134e"
	# CHAR : 󱍏
	md_head_snowflake_outline = "\uf134f"
	# CHAR : 󱍐
	md_head_sync = "\uf1350"
	# CHAR : 󱍑
	md_head_sync_outline = "\uf1351"
	# CHAR : 󰋋
	md_headphones = "\uf02cb"
	# CHAR : 󰥰
	md_headphones_bluetooth = "\uf0970"
	# CHAR : 󰋌
	md_headphones_box = "\uf02cc"
	# CHAR : 󰟎
	md_headphones_off = "\uf07ce"
	# CHAR : 󰋍
	md_headphones_settings = "\uf02cd"
	# CHAR : 󰋎
	md_headset = "\uf02ce"
	# CHAR : 󰋏
	md_headset_dock = "\uf02cf"
	# CHAR : 󰋐
	md_headset_off = "\uf02d0"
	# CHAR : 󰋑
	md_heart = "\uf02d1"
	# CHAR : 󰋒
	md_heart_box = "\uf02d2"
	# CHAR : 󰋓
	md_heart_box_outline = "\uf02d3"
	# CHAR : 󰋔
	md_heart_broken = "\uf02d4"
	# CHAR : 󰴔
	md_heart_broken_outline = "\uf0d14"
	# CHAR : 󰥱
	md_heart_circle = "\uf0971"
	# CHAR : 󰥲
	md_heart_circle_outline = "\uf0972"
	# CHAR : 󱙣
	md_heart_cog = "\uf1663"
	# CHAR : 󱙤
	md_heart_cog_outline = "\uf1664"
	# CHAR : 󰻹
	md_heart_flash = "\uf0ef9"
	# CHAR : 󰛟
	md_heart_half = "\uf06df"
	# CHAR : 󰛞
	md_heart_half_full = "\uf06de"
	# CHAR : 󰛠
	md_heart_half_outline = "\uf06e0"
	# CHAR : 󱐯
	md_heart_minus = "\uf142f"
	# CHAR : 󱐲
	md_heart_minus_outline = "\uf1432"
	# CHAR : 󰩖
	md_heart_multiple = "\uf0a56"
	# CHAR : 󰩗
	md_heart_multiple_outline = "\uf0a57"
	# CHAR : 󰝙
	md_heart_off = "\uf0759"
	# CHAR : 󱐴
	md_heart_off_outline = "\uf1434"
	# CHAR : 󰋕
	md_heart_outline = "\uf02d5"
	# CHAR : 󱐮
	md_heart_plus = "\uf142e"
	# CHAR : 󱐱
	md_heart_plus_outline = "\uf1431"
	# CHAR : 󰗶
	md_heart_pulse = "\uf05f6"
	# CHAR : 󱐰
	md_heart_remove = "\uf1430"
	# CHAR : 󱐳
	md_heart_remove_outline = "\uf1433"
	# CHAR : 󱙥
	md_heart_settings = "\uf1665"
	# CHAR : 󱙦
	md_heart_settings_outline = "\uf1666"
	# CHAR : 󱩃
	md_heat_pump = "\uf1a43"
	# CHAR : 󱩄
	md_heat_pump_outline = "\uf1a44"
	# CHAR : 󱩅
	md_heat_wave = "\uf1a45"
	# CHAR : 󱪯
	md_heating_coil = "\uf1aaf"
	# CHAR : 󰫂
	md_helicopter = "\uf0ac2"
	# CHAR : 󰋖
	md_help = "\uf02d6"
	# CHAR : 󰞋
	md_help_box = "\uf078b"
	# CHAR : 󰋗
	md_help_circle = "\uf02d7"
	# CHAR : 󰘥
	md_help_circle_outline = "\uf0625"
	# CHAR : 󰛵
	md_help_network = "\uf06f5"
	# CHAR : 󰲊
	md_help_network_outline = "\uf0c8a"
	# CHAR : 󰮥
	md_help_rhombus = "\uf0ba5"
	# CHAR : 󰮦
	md_help_rhombus_outline = "\uf0ba6"
	# CHAR : 󱊧
	md_hexadecimal = "\uf12a7"
	# CHAR : 󰋘
	md_hexagon = "\uf02d8"
	# CHAR : 󰛡
	md_hexagon_multiple = "\uf06e1"
	# CHAR : 󱃲
	md_hexagon_multiple_outline = "\uf10f2"
	# CHAR : 󰋙
	md_hexagon_outline = "\uf02d9"
	# CHAR : 󰫃
	md_hexagon_slice_1 = "\uf0ac3"
	# CHAR : 󰫄
	md_hexagon_slice_2 = "\uf0ac4"
	# CHAR : 󰫅
	md_hexagon_slice_3 = "\uf0ac5"
	# CHAR : 󰫆
	md_hexagon_slice_4 = "\uf0ac6"
	# CHAR : 󰫇
	md_hexagon_slice_5 = "\uf0ac7"
	# CHAR : 󰫈
	md_hexagon_slice_6 = "\uf0ac8"
	# CHAR : 󰫉
	md_hexagram = "\uf0ac9"
	# CHAR : 󰫊
	md_hexagram_outline = "\uf0aca"
	# CHAR : 󰟏
	md_high_definition = "\uf07cf"
	# CHAR : 󰡸
	md_high_definition_box = "\uf0878"
	# CHAR : 󰗷
	md_highway = "\uf05f7"
	# CHAR : 󰵿
	md_hiking = "\uf0d7f"
	# CHAR : 󰋚
	md_history = "\uf02da"
	# CHAR : 󰡹
	md_hockey_puck = "\uf0879"
	# CHAR : 󰡺
	md_hockey_sticks = "\uf087a"
	# CHAR : 󰋛
	md_hololens = "\uf02db"
	# CHAR : 󰋜
	md_home = "\uf02dc"
	# CHAR : 󰠦
	md_home_account = "\uf0826"
	# CHAR : 󰡻
	md_home_alert = "\uf087b"
	# CHAR : 󱗐
	md_home_alert_outline = "\uf15d0"
	# CHAR : 󰺺
	md_home_analytics = "\uf0eba"
	# CHAR : 󰟐
	md_home_assistant = "\uf07d0"
	# CHAR : 󰟑
	md_home_automation = "\uf07d1"
	# CHAR : 󱤁
	md_home_battery = "\uf1901"
	# CHAR : 󱤂
	md_home_battery_outline = "\uf1902"
	# CHAR : 󰟒
	md_home_circle = "\uf07d2"
	# CHAR : 󱁍
	md_home_circle_outline = "\uf104d"
	# CHAR : 󰴕
	md_home_city = "\uf0d15"
	# CHAR : 󰴖
	md_home_city_outline = "\uf0d16"
	# CHAR : 󱨒
	md_home_clock = "\uf1a12"
	# CHAR : 󱨓
	md_home_clock_outline = "\uf1a13"
	# CHAR : 󱅙
	md_home_edit = "\uf1159"
	# CHAR : 󱅚
	md_home_edit_outline = "\uf115a"
	# CHAR : 󰾛
	md_home_export_outline = "\uf0f9b"
	# CHAR : 󰻺
	md_home_flood = "\uf0efa"
	# CHAR : 󰷒
	md_home_floor_0 = "\uf0dd2"
	# CHAR : 󰶀
	md_home_floor_1 = "\uf0d80"
	# CHAR : 󰶁
	md_home_floor_2 = "\uf0d81"
	# CHAR : 󰶂
	md_home_floor_3 = "\uf0d82"
	# CHAR : 󰶃
	md_home_floor_a = "\uf0d83"
	# CHAR : 󰶄
	md_home_floor_b = "\uf0d84"
	# CHAR : 󰶅
	md_home_floor_g = "\uf0d85"
	# CHAR : 󰶆
	md_home_floor_l = "\uf0d86"
	# CHAR : 󰷓
	md_home_floor_negative_1 = "\uf0dd3"
	# CHAR : 󰷔
	md_home_group = "\uf0dd4"
	# CHAR : 󱧁
	md_home_group_minus = "\uf19c1"
	# CHAR : 󱧀
	md_home_group_plus = "\uf19c0"
	# CHAR : 󱧂
	md_home_group_remove = "\uf19c2"
	# CHAR : 󰠧
	md_home_heart = "\uf0827"
	# CHAR : 󰾜
	md_home_import_outline = "\uf0f9c"
	# CHAR : 󱉑
	md_home_lightbulb = "\uf1251"
	# CHAR : 󱉒
	md_home_lightbulb_outline = "\uf1252"
	# CHAR : 󱤃
	md_home_lightning_bolt = "\uf1903"
	# CHAR : 󱤄
	md_home_lightning_bolt_outline = "\uf1904"
	# CHAR : 󰣫
	md_home_lock = "\uf08eb"
	# CHAR : 󰣬
	md_home_lock_open = "\uf08ec"
	# CHAR : 󰗸
	md_home_map_marker = "\uf05f8"
	# CHAR : 󰥴
	md_home_minus = "\uf0974"
	# CHAR : 󱏕
	md_home_minus_outline = "\uf13d5"
	# CHAR : 󰋝
	md_home_modern = "\uf02dd"
	# CHAR : 󱩆
	md_home_off = "\uf1a46"
	# CHAR : 󱩇
	md_home_off_outline = "\uf1a47"
	# CHAR : 󰚡
	md_home_outline = "\uf06a1"
	# CHAR : 󰥵
	md_home_plus = "\uf0975"
	# CHAR : 󱏖
	md_home_plus_outline = "\uf13d6"
	# CHAR : 󱉇
	md_home_remove = "\uf1247"
	# CHAR : 󱏗
	md_home_remove_outline = "\uf13d7"
	# CHAR : 󱄫
	md_home_roof = "\uf112b"
	# CHAR : 󱎰
	md_home_search = "\uf13b0"
	# CHAR : 󱎱
	md_home_search_outline = "\uf13b1"
	# CHAR : 󱞔
	md_home_switch = "\uf1794"
	# CHAR : 󱞕
	md_home_switch_outline = "\uf1795"
	# CHAR : 󰽔
	md_home_thermometer = "\uf0f54"
	# CHAR : 󰽕
	md_home_thermometer_outline = "\uf0f55"
	# CHAR : 󰋞
	md_home_variant = "\uf02de"
	# CHAR : 󰮧
	md_home_variant_outline = "\uf0ba7"
	# CHAR : 󰛢
	md_hook = "\uf06e2"
	# CHAR : 󰛣
	md_hook_off = "\uf06e3"
	# CHAR : 󰹖
	md_hoop_house = "\uf0e56"
	# CHAR : 󰋟
	md_hops = "\uf02df"
	# CHAR : 󱃳
	md_horizontal_rotate_clockwise = "\uf10f3"
	# CHAR : 󱃴
	md_horizontal_rotate_counterclockwise = "\uf10f4"
	# CHAR : 󱖿
	md_horse = "\uf15bf"
	# CHAR : 󱗀
	md_horse_human = "\uf15c0"
	# CHAR : 󱗁
	md_horse_variant = "\uf15c1"
	# CHAR : 󱡮
	md_horse_variant_fast = "\uf186e"
	# CHAR : 󰩘
	md_horseshoe = "\uf0a58"
	# CHAR : 󰿶
	md_hospital = "\uf0ff6"
	# CHAR : 󰋠
	md_hospital_box = "\uf02e0"
	# CHAR : 󰿷
	md_hospital_box_outline = "\uf0ff7"
	# CHAR : 󰋡
	md_hospital_building = "\uf02e1"
	# CHAR : 󰋢
	md_hospital_marker = "\uf02e2"
	# CHAR : 󰠨
	md_hot_tub = "\uf0828"
	# CHAR : 󱑸
	md_hours_24 = "\uf1478"
	# CHAR : 󰴗
	md_hubspot = "\uf0d17"
	# CHAR : 󰠩
	md_hulu = "\uf0829"
	# CHAR : 󰋦
	md_human = "\uf02e6"
	# CHAR : 󱎋
	md_human_baby_changing_table = "\uf138b"
	# CHAR : 󱖁
	md_human_cane = "\uf1581"
	# CHAR : 󱖛
	md_human_capacity_decrease = "\uf159b"
	# CHAR : 󱖜
	md_human_capacity_increase = "\uf159c"
	# CHAR : 󰋧
	md_human_child = "\uf02e7"
	# CHAR : 󱦀
	md_human_dolly = "\uf1980"
	# CHAR : 󱓨
	md_human_edit = "\uf14e8"
	# CHAR : 󰙉
	md_human_female = "\uf0649"
	# CHAR : 󰩙
	md_human_female_boy = "\uf0a59"
	# CHAR : 󱗉
	md_human_female_dance = "\uf15c9"
	# CHAR : 󰩚
	md_human_female_female = "\uf0a5a"
	# CHAR : 󰩛
	md_human_female_girl = "\uf0a5b"
	# CHAR : 󱟄
	md_human_greeting = "\uf17c4"
	# CHAR : 󱖝
	md_human_greeting_proximity = "\uf159d"
	# CHAR : 󰙊
	md_human_greeting_variant = "\uf064a"
	# CHAR : 󰙋
	md_human_handsdown = "\uf064b"
	# CHAR : 󰙌
	md_human_handsup = "\uf064c"
	# CHAR : 󰙍
	md_human_male = "\uf064d"
	# CHAR : 󰢐
	md_human_male_board = "\uf0890"
	# CHAR : 󰡆
	md_human_male_board_poll = "\uf0846"
	# CHAR : 󰩜
	md_human_male_boy = "\uf0a5c"
	# CHAR : 󱎌
	md_human_male_child = "\uf138c"
	# CHAR : 󰋨
	md_human_male_female = "\uf02e8"
	# CHAR : 󱠣
	md_human_male_female_child = "\uf1823"
	# CHAR : 󰩝
	md_human_male_girl = "\uf0a5d"
	# CHAR : 󰻻
	md_human_male_height = "\uf0efb"
	# CHAR : 󰻼
	md_human_male_height_variant = "\uf0efc"
	# CHAR : 󰩞
	md_human_male_male = "\uf0a5e"
	# CHAR : 󱡈
	md_human_non_binary = "\uf1848"
	# CHAR : 󰗏
	md_human_pregnant = "\uf05cf"
	# CHAR : 󱕱
	md_human_queue = "\uf1571"
	# CHAR : 󱇩
	md_human_scooter = "\uf11e9"
	# CHAR : 󱎍
	md_human_wheelchair = "\uf138d"
	# CHAR : 󱦁
	md_human_white_cane = "\uf1981"
	# CHAR : 󰝄
	md_humble_bundle = "\uf0744"
	# CHAR : 󱍒
	md_hvac = "\uf1352"
	# CHAR : 󱖞
	md_hvac_off = "\uf159e"
	# CHAR : 󱌤
	md_hydraulic_oil_level = "\uf1324"
	# CHAR : 󱌥
	md_hydraulic_oil_temperature = "\uf1325"
	# CHAR : 󱋥
	md_hydro_power = "\uf12e5"
	# CHAR : 󱢔
	md_hydrogen_station = "\uf1894"
	# CHAR : 󰠪
	md_ice_cream = "\uf082a"
	# CHAR : 󰹒
	md_ice_cream_off = "\uf0e52"
	# CHAR : 󰻽
	md_ice_pop = "\uf0efd"
	# CHAR : 󰿀
	md_id_card = "\uf0fc0"
	# CHAR : 󰻾
	md_identifier = "\uf0efe"
	# CHAR : 󱌱
	md_ideogram_cjk = "\uf1331"
	# CHAR : 󱌲
	md_ideogram_cjk_variant = "\uf1332"
	# CHAR : 󰋩
	md_image = "\uf02e9"
	# CHAR : 󰋪
	md_image_album = "\uf02ea"
	# CHAR : 󰋫
	md_image_area = "\uf02eb"
	# CHAR : 󰋬
	md_image_area_close = "\uf02ec"
	# CHAR : 󰿁
	md_image_auto_adjust = "\uf0fc1"
	# CHAR : 󰋭
	md_image_broken = "\uf02ed"
	# CHAR : 󰋮
	md_image_broken_variant = "\uf02ee"
	# CHAR : 󱇣
	md_image_edit = "\uf11e3"
	# CHAR : 󱇤
	md_image_edit_outline = "\uf11e4"
	# CHAR : 󰋰
	md_image_filter_black_white = "\uf02f0"
	# CHAR : 󰋱
	md_image_filter_center_focus = "\uf02f1"
	# CHAR : 󰻿
	md_image_filter_center_focus_strong = "\uf0eff"
	# CHAR : 󰼀
	md_image_filter_center_focus_strong_outline = "\uf0f00"
	# CHAR : 󰋲
	md_image_filter_center_focus_weak = "\uf02f2"
	# CHAR : 󰋳
	md_image_filter_drama = "\uf02f3"
	# CHAR : 󰋴
	md_image_filter_frames = "\uf02f4"
	# CHAR : 󰋵
	md_image_filter_hdr = "\uf02f5"
	# CHAR : 󰋶
	md_image_filter_none = "\uf02f6"
	# CHAR : 󰋷
	md_image_filter_tilt_shift = "\uf02f7"
	# CHAR : 󰋸
	md_image_filter_vintage = "\uf02f8"
	# CHAR : 󰹉
	md_image_frame = "\uf0e49"
	# CHAR : 󱪰
	md_image_lock = "\uf1ab0"
	# CHAR : 󱪱
	md_image_lock_outline = "\uf1ab1"
	# CHAR : 󱝻
	md_image_marker = "\uf177b"
	# CHAR : 󱝼
	md_image_marker_outline = "\uf177c"
	# CHAR : 󱐙
	md_image_minus = "\uf1419"
	# CHAR : 󰧸
	md_image_move = "\uf09f8"
	# CHAR : 󰋹
	md_image_multiple = "\uf02f9"
	# CHAR : 󰋯
	md_image_multiple_outline = "\uf02ef"
	# CHAR : 󰠫
	md_image_off = "\uf082b"
	# CHAR : 󱇑
	md_image_off_outline = "\uf11d1"
	# CHAR : 󰥶
	md_image_outline = "\uf0976"
	# CHAR : 󰡼
	md_image_plus = "\uf087c"
	# CHAR : 󱧾
	md_image_refresh = "\uf19fe"
	# CHAR : 󱧿
	md_image_refresh_outline = "\uf19ff"
	# CHAR : 󱐘
	md_image_remove = "\uf1418"
	# CHAR : 󰥷
	md_image_search = "\uf0977"
	# CHAR : 󰥸
	md_image_search_outline = "\uf0978"
	# CHAR : 󰲍
	md_image_size_select_actual = "\uf0c8d"
	# CHAR : 󰲎
	md_image_size_select_large = "\uf0c8e"
	# CHAR : 󰲏
	md_image_size_select_small = "\uf0c8f"
	# CHAR : 󱨀
	md_image_sync = "\uf1a00"
	# CHAR : 󱨁
	md_image_sync_outline = "\uf1a01"
	# CHAR : 󱘍
	md_image_text = "\uf160d"
	# CHAR : 󰋺
	md_import = "\uf02fa"
	# CHAR : 󰚇
	md_inbox = "\uf0687"
	# CHAR : 󰋻
	md_inbox_arrow_down = "\uf02fb"
	# CHAR : 󱉰
	md_inbox_arrow_down_outline = "\uf1270"
	# CHAR : 󰏑
	md_inbox_arrow_up = "\uf03d1"
	# CHAR : 󱉱
	md_inbox_arrow_up_outline = "\uf1271"
	# CHAR : 󱉲
	md_inbox_full = "\uf1272"
	# CHAR : 󱉳
	md_inbox_full_outline = "\uf1273"
	# CHAR : 󰢰
	md_inbox_multiple = "\uf08b0"
	# CHAR : 󰮨
	md_inbox_multiple_outline = "\uf0ba8"
	# CHAR : 󱉴
	md_inbox_outline = "\uf1274"
	# CHAR : 󱖟
	md_inbox_remove = "\uf159f"
	# CHAR : 󱖠
	md_inbox_remove_outline = "\uf15a0"
	# CHAR : 󰗹
	md_incognito = "\uf05f9"
	# CHAR : 󱐡
	md_incognito_circle = "\uf1421"
	# CHAR : 󱐢
	md_incognito_circle_off = "\uf1422"
	# CHAR : 󰁵
	md_incognito_off = "\uf0075"
	# CHAR : 󱡌
	md_induction = "\uf184c"
	# CHAR : 󰛤
	md_infinity = "\uf06e4"
	# CHAR : 󰋼
	md_information = "\uf02fc"
	# CHAR : 󱞌
	md_information_off = "\uf178c"
	# CHAR : 󱞍
	md_information_off_outline = "\uf178d"
	# CHAR : 󰋽
	md_information_outline = "\uf02fd"
	# CHAR : 󰙎
	md_information_variant = "\uf064e"
	# CHAR : 󰋾
	md_instagram = "\uf02fe"
	# CHAR : 󱁎
	md_instrument_triangle = "\uf104e"
	# CHAR : 󱤓
	md_integrated_circuit_chip = "\uf1913"
	# CHAR : 󰌁
	md_invert_colors = "\uf0301"
	# CHAR : 󰹊
	md_invert_colors_off = "\uf0e4a"
	# CHAR : 󱋨
	md_iobroker = "\uf12e8"
	# CHAR : 󰩟
	md_ip = "\uf0a5f"
	# CHAR : 󰩠
	md_ip_network = "\uf0a60"
	# CHAR : 󰲐
	md_ip_network_outline = "\uf0c90"
	# CHAR : 󱦂
	md_ip_outline = "\uf1982"
	# CHAR : 󰲑
	md_ipod = "\uf0c91"
	# CHAR : 󱠤
	md_iron = "\uf1824"
	# CHAR : 󱠸
	md_iron_board = "\uf1838"
	# CHAR : 󱠥
	md_iron_outline = "\uf1825"
	# CHAR : 󱁏
	md_island = "\uf104f"
	# CHAR : 󱂹
	md_iv_bag = "\uf10b9"
	# CHAR : 󰷕
	md_jabber = "\uf0dd5"
	# CHAR : 󰌂
	md_jeepney = "\uf0302"
	# CHAR : 󰼁
	md_jellyfish = "\uf0f01"
	# CHAR : 󰼂
	md_jellyfish_outline = "\uf0f02"
	# CHAR : 󰌃
	md_jira = "\uf0303"
	# CHAR : 󰡽
	md_jquery = "\uf087d"
	# CHAR : 󰌄
	md_jsfiddle = "\uf0304"
	# CHAR : 󱋿
	md_jump_rope = "\uf12ff"
	# CHAR : 󰶇
	md_kabaddi = "\uf0d87"
	# CHAR : 󱕘
	md_kangaroo = "\uf1558"
	# CHAR : 󰠬
	md_karate = "\uf082c"
	# CHAR : 󰢯
	md_kayaking = "\uf08af"
	# CHAR : 󰌅
	md_keg = "\uf0305"
	# CHAR : 󰗺
	md_kettle = "\uf05fa"
	# CHAR : 󱌗
	md_kettle_alert = "\uf1317"
	# CHAR : 󱌘
	md_kettle_alert_outline = "\uf1318"
	# CHAR : 󱌛
	md_kettle_off = "\uf131b"
	# CHAR : 󱌜
	md_kettle_off_outline = "\uf131c"
	# CHAR : 󰽖
	md_kettle_outline = "\uf0f56"
	# CHAR : 󱜼
	md_kettle_pour_over = "\uf173c"
	# CHAR : 󱌙
	md_kettle_steam = "\uf1319"
	# CHAR : 󱌚
	md_kettle_steam_outline = "\uf131a"
	# CHAR : 󱌀
	md_kettlebell = "\uf1300"
	# CHAR : 󰌆
	md_key = "\uf0306"
	# CHAR : 󱦃
	md_key_alert = "\uf1983"
	# CHAR : 󱦄
	md_key_alert_outline = "\uf1984"
	# CHAR : 󱌒
	md_key_arrow_right = "\uf1312"
	# CHAR : 󱕴
	md_key_chain = "\uf1574"
	# CHAR : 󱕵
	md_key_chain_variant = "\uf1575"
	# CHAR : 󰌇
	md_key_change = "\uf0307"
	# CHAR : 󱆟
	md_key_link = "\uf119f"
	# CHAR : 󰌈
	md_key_minus = "\uf0308"
	# CHAR : 󰷖
	md_key_outline = "\uf0dd6"
	# CHAR : 󰌉
	md_key_plus = "\uf0309"
	# CHAR : 󰌊
	md_key_remove = "\uf030a"
	# CHAR : 󱆞
	md_key_star = "\uf119e"
	# CHAR : 󰌋
	md_key_variant = "\uf030b"
	# CHAR : 󰿂
	md_key_wireless = "\uf0fc2"
	# CHAR : 󰌌
	md_keyboard = "\uf030c"
	# CHAR : 󰌍
	md_keyboard_backspace = "\uf030d"
	# CHAR : 󰌎
	md_keyboard_caps = "\uf030e"
	# CHAR : 󰌏
	md_keyboard_close = "\uf030f"
	# CHAR : 󱊷
	md_keyboard_esc = "\uf12b7"
	# CHAR : 󱊫
	md_keyboard_f1 = "\uf12ab"
	# CHAR : 󱊴
	md_keyboard_f10 = "\uf12b4"
	# CHAR : 󱊵
	md_keyboard_f11 = "\uf12b5"
	# CHAR : 󱊶
	md_keyboard_f12 = "\uf12b6"
	# CHAR : 󱊬
	md_keyboard_f2 = "\uf12ac"
	# CHAR : 󱊭
	md_keyboard_f3 = "\uf12ad"
	# CHAR : 󱊮
	md_keyboard_f4 = "\uf12ae"
	# CHAR : 󱊯
	md_keyboard_f5 = "\uf12af"
	# CHAR : 󱊰
	md_keyboard_f6 = "\uf12b0"
	# CHAR : 󱊱
	md_keyboard_f7 = "\uf12b1"
	# CHAR : 󱊲
	md_keyboard_f8 = "\uf12b2"
	# CHAR : 󱊳
	md_keyboard_f9 = "\uf12b3"
	# CHAR : 󰌐
	md_keyboard_off = "\uf0310"
	# CHAR : 󰹋
	md_keyboard_off_outline = "\uf0e4b"
	# CHAR : 󰥻
	md_keyboard_outline = "\uf097b"
	# CHAR : 󰌑
	md_keyboard_return = "\uf0311"
	# CHAR : 󰧹
	md_keyboard_settings = "\uf09f9"
	# CHAR : 󰧺
	md_keyboard_settings_outline = "\uf09fa"
	# CHAR : 󱁐
	md_keyboard_space = "\uf1050"
	# CHAR : 󰌒
	md_keyboard_tab = "\uf0312"
	# CHAR : 󰌥
	md_keyboard_tab_reverse = "\uf0325"
	# CHAR : 󰌓
	md_keyboard_variant = "\uf0313"
	# CHAR : 󱃽
	md_khanda = "\uf10fd"
	# CHAR : 󰝅
	md_kickstarter = "\uf0745"
	# CHAR : 󱦅
	md_kite = "\uf1985"
	# CHAR : 󱦆
	md_kite_outline = "\uf1986"
	# CHAR : 󱝄
	md_kitesurfing = "\uf1744"
	# CHAR : 󱍛
	md_klingon = "\uf135b"
	# CHAR : 󰧻
	md_knife = "\uf09fb"
	# CHAR : 󰧼
	md_knife_military = "\uf09fc"
	# CHAR : 󱜿
	md_koala = "\uf173f"
	# CHAR : 󰌔
	md_kodi = "\uf0314"
	# CHAR : 󱃾
	md_kubernetes = "\uf10fe"
	# CHAR : 󰌕
	md_label = "\uf0315"
	# CHAR : 󱍵
	md_label_multiple = "\uf1375"
	# CHAR : 󱍶
	md_label_multiple_outline = "\uf1376"
	# CHAR : 󰫋
	md_label_off = "\uf0acb"
	# CHAR : 󰫌
	md_label_off_outline = "\uf0acc"
	# CHAR : 󰌖
	md_label_outline = "\uf0316"
	# CHAR : 󱋪
	md_label_percent = "\uf12ea"
	# CHAR : 󱋫
	md_label_percent_outline = "\uf12eb"
	# CHAR : 󰫍
	md_label_variant = "\uf0acd"
	# CHAR : 󰫎
	md_label_variant_outline = "\uf0ace"
	# CHAR : 󱖢
	md_ladder = "\uf15a2"
	# CHAR : 󰠭
	md_ladybug = "\uf082d"
	# CHAR : 󰘧
	md_lambda = "\uf0627"
	# CHAR : 󰚵
	md_lamp = "\uf06b5"
	# CHAR : 󱟐
	md_lamp_outline = "\uf17d0"
	# CHAR : 󱕶
	md_lamps = "\uf1576"
	# CHAR : 󱟑
	md_lamps_outline = "\uf17d1"
	# CHAR : 󰌗
	md_lan = "\uf0317"
	# CHAR : 󱊪
	md_lan_check = "\uf12aa"
	# CHAR : 󰌘
	md_lan_connect = "\uf0318"
	# CHAR : 󰌙
	md_lan_disconnect = "\uf0319"
	# CHAR : 󰌚
	md_lan_pending = "\uf031a"
	# CHAR : 󱪲
	md_land_fields = "\uf1ab2"
	# CHAR : 󱪳
	md_land_plots = "\uf1ab3"
	# CHAR : 󱪴
	md_land_plots_circle = "\uf1ab4"
	# CHAR : 󱪵
	md_land_plots_circle_variant = "\uf1ab5"
	# CHAR : 󱪶
	md_land_rows_horizontal = "\uf1ab6"
	# CHAR : 󱪷
	md_land_rows_vertical = "\uf1ab7"
	# CHAR : 󱩈
	md_landslide = "\uf1a48"
	# CHAR : 󱩉
	md_landslide_outline = "\uf1a49"
	# CHAR : 󰙱
	md_language_c = "\uf0671"
	# CHAR : 󰙲
	md_language_cpp = "\uf0672"
	# CHAR : 󰌛
	md_language_csharp = "\uf031b"
	# CHAR : 󰌜
	md_language_css3 = "\uf031c"
	# CHAR : 󱈚
	md_language_fortran = "\uf121a"
	# CHAR : 󰟓
	md_language_go = "\uf07d3"
	# CHAR : 󰲒
	md_language_haskell = "\uf0c92"
	# CHAR : 󰌝
	md_language_html5 = "\uf031d"
	# CHAR : 󰬷
	md_language_java = "\uf0b37"
	# CHAR : 󰌞
	md_language_javascript = "\uf031e"
	# CHAR : 󱈙
	md_language_kotlin = "\uf1219"
	# CHAR : 󰢱
	md_language_lua = "\uf08b1"
	# CHAR : 󰍔
	md_language_markdown = "\uf0354"
	# CHAR : 󰽛
	md_language_markdown_outline = "\uf0f5b"
	# CHAR : 󰌟
	md_language_php = "\uf031f"
	# CHAR : 󰌠
	md_language_python = "\uf0320"
	# CHAR : 󰟔
	md_language_r = "\uf07d4"
	# CHAR : 󰴭
	md_language_ruby = "\uf0d2d"
	# CHAR : 󰫏
	md_language_ruby_on_rails = "\uf0acf"
	# CHAR : 󱘗
	md_language_rust = "\uf1617"
	# CHAR : 󰛥
	md_language_swift = "\uf06e5"
	# CHAR : 󰛦
	md_language_typescript = "\uf06e6"
	# CHAR : 󰙳
	md_language_xaml = "\uf0673"
	# CHAR : 󰌢
	md_laptop = "\uf0322"
	# CHAR : 󱩊
	md_laptop_account = "\uf1a4a"
	# CHAR : 󰛧
	md_laptop_off = "\uf06e7"
	# CHAR : 󰫐
	md_laravel = "\uf0ad0"
	# CHAR : 󱒄
	md_laser_pointer = "\uf1484"
	# CHAR : 󰼃
	md_lasso = "\uf0f03"
	# CHAR : 󰑆
	md_lastpass = "\uf0446"
	# CHAR : 󰽗
	md_latitude = "\uf0f57"
	# CHAR : 󰌧
	md_launch = "\uf0327"
	# CHAR : 󰟕
	md_lava_lamp = "\uf07d5"
	# CHAR : 󰌨
	md_layers = "\uf0328"
	# CHAR : 󱢒
	md_layers_edit = "\uf1892"
	# CHAR : 󰹌
	md_layers_minus = "\uf0e4c"
	# CHAR : 󰌩
	md_layers_off = "\uf0329"
	# CHAR : 󰧽
	md_layers_off_outline = "\uf09fd"
	# CHAR : 󰧾
	md_layers_outline = "\uf09fe"
	# CHAR : 󰹍
	md_layers_plus = "\uf0e4d"
	# CHAR : 󰹎
	md_layers_remove = "\uf0e4e"
	# CHAR : 󱈆
	md_layers_search = "\uf1206"
	# CHAR : 󱈇
	md_layers_search_outline = "\uf1207"
	# CHAR : 󰽘
	md_layers_triple = "\uf0f58"
	# CHAR : 󰽙
	md_layers_triple_outline = "\uf0f59"
	# CHAR : 󰙏
	md_lead_pencil = "\uf064f"
	# CHAR : 󰌪
	md_leaf = "\uf032a"
	# CHAR : 󱤅
	md_leaf_circle = "\uf1905"
	# CHAR : 󱤆
	md_leaf_circle_outline = "\uf1906"
	# CHAR : 󰲓
	md_leaf_maple = "\uf0c93"
	# CHAR : 󱋚
	md_leaf_maple_off = "\uf12da"
	# CHAR : 󱋙
	md_leaf_off = "\uf12d9"
	# CHAR : 󰷗
	md_leak = "\uf0dd7"
	# CHAR : 󰷘
	md_leak_off = "\uf0dd8"
	# CHAR : 󱫰
	md_lecturn = "\uf1af0"
	# CHAR : 󰌫
	md_led_off = "\uf032b"
	# CHAR : 󰌬
	md_led_on = "\uf032c"
	# CHAR : 󰌭
	md_led_outline = "\uf032d"
	# CHAR : 󰟖
	md_led_strip = "\uf07d6"
	# CHAR : 󱁑
	md_led_strip_variant = "\uf1051"
	# CHAR : 󱩋
	md_led_strip_variant_off = "\uf1a4b"
	# CHAR : 󰌮
	md_led_variant_off = "\uf032e"
	# CHAR : 󰌯
	md_led_variant_on = "\uf032f"
	# CHAR : 󰌰
	md_led_variant_outline = "\uf0330"
	# CHAR : 󱅽
	md_leek = "\uf117d"
	# CHAR : 󰥼
	md_less_than = "\uf097c"
	# CHAR : 󰥽
	md_less_than_or_equal = "\uf097d"
	# CHAR : 󰌱
	md_library = "\uf0331"
	# CHAR : 󱨢
	md_library_outline = "\uf1a22"
	# CHAR : 󰮩
	md_library_shelves = "\uf0ba9"
	# CHAR : 󰿃
	md_license = "\uf0fc3"
	# CHAR : 󰡾
	md_lifebuoy = "\uf087e"
	# CHAR : 󱦇
	md_light_flood_down = "\uf1987"
	# CHAR : 󱦈
	md_light_flood_up = "\uf1988"
	# CHAR : 󱞛
	md_light_recessed = "\uf179b"
	# CHAR : 󰥾
	md_light_switch = "\uf097e"
	# CHAR : 󱨤
	md_light_switch_off = "\uf1a24"
	# CHAR : 󰌵
	md_lightbulb = "\uf0335"
	# CHAR : 󱧡
	md_lightbulb_alert = "\uf19e1"
	# CHAR : 󱧢
	md_lightbulb_alert_outline = "\uf19e2"
	# CHAR : 󱠀
	md_lightbulb_auto = "\uf1800"
	# CHAR : 󱠁
	md_lightbulb_auto_outline = "\uf1801"
	# CHAR : 󱈈
	md_lightbulb_cfl = "\uf1208"
	# CHAR : 󱈉
	md_lightbulb_cfl_off = "\uf1209"
	# CHAR : 󱉵
	md_lightbulb_cfl_spiral = "\uf1275"
	# CHAR : 󱋃
	md_lightbulb_cfl_spiral_off = "\uf12c3"
	# CHAR : 󱠄
	md_lightbulb_fluorescent_tube = "\uf1804"
	# CHAR : 󱠅
	md_lightbulb_fluorescent_tube_outline = "\uf1805"
	# CHAR : 󱉓
	md_lightbulb_group = "\uf1253"
	# CHAR : 󱋍
	md_lightbulb_group_off = "\uf12cd"
	# CHAR : 󱋎
	md_lightbulb_group_off_outline = "\uf12ce"
	# CHAR : 󱉔
	md_lightbulb_group_outline = "\uf1254"
	# CHAR : 󱉕
	md_lightbulb_multiple = "\uf1255"
	# CHAR : 󱋏
	md_lightbulb_multiple_off = "\uf12cf"
	# CHAR : 󱋐
	md_lightbulb_multiple_off_outline = "\uf12d0"
	# CHAR : 󱉖
	md_lightbulb_multiple_outline = "\uf1256"
	# CHAR : 󱩌
	md_lightbulb_night = "\uf1a4c"
	# CHAR : 󱩍
	md_lightbulb_night_outline = "\uf1a4d"
	# CHAR : 󰹏
	md_lightbulb_off = "\uf0e4f"
	# CHAR : 󰹐
	md_lightbulb_off_outline = "\uf0e50"
	# CHAR : 󰛨
	md_lightbulb_on = "\uf06e8"
	# CHAR : 󱩎
	md_lightbulb_on_10 = "\uf1a4e"
	# CHAR : 󱩏
	md_lightbulb_on_20 = "\uf1a4f"
	# CHAR : 󱩐
	md_lightbulb_on_30 = "\uf1a50"
	# CHAR : 󱩑
	md_lightbulb_on_40 = "\uf1a51"
	# CHAR : 󱩒
	md_lightbulb_on_50 = "\uf1a52"
	# CHAR : 󱩓
	md_lightbulb_on_60 = "\uf1a53"
	# CHAR : 󱩔
	md_lightbulb_on_70 = "\uf1a54"
	# CHAR : 󱩕
	md_lightbulb_on_80 = "\uf1a55"
	# CHAR : 󱩖
	md_lightbulb_on_90 = "\uf1a56"
	# CHAR : 󰛩
	md_lightbulb_on_outline = "\uf06e9"
	# CHAR : 󰌶
	md_lightbulb_outline = "\uf0336"
	# CHAR : 󱧣
	md_lightbulb_question = "\uf19e3"
	# CHAR : 󱧤
	md_lightbulb_question_outline = "\uf19e4"
	# CHAR : 󱟴
	md_lightbulb_spot = "\uf17f4"
	# CHAR : 󱟵
	md_lightbulb_spot_off = "\uf17f5"
	# CHAR : 󱠂
	md_lightbulb_variant = "\uf1802"
	# CHAR : 󱠃
	md_lightbulb_variant_outline = "\uf1803"
	# CHAR : 󰧿
	md_lighthouse = "\uf09ff"
	# CHAR : 󰨀
	md_lighthouse_on = "\uf0a00"
	# CHAR : 󱐋
	md_lightning_bolt = "\uf140b"
	# CHAR : 󰠠
	md_lightning_bolt_circle = "\uf0820"
	# CHAR : 󱐌
	md_lightning_bolt_outline = "\uf140c"
	# CHAR : 󰘤
	md_line_scan = "\uf0624"
	# CHAR : 󱑶
	md_lingerie = "\uf1476"
	# CHAR : 󰌷
	md_link = "\uf0337"
	# CHAR : 󰴚
	md_link_box = "\uf0d1a"
	# CHAR : 󰴛
	md_link_box_outline = "\uf0d1b"
	# CHAR : 󰴜
	md_link_box_variant = "\uf0d1c"
	# CHAR : 󰴝
	md_link_box_variant_outline = "\uf0d1d"
	# CHAR : 󱂺
	md_link_lock = "\uf10ba"
	# CHAR : 󰌸
	md_link_off = "\uf0338"
	# CHAR : 󰲔
	md_link_plus = "\uf0c94"
	# CHAR : 󰌹
	md_link_variant = "\uf0339"
	# CHAR : 󱃿
	md_link_variant_minus = "\uf10ff"
	# CHAR : 󰌺
	md_link_variant_off = "\uf033a"
	# CHAR : 󱄀
	md_link_variant_plus = "\uf1100"
	# CHAR : 󱄁
	md_link_variant_remove = "\uf1101"
	# CHAR : 󰌻
	md_linkedin = "\uf033b"
	# CHAR : 󰌽
	md_linux = "\uf033d"
	# CHAR : 󰣭
	md_linux_mint = "\uf08ed"
	# CHAR : 󱎵
	md_lipstick = "\uf13b5"
	# CHAR : 󱠦
	md_liquid_spot = "\uf1826"
	# CHAR : 󱤞
	md_liquor = "\uf191e"
	# CHAR : 󱖫
	md_list_status = "\uf15ab"
	# CHAR : 󰩡
	md_litecoin = "\uf0a61"
	# CHAR : 󰝲
	md_loading = "\uf0772"
	# CHAR : 󰿄
	md_location_enter = "\uf0fc4"
	# CHAR : 󰿅
	md_location_exit = "\uf0fc5"
	# CHAR : 󰌾
	md_lock = "\uf033e"
	# CHAR : 󰣮
	md_lock_alert = "\uf08ee"
	# CHAR : 󱗑
	md_lock_alert_outline = "\uf15d1"
	# CHAR : 󱎚
	md_lock_check = "\uf139a"
	# CHAR : 󱚨
	md_lock_check_outline = "\uf16a8"
	# CHAR : 󰥿
	md_lock_clock = "\uf097f"
	# CHAR : 󱚩
	md_lock_minus = "\uf16a9"
	# CHAR : 󱚪
	md_lock_minus_outline = "\uf16aa"
	# CHAR : 󱙱
	md_lock_off = "\uf1671"
	# CHAR : 󱙲
	md_lock_off_outline = "\uf1672"
	# CHAR : 󰌿
	md_lock_open = "\uf033f"
	# CHAR : 󱎛
	md_lock_open_alert = "\uf139b"
	# CHAR : 󱗒
	md_lock_open_alert_outline = "\uf15d2"
	# CHAR : 󱎜
	md_lock_open_check = "\uf139c"
	# CHAR : 󱚫
	md_lock_open_check_outline = "\uf16ab"
	# CHAR : 󱚬
	md_lock_open_minus = "\uf16ac"
	# CHAR : 󱚭
	md_lock_open_minus_outline = "\uf16ad"
	# CHAR : 󰍀
	md_lock_open_outline = "\uf0340"
	# CHAR : 󱚮
	md_lock_open_plus = "\uf16ae"
	# CHAR : 󱚯
	md_lock_open_plus_outline = "\uf16af"
	# CHAR : 󱚰
	md_lock_open_remove = "\uf16b0"
	# CHAR : 󱚱
	md_lock_open_remove_outline = "\uf16b1"
	# CHAR : 󰿆
	md_lock_open_variant = "\uf0fc6"
	# CHAR : 󰿇
	md_lock_open_variant_outline = "\uf0fc7"
	# CHAR : 󰍁
	md_lock_outline = "\uf0341"
	# CHAR : 󰛪
	md_lock_pattern = "\uf06ea"
	# CHAR : 󰗻
	md_lock_plus = "\uf05fb"
	# CHAR : 󱚲
	md_lock_plus_outline = "\uf16b2"
	# CHAR : 󰣯
	md_lock_question = "\uf08ef"
	# CHAR : 󱚳
	md_lock_remove = "\uf16b3"
	# CHAR : 󱚴
	md_lock_remove_outline = "\uf16b4"
	# CHAR : 󰝳
	md_lock_reset = "\uf0773"
	# CHAR : 󰢲
	md_lock_smart = "\uf08b2"
	# CHAR : 󰟗
	md_locker = "\uf07d7"
	# CHAR : 󰟘
	md_locker_multiple = "\uf07d8"
	# CHAR : 󰍂
	md_login = "\uf0342"
	# CHAR : 󰍃
	md_logout = "\uf0343"
	# CHAR : 󰗽
	md_logout_variant = "\uf05fd"
	# CHAR : 󰽚
	md_longitude = "\uf0f5a"
	# CHAR : 󰍄
	md_looks = "\uf0344"
	# CHAR : 󱖂
	md_lotion = "\uf1582"
	# CHAR : 󱖃
	md_lotion_outline = "\uf1583"
	# CHAR : 󱖄
	md_lotion_plus = "\uf1584"
	# CHAR : 󱖅
	md_lotion_plus_outline = "\uf1585"
	# CHAR : 󰍅
	md_loupe = "\uf0345"
	# CHAR : 󰍆
	md_lumx = "\uf0346"
	# CHAR : 󱂄
	md_lungs = "\uf1084"
	# CHAR : 󱡃
	md_mace = "\uf1843"
	# CHAR : 󰌤
	md_magazine_pistol = "\uf0324"
	# CHAR : 󰌣
	md_magazine_rifle = "\uf0323"
	# CHAR : 󱡄
	md_magic_staff = "\uf1844"
	# CHAR : 󰍇
	md_magnet = "\uf0347"
	# CHAR : 󰍈
	md_magnet_on = "\uf0348"
	# CHAR : 󰍉
	md_magnify = "\uf0349"
	# CHAR : 󰦀
	md_magnify_close = "\uf0980"
	# CHAR : 󱡴
	md_magnify_expand = "\uf1874"
	# CHAR : 󰍊
	md_magnify_minus = "\uf034a"
	# CHAR : 󰩢
	md_magnify_minus_cursor = "\uf0a62"
	# CHAR : 󰛬
	md_magnify_minus_outline = "\uf06ec"
	# CHAR : 󰍋
	md_magnify_plus = "\uf034b"
	# CHAR : 󰩣
	md_magnify_plus_cursor = "\uf0a63"
	# CHAR : 󰛭
	md_magnify_plus_outline = "\uf06ed"
	# CHAR : 󱈌
	md_magnify_remove_cursor = "\uf120c"
	# CHAR : 󱈍
	md_magnify_remove_outline = "\uf120d"
	# CHAR : 󱉶
	md_magnify_scan = "\uf1276"
	# CHAR : 󰺻
	md_mail = "\uf0ebb"
	# CHAR : 󰛮
	md_mailbox = "\uf06ee"
	# CHAR : 󰶈
	md_mailbox_open = "\uf0d88"
	# CHAR : 󰶉
	md_mailbox_open_outline = "\uf0d89"
	# CHAR : 󰶊
	md_mailbox_open_up = "\uf0d8a"
	# CHAR : 󰶋
	md_mailbox_open_up_outline = "\uf0d8b"
	# CHAR : 󰶌
	md_mailbox_outline = "\uf0d8c"
	# CHAR : 󰶍
	md_mailbox_up = "\uf0d8d"
	# CHAR : 󰶎
	md_mailbox_up_outline = "\uf0d8e"
	# CHAR : 󱘊
	md_manjaro = "\uf160a"
	# CHAR : 󰍍
	md_map = "\uf034d"
	# CHAR : 󰺼
	md_map_check = "\uf0ebc"
	# CHAR : 󰺽
	md_map_check_outline = "\uf0ebd"
	# CHAR : 󰴞
	md_map_clock = "\uf0d1e"
	# CHAR : 󰴟
	md_map_clock_outline = "\uf0d1f"
	# CHAR : 󰨁
	md_map_legend = "\uf0a01"
	# CHAR : 󰍎
	md_map_marker = "\uf034e"
	# CHAR : 󱣣
	md_map_marker_account = "\uf18e3"
	# CHAR : 󱣤
	md_map_marker_account_outline = "\uf18e4"
	# CHAR : 󰼅
	md_map_marker_alert = "\uf0f05"
	# CHAR : 󰼆
	md_map_marker_alert_outline = "\uf0f06"
	# CHAR : 󰲕
	md_map_marker_check = "\uf0c95"
	# CHAR : 󱋻
	md_map_marker_check_outline = "\uf12fb"
	# CHAR : 󰍏
	md_map_marker_circle = "\uf034f"
	# CHAR : 󰣰
	md_map_marker_distance = "\uf08f0"
	# CHAR : 󱄂
	md_map_marker_down = "\uf1102"
	# CHAR : 󱋛
	md_map_marker_left = "\uf12db"
	# CHAR : 󱋝
	md_map_marker_left_outline = "\uf12dd"
	# CHAR : 󰙐
	md_map_marker_minus = "\uf0650"
	# CHAR : 󱋹
	md_map_marker_minus_outline = "\uf12f9"
	# CHAR : 󰍐
	md_map_marker_multiple = "\uf0350"
	# CHAR : 󱉷
	md_map_marker_multiple_outline = "\uf1277"
	# CHAR : 󰍑
	md_map_marker_off = "\uf0351"
	# CHAR : 󱋽
	md_map_marker_off_outline = "\uf12fd"
	# CHAR : 󰟙
	md_map_marker_outline = "\uf07d9"
	# CHAR : 󰴠
	md_map_marker_path = "\uf0d20"
	# CHAR : 󰙑
	md_map_marker_plus = "\uf0651"
	# CHAR : 󱋸
	md_map_marker_plus_outline = "\uf12f8"
	# CHAR : 󰼇
	md_map_marker_question = "\uf0f07"
	# CHAR : 󰼈
	md_map_marker_question_outline = "\uf0f08"
	# CHAR : 󰍒
	md_map_marker_radius = "\uf0352"
	# CHAR : 󱋼
	md_map_marker_radius_outline = "\uf12fc"
	# CHAR : 󰼉
	md_map_marker_remove = "\uf0f09"
	# CHAR : 󱋺
	md_map_marker_remove_outline = "\uf12fa"
	# CHAR : 󰼊
	md_map_marker_remove_variant = "\uf0f0a"
	# CHAR : 󱋜
	md_map_marker_right = "\uf12dc"
	# CHAR : 󱋞
	md_map_marker_right_outline = "\uf12de"
	# CHAR : 󱘈
	md_map_marker_star = "\uf1608"
	# CHAR : 󱘉
	md_map_marker_star_outline = "\uf1609"
	# CHAR : 󱄃
	md_map_marker_up = "\uf1103"
	# CHAR : 󰦁
	md_map_minus = "\uf0981"
	# CHAR : 󰦂
	md_map_outline = "\uf0982"
	# CHAR : 󰦃
	md_map_plus = "\uf0983"
	# CHAR : 󰦄
	md_map_search = "\uf0984"
	# CHAR : 󰦅
	md_map_search_outline = "\uf0985"
	# CHAR : 󰮪
	md_mapbox = "\uf0baa"
	# CHAR : 󰍓
	md_margin = "\uf0353"
	# CHAR : 󰙒
	md_marker = "\uf0652"
	# CHAR : 󰷙
	md_marker_cancel = "\uf0dd9"
	# CHAR : 󰍕
	md_marker_check = "\uf0355"
	# CHAR : 󰫑
	md_mastodon = "\uf0ad1"
	# CHAR : 󰦆
	md_material_design = "\uf0986"
	# CHAR : 󰍗
	md_material_ui = "\uf0357"
	# CHAR : 󰍘
	md_math_compass = "\uf0358"
	# CHAR : 󰲖
	md_math_cos = "\uf0c96"
	# CHAR : 󰿈
	md_math_integral = "\uf0fc8"
	# CHAR : 󰿉
	md_math_integral_box = "\uf0fc9"
	# CHAR : 󱂅
	md_math_log = "\uf1085"
	# CHAR : 󰿊
	md_math_norm = "\uf0fca"
	# CHAR : 󰿋
	md_math_norm_box = "\uf0fcb"
	# CHAR : 󰲗
	md_math_sin = "\uf0c97"
	# CHAR : 󰲘
	md_math_tan = "\uf0c98"
	# CHAR : 󰘨
	md_matrix = "\uf0628"
	# CHAR : 󰦇
	md_medal = "\uf0987"
	# CHAR : 󱌦
	md_medal_outline = "\uf1326"
	# CHAR : 󰛯
	md_medical_bag = "\uf06ef"
	# CHAR : 󱪸
	md_medical_cotton_swab = "\uf1ab8"
	# CHAR : 󱅻
	md_meditation = "\uf117b"
	# CHAR : 󰍛
	md_memory = "\uf035b"
	# CHAR : 󱟔
	md_menorah = "\uf17d4"
	# CHAR : 󱟕
	md_menorah_fire = "\uf17d5"
	# CHAR : 󰍜
	md_menu = "\uf035c"
	# CHAR : 󰍝
	md_menu_down = "\uf035d"
	# CHAR : 󰚶
	md_menu_down_outline = "\uf06b6"
	# CHAR : 󰍞
	md_menu_left = "\uf035e"
	# CHAR : 󰨂
	md_menu_left_outline = "\uf0a02"
	# CHAR : 󰮫
	md_menu_open = "\uf0bab"
	# CHAR : 󰍟
	md_menu_right = "\uf035f"
	# CHAR : 󰨃
	md_menu_right_outline = "\uf0a03"
	# CHAR : 󰩤
	md_menu_swap = "\uf0a64"
	# CHAR : 󰩥
	md_menu_swap_outline = "\uf0a65"
	# CHAR : 󰍠
	md_menu_up = "\uf0360"
	# CHAR : 󰚷
	md_menu_up_outline = "\uf06b7"
	# CHAR : 󰽜
	md_merge = "\uf0f5c"
	# CHAR : 󰍡
	md_message = "\uf0361"
	# CHAR : 󰍢
	md_message_alert = "\uf0362"
	# CHAR : 󰨄
	md_message_alert_outline = "\uf0a04"
	# CHAR : 󱋲
	md_message_arrow_left = "\uf12f2"
	# CHAR : 󱋳
	md_message_arrow_left_outline = "\uf12f3"
	# CHAR : 󱋴
	md_message_arrow_right = "\uf12f4"
	# CHAR : 󱋵
	md_message_arrow_right_outline = "\uf12f5"
	# CHAR : 󱥁
	md_message_badge = "\uf1941"
	# CHAR : 󱥂
	md_message_badge_outline = "\uf1942"
	# CHAR : 󱖬
	md_message_bookmark = "\uf15ac"
	# CHAR : 󱖭
	md_message_bookmark_outline = "\uf15ad"
	# CHAR : 󰚢
	md_message_bulleted = "\uf06a2"
	# CHAR : 󰚣
	md_message_bulleted_off = "\uf06a3"
	# CHAR : 󰛱
	md_message_cog = "\uf06f1"
	# CHAR : 󱅲
	md_message_cog_outline = "\uf1172"
	# CHAR : 󰍣
	md_message_draw = "\uf0363"
	# CHAR : 󱧌
	md_message_fast = "\uf19cc"
	# CHAR : 󱧍
	md_message_fast_outline = "\uf19cd"
	# CHAR : 󱖩
	md_message_flash = "\uf15a9"
	# CHAR : 󱖪
	md_message_flash_outline = "\uf15aa"
	# CHAR : 󰍤
	md_message_image = "\uf0364"
	# CHAR : 󱅬
	md_message_image_outline = "\uf116c"
	# CHAR : 󰿌
	md_message_lock = "\uf0fcc"
	# CHAR : 󱅭
	md_message_lock_outline = "\uf116d"
	# CHAR : 󱅮
	md_message_minus = "\uf116e"
	# CHAR : 󱅯
	md_message_minus_outline = "\uf116f"
	# CHAR : 󱙍
	md_message_off = "\uf164d"
	# CHAR : 󱙎
	md_message_off_outline = "\uf164e"
	# CHAR : 󰍥
	md_message_outline = "\uf0365"
	# CHAR : 󰙓
	md_message_plus = "\uf0653"
	# CHAR : 󱂻
	md_message_plus_outline = "\uf10bb"
	# CHAR : 󰍦
	md_message_processing = "\uf0366"
	# CHAR : 󱅰
	md_message_processing_outline = "\uf1170"
	# CHAR : 󱜺
	md_message_question = "\uf173a"
	# CHAR : 󱜻
	md_message_question_outline = "\uf173b"
	# CHAR : 󰍧
	md_message_reply = "\uf0367"
	# CHAR : 󱜽
	md_message_reply_outline = "\uf173d"
	# CHAR : 󰍨
	md_message_reply_text = "\uf0368"
	# CHAR : 󱜾
	md_message_reply_text_outline = "\uf173e"
	# CHAR : 󰛰
	md_message_settings = "\uf06f0"
	# CHAR : 󱅱
	md_message_settings_outline = "\uf1171"
	# CHAR : 󰚚
	md_message_star = "\uf069a"
	# CHAR : 󱉐
	md_message_star_outline = "\uf1250"
	# CHAR : 󰍩
	md_message_text = "\uf0369"
	# CHAR : 󱅳
	md_message_text_clock = "\uf1173"
	# CHAR : 󱅴
	md_message_text_clock_outline = "\uf1174"
	# CHAR : 󱧎
	md_message_text_fast = "\uf19ce"
	# CHAR : 󱧏
	md_message_text_fast_outline = "\uf19cf"
	# CHAR : 󰿍
	md_message_text_lock = "\uf0fcd"
	# CHAR : 󱅵
	md_message_text_lock_outline = "\uf1175"
	# CHAR : 󰍪
	md_message_text_outline = "\uf036a"
	# CHAR : 󰍫
	md_message_video = "\uf036b"
	# CHAR : 󰘩
	md_meteor = "\uf0629"
	# CHAR : 󱩗
	md_meter_electric = "\uf1a57"
	# CHAR : 󱩘
	md_meter_electric_outline = "\uf1a58"
	# CHAR : 󱩙
	md_meter_gas = "\uf1a59"
	# CHAR : 󱩚
	md_meter_gas_outline = "\uf1a5a"
	# CHAR : 󰟚
	md_metronome = "\uf07da"
	# CHAR : 󰟛
	md_metronome_tick = "\uf07db"
	# CHAR : 󰟜
	md_micro_sd = "\uf07dc"
	# CHAR : 󰍬
	md_microphone = "\uf036c"
	# CHAR : 󰢳
	md_microphone_minus = "\uf08b3"
	# CHAR : 󰍭
	md_microphone_off = "\uf036d"
	# CHAR : 󰍮
	md_microphone_outline = "\uf036e"
	# CHAR : 󰢴
	md_microphone_plus = "\uf08b4"
	# CHAR : 󱦉
	md_microphone_question = "\uf1989"
	# CHAR : 󱦊
	md_microphone_question_outline = "\uf198a"
	# CHAR : 󰍯
	md_microphone_settings = "\uf036f"
	# CHAR : 󰍰
	md_microphone_variant = "\uf0370"
	# CHAR : 󰍱
	md_microphone_variant_off = "\uf0371"
	# CHAR : 󰙔
	md_microscope = "\uf0654"
	# CHAR : 󰍲
	md_microsoft = "\uf0372"
	# CHAR : 󱎎
	md_microsoft_access = "\uf138e"
	# CHAR : 󰠅
	md_microsoft_azure = "\uf0805"
	# CHAR : 󰿕
	md_microsoft_azure_devops = "\uf0fd5"
	# CHAR : 󰂤
	md_microsoft_bing = "\uf00a4"
	# CHAR : 󰦈
	md_microsoft_dynamics_365 = "\uf0988"
	# CHAR : 󰇩
	md_microsoft_edge = "\uf01e9"
	# CHAR : 󱎏
	md_microsoft_excel = "\uf138f"
	# CHAR : 󰌀
	md_microsoft_internet_explorer = "\uf0300"
	# CHAR : 󰏆
	md_microsoft_office = "\uf03c6"
	# CHAR : 󰏊
	md_microsoft_onedrive = "\uf03ca"
	# CHAR : 󰝇
	md_microsoft_onenote = "\uf0747"
	# CHAR : 󰴢
	md_microsoft_outlook = "\uf0d22"
	# CHAR : 󱎐
	md_microsoft_powerpoint = "\uf1390"
	# CHAR : 󱎑
	md_microsoft_sharepoint = "\uf1391"
	# CHAR : 󰊻
	md_microsoft_teams = "\uf02bb"
	# CHAR : 󰘐
	md_microsoft_visual_studio = "\uf0610"
	# CHAR : 󰨞
	md_microsoft_visual_studio_code = "\uf0a1e"
	# CHAR : 󰖳
	md_microsoft_windows = "\uf05b3"
	# CHAR : 󰨡
	md_microsoft_windows_classic = "\uf0a21"
	# CHAR : 󱎒
	md_microsoft_word = "\uf1392"
	# CHAR : 󰖹
	md_microsoft_xbox = "\uf05b9"
	# CHAR : 󰖺
	md_microsoft_xbox_controller = "\uf05ba"
	# CHAR : 󰝋
	md_microsoft_xbox_controller_battery_alert = "\uf074b"
	# CHAR : 󰨢
	md_microsoft_xbox_controller_battery_charging = "\uf0a22"
	# CHAR : 󰝌
	md_microsoft_xbox_controller_battery_empty = "\uf074c"
	# CHAR : 󰝍
	md_microsoft_xbox_controller_battery_full = "\uf074d"
	# CHAR : 󰝎
	md_microsoft_xbox_controller_battery_low = "\uf074e"
	# CHAR : 󰝏
	md_microsoft_xbox_controller_battery_medium = "\uf074f"
	# CHAR : 󰝐
	md_microsoft_xbox_controller_battery_unknown = "\uf0750"
	# CHAR : 󰹯
	md_microsoft_xbox_controller_menu = "\uf0e6f"
	# CHAR : 󰖻
	md_microsoft_xbox_controller_off = "\uf05bb"
	# CHAR : 󰹰
	md_microsoft_xbox_controller_view = "\uf0e70"
	# CHAR : 󰲙
	md_microwave = "\uf0c99"
	# CHAR : 󱐣
	md_microwave_off = "\uf1423"
	# CHAR : 󰽝
	md_middleware = "\uf0f5d"
	# CHAR : 󰽞
	md_middleware_outline = "\uf0f5e"
	# CHAR : 󰣱
	md_midi = "\uf08f1"
	# CHAR : 󰣲
	md_midi_port = "\uf08f2"
	# CHAR : 󰷚
	md_mine = "\uf0dda"
	# CHAR : 󰍳
	md_minecraft = "\uf0373"
	# CHAR : 󰨅
	md_mini_sd = "\uf0a05"
	# CHAR : 󰨆
	md_minidisc = "\uf0a06"
	# CHAR : 󰍴
	md_minus = "\uf0374"
	# CHAR : 󰍵
	md_minus_box = "\uf0375"
	# CHAR : 󱅁
	md_minus_box_multiple = "\uf1141"
	# CHAR : 󱅂
	md_minus_box_multiple_outline = "\uf1142"
	# CHAR : 󰛲
	md_minus_box_outline = "\uf06f2"
	# CHAR : 󰍶
	md_minus_circle = "\uf0376"
	# CHAR : 󰍚
	md_minus_circle_multiple = "\uf035a"
	# CHAR : 󰫓
	md_minus_circle_multiple_outline = "\uf0ad3"
	# CHAR : 󱑙
	md_minus_circle_off = "\uf1459"
	# CHAR : 󱑚
	md_minus_circle_off_outline = "\uf145a"
	# CHAR : 󰍷
	md_minus_circle_outline = "\uf0377"
	# CHAR : 󰍸
	md_minus_network = "\uf0378"
	# CHAR : 󰲚
	md_minus_network_outline = "\uf0c9a"
	# CHAR : 󱘹
	md_minus_thick = "\uf1639"
	# CHAR : 󱇽
	md_mirror = "\uf11fd"
	# CHAR : 󱞟
	md_mirror_rectangle = "\uf179f"
	# CHAR : 󱞠
	md_mirror_variant = "\uf17a0"
	# CHAR : 󰶏
	md_mixed_martial_arts = "\uf0d8f"
	# CHAR : 󰡿
	md_mixed_reality = "\uf087f"
	# CHAR : 󰮬
	md_molecule = "\uf0bac"
	# CHAR : 󱋾
	md_molecule_co = "\uf12fe"
	# CHAR : 󰟤
	md_molecule_co2 = "\uf07e4"
	# CHAR : 󰍹
	md_monitor = "\uf0379"
	# CHAR : 󱩛
	md_monitor_account = "\uf1a5b"
	# CHAR : 󱧐
	md_monitor_arrow_down = "\uf19d0"
	# CHAR : 󱧑
	md_monitor_arrow_down_variant = "\uf19d1"
	# CHAR : 󰦉
	md_monitor_cellphone = "\uf0989"
	# CHAR : 󰦊
	md_monitor_cellphone_star = "\uf098a"
	# CHAR : 󰨇
	md_monitor_dashboard = "\uf0a07"
	# CHAR : 󱋆
	md_monitor_edit = "\uf12c6"
	# CHAR : 󱎴
	md_monitor_eye = "\uf13b4"
	# CHAR : 󰷛
	md_monitor_lock = "\uf0ddb"
	# CHAR : 󰍺
	md_monitor_multiple = "\uf037a"
	# CHAR : 󰶐
	md_monitor_off = "\uf0d90"
	# CHAR : 󰹑
	md_monitor_screenshot = "\uf0e51"
	# CHAR : 󱒃
	md_monitor_share = "\uf1483"
	# CHAR : 󱄄
	md_monitor_shimmer = "\uf1104"
	# CHAR : 󱡶
	md_monitor_small = "\uf1876"
	# CHAR : 󰽟
	md_monitor_speaker = "\uf0f5f"
	# CHAR : 󰽠
	md_monitor_speaker_off = "\uf0f60"
	# CHAR : 󰷜
	md_monitor_star = "\uf0ddc"
	# CHAR : 󰽡
	md_moon_first_quarter = "\uf0f61"
	# CHAR : 󰽢
	md_moon_full = "\uf0f62"
	# CHAR : 󰽣
	md_moon_last_quarter = "\uf0f63"
	# CHAR : 󰽤
	md_moon_new = "\uf0f64"
	# CHAR : 󰽥
	md_moon_waning_crescent = "\uf0f65"
	# CHAR : 󰽦
	md_moon_waning_gibbous = "\uf0f66"
	# CHAR : 󰽧
	md_moon_waxing_crescent = "\uf0f67"
	# CHAR : 󰽨
	md_moon_waxing_gibbous = "\uf0f68"
	# CHAR : 󱂆
	md_moped = "\uf1086"
	# CHAR : 󱖷
	md_moped_electric = "\uf15b7"
	# CHAR : 󱖸
	md_moped_electric_outline = "\uf15b8"
	# CHAR : 󱖹
	md_moped_outline = "\uf15b9"
	# CHAR : 󰍻
	md_more = "\uf037b"
	# CHAR : 󱝈
	md_mortar_pestle = "\uf1748"
	# CHAR : 󰏱
	md_mortar_pestle_plus = "\uf03f1"
	# CHAR : 󱠧
	md_mosque = "\uf1827"
	# CHAR : 󱌔
	md_mother_heart = "\uf1314"
	# CHAR : 󰴡
	md_mother_nurse = "\uf0d21"
	# CHAR : 󱖲
	md_motion = "\uf15b2"
	# CHAR : 󱖳
	md_motion_outline = "\uf15b3"
	# CHAR : 󱖐
	md_motion_pause = "\uf1590"
	# CHAR : 󱖒
	md_motion_pause_outline = "\uf1592"
	# CHAR : 󱖏
	md_motion_play = "\uf158f"
	# CHAR : 󱖑
	md_motion_play_outline = "\uf1591"
	# CHAR : 󰶑
	md_motion_sensor = "\uf0d91"
	# CHAR : 󱐵
	md_motion_sensor_off = "\uf1435"
	# CHAR : 󰍼
	md_motorbike = "\uf037c"
	# CHAR : 󱖺
	md_motorbike_electric = "\uf15ba"
	# CHAR : 󰍽
	md_mouse = "\uf037d"
	# CHAR : 󰦋
	md_mouse_bluetooth = "\uf098b"
	# CHAR : 󱕐
	md_mouse_move_down = "\uf1550"
	# CHAR : 󱕑
	md_mouse_move_up = "\uf1551"
	# CHAR : 󱕒
	md_mouse_move_vertical = "\uf1552"
	# CHAR : 󰍾
	md_mouse_off = "\uf037e"
	# CHAR : 󰍿
	md_mouse_variant = "\uf037f"
	# CHAR : 󰎀
	md_mouse_variant_off = "\uf0380"
	# CHAR : 󰙕
	md_move_resize = "\uf0655"
	# CHAR : 󰙖
	md_move_resize_variant = "\uf0656"
	# CHAR : 󰎁
	md_movie = "\uf0381"
	# CHAR : 󱛳
	md_movie_check = "\uf16f3"
	# CHAR : 󱛴
	md_movie_check_outline = "\uf16f4"
	# CHAR : 󱛵
	md_movie_cog = "\uf16f5"
	# CHAR : 󱛶
	md_movie_cog_outline = "\uf16f6"
	# CHAR : 󱄢
	md_movie_edit = "\uf1122"
	# CHAR : 󱄣
	md_movie_edit_outline = "\uf1123"
	# CHAR : 󱄤
	md_movie_filter = "\uf1124"
	# CHAR : 󱄥
	md_movie_filter_outline = "\uf1125"
	# CHAR : 󱛷
	md_movie_minus = "\uf16f7"
	# CHAR : 󱛸
	md_movie_minus_outline = "\uf16f8"
	# CHAR : 󱛹
	md_movie_off = "\uf16f9"
	# CHAR : 󱛺
	md_movie_off_outline = "\uf16fa"
	# CHAR : 󰿎
	md_movie_open = "\uf0fce"
	# CHAR : 󱛻
	md_movie_open_check = "\uf16fb"
	# CHAR : 󱛼
	md_movie_open_check_outline = "\uf16fc"
	# CHAR : 󱛽
	md_movie_open_cog = "\uf16fd"
	# CHAR : 󱛾
	md_movie_open_cog_outline = "\uf16fe"
	# CHAR : 󱛿
	md_movie_open_edit = "\uf16ff"
	# CHAR : 󱜀
	md_movie_open_edit_outline = "\uf1700"
	# CHAR : 󱜁
	md_movie_open_minus = "\uf1701"
	# CHAR : 󱜂
	md_movie_open_minus_outline = "\uf1702"
	# CHAR : 󱜃
	md_movie_open_off = "\uf1703"
	# CHAR : 󱜄
	md_movie_open_off_outline = "\uf1704"
	# CHAR : 󰿏
	md_movie_open_outline = "\uf0fcf"
	# CHAR : 󱜅
	md_movie_open_play = "\uf1705"
	# CHAR : 󱜆
	md_movie_open_play_outline = "\uf1706"
	# CHAR : 󱜇
	md_movie_open_plus = "\uf1707"
	# CHAR : 󱜈
	md_movie_open_plus_outline = "\uf1708"
	# CHAR : 󱜉
	md_movie_open_remove = "\uf1709"
	# CHAR : 󱜊
	md_movie_open_remove_outline = "\uf170a"
	# CHAR : 󱜋
	md_movie_open_settings = "\uf170b"
	# CHAR : 󱜌
	md_movie_open_settings_outline = "\uf170c"
	# CHAR : 󱜍
	md_movie_open_star = "\uf170d"
	# CHAR : 󱜎
	md_movie_open_star_outline = "\uf170e"
	# CHAR : 󰷝
	md_movie_outline = "\uf0ddd"
	# CHAR : 󱜏
	md_movie_play = "\uf170f"
	# CHAR : 󱜐
	md_movie_play_outline = "\uf1710"
	# CHAR : 󱜑
	md_movie_plus = "\uf1711"
	# CHAR : 󱜒
	md_movie_plus_outline = "\uf1712"
	# CHAR : 󱜓
	md_movie_remove = "\uf1713"
	# CHAR : 󱜔
	md_movie_remove_outline = "\uf1714"
	# CHAR : 󰟞
	md_movie_roll = "\uf07de"
	# CHAR : 󱇒
	md_movie_search = "\uf11d2"
	# CHAR : 󱇓
	md_movie_search_outline = "\uf11d3"
	# CHAR : 󱜕
	md_movie_settings = "\uf1715"
	# CHAR : 󱜖
	md_movie_settings_outline = "\uf1716"
	# CHAR : 󱜗
	md_movie_star = "\uf1717"
	# CHAR : 󱜘
	md_movie_star_outline = "\uf1718"
	# CHAR : 󱙯
	md_mower = "\uf166f"
	# CHAR : 󱙰
	md_mower_bag = "\uf1670"
	# CHAR : 󰦌
	md_muffin = "\uf098c"
	# CHAR : 󱢓
	md_multicast = "\uf1893"
	# CHAR : 󰎂
	md_multiplication = "\uf0382"
	# CHAR : 󰎃
	md_multiplication_box = "\uf0383"
	# CHAR : 󰟟
	md_mushroom = "\uf07df"
	# CHAR : 󱏺
	md_mushroom_off = "\uf13fa"
	# CHAR : 󱏻
	md_mushroom_off_outline = "\uf13fb"
	# CHAR : 󰟠
	md_mushroom_outline = "\uf07e0"
	# CHAR : 󰝚
	md_music = "\uf075a"
	# CHAR : 󰽩
	md_music_accidental_double_flat = "\uf0f69"
	# CHAR : 󰽪
	md_music_accidental_double_sharp = "\uf0f6a"
	# CHAR : 󰽫
	md_music_accidental_flat = "\uf0f6b"
	# CHAR : 󰽬
	md_music_accidental_natural = "\uf0f6c"
	# CHAR : 󰽭
	md_music_accidental_sharp = "\uf0f6d"
	# CHAR : 󰎄
	md_music_box = "\uf0384"
	# CHAR : 󰌳
	md_music_box_multiple = "\uf0333"
	# CHAR : 󰼄
	md_music_box_multiple_outline = "\uf0f04"
	# CHAR : 󰎅
	md_music_box_outline = "\uf0385"
	# CHAR : 󰎆
	md_music_circle = "\uf0386"
	# CHAR : 󰫔
	md_music_circle_outline = "\uf0ad4"
	# CHAR : 󰽮
	md_music_clef_alto = "\uf0f6e"
	# CHAR : 󰽯
	md_music_clef_bass = "\uf0f6f"
	# CHAR : 󰽰
	md_music_clef_treble = "\uf0f70"
	# CHAR : 󰎇
	md_music_note = "\uf0387"
	# CHAR : 󰗾
	md_music_note_bluetooth = "\uf05fe"
	# CHAR : 󰗿
	md_music_note_bluetooth_off = "\uf05ff"
	# CHAR : 󰽱
	md_music_note_eighth_dotted = "\uf0f71"
	# CHAR : 󰎉
	md_music_note_half = "\uf0389"
	# CHAR : 󰽲
	md_music_note_half_dotted = "\uf0f72"
	# CHAR : 󰎊
	md_music_note_off = "\uf038a"
	# CHAR : 󰽳
	md_music_note_off_outline = "\uf0f73"
	# CHAR : 󰽴
	md_music_note_outline = "\uf0f74"
	# CHAR : 󰷞
	md_music_note_plus = "\uf0dde"
	# CHAR : 󰎋
	md_music_note_quarter = "\uf038b"
	# CHAR : 󰽵
	md_music_note_quarter_dotted = "\uf0f75"
	# CHAR : 󰎌
	md_music_note_sixteenth = "\uf038c"
	# CHAR : 󰽶
	md_music_note_sixteenth_dotted = "\uf0f76"
	# CHAR : 󰎍
	md_music_note_whole = "\uf038d"
	# CHAR : 󰽷
	md_music_note_whole_dotted = "\uf0f77"
	# CHAR : 󰝛
	md_music_off = "\uf075b"
	# CHAR : 󰽸
	md_music_rest_eighth = "\uf0f78"
	# CHAR : 󰽹
	md_music_rest_half = "\uf0f79"
	# CHAR : 󰽺
	md_music_rest_quarter = "\uf0f7a"
	# CHAR : 󰽻
	md_music_rest_sixteenth = "\uf0f7b"
	# CHAR : 󰽼
	md_music_rest_whole = "\uf0f7c"
	# CHAR : 󱗞
	md_mustache = "\uf15de"
	# CHAR : 󰷟
	md_nail = "\uf0ddf"
	# CHAR : 󰣳
	md_nas = "\uf08f3"
	# CHAR : 󰢀
	md_nativescript = "\uf0880"
	# CHAR : 󰎎
	md_nature = "\uf038e"
	# CHAR : 󰎏
	md_nature_people = "\uf038f"
	# CHAR : 󰎐
	md_navigation = "\uf0390"
	# CHAR : 󱘇
	md_navigation_outline = "\uf1607"
	# CHAR : 󱣱
	md_navigation_variant_outline = "\uf18f1"
	# CHAR : 󰗍
	md_near_me = "\uf05cd"
	# CHAR : 󰼋
	md_necklace = "\uf0f0b"
	# CHAR : 󰎑
	md_needle = "\uf0391"
	# CHAR : 󱧒
	md_needle_off = "\uf19d2"
	# CHAR : 󰝆
	md_netflix = "\uf0746"
	# CHAR : 󰛳
	md_network = "\uf06f3"
	# CHAR : 󰲛
	md_network_off = "\uf0c9b"
	# CHAR : 󰲜
	md_network_off_outline = "\uf0c9c"
	# CHAR : 󰲝
	md_network_outline = "\uf0c9d"
	# CHAR : 󱫋
	md_network_pos = "\uf1acb"
	# CHAR : 󰣴
	md_network_strength_1 = "\uf08f4"
	# CHAR : 󰣵
	md_network_strength_1_alert = "\uf08f5"
	# CHAR : 󰣶
	md_network_strength_2 = "\uf08f6"
	# CHAR : 󰣷
	md_network_strength_2_alert = "\uf08f7"
	# CHAR : 󰣸
	md_network_strength_3 = "\uf08f8"
	# CHAR : 󰣹
	md_network_strength_3_alert = "\uf08f9"
	# CHAR : 󰣺
	md_network_strength_4 = "\uf08fa"
	# CHAR : 󰣻
	md_network_strength_4_alert = "\uf08fb"
	# CHAR : 󱤚
	md_network_strength_4_cog = "\uf191a"
	# CHAR : 󰣼
	md_network_strength_off = "\uf08fc"
	# CHAR : 󰣽
	md_network_strength_off_outline = "\uf08fd"
	# CHAR : 󰣾
	md_network_strength_outline = "\uf08fe"
	# CHAR : 󰎔
	md_new_box = "\uf0394"
	# CHAR : 󰎕
	md_newspaper = "\uf0395"
	# CHAR : 󱥃
	md_newspaper_check = "\uf1943"
	# CHAR : 󰼌
	md_newspaper_minus = "\uf0f0c"
	# CHAR : 󰼍
	md_newspaper_plus = "\uf0f0d"
	# CHAR : 󱥄
	md_newspaper_remove = "\uf1944"
	# CHAR : 󱀁
	md_newspaper_variant = "\uf1001"
	# CHAR : 󱀂
	md_newspaper_variant_multiple = "\uf1002"
	# CHAR : 󱀃
	md_newspaper_variant_multiple_outline = "\uf1003"
	# CHAR : 󱀄
	md_newspaper_variant_outline = "\uf1004"
	# CHAR : 󰎖
	md_nfc = "\uf0396"
	# CHAR : 󰹓
	md_nfc_search_variant = "\uf0e53"
	# CHAR : 󰎗
	md_nfc_tap = "\uf0397"
	# CHAR : 󰎘
	md_nfc_variant = "\uf0398"
	# CHAR : 󰹔
	md_nfc_variant_off = "\uf0e54"
	# CHAR : 󰝴
	md_ninja = "\uf0774"
	# CHAR : 󱎓
	md_nintendo_game_boy = "\uf1393"
	# CHAR : 󰟡
	md_nintendo_switch = "\uf07e1"
	# CHAR : 󰖫
	md_nintendo_wii = "\uf05ab"
	# CHAR : 󰜭
	md_nintendo_wiiu = "\uf072d"
	# CHAR : 󱄅
	md_nix = "\uf1105"
	# CHAR : 󰎙
	md_nodejs = "\uf0399"
	# CHAR : 󱅾
	md_noodles = "\uf117e"
	# CHAR : 󰦍
	md_not_equal = "\uf098d"
	# CHAR : 󰦎
	md_not_equal_variant = "\uf098e"
	# CHAR : 󰎚
	md_note = "\uf039a"
	# CHAR : 󱝽
	md_note_alert = "\uf177d"
	# CHAR : 󱝾
	md_note_alert_outline = "\uf177e"
	# CHAR : 󱝿
	md_note_check = "\uf177f"
	# CHAR : 󱞀
	md_note_check_outline = "\uf1780"
	# CHAR : 󱞁
	md_note_edit = "\uf1781"
	# CHAR : 󱞂
	md_note_edit_outline = "\uf1782"
	# CHAR : 󱙏
	md_note_minus = "\uf164f"
	# CHAR : 󱙐
	md_note_minus_outline = "\uf1650"
	# CHAR : 󰚸
	md_note_multiple = "\uf06b8"
	# CHAR : 󰚹
	md_note_multiple_outline = "\uf06b9"
	# CHAR : 󱞃
	md_note_off = "\uf1783"
	# CHAR : 󱞄
	md_note_off_outline = "\uf1784"
	# CHAR : 󰎛
	md_note_outline = "\uf039b"
	# CHAR : 󰎜
	md_note_plus = "\uf039c"
	# CHAR : 󰎝
	md_note_plus_outline = "\uf039d"
	# CHAR : 󱙑
	md_note_remove = "\uf1651"
	# CHAR : 󱙒
	md_note_remove_outline = "\uf1652"
	# CHAR : 󱙓
	md_note_search = "\uf1653"
	# CHAR : 󱙔
	md_note_search_outline = "\uf1654"
	# CHAR : 󰎞
	md_note_text = "\uf039e"
	# CHAR : 󱇗
	md_note_text_outline = "\uf11d7"
	# CHAR : 󰠮
	md_notebook = "\uf082e"
	# CHAR : 󱓵
	md_notebook_check = "\uf14f5"
	# CHAR : 󱓶
	md_notebook_check_outline = "\uf14f6"
	# CHAR : 󱓧
	md_notebook_edit = "\uf14e7"
	# CHAR : 󱓩
	md_notebook_edit_outline = "\uf14e9"
	# CHAR : 󱨋
	md_notebook_heart = "\uf1a0b"
	# CHAR : 󱨌
	md_notebook_heart_outline = "\uf1a0c"
	# CHAR : 󱘐
	md_notebook_minus = "\uf1610"
	# CHAR : 󱘑
	md_notebook_minus_outline = "\uf1611"
	# CHAR : 󰹕
	md_notebook_multiple = "\uf0e55"
	# CHAR : 󰺿
	md_notebook_outline = "\uf0ebf"
	# CHAR : 󱘒
	md_notebook_plus = "\uf1612"
	# CHAR : 󱘓
	md_notebook_plus_outline = "\uf1613"
	# CHAR : 󱘔
	md_notebook_remove = "\uf1614"
	# CHAR : 󱘕
	md_notebook_remove_outline = "\uf1615"
	# CHAR : 󰎟
	md_notification_clear_all = "\uf039f"
	# CHAR : 󰛷
	md_npm = "\uf06f7"
	# CHAR : 󰚤
	md_nuke = "\uf06a4"
	# CHAR : 󰟢
	md_null = "\uf07e2"
	# CHAR : 󰎠
	md_numeric = "\uf03a0"
	# CHAR : 󰎡
	md_numeric_0_box = "\uf03a1"
	# CHAR : 󰼎
	md_numeric_0_box_multiple = "\uf0f0e"
	# CHAR : 󰎢
	md_numeric_0_box_multiple_outline = "\uf03a2"
	# CHAR : 󰎣
	md_numeric_0_box_outline = "\uf03a3"
	# CHAR : 󰬺
	md_numeric_1 = "\uf0b3a"
	# CHAR : 󰿩
	md_numeric_10 = "\uf0fe9"
	# CHAR : 󰽽
	md_numeric_10_box = "\uf0f7d"
	# CHAR : 󰿪
	md_numeric_10_box_multiple = "\uf0fea"
	# CHAR : 󰿫
	md_numeric_10_box_multiple_outline = "\uf0feb"
	# CHAR : 󰽾
	md_numeric_10_box_outline = "\uf0f7e"
	# CHAR : 󰿬
	md_numeric_10_circle = "\uf0fec"
	# CHAR : 󰿭
	md_numeric_10_circle_outline = "\uf0fed"
	# CHAR : 󰎤
	md_numeric_1_box = "\uf03a4"
	# CHAR : 󰼏
	md_numeric_1_box_multiple = "\uf0f0f"
	# CHAR : 󰎥
	md_numeric_1_box_multiple_outline = "\uf03a5"
	# CHAR : 󰎦
	md_numeric_1_box_outline = "\uf03a6"
	# CHAR : 󰲠
	md_numeric_1_circle = "\uf0ca0"
	# CHAR : 󰲡
	md_numeric_1_circle_outline = "\uf0ca1"
	# CHAR : 󰬻
	md_numeric_2 = "\uf0b3b"
	# CHAR : 󰎧
	md_numeric_2_box = "\uf03a7"
	# CHAR : 󰼐
	md_numeric_2_box_multiple = "\uf0f10"
	# CHAR : 󰎨
	md_numeric_2_box_multiple_outline = "\uf03a8"
	# CHAR : 󰎩
	md_numeric_2_box_outline = "\uf03a9"
	# CHAR : 󰲢
	md_numeric_2_circle = "\uf0ca2"
	# CHAR : 󰲣
	md_numeric_2_circle_outline = "\uf0ca3"
	# CHAR : 󰬼
	md_numeric_3 = "\uf0b3c"
	# CHAR : 󰎪
	md_numeric_3_box = "\uf03aa"
	# CHAR : 󰼑
	md_numeric_3_box_multiple = "\uf0f11"
	# CHAR : 󰎫
	md_numeric_3_box_multiple_outline = "\uf03ab"
	# CHAR : 󰎬
	md_numeric_3_box_outline = "\uf03ac"
	# CHAR : 󰲤
	md_numeric_3_circle = "\uf0ca4"
	# CHAR : 󰲥
	md_numeric_3_circle_outline = "\uf0ca5"
	# CHAR : 󰬽
	md_numeric_4 = "\uf0b3d"
	# CHAR : 󰎭
	md_numeric_4_box = "\uf03ad"
	# CHAR : 󰼒
	md_numeric_4_box_multiple = "\uf0f12"
	# CHAR : 󰎲
	md_numeric_4_box_multiple_outline = "\uf03b2"
	# CHAR : 󰎮
	md_numeric_4_box_outline = "\uf03ae"
	# CHAR : 󰲦
	md_numeric_4_circle = "\uf0ca6"
	# CHAR : 󰲧
	md_numeric_4_circle_outline = "\uf0ca7"
	# CHAR : 󰬾
	md_numeric_5 = "\uf0b3e"
	# CHAR : 󰎱
	md_numeric_5_box = "\uf03b1"
	# CHAR : 󰼓
	md_numeric_5_box_multiple = "\uf0f13"
	# CHAR : 󰎯
	md_numeric_5_box_multiple_outline = "\uf03af"
	# CHAR : 󰎰
	md_numeric_5_box_outline = "\uf03b0"
	# CHAR : 󰲨
	md_numeric_5_circle = "\uf0ca8"
	# CHAR : 󰲩
	md_numeric_5_circle_outline = "\uf0ca9"
	# CHAR : 󰬿
	md_numeric_6 = "\uf0b3f"
	# CHAR : 󰎳
	md_numeric_6_box = "\uf03b3"
	# CHAR : 󰼔
	md_numeric_6_box_multiple = "\uf0f14"
	# CHAR : 󰎴
	md_numeric_6_box_multiple_outline = "\uf03b4"
	# CHAR : 󰎵
	md_numeric_6_box_outline = "\uf03b5"
	# CHAR : 󰲪
	md_numeric_6_circle = "\uf0caa"
	# CHAR : 󰲫
	md_numeric_6_circle_outline = "\uf0cab"
	# CHAR : 󰭀
	md_numeric_7 = "\uf0b40"
	# CHAR : 󰎶
	md_numeric_7_box = "\uf03b6"
	# CHAR : 󰼕
	md_numeric_7_box_multiple = "\uf0f15"
	# CHAR : 󰎷
	md_numeric_7_box_multiple_outline = "\uf03b7"
	# CHAR : 󰎸
	md_numeric_7_box_outline = "\uf03b8"
	# CHAR : 󰲬
	md_numeric_7_circle = "\uf0cac"
	# CHAR : 󰲭
	md_numeric_7_circle_outline = "\uf0cad"
	# CHAR : 󰭁
	md_numeric_8 = "\uf0b41"
	# CHAR : 󰎹
	md_numeric_8_box = "\uf03b9"
	# CHAR : 󰼖
	md_numeric_8_box_multiple = "\uf0f16"
	# CHAR : 󰎺
	md_numeric_8_box_multiple_outline = "\uf03ba"
	# CHAR : 󰎻
	md_numeric_8_box_outline = "\uf03bb"
	# CHAR : 󰲮
	md_numeric_8_circle = "\uf0cae"
	# CHAR : 󰲯
	md_numeric_8_circle_outline = "\uf0caf"
	# CHAR : 󰭂
	md_numeric_9 = "\uf0b42"
	# CHAR : 󰎼
	md_numeric_9_box = "\uf03bc"
	# CHAR : 󰼗
	md_numeric_9_box_multiple = "\uf0f17"
	# CHAR : 󰎽
	md_numeric_9_box_multiple_outline = "\uf03bd"
	# CHAR : 󰎾
	md_numeric_9_box_outline = "\uf03be"
	# CHAR : 󰲰
	md_numeric_9_circle = "\uf0cb0"
	# CHAR : 󰲱
	md_numeric_9_circle_outline = "\uf0cb1"
	# CHAR : 󰿮
	md_numeric_9_plus = "\uf0fee"
	# CHAR : 󰎿
	md_numeric_9_plus_box = "\uf03bf"
	# CHAR : 󰼘
	md_numeric_9_plus_box_multiple = "\uf0f18"
	# CHAR : 󰏀
	md_numeric_9_plus_box_multiple_outline = "\uf03c0"
	# CHAR : 󰏁
	md_numeric_9_plus_box_outline = "\uf03c1"
	# CHAR : 󰲲
	md_numeric_9_plus_circle = "\uf0cb2"
	# CHAR : 󰲳
	md_numeric_9_plus_circle_outline = "\uf0cb3"
	# CHAR : 󱁒
	md_numeric_negative_1 = "\uf1052"
	# CHAR : 󱧓
	md_numeric_off = "\uf19d3"
	# CHAR : 󱗋
	md_numeric_positive_1 = "\uf15cb"
	# CHAR : 󰛸
	md_nut = "\uf06f8"
	# CHAR : 󰏂
	md_nutrition = "\uf03c2"
	# CHAR : 󱄆
	md_nuxt = "\uf1106"
	# CHAR : 󰙼
	md_oar = "\uf067c"
	# CHAR : 󰷠
	md_ocarina = "\uf0de0"
	# CHAR : 󱋩
	md_oci = "\uf12e9"
	# CHAR : 󱄺
	md_ocr = "\uf113a"
	# CHAR : 󰏃
	md_octagon = "\uf03c3"
	# CHAR : 󰏄
	md_octagon_outline = "\uf03c4"
	# CHAR : 󰛹
	md_octagram = "\uf06f9"
	# CHAR : 󰝵
	md_octagram_outline = "\uf0775"
	# CHAR : 󱥐
	md_octahedron = "\uf1950"
	# CHAR : 󱥑
	md_octahedron_off = "\uf1951"
	# CHAR : 󰏅
	md_odnoklassniki = "\uf03c5"
	# CHAR : 󱈛
	md_offer = "\uf121b"
	# CHAR : 󰦑
	md_office_building = "\uf0991"
	# CHAR : 󱥉
	md_office_building_cog = "\uf1949"
	# CHAR : 󱥊
	md_office_building_cog_outline = "\uf194a"
	# CHAR : 󱔠
	md_office_building_marker = "\uf1520"
	# CHAR : 󱔡
	md_office_building_marker_outline = "\uf1521"
	# CHAR : 󱔟
	md_office_building_outline = "\uf151f"
	# CHAR : 󰏇
	md_oil = "\uf03c7"
	# CHAR : 󰼙
	md_oil_lamp = "\uf0f19"
	# CHAR : 󱁓
	md_oil_level = "\uf1053"
	# CHAR : 󰿸
	md_oil_temperature = "\uf0ff8"
	# CHAR : 󰥳
	md_om = "\uf0973"
	# CHAR : 󰏉
	md_omega = "\uf03c9"
	# CHAR : 󰮭
	md_one_up = "\uf0bad"
	# CHAR : 󰢁
	md_onepassword = "\uf0881"
	# CHAR : 󰗌
	md_opacity = "\uf05cc"
	# CHAR : 󰏋
	md_open_in_app = "\uf03cb"
	# CHAR : 󰏌
	md_open_in_new = "\uf03cc"
	# CHAR : 󰮮
	md_open_source_initiative = "\uf0bae"
	# CHAR : 󰏍
	md_openid = "\uf03cd"
	# CHAR : 󰏎
	md_opera = "\uf03ce"
	# CHAR : 󰀘
	md_orbit = "\uf0018"
	# CHAR : 󱗛
	md_orbit_variant = "\uf15db"
	# CHAR : 󰈍
	md_order_alphabetical_ascending = "\uf020d"
	# CHAR : 󰴇
	md_order_alphabetical_descending = "\uf0d07"
	# CHAR : 󰊾
	md_order_bool_ascending = "\uf02be"
	# CHAR : 󰦏
	md_order_bool_ascending_variant = "\uf098f"
	# CHAR : 󱎄
	md_order_bool_descending = "\uf1384"
	# CHAR : 󰦐
	md_order_bool_descending_variant = "\uf0990"
	# CHAR : 󰕅
	md_order_numeric_ascending = "\uf0545"
	# CHAR : 󰕆
	md_order_numeric_descending = "\uf0546"
	# CHAR : 󰭃
	md_origin = "\uf0b43"
	# CHAR : 󰏏
	md_ornament = "\uf03cf"
	# CHAR : 󰏐
	md_ornament_variant = "\uf03d0"
	# CHAR : 󱁔
	md_outdoor_lamp = "\uf1054"
	# CHAR : 󱀅
	md_overscan = "\uf1005"
	# CHAR : 󰏒
	md_owl = "\uf03d2"
	# CHAR : 󰮯
	md_pac_man = "\uf0baf"
	# CHAR : 󰏓
	md_package = "\uf03d3"
	# CHAR : 󰏔
	md_package_down = "\uf03d4"
	# CHAR : 󰏕
	md_package_up = "\uf03d5"
	# CHAR : 󰏖
	md_package_variant = "\uf03d6"
	# CHAR : 󰏗
	md_package_variant_closed = "\uf03d7"
	# CHAR : 󱧔
	md_package_variant_closed_minus = "\uf19d4"
	# CHAR : 󱧕
	md_package_variant_closed_plus = "\uf19d5"
	# CHAR : 󱧖
	md_package_variant_closed_remove = "\uf19d6"
	# CHAR : 󱧗
	md_package_variant_minus = "\uf19d7"
	# CHAR : 󱧘
	md_package_variant_plus = "\uf19d8"
	# CHAR : 󱧙
	md_package_variant_remove = "\uf19d9"
	# CHAR : 󰘀
	md_page_first = "\uf0600"
	# CHAR : 󰘁
	md_page_last = "\uf0601"
	# CHAR : 󰛺
	md_page_layout_body = "\uf06fa"
	# CHAR : 󰛻
	md_page_layout_footer = "\uf06fb"
	# CHAR : 󰛼
	md_page_layout_header = "\uf06fc"
	# CHAR : 󰽿
	md_page_layout_header_footer = "\uf0f7f"
	# CHAR : 󰛽
	md_page_layout_sidebar_left = "\uf06fd"
	# CHAR : 󰛾
	md_page_layout_sidebar_right = "\uf06fe"
	# CHAR : 󰮰
	md_page_next = "\uf0bb0"
	# CHAR : 󰮱
	md_page_next_outline = "\uf0bb1"
	# CHAR : 󰮲
	md_page_previous = "\uf0bb2"
	# CHAR : 󰮳
	md_page_previous_outline = "\uf0bb3"
	# CHAR : 󱐗
	md_pail = "\uf1417"
	# CHAR : 󱐷
	md_pail_minus = "\uf1437"
	# CHAR : 󱐼
	md_pail_minus_outline = "\uf143c"
	# CHAR : 󱐹
	md_pail_off = "\uf1439"
	# CHAR : 󱐾
	md_pail_off_outline = "\uf143e"
	# CHAR : 󱐺
	md_pail_outline = "\uf143a"
	# CHAR : 󱐶
	md_pail_plus = "\uf1436"
	# CHAR : 󱐻
	md_pail_plus_outline = "\uf143b"
	# CHAR : 󱐸
	md_pail_remove = "\uf1438"
	# CHAR : 󱐽
	md_pail_remove_outline = "\uf143d"
	# CHAR : 󰏘
	md_palette = "\uf03d8"
	# CHAR : 󰏙
	md_palette_advanced = "\uf03d9"
	# CHAR : 󰸌
	md_palette_outline = "\uf0e0c"
	# CHAR : 󰢵
	md_palette_swatch = "\uf08b5"
	# CHAR : 󱍜
	md_palette_swatch_outline = "\uf135c"
	# CHAR : 󱥚
	md_palette_swatch_variant = "\uf195a"
	# CHAR : 󱁕
	md_palm_tree = "\uf1055"
	# CHAR : 󰮴
	md_pan = "\uf0bb4"
	# CHAR : 󰮵
	md_pan_bottom_left = "\uf0bb5"
	# CHAR : 󰮶
	md_pan_bottom_right = "\uf0bb6"
	# CHAR : 󰮷
	md_pan_down = "\uf0bb7"
	# CHAR : 󰮸
	md_pan_horizontal = "\uf0bb8"
	# CHAR : 󰮹
	md_pan_left = "\uf0bb9"
	# CHAR : 󰮺
	md_pan_right = "\uf0bba"
	# CHAR : 󰮻
	md_pan_top_left = "\uf0bbb"
	# CHAR : 󰮼
	md_pan_top_right = "\uf0bbc"
	# CHAR : 󰮽
	md_pan_up = "\uf0bbd"
	# CHAR : 󰮾
	md_pan_vertical = "\uf0bbe"
	# CHAR : 󰏚
	md_panda = "\uf03da"
	# CHAR : 󰏛
	md_pandora = "\uf03db"
	# CHAR : 󰏜
	md_panorama = "\uf03dc"
	# CHAR : 󰏝
	md_panorama_fisheye = "\uf03dd"
	# CHAR : 󱤨
	md_panorama_horizontal = "\uf1928"
	# CHAR : 󰏞
	md_panorama_horizontal_outline = "\uf03de"
	# CHAR : 󱦌
	md_panorama_outline = "\uf198c"
	# CHAR : 󱦍
	md_panorama_sphere = "\uf198d"
	# CHAR : 󱦎
	md_panorama_sphere_outline = "\uf198e"
	# CHAR : 󱦏
	md_panorama_variant = "\uf198f"
	# CHAR : 󱦐
	md_panorama_variant_outline = "\uf1990"
	# CHAR : 󱤩
	md_panorama_vertical = "\uf1929"
	# CHAR : 󰏟
	md_panorama_vertical_outline = "\uf03df"
	# CHAR : 󱥟
	md_panorama_wide_angle = "\uf195f"
	# CHAR : 󰏠
	md_panorama_wide_angle_outline = "\uf03e0"
	# CHAR : 󰏡
	md_paper_cut_vertical = "\uf03e1"
	# CHAR : 󱅗
	md_paper_roll = "\uf1157"
	# CHAR : 󱅘
	md_paper_roll_outline = "\uf1158"
	# CHAR : 󰏢
	md_paperclip = "\uf03e2"
	# CHAR : 󱫆
	md_paperclip_check = "\uf1ac6"
	# CHAR : 󱧚
	md_paperclip_lock = "\uf19da"
	# CHAR : 󱫇
	md_paperclip_minus = "\uf1ac7"
	# CHAR : 󱫈
	md_paperclip_off = "\uf1ac8"
	# CHAR : 󱫉
	md_paperclip_plus = "\uf1ac9"
	# CHAR : 󱫊
	md_paperclip_remove = "\uf1aca"
	# CHAR : 󰲴
	md_parachute = "\uf0cb4"
	# CHAR : 󰲵
	md_parachute_outline = "\uf0cb5"
	# CHAR : 󱝅
	md_paragliding = "\uf1745"
	# CHAR : 󰏣
	md_parking = "\uf03e3"
	# CHAR : 󱁖
	md_party_popper = "\uf1056"
	# CHAR : 󰟣
	md_passport = "\uf07e3"
	# CHAR : 󰷡
	md_passport_biometric = "\uf0de1"
	# CHAR : 󱅠
	md_pasta = "\uf1160"
	# CHAR : 󰾀
	md_patio_heater = "\uf0f80"
	# CHAR : 󰢂
	md_patreon = "\uf0882"
	# CHAR : 󰏤
	md_pause = "\uf03e4"
	# CHAR : 󰏥
	md_pause_circle = "\uf03e5"
	# CHAR : 󰏦
	md_pause_circle_outline = "\uf03e6"
	# CHAR : 󰏧
	md_pause_octagon = "\uf03e7"
	# CHAR : 󰏨
	md_pause_octagon_outline = "\uf03e8"
	# CHAR : 󰏩
	md_paw = "\uf03e9"
	# CHAR : 󰙗
	md_paw_off = "\uf0657"
	# CHAR : 󱙶
	md_paw_off_outline = "\uf1676"
	# CHAR : 󱙵
	md_paw_outline = "\uf1675"
	# CHAR : 󰢄
	md_peace = "\uf0884"
	# CHAR : 󰿼
	md_peanut = "\uf0ffc"
	# CHAR : 󰿽
	md_peanut_off = "\uf0ffd"
	# CHAR : 󰿿
	md_peanut_off_outline = "\uf0fff"
	# CHAR : 󰿾
	md_peanut_outline = "\uf0ffe"
	# CHAR : 󰏪
	md_pen = "\uf03ea"
	# CHAR : 󰷢
	md_pen_lock = "\uf0de2"
	# CHAR : 󰷣
	md_pen_minus = "\uf0de3"
	# CHAR : 󰷤
	md_pen_off = "\uf0de4"
	# CHAR : 󰷥
	md_pen_plus = "\uf0de5"
	# CHAR : 󰷦
	md_pen_remove = "\uf0de6"
	# CHAR : 󰏫
	md_pencil = "\uf03eb"
	# CHAR : 󰏬
	md_pencil_box = "\uf03ec"
	# CHAR : 󱅄
	md_pencil_box_multiple = "\uf1144"
	# CHAR : 󱅅
	md_pencil_box_multiple_outline = "\uf1145"
	# CHAR : 󰏭
	md_pencil_box_outline = "\uf03ed"
	# CHAR : 󰛿
	md_pencil_circle = "\uf06ff"
	# CHAR : 󰝶
	md_pencil_circle_outline = "\uf0776"
	# CHAR : 󰏮
	md_pencil_lock = "\uf03ee"
	# CHAR : 󰷧
	md_pencil_lock_outline = "\uf0de7"
	# CHAR : 󰷨
	md_pencil_minus = "\uf0de8"
	# CHAR : 󰷩
	md_pencil_minus_outline = "\uf0de9"
	# CHAR : 󰏯
	md_pencil_off = "\uf03ef"
	# CHAR : 󰷪
	md_pencil_off_outline = "\uf0dea"
	# CHAR : 󰲶
	md_pencil_outline = "\uf0cb6"
	# CHAR : 󰷫
	md_pencil_plus = "\uf0deb"
	# CHAR : 󰷬
	md_pencil_plus_outline = "\uf0dec"
	# CHAR : 󰷭
	md_pencil_remove = "\uf0ded"
	# CHAR : 󰷮
	md_pencil_remove_outline = "\uf0dee"
	# CHAR : 󱍓
	md_pencil_ruler = "\uf1353"
	# CHAR : 󰻀
	md_penguin = "\uf0ec0"
	# CHAR : 󰜁
	md_pentagon = "\uf0701"
	# CHAR : 󰜀
	md_pentagon_outline = "\uf0700"
	# CHAR : 󱙧
	md_pentagram = "\uf1667"
	# CHAR : 󰏰
	md_percent = "\uf03f0"
	# CHAR : 󱨂
	md_percent_box = "\uf1a02"
	# CHAR : 󱨃
	md_percent_box_outline = "\uf1a03"
	# CHAR : 󱨄
	md_percent_circle = "\uf1a04"
	# CHAR : 󱨅
	md_percent_circle_outline = "\uf1a05"
	# CHAR : 󱉸
	md_percent_outline = "\uf1278"
	# CHAR : 󰢶
	md_periodic_table = "\uf08b6"
	# CHAR : 󰴣
	md_perspective_less = "\uf0d23"
	# CHAR : 󰴤
	md_perspective_more = "\uf0d24"
	# CHAR : 󱟅
	md_ph = "\uf17c5"
	# CHAR : 󰏲
	md_phone = "\uf03f2"
	# CHAR : 󰼚
	md_phone_alert = "\uf0f1a"
	# CHAR : 󱆎
	md_phone_alert_outline = "\uf118e"
	# CHAR : 󰏳
	md_phone_bluetooth = "\uf03f3"
	# CHAR : 󱆏
	md_phone_bluetooth_outline = "\uf118f"
	# CHAR : 󱂼
	md_phone_cancel = "\uf10bc"
	# CHAR : 󱆐
	md_phone_cancel_outline = "\uf1190"
	# CHAR : 󱆩
	md_phone_check = "\uf11a9"
	# CHAR : 󱆪
	md_phone_check_outline = "\uf11aa"
	# CHAR : 󰘂
	md_phone_classic = "\uf0602"
	# CHAR : 󱉹
	md_phone_classic_off = "\uf1279"
	# CHAR : 󱧛
	md_phone_clock = "\uf19db"
	# CHAR : 󱕙
	md_phone_dial = "\uf1559"
	# CHAR : 󱕚
	md_phone_dial_outline = "\uf155a"
	# CHAR : 󰏴
	md_phone_forward = "\uf03f4"
	# CHAR : 󱆑
	md_phone_forward_outline = "\uf1191"
	# CHAR : 󰏵
	md_phone_hangup = "\uf03f5"
	# CHAR : 󱆒
	md_phone_hangup_outline = "\uf1192"
	# CHAR : 󰏶
	md_phone_in_talk = "\uf03f6"
	# CHAR : 󱆂
	md_phone_in_talk_outline = "\uf1182"
	# CHAR : 󰏷
	md_phone_incoming = "\uf03f7"
	# CHAR : 󱆓
	md_phone_incoming_outline = "\uf1193"
	# CHAR : 󰏸
	md_phone_lock = "\uf03f8"
	# CHAR : 󱆔
	md_phone_lock_outline = "\uf1194"
	# CHAR : 󰏹
	md_phone_log = "\uf03f9"
	# CHAR : 󱆕
	md_phone_log_outline = "\uf1195"
	# CHAR : 󱆖
	md_phone_message = "\uf1196"
	# CHAR : 󱆗
	md_phone_message_outline = "\uf1197"
	# CHAR : 󰙘
	md_phone_minus = "\uf0658"
	# CHAR : 󱆘
	md_phone_minus_outline = "\uf1198"
	# CHAR : 󰏺
	md_phone_missed = "\uf03fa"
	# CHAR : 󱆥
	md_phone_missed_outline = "\uf11a5"
	# CHAR : 󰷯
	md_phone_off = "\uf0def"
	# CHAR : 󱆦
	md_phone_off_outline = "\uf11a6"
	# CHAR : 󰏻
	md_phone_outgoing = "\uf03fb"
	# CHAR : 󱆙
	md_phone_outgoing_outline = "\uf1199"
	# CHAR : 󰷰
	md_phone_outline = "\uf0df0"
	# CHAR : 󰏼
	md_phone_paused = "\uf03fc"
	# CHAR : 󱆚
	md_phone_paused_outline = "\uf119a"
	# CHAR : 󰙙
	md_phone_plus = "\uf0659"
	# CHAR : 󱆛
	md_phone_plus_outline = "\uf119b"
	# CHAR : 󱦓
	md_phone_refresh = "\uf1993"
	# CHAR : 󱦔
	md_phone_refresh_outline = "\uf1994"
	# CHAR : 󱔯
	md_phone_remove = "\uf152f"
	# CHAR : 󱔰
	md_phone_remove_outline = "\uf1530"
	# CHAR : 󰠯
	md_phone_return = "\uf082f"
	# CHAR : 󱆜
	md_phone_return_outline = "\uf119c"
	# CHAR : 󱆫
	md_phone_ring = "\uf11ab"
	# CHAR : 󱆬
	md_phone_ring_outline = "\uf11ac"
	# CHAR : 󰢅
	md_phone_rotate_landscape = "\uf0885"
	# CHAR : 󰢆
	md_phone_rotate_portrait = "\uf0886"
	# CHAR : 󰏽
	md_phone_settings = "\uf03fd"
	# CHAR : 󱆝
	md_phone_settings_outline = "\uf119d"
	# CHAR : 󱦕
	md_phone_sync = "\uf1995"
	# CHAR : 󱦖
	md_phone_sync_outline = "\uf1996"
	# CHAR : 󰏾
	md_phone_voip = "\uf03fe"
	# CHAR : 󰏿
	md_pi = "\uf03ff"
	# CHAR : 󰐀
	md_pi_box = "\uf0400"
	# CHAR : 󰷱
	md_pi_hole = "\uf0df1"
	# CHAR : 󰙽
	md_piano = "\uf067d"
	# CHAR : 󰚘
	md_piano_off = "\uf0698"
	# CHAR : 󰢷
	md_pickaxe = "\uf08b7"
	# CHAR : 󰹗
	md_picture_in_picture_bottom_right = "\uf0e57"
	# CHAR : 󰹘
	md_picture_in_picture_bottom_right_outline = "\uf0e58"
	# CHAR : 󰹙
	md_picture_in_picture_top_right = "\uf0e59"
	# CHAR : 󰹚
	md_picture_in_picture_top_right_outline = "\uf0e5a"
	# CHAR : 󰢇
	md_pier = "\uf0887"
	# CHAR : 󰢈
	md_pier_crane = "\uf0888"
	# CHAR : 󰐁
	md_pig = "\uf0401"
	# CHAR : 󱀆
	md_pig_variant = "\uf1006"
	# CHAR : 󱙸
	md_pig_variant_outline = "\uf1678"
	# CHAR : 󱀇
	md_piggy_bank = "\uf1007"
	# CHAR : 󱙹
	md_piggy_bank_outline = "\uf1679"
	# CHAR : 󰐂
	md_pill = "\uf0402"
	# CHAR : 󱩜
	md_pill_off = "\uf1a5c"
	# CHAR : 󰜂
	md_pillar = "\uf0702"
	# CHAR : 󰐃
	md_pin = "\uf0403"
	# CHAR : 󰐄
	md_pin_off = "\uf0404"
	# CHAR : 󰤰
	md_pin_off_outline = "\uf0930"
	# CHAR : 󰤱
	md_pin_outline = "\uf0931"
	# CHAR : 󰐅
	md_pine_tree = "\uf0405"
	# CHAR : 󰐆
	md_pine_tree_box = "\uf0406"
	# CHAR : 󱐚
	md_pine_tree_fire = "\uf141a"
	# CHAR : 󰐇
	md_pinterest = "\uf0407"
	# CHAR : 󰫕
	md_pinwheel = "\uf0ad5"
	# CHAR : 󰫖
	md_pinwheel_outline = "\uf0ad6"
	# CHAR : 󰟥
	md_pipe = "\uf07e5"
	# CHAR : 󰟦
	md_pipe_disconnected = "\uf07e6"
	# CHAR : 󰢉
	md_pipe_leak = "\uf0889"
	# CHAR : 󱡍
	md_pipe_valve = "\uf184d"
	# CHAR : 󱍔
	md_pipe_wrench = "\uf1354"
	# CHAR : 󰨈
	md_pirate = "\uf0a08"
	# CHAR : 󰜃
	md_pistol = "\uf0703"
	# CHAR : 󰢊
	md_piston = "\uf088a"
	# CHAR : 󱕓
	md_pitchfork = "\uf1553"
	# CHAR : 󰐉
	md_pizza = "\uf0409"
	# CHAR : 󰐊
	md_play = "\uf040a"
	# CHAR : 󱉺
	md_play_box = "\uf127a"
	# CHAR : 󱨖
	md_play_box_lock = "\uf1a16"
	# CHAR : 󱨗
	md_play_box_lock_open = "\uf1a17"
	# CHAR : 󱨘
	md_play_box_lock_open_outline = "\uf1a18"
	# CHAR : 󱨙
	md_play_box_lock_outline = "\uf1a19"
	# CHAR : 󰴙
	md_play_box_multiple = "\uf0d19"
	# CHAR : 󱏦
	md_play_box_multiple_outline = "\uf13e6"
	# CHAR : 󰐋
	md_play_box_outline = "\uf040b"
	# CHAR : 󰐌
	md_play_circle = "\uf040c"
	# CHAR : 󰐍
	md_play_circle_outline = "\uf040d"
	# CHAR : 󰢋
	md_play_network = "\uf088b"
	# CHAR : 󰲷
	md_play_network_outline = "\uf0cb7"
	# CHAR : 󰼛
	md_play_outline = "\uf0f1b"
	# CHAR : 󰐎
	md_play_pause = "\uf040e"
	# CHAR : 󰐏
	md_play_protected_content = "\uf040f"
	# CHAR : 󰣿
	md_play_speed = "\uf08ff"
	# CHAR : 󰗇
	md_playlist_check = "\uf05c7"
	# CHAR : 󰤀
	md_playlist_edit = "\uf0900"
	# CHAR : 󰐐
	md_playlist_minus = "\uf0410"
	# CHAR : 󰲸
	md_playlist_music = "\uf0cb8"
	# CHAR : 󰲹
	md_playlist_music_outline = "\uf0cb9"
	# CHAR : 󰐑
	md_playlist_play = "\uf0411"
	# CHAR : 󰐒
	md_playlist_plus = "\uf0412"
	# CHAR : 󰐓
	md_playlist_remove = "\uf0413"
	# CHAR : 󰷲
	md_playlist_star = "\uf0df2"
	# CHAR : 󰚺
	md_plex = "\uf06ba"
	# CHAR : 󱦤
	md_pliers = "\uf19a4"
	# CHAR : 󰐕
	md_plus = "\uf0415"
	# CHAR : 󰐖
	md_plus_box = "\uf0416"
	# CHAR : 󰌴
	md_plus_box_multiple = "\uf0334"
	# CHAR : 󱅃
	md_plus_box_multiple_outline = "\uf1143"
	# CHAR : 󰜄
	md_plus_box_outline = "\uf0704"
	# CHAR : 󰐗
	md_plus_circle = "\uf0417"
	# CHAR : 󰍌
	md_plus_circle_multiple = "\uf034c"
	# CHAR : 󰐘
	md_plus_circle_multiple_outline = "\uf0418"
	# CHAR : 󰐙
	md_plus_circle_outline = "\uf0419"
	# CHAR : 󱩝
	md_plus_lock = "\uf1a5d"
	# CHAR : 󱩞
	md_plus_lock_open = "\uf1a5e"
	# CHAR : 󰦒
	md_plus_minus = "\uf0992"
	# CHAR : 󰦓
	md_plus_minus_box = "\uf0993"
	# CHAR : 󱓉
	md_plus_minus_variant = "\uf14c9"
	# CHAR : 󰐚
	md_plus_network = "\uf041a"
	# CHAR : 󰲺
	md_plus_network_outline = "\uf0cba"
	# CHAR : 󰜅
	md_plus_outline = "\uf0705"
	# CHAR : 󱇬
	md_plus_thick = "\uf11ec"
	# CHAR : 󰦔
	md_podcast = "\uf0994"
	# CHAR : 󰴥
	md_podium = "\uf0d25"
	# CHAR : 󰴦
	md_podium_bronze = "\uf0d26"
	# CHAR : 󰴧
	md_podium_gold = "\uf0d27"
	# CHAR : 󰴨
	md_podium_silver = "\uf0d28"
	# CHAR : 󰶒
	md_point_of_sale = "\uf0d92"
	# CHAR : 󰐝
	md_pokeball = "\uf041d"
	# CHAR : 󰨉
	md_pokemon_go = "\uf0a09"
	# CHAR : 󰠰
	md_poker_chip = "\uf0830"
	# CHAR : 󰐞
	md_polaroid = "\uf041e"
	# CHAR : 󱅧
	md_police_badge = "\uf1167"
	# CHAR : 󱅨
	md_police_badge_outline = "\uf1168"
	# CHAR : 󱠹
	md_police_station = "\uf1839"
	# CHAR : 󰐟
	md_poll = "\uf041f"
	# CHAR : 󱓃
	md_polo = "\uf14c3"
	# CHAR : 󰐡
	md_polymer = "\uf0421"
	# CHAR : 󰘆
	md_pool = "\uf0606"
	# CHAR : 󱩟
	md_pool_thermometer = "\uf1a5f"
	# CHAR : 󰐢
	md_popcorn = "\uf0422"
	# CHAR : 󱀈
	md_post = "\uf1008"
	# CHAR : 󱩠
	md_post_lamp = "\uf1a60"
	# CHAR : 󱀉
	md_post_outline = "\uf1009"
	# CHAR : 󰲻
	md_postage_stamp = "\uf0cbb"
	# CHAR : 󰋥
	md_pot = "\uf02e5"
	# CHAR : 󰙛
	md_pot_mix = "\uf065b"
	# CHAR : 󰙷
	md_pot_mix_outline = "\uf0677"
	# CHAR : 󰋿
	md_pot_outline = "\uf02ff"
	# CHAR : 󰙚
	md_pot_steam = "\uf065a"
	# CHAR : 󰌦
	md_pot_steam_outline = "\uf0326"
	# CHAR : 󰐣
	md_pound = "\uf0423"
	# CHAR : 󰐤
	md_pound_box = "\uf0424"
	# CHAR : 󱅿
	md_pound_box_outline = "\uf117f"
	# CHAR : 󰐥
	md_power = "\uf0425"
	# CHAR : 󰤁
	md_power_cycle = "\uf0901"
	# CHAR : 󰤂
	md_power_off = "\uf0902"
	# CHAR : 󰤃
	md_power_on = "\uf0903"
	# CHAR : 󰚥
	md_power_plug = "\uf06a5"
	# CHAR : 󰚦
	md_power_plug_off = "\uf06a6"
	# CHAR : 󱐤
	md_power_plug_off_outline = "\uf1424"
	# CHAR : 󱐥
	md_power_plug_outline = "\uf1425"
	# CHAR : 󰐦
	md_power_settings = "\uf0426"
	# CHAR : 󰤄
	md_power_sleep = "\uf0904"
	# CHAR : 󰐧
	md_power_socket = "\uf0427"
	# CHAR : 󰤅
	md_power_socket_au = "\uf0905"
	# CHAR : 󰾳
	md_power_socket_ch = "\uf0fb3"
	# CHAR : 󱄇
	md_power_socket_de = "\uf1107"
	# CHAR : 󰟧
	md_power_socket_eu = "\uf07e7"
	# CHAR : 󱄈
	md_power_socket_fr = "\uf1108"
	# CHAR : 󱓿
	md_power_socket_it = "\uf14ff"
	# CHAR : 󱄉
	md_power_socket_jp = "\uf1109"
	# CHAR : 󰟨
	md_power_socket_uk = "\uf07e8"
	# CHAR : 󰟩
	md_power_socket_us = "\uf07e9"
	# CHAR : 󰤆
	md_power_standby = "\uf0906"
	# CHAR : 󰨊
	md_powershell = "\uf0a0a"
	# CHAR : 󰜆
	md_prescription = "\uf0706"
	# CHAR : 󰐨
	md_presentation = "\uf0428"
	# CHAR : 󰐩
	md_presentation_play = "\uf0429"
	# CHAR : 󱕢
	md_pretzel = "\uf1562"
	# CHAR : 󰐪
	md_printer = "\uf042a"
	# CHAR : 󰐫
	md_printer_3d = "\uf042b"
	# CHAR : 󰹛
	md_printer_3d_nozzle = "\uf0e5b"
	# CHAR : 󱇀
	md_printer_3d_nozzle_alert = "\uf11c0"
	# CHAR : 󱇁
	md_printer_3d_nozzle_alert_outline = "\uf11c1"
	# CHAR : 󱢸
	md_printer_3d_nozzle_heat = "\uf18b8"
	# CHAR : 󱢹
	md_printer_3d_nozzle_heat_outline = "\uf18b9"
	# CHAR : 󰹜
	md_printer_3d_nozzle_outline = "\uf0e5c"
	# CHAR : 󰐬
	md_printer_alert = "\uf042c"
	# CHAR : 󱅆
	md_printer_check = "\uf1146"
	# CHAR : 󱑘
	md_printer_eye = "\uf1458"
	# CHAR : 󰹝
	md_printer_off = "\uf0e5d"
	# CHAR : 󱞅
	md_printer_off_outline = "\uf1785"
	# CHAR : 󱞆
	md_printer_outline = "\uf1786"
	# CHAR : 󱁗
	md_printer_pos = "\uf1057"
	# CHAR : 󱑗
	md_printer_search = "\uf1457"
	# CHAR : 󰜇
	md_printer_settings = "\uf0707"
	# CHAR : 󰨋
	md_printer_wireless = "\uf0a0b"
	# CHAR : 󰘃
	md_priority_high = "\uf0603"
	# CHAR : 󰘄
	md_priority_low = "\uf0604"
	# CHAR : 󰐭
	md_professional_hexagon = "\uf042d"
	# CHAR : 󰲼
	md_progress_alert = "\uf0cbc"
	# CHAR : 󰦕
	md_progress_check = "\uf0995"
	# CHAR : 󰦖
	md_progress_clock = "\uf0996"
	# CHAR : 󱄊
	md_progress_close = "\uf110a"
	# CHAR : 󰦗
	md_progress_download = "\uf0997"
	# CHAR : 󱞇
	md_progress_pencil = "\uf1787"
	# CHAR : 󱔢
	md_progress_question = "\uf1522"
	# CHAR : 󱞈
	md_progress_star = "\uf1788"
	# CHAR : 󰦘
	md_progress_upload = "\uf0998"
	# CHAR : 󰲽
	md_progress_wrench = "\uf0cbd"
	# CHAR : 󰐮
	md_projector = "\uf042e"
	# CHAR : 󱨣
	md_projector_off = "\uf1a23"
	# CHAR : 󰐯
	md_projector_screen = "\uf042f"
	# CHAR : 󱠍
	md_projector_screen_off = "\uf180d"
	# CHAR : 󱠎
	md_projector_screen_off_outline = "\uf180e"
	# CHAR : 󱜤
	md_projector_screen_outline = "\uf1724"
	# CHAR : 󱠏
	md_projector_screen_variant = "\uf180f"
	# CHAR : 󱠐
	md_projector_screen_variant_off = "\uf1810"
	# CHAR : 󱠑
	md_projector_screen_variant_off_outline = "\uf1811"
	# CHAR : 󱠒
	md_projector_screen_variant_outline = "\uf1812"
	# CHAR : 󱍗
	md_propane_tank = "\uf1357"
	# CHAR : 󱍘
	md_propane_tank_outline = "\uf1358"
	# CHAR : 󰿘
	md_protocol = "\uf0fd8"
	# CHAR : 󰚧
	md_publish = "\uf06a7"
	# CHAR : 󱥅
	md_publish_off = "\uf1945"
	# CHAR : 󰐰
	md_pulse = "\uf0430"
	# CHAR : 󱐂
	md_pump = "\uf1402"
	# CHAR : 󰮿
	md_pumpkin = "\uf0bbf"
	# CHAR : 󰼜
	md_purse = "\uf0f1c"
	# CHAR : 󰼝
	md_purse_outline = "\uf0f1d"
	# CHAR : 󰐱
	md_puzzle = "\uf0431"
	# CHAR : 󱐦
	md_puzzle_check = "\uf1426"
	# CHAR : 󱐧
	md_puzzle_check_outline = "\uf1427"
	# CHAR : 󱓓
	md_puzzle_edit = "\uf14d3"
	# CHAR : 󱓙
	md_puzzle_edit_outline = "\uf14d9"
	# CHAR : 󱓔
	md_puzzle_heart = "\uf14d4"
	# CHAR : 󱓚
	md_puzzle_heart_outline = "\uf14da"
	# CHAR : 󱓑
	md_puzzle_minus = "\uf14d1"
	# CHAR : 󱓗
	md_puzzle_minus_outline = "\uf14d7"
	# CHAR : 󰩦
	md_puzzle_outline = "\uf0a66"
	# CHAR : 󱓐
	md_puzzle_plus = "\uf14d0"
	# CHAR : 󱓖
	md_puzzle_plus_outline = "\uf14d6"
	# CHAR : 󱓒
	md_puzzle_remove = "\uf14d2"
	# CHAR : 󱓘
	md_puzzle_remove_outline = "\uf14d8"
	# CHAR : 󱓕
	md_puzzle_star = "\uf14d5"
	# CHAR : 󱓛
	md_puzzle_star_outline = "\uf14db"
	# CHAR : 󱥒
	md_pyramid = "\uf1952"
	# CHAR : 󱥓
	md_pyramid_off = "\uf1953"
	# CHAR : 󰦙
	md_qi = "\uf0999"
	# CHAR : 󰘅
	md_qqchat = "\uf0605"
	# CHAR : 󰐲
	md_qrcode = "\uf0432"
	# CHAR : 󰢸
	md_qrcode_edit = "\uf08b8"
	# CHAR : 󱆌
	md_qrcode_minus = "\uf118c"
	# CHAR : 󱆋
	md_qrcode_plus = "\uf118b"
	# CHAR : 󱆍
	md_qrcode_remove = "\uf118d"
	# CHAR : 󰐳
	md_qrcode_scan = "\uf0433"
	# CHAR : 󰐴
	md_quadcopter = "\uf0434"
	# CHAR : 󰐵
	md_quality_high = "\uf0435"
	# CHAR : 󰨌
	md_quality_low = "\uf0a0c"
	# CHAR : 󰨍
	md_quality_medium = "\uf0a0d"
	# CHAR : 󰴩
	md_quora = "\uf0d29"
	# CHAR : 󰤇
	md_rabbit = "\uf0907"
	# CHAR : 󱩡
	md_rabbit_variant = "\uf1a61"
	# CHAR : 󱩢
	md_rabbit_variant_outline = "\uf1a62"
	# CHAR : 󰶓
	md_racing_helmet = "\uf0d93"
	# CHAR : 󰶔
	md_racquetball = "\uf0d94"
	# CHAR : 󰐷
	md_radar = "\uf0437"
	# CHAR : 󰐸
	md_radiator = "\uf0438"
	# CHAR : 󰫗
	md_radiator_disabled = "\uf0ad7"
	# CHAR : 󰫘
	md_radiator_off = "\uf0ad8"
	# CHAR : 󰐹
	md_radio = "\uf0439"
	# CHAR : 󰲾
	md_radio_am = "\uf0cbe"
	# CHAR : 󰲿
	md_radio_fm = "\uf0cbf"
	# CHAR : 󰐺
	md_radio_handheld = "\uf043a"
	# CHAR : 󱈜
	md_radio_off = "\uf121c"
	# CHAR : 󰐻
	md_radio_tower = "\uf043b"
	# CHAR : 󰐼
	md_radioactive = "\uf043c"
	# CHAR : 󱡝
	md_radioactive_circle = "\uf185d"
	# CHAR : 󱡞
	md_radioactive_circle_outline = "\uf185e"
	# CHAR : 󰻁
	md_radioactive_off = "\uf0ec1"
	# CHAR : 󰐾
	md_radiobox_marked = "\uf043e"
	# CHAR : 󱓅
	md_radiology_box = "\uf14c5"
	# CHAR : 󱓆
	md_radiology_box_outline = "\uf14c6"
	# CHAR : 󰳀
	md_radius = "\uf0cc0"
	# CHAR : 󰳁
	md_radius_outline = "\uf0cc1"
	# CHAR : 󰼞
	md_railroad_light = "\uf0f1e"
	# CHAR : 󱕄
	md_rake = "\uf1544"
	# CHAR : 󰐿
	md_raspberry_pi = "\uf043f"
	# CHAR : 󱨏
	md_raw = "\uf1a0f"
	# CHAR : 󱨐
	md_raw_off = "\uf1a10"
	# CHAR : 󰑀
	md_ray_end = "\uf0440"
	# CHAR : 󰑁
	md_ray_end_arrow = "\uf0441"
	# CHAR : 󰑂
	md_ray_start = "\uf0442"
	# CHAR : 󰑃
	md_ray_start_arrow = "\uf0443"
	# CHAR : 󰑄
	md_ray_start_end = "\uf0444"
	# CHAR : 󱗘
	md_ray_start_vertex_end = "\uf15d8"
	# CHAR : 󰑅
	md_ray_vertex = "\uf0445"
	# CHAR : 󱦗
	md_razor_double_edge = "\uf1997"
	# CHAR : 󱦘
	md_razor_single_edge = "\uf1998"
	# CHAR : 󰜈
	md_react = "\uf0708"
	# CHAR : 󰑇
	md_read = "\uf0447"
	# CHAR : 󰑉
	md_receipt = "\uf0449"
	# CHAR : 󱧜
	md_receipt_outline = "\uf19dc"
	# CHAR : 󱩣
	md_receipt_text_check = "\uf1a63"
	# CHAR : 󱩤
	md_receipt_text_check_outline = "\uf1a64"
	# CHAR : 󱩥
	md_receipt_text_minus = "\uf1a65"
	# CHAR : 󱩦
	md_receipt_text_minus_outline = "\uf1a66"
	# CHAR : 󱩧
	md_receipt_text_plus = "\uf1a67"
	# CHAR : 󱩨
	md_receipt_text_plus_outline = "\uf1a68"
	# CHAR : 󱩩
	md_receipt_text_remove = "\uf1a69"
	# CHAR : 󱩪
	md_receipt_text_remove_outline = "\uf1a6a"
	# CHAR : 󰑊
	md_record = "\uf044a"
	# CHAR : 󰻂
	md_record_circle = "\uf0ec2"
	# CHAR : 󰻃
	md_record_circle_outline = "\uf0ec3"
	# CHAR : 󰦚
	md_record_player = "\uf099a"
	# CHAR : 󰑋
	md_record_rec = "\uf044b"
	# CHAR : 󰹞
	md_rectangle = "\uf0e5e"
	# CHAR : 󰹟
	md_rectangle_outline = "\uf0e5f"
	# CHAR : 󰑌
	md_recycle = "\uf044c"
	# CHAR : 󱎝
	md_recycle_variant = "\uf139d"
	# CHAR : 󰑍
	md_reddit = "\uf044d"
	# CHAR : 󱄛
	md_redhat = "\uf111b"
	# CHAR : 󰑎
	md_redo = "\uf044e"
	# CHAR : 󰑏
	md_redo_variant = "\uf044f"
	# CHAR : 󰨎
	md_reflect_horizontal = "\uf0a0e"
	# CHAR : 󰨏
	md_reflect_vertical = "\uf0a0f"
	# CHAR : 󰑐
	md_refresh = "\uf0450"
	# CHAR : 󱣲
	md_refresh_auto = "\uf18f2"
	# CHAR : 󱍷
	md_refresh_circle = "\uf1377"
	# CHAR : 󰑑
	md_regex = "\uf0451"
	# CHAR : 󰩧
	md_registered_trademark = "\uf0a67"
	# CHAR : 󱖈
	md_reiterate = "\uf1588"
	# CHAR : 󱒖
	md_relation_many_to_many = "\uf1496"
	# CHAR : 󱒗
	md_relation_many_to_one = "\uf1497"
	# CHAR : 󱒘
	md_relation_many_to_one_or_many = "\uf1498"
	# CHAR : 󱒙
	md_relation_many_to_only_one = "\uf1499"
	# CHAR : 󱒚
	md_relation_many_to_zero_or_many = "\uf149a"
	# CHAR : 󱒛
	md_relation_many_to_zero_or_one = "\uf149b"
	# CHAR : 󱒜
	md_relation_one_or_many_to_many = "\uf149c"
	# CHAR : 󱒝
	md_relation_one_or_many_to_one = "\uf149d"
	# CHAR : 󱒞
	md_relation_one_or_many_to_one_or_many = "\uf149e"
	# CHAR : 󱒟
	md_relation_one_or_many_to_only_one = "\uf149f"
	# CHAR : 󱒠
	md_relation_one_or_many_to_zero_or_many = "\uf14a0"
	# CHAR : 󱒡
	md_relation_one_or_many_to_zero_or_one = "\uf14a1"
	# CHAR : 󱒢
	md_relation_one_to_many = "\uf14a2"
	# CHAR : 󱒣
	md_relation_one_to_one = "\uf14a3"
	# CHAR : 󱒤
	md_relation_one_to_one_or_many = "\uf14a4"
	# CHAR : 󱒥
	md_relation_one_to_only_one = "\uf14a5"
	# CHAR : 󱒦
	md_relation_one_to_zero_or_many = "\uf14a6"
	# CHAR : 󱒧
	md_relation_one_to_zero_or_one = "\uf14a7"
	# CHAR : 󱒨
	md_relation_only_one_to_many = "\uf14a8"
	# CHAR : 󱒩
	md_relation_only_one_to_one = "\uf14a9"
	# CHAR : 󱒪
	md_relation_only_one_to_one_or_many = "\uf14aa"
	# CHAR : 󱒫
	md_relation_only_one_to_only_one = "\uf14ab"
	# CHAR : 󱒬
	md_relation_only_one_to_zero_or_many = "\uf14ac"
	# CHAR : 󱒭
	md_relation_only_one_to_zero_or_one = "\uf14ad"
	# CHAR : 󱒮
	md_relation_zero_or_many_to_many = "\uf14ae"
	# CHAR : 󱒯
	md_relation_zero_or_many_to_one = "\uf14af"
	# CHAR : 󱒰
	md_relation_zero_or_many_to_one_or_many = "\uf14b0"
	# CHAR : 󱒱
	md_relation_zero_or_many_to_only_one = "\uf14b1"
	# CHAR : 󱒲
	md_relation_zero_or_many_to_zero_or_many = "\uf14b2"
	# CHAR : 󱒳
	md_relation_zero_or_many_to_zero_or_one = "\uf14b3"
	# CHAR : 󱒴
	md_relation_zero_or_one_to_many = "\uf14b4"
	# CHAR : 󱒵
	md_relation_zero_or_one_to_one = "\uf14b5"
	# CHAR : 󱒶
	md_relation_zero_or_one_to_one_or_many = "\uf14b6"
	# CHAR : 󱒷
	md_relation_zero_or_one_to_only_one = "\uf14b7"
	# CHAR : 󱒸
	md_relation_zero_or_one_to_zero_or_many = "\uf14b8"
	# CHAR : 󱒹
	md_relation_zero_or_one_to_zero_or_one = "\uf14b9"
	# CHAR : 󰑒
	md_relative_scale = "\uf0452"
	# CHAR : 󰑓
	md_reload = "\uf0453"
	# CHAR : 󱄋
	md_reload_alert = "\uf110b"
	# CHAR : 󰢌
	md_reminder = "\uf088c"
	# CHAR : 󰑔
	md_remote = "\uf0454"
	# CHAR : 󰢹
	md_remote_desktop = "\uf08b9"
	# CHAR : 󰻄
	md_remote_off = "\uf0ec4"
	# CHAR : 󰻅
	md_remote_tv = "\uf0ec5"
	# CHAR : 󰻆
	md_remote_tv_off = "\uf0ec6"
	# CHAR : 󰑕
	md_rename_box = "\uf0455"
	# CHAR : 󰚈
	md_reorder_horizontal = "\uf0688"
	# CHAR : 󰚉
	md_reorder_vertical = "\uf0689"
	# CHAR : 󰑖
	md_repeat = "\uf0456"
	# CHAR : 󰑗
	md_repeat_off = "\uf0457"
	# CHAR : 󰑘
	md_repeat_once = "\uf0458"
	# CHAR : 󰕇
	md_repeat_variant = "\uf0547"
	# CHAR : 󰑙
	md_replay = "\uf0459"
	# CHAR : 󰑚
	md_reply = "\uf045a"
	# CHAR : 󰑛
	md_reply_all = "\uf045b"
	# CHAR : 󰼟
	md_reply_all_outline = "\uf0f1f"
	# CHAR : 󱆮
	md_reply_circle = "\uf11ae"
	# CHAR : 󰼠
	md_reply_outline = "\uf0f20"
	# CHAR : 󰑜
	md_reproduction = "\uf045c"
	# CHAR : 󰭄
	md_resistor = "\uf0b44"
	# CHAR : 󰭅
	md_resistor_nodes = "\uf0b45"
	# CHAR : 󰩨
	md_resize = "\uf0a68"
	# CHAR : 󰑝
	md_resize_bottom_right = "\uf045d"
	# CHAR : 󰑞
	md_responsive = "\uf045e"
	# CHAR : 󰜉
	md_restart = "\uf0709"
	# CHAR : 󱄌
	md_restart_alert = "\uf110c"
	# CHAR : 󰶕
	md_restart_off = "\uf0d95"
	# CHAR : 󰦛
	md_restore = "\uf099b"
	# CHAR : 󱄍
	md_restore_alert = "\uf110d"
	# CHAR : 󰑟
	md_rewind = "\uf045f"
	# CHAR : 󰴪
	md_rewind_10 = "\uf0d2a"
	# CHAR : 󱥆
	md_rewind_15 = "\uf1946"
	# CHAR : 󰶖
	md_rewind_30 = "\uf0d96"
	# CHAR : 󱇹
	md_rewind_5 = "\uf11f9"
	# CHAR : 󱘌
	md_rewind_60 = "\uf160c"
	# CHAR : 󰜊
	md_rewind_outline = "\uf070a"
	# CHAR : 󰜋
	md_rhombus = "\uf070b"
	# CHAR : 󰨐
	md_rhombus_medium = "\uf0a10"
	# CHAR : 󱓜
	md_rhombus_medium_outline = "\uf14dc"
	# CHAR : 󰜌
	md_rhombus_outline = "\uf070c"
	# CHAR : 󰨑
	md_rhombus_split = "\uf0a11"
	# CHAR : 󱓝
	md_rhombus_split_outline = "\uf14dd"
	# CHAR : 󰑠
	md_ribbon = "\uf0460"
	# CHAR : 󰟪
	md_rice = "\uf07ea"
	# CHAR : 󱖻
	md_rickshaw = "\uf15bb"
	# CHAR : 󱖼
	md_rickshaw_electric = "\uf15bc"
	# CHAR : 󰟫
	md_ring = "\uf07eb"
	# CHAR : 󰹠
	md_rivet = "\uf0e60"
	# CHAR : 󰑡
	md_road = "\uf0461"
	# CHAR : 󰑢
	md_road_variant = "\uf0462"
	# CHAR : 󱁘
	md_robber = "\uf1058"
	# CHAR : 󰚩
	md_robot = "\uf06a9"
	# CHAR : 󱚝
	md_robot_angry = "\uf169d"
	# CHAR : 󱚞
	md_robot_angry_outline = "\uf169e"
	# CHAR : 󱚟
	md_robot_confused = "\uf169f"
	# CHAR : 󱚠
	md_robot_confused_outline = "\uf16a0"
	# CHAR : 󱚡
	md_robot_dead = "\uf16a1"
	# CHAR : 󱚢
	md_robot_dead_outline = "\uf16a2"
	# CHAR : 󱚣
	md_robot_excited = "\uf16a3"
	# CHAR : 󱚤
	md_robot_excited_outline = "\uf16a4"
	# CHAR : 󱜙
	md_robot_happy = "\uf1719"
	# CHAR : 󱜚
	md_robot_happy_outline = "\uf171a"
	# CHAR : 󰭆
	md_robot_industrial = "\uf0b46"
	# CHAR : 󱨚
	md_robot_industrial_outline = "\uf1a1a"
	# CHAR : 󱚥
	md_robot_love = "\uf16a5"
	# CHAR : 󱚦
	md_robot_love_outline = "\uf16a6"
	# CHAR : 󱇷
	md_robot_mower = "\uf11f7"
	# CHAR : 󱇳
	md_robot_mower_outline = "\uf11f3"
	# CHAR : 󱚧
	md_robot_off = "\uf16a7"
	# CHAR : 󱙻
	md_robot_off_outline = "\uf167b"
	# CHAR : 󱙺
	md_robot_outline = "\uf167a"
	# CHAR : 󰜍
	md_robot_vacuum = "\uf070d"
	# CHAR : 󰤈
	md_robot_vacuum_variant = "\uf0908"
	# CHAR : 󰑣
	md_rocket = "\uf0463"
	# CHAR : 󱓞
	md_rocket_launch = "\uf14de"
	# CHAR : 󱓟
	md_rocket_launch_outline = "\uf14df"
	# CHAR : 󱎯
	md_rocket_outline = "\uf13af"
	# CHAR : 󱌧
	md_rodent = "\uf1327"
	# CHAR : 󱩫
	md_roller_shade = "\uf1a6b"
	# CHAR : 󱩬
	md_roller_shade_closed = "\uf1a6c"
	# CHAR : 󰴫
	md_roller_skate = "\uf0d2b"
	# CHAR : 󰅅
	md_roller_skate_off = "\uf0145"
	# CHAR : 󰴬
	md_rollerblade = "\uf0d2c"
	# CHAR : 󰀮
	md_rollerblade_off = "\uf002e"
	# CHAR : 󰯀
	md_rollupjs = "\uf0bc0"
	# CHAR : 󱪹
	md_rolodex = "\uf1ab9"
	# CHAR : 󱪺
	md_rolodex_outline = "\uf1aba"
	# CHAR : 󱂉
	md_roman_numeral_2 = "\uf1089"
	# CHAR : 󱂊
	md_roman_numeral_3 = "\uf108a"
	# CHAR : 󱂋
	md_roman_numeral_4 = "\uf108b"
	# CHAR : 󱂍
	md_roman_numeral_6 = "\uf108d"
	# CHAR : 󱂎
	md_roman_numeral_7 = "\uf108e"
	# CHAR : 󱂏
	md_roman_numeral_8 = "\uf108f"
	# CHAR : 󱂐
	md_roman_numeral_9 = "\uf1090"
	# CHAR : 󰢍
	md_room_service = "\uf088d"
	# CHAR : 󰶗
	md_room_service_outline = "\uf0d97"
	# CHAR : 󱦙
	md_rotate_360 = "\uf1999"
	# CHAR : 󰻇
	md_rotate_3d = "\uf0ec7"
	# CHAR : 󰑤
	md_rotate_3d_variant = "\uf0464"
	# CHAR : 󰑥
	md_rotate_left = "\uf0465"
	# CHAR : 󰑦
	md_rotate_left_variant = "\uf0466"
	# CHAR : 󰶘
	md_rotate_orbit = "\uf0d98"
	# CHAR : 󰑧
	md_rotate_right = "\uf0467"
	# CHAR : 󰑨
	md_rotate_right_variant = "\uf0468"
	# CHAR : 󰘇
	md_rounded_corner = "\uf0607"
	# CHAR : 󱇢
	md_router = "\uf11e2"
	# CHAR : 󱂇
	md_router_network = "\uf1087"
	# CHAR : 󰑩
	md_router_wireless = "\uf0469"
	# CHAR : 󱖣
	md_router_wireless_off = "\uf15a3"
	# CHAR : 󰩩
	md_router_wireless_settings = "\uf0a69"
	# CHAR : 󰑪
	md_routes = "\uf046a"
	# CHAR : 󱁙
	md_routes_clock = "\uf1059"
	# CHAR : 󰘈
	md_rowing = "\uf0608"
	# CHAR : 󰑫
	md_rss = "\uf046b"
	# CHAR : 󰑬
	md_rss_box = "\uf046c"
	# CHAR : 󰼡
	md_rss_off = "\uf0f21"
	# CHAR : 󱑵
	md_rug = "\uf1475"
	# CHAR : 󰶙
	md_rugby = "\uf0d99"
	# CHAR : 󰑭
	md_ruler = "\uf046d"
	# CHAR : 󰳂
	md_ruler_square = "\uf0cc2"
	# CHAR : 󰺾
	md_ruler_square_compass = "\uf0ebe"
	# CHAR : 󰜎
	md_run = "\uf070e"
	# CHAR : 󰑮
	md_run_fast = "\uf046e"
	# CHAR : 󱇔
	md_rv_truck = "\uf11d4"
	# CHAR : 󰴮
	md_sack = "\uf0d2e"
	# CHAR : 󰴯
	md_sack_percent = "\uf0d2f"
	# CHAR : 󰩪
	md_safe = "\uf0a6a"
	# CHAR : 󱉼
	md_safe_square = "\uf127c"
	# CHAR : 󱉽
	md_safe_square_outline = "\uf127d"
	# CHAR : 󰴰
	md_safety_goggles = "\uf0d30"
	# CHAR : 󰻈
	md_sail_boat = "\uf0ec8"
	# CHAR : 󱫯
	md_sail_boat_sink = "\uf1aef"
	# CHAR : 󰑯
	md_sale = "\uf046f"
	# CHAR : 󱨆
	md_sale_outline = "\uf1a06"
	# CHAR : 󰢎
	md_salesforce = "\uf088e"
	# CHAR : 󰟬
	md_sass = "\uf07ec"
	# CHAR : 󰑰
	md_satellite = "\uf0470"
	# CHAR : 󰤉
	md_satellite_uplink = "\uf0909"
	# CHAR : 󰑱
	md_satellite_variant = "\uf0471"
	# CHAR : 󰢺
	md_sausage = "\uf08ba"
	# CHAR : 󱞉
	md_sausage_off = "\uf1789"
	# CHAR : 󰹡
	md_saw_blade = "\uf0e61"
	# CHAR : 󱑺
	md_sawtooth_wave = "\uf147a"
	# CHAR : 󰘉
	md_saxophone = "\uf0609"
	# CHAR : 󰑲
	md_scale = "\uf0472"
	# CHAR : 󰗑
	md_scale_balance = "\uf05d1"
	# CHAR : 󰑳
	md_scale_bathroom = "\uf0473"
	# CHAR : 󱁚
	md_scale_off = "\uf105a"
	# CHAR : 󱦸
	md_scale_unbalanced = "\uf19b8"
	# CHAR : 󱏘
	md_scan_helper = "\uf13d8"
	# CHAR : 󰚫
	md_scanner = "\uf06ab"
	# CHAR : 󰤊
	md_scanner_off = "\uf090a"
	# CHAR : 󰻉
	md_scatter_plot = "\uf0ec9"
	# CHAR : 󰻊
	md_scatter_plot_outline = "\uf0eca"
	# CHAR : 󱥘
	md_scent = "\uf1958"
	# CHAR : 󱥙
	md_scent_off = "\uf1959"
	# CHAR : 󰑴
	md_school = "\uf0474"
	# CHAR : 󱆀
	md_school_outline = "\uf1180"
	# CHAR : 󰩫
	md_scissors_cutting = "\uf0a6b"
	# CHAR : 󱖽
	md_scooter = "\uf15bd"
	# CHAR : 󱖾
	md_scooter_electric = "\uf15be"
	# CHAR : 󱉾
	md_scoreboard = "\uf127e"
	# CHAR : 󱉿
	md_scoreboard_outline = "\uf127f"
	# CHAR : 󰑵
	md_screen_rotation = "\uf0475"
	# CHAR : 󰑸
	md_screen_rotation_lock = "\uf0478"
	# CHAR : 󰷳
	md_screw_flat_top = "\uf0df3"
	# CHAR : 󰷴
	md_screw_lag = "\uf0df4"
	# CHAR : 󰷵
	md_screw_machine_flat_top = "\uf0df5"
	# CHAR : 󰷶
	md_screw_machine_round_top = "\uf0df6"
	# CHAR : 󰷷
	md_screw_round_top = "\uf0df7"
	# CHAR : 󰑶
	md_screwdriver = "\uf0476"
	# CHAR : 󰯁
	md_script = "\uf0bc1"
	# CHAR : 󰑷
	md_script_outline = "\uf0477"
	# CHAR : 󰯂
	md_script_text = "\uf0bc2"
	# CHAR : 󱜥
	md_script_text_key = "\uf1725"
	# CHAR : 󱜦
	md_script_text_key_outline = "\uf1726"
	# CHAR : 󰯃
	md_script_text_outline = "\uf0bc3"
	# CHAR : 󱜧
	md_script_text_play = "\uf1727"
	# CHAR : 󱜨
	md_script_text_play_outline = "\uf1728"
	# CHAR : 󰑹
	md_sd = "\uf0479"
	# CHAR : 󰑺
	md_seal = "\uf047a"
	# CHAR : 󰿙
	md_seal_variant = "\uf0fd9"
	# CHAR : 󰜏
	md_search_web = "\uf070f"
	# CHAR : 󰳃
	md_seat = "\uf0cc3"
	# CHAR : 󰑻
	md_seat_flat = "\uf047b"
	# CHAR : 󰑼
	md_seat_flat_angled = "\uf047c"
	# CHAR : 󰑽
	md_seat_individual_suite = "\uf047d"
	# CHAR : 󰑾
	md_seat_legroom_extra = "\uf047e"
	# CHAR : 󰑿
	md_seat_legroom_normal = "\uf047f"
	# CHAR : 󰒀
	md_seat_legroom_reduced = "\uf0480"
	# CHAR : 󰳄
	md_seat_outline = "\uf0cc4"
	# CHAR : 󱉉
	md_seat_passenger = "\uf1249"
	# CHAR : 󰒁
	md_seat_recline_extra = "\uf0481"
	# CHAR : 󰒂
	md_seat_recline_normal = "\uf0482"
	# CHAR : 󰳅
	md_seatbelt = "\uf0cc5"
	# CHAR : 󰒃
	md_security = "\uf0483"
	# CHAR : 󰒄
	md_security_network = "\uf0484"
	# CHAR : 󰹢
	md_seed = "\uf0e62"
	# CHAR : 󱏽
	md_seed_off = "\uf13fd"
	# CHAR : 󱏾
	md_seed_off_outline = "\uf13fe"
	# CHAR : 󰹣
	md_seed_outline = "\uf0e63"
	# CHAR : 󱩭
	md_seed_plus = "\uf1a6d"
	# CHAR : 󱩮
	md_seed_plus_outline = "\uf1a6e"
	# CHAR : 󱖤
	md_seesaw = "\uf15a4"
	# CHAR : 󰻋
	md_segment = "\uf0ecb"
	# CHAR : 󰒅
	md_select = "\uf0485"
	# CHAR : 󰒆
	md_select_all = "\uf0486"
	# CHAR : 󰴱
	md_select_color = "\uf0d31"
	# CHAR : 󰫙
	md_select_compare = "\uf0ad9"
	# CHAR : 󰩬
	md_select_drag = "\uf0a6c"
	# CHAR : 󰾂
	md_select_group = "\uf0f82"
	# CHAR : 󰒇
	md_select_inverse = "\uf0487"
	# CHAR : 󱊀
	md_select_marker = "\uf1280"
	# CHAR : 󱊁
	md_select_multiple = "\uf1281"
	# CHAR : 󱊂
	md_select_multiple_marker = "\uf1282"
	# CHAR : 󰒈
	md_select_off = "\uf0488"
	# CHAR : 󰿚
	md_select_place = "\uf0fda"
	# CHAR : 󱟁
	md_select_remove = "\uf17c1"
	# CHAR : 󱈄
	md_select_search = "\uf1204"
	# CHAR : 󰒉
	md_selection = "\uf0489"
	# CHAR : 󰩭
	md_selection_drag = "\uf0a6d"
	# CHAR : 󰴲
	md_selection_ellipse = "\uf0d32"
	# CHAR : 󰼢
	md_selection_ellipse_arrow_inside = "\uf0f22"
	# CHAR : 󱟂
	md_selection_ellipse_remove = "\uf17c2"
	# CHAR : 󱊃
	md_selection_marker = "\uf1283"
	# CHAR : 󱊅
	md_selection_multiple = "\uf1285"
	# CHAR : 󱊄
	md_selection_multiple_marker = "\uf1284"
	# CHAR : 󰝷
	md_selection_off = "\uf0777"
	# CHAR : 󱟃
	md_selection_remove = "\uf17c3"
	# CHAR : 󱈅
	md_selection_search = "\uf1205"
	# CHAR : 󱌖
	md_semantic_web = "\uf1316"
	# CHAR : 󰒊
	md_send = "\uf048a"
	# CHAR : 󱅡
	md_send_check = "\uf1161"
	# CHAR : 󱅢
	md_send_check_outline = "\uf1162"
	# CHAR : 󰷸
	md_send_circle = "\uf0df8"
	# CHAR : 󰷹
	md_send_circle_outline = "\uf0df9"
	# CHAR : 󱅣
	md_send_clock = "\uf1163"
	# CHAR : 󱅤
	md_send_clock_outline = "\uf1164"
	# CHAR : 󰟭
	md_send_lock = "\uf07ed"
	# CHAR : 󱅦
	md_send_lock_outline = "\uf1166"
	# CHAR : 󱅥
	md_send_outline = "\uf1165"
	# CHAR : 󰙜
	md_serial_port = "\uf065c"
	# CHAR : 󰒋
	md_server = "\uf048b"
	# CHAR : 󰒌
	md_server_minus = "\uf048c"
	# CHAR : 󰒍
	md_server_network = "\uf048d"
	# CHAR : 󰒎
	md_server_network_off = "\uf048e"
	# CHAR : 󰒏
	md_server_off = "\uf048f"
	# CHAR : 󰒐
	md_server_plus = "\uf0490"
	# CHAR : 󰒑
	md_server_remove = "\uf0491"
	# CHAR : 󰒒
	md_server_security = "\uf0492"
	# CHAR : 󰝸
	md_set_all = "\uf0778"
	# CHAR : 󰝹
	md_set_center = "\uf0779"
	# CHAR : 󰝺
	md_set_center_right = "\uf077a"
	# CHAR : 󰝻
	md_set_left = "\uf077b"
	# CHAR : 󰝼
	md_set_left_center = "\uf077c"
	# CHAR : 󰝽
	md_set_left_right = "\uf077d"
	# CHAR : 󱓠
	md_set_merge = "\uf14e0"
	# CHAR : 󰝾
	md_set_none = "\uf077e"
	# CHAR : 󰝿
	md_set_right = "\uf077f"
	# CHAR : 󱓡
	md_set_split = "\uf14e1"
	# CHAR : 󱑝
	md_set_square = "\uf145d"
	# CHAR : 󰦟
	md_set_top_box = "\uf099f"
	# CHAR : 󰩮
	md_settings_helper = "\uf0a6e"
	# CHAR : 󱄎
	md_shaker = "\uf110e"
	# CHAR : 󱄏
	md_shaker_outline = "\uf110f"
	# CHAR : 󰠱
	md_shape = "\uf0831"
	# CHAR : 󰙝
	md_shape_circle_plus = "\uf065d"
	# CHAR : 󰠲
	md_shape_outline = "\uf0832"
	# CHAR : 󱇺
	md_shape_oval_plus = "\uf11fa"
	# CHAR : 󰒕
	md_shape_plus = "\uf0495"
	# CHAR : 󰙞
	md_shape_polygon_plus = "\uf065e"
	# CHAR : 󰙟
	md_shape_rectangle_plus = "\uf065f"
	# CHAR : 󰙠
	md_shape_square_plus = "\uf0660"
	# CHAR : 󱓺
	md_shape_square_rounded_plus = "\uf14fa"
	# CHAR : 󰒖
	md_share = "\uf0496"
	# CHAR : 󱇴
	md_share_all = "\uf11f4"
	# CHAR : 󱇵
	md_share_all_outline = "\uf11f5"
	# CHAR : 󱆭
	md_share_circle = "\uf11ad"
	# CHAR : 󰼣
	md_share_off = "\uf0f23"
	# CHAR : 󰼤
	md_share_off_outline = "\uf0f24"
	# CHAR : 󰤲
	md_share_outline = "\uf0932"
	# CHAR : 󰒗
	md_share_variant = "\uf0497"
	# CHAR : 󱔔
	md_share_variant_outline = "\uf1514"
	# CHAR : 󱢺
	md_shark = "\uf18ba"
	# CHAR : 󱙳
	md_shark_fin = "\uf1673"
	# CHAR : 󱙴
	md_shark_fin_outline = "\uf1674"
	# CHAR : 󱢻
	md_shark_off = "\uf18bb"
	# CHAR : 󰳆
	md_sheep = "\uf0cc6"
	# CHAR : 󰒘
	md_shield = "\uf0498"
	# CHAR : 󰢏
	md_shield_account = "\uf088f"
	# CHAR : 󰨒
	md_shield_account_outline = "\uf0a12"
	# CHAR : 󱖧
	md_shield_account_variant = "\uf15a7"
	# CHAR : 󱖨
	md_shield_account_variant_outline = "\uf15a8"
	# CHAR : 󰚻
	md_shield_airplane = "\uf06bb"
	# CHAR : 󰳇
	md_shield_airplane_outline = "\uf0cc7"
	# CHAR : 󰻌
	md_shield_alert = "\uf0ecc"
	# CHAR : 󰻍
	md_shield_alert_outline = "\uf0ecd"
	# CHAR : 󱏚
	md_shield_bug = "\uf13da"
	# CHAR : 󱏛
	md_shield_bug_outline = "\uf13db"
	# CHAR : 󰾃
	md_shield_car = "\uf0f83"
	# CHAR : 󰕥
	md_shield_check = "\uf0565"
	# CHAR : 󰳈
	md_shield_check_outline = "\uf0cc8"
	# CHAR : 󰳉
	md_shield_cross = "\uf0cc9"
	# CHAR : 󰳊
	md_shield_cross_outline = "\uf0cca"
	# CHAR : 󱢼
	md_shield_crown = "\uf18bc"
	# CHAR : 󱢽
	md_shield_crown_outline = "\uf18bd"
	# CHAR : 󱆠
	md_shield_edit = "\uf11a0"
	# CHAR : 󱆡
	md_shield_edit_outline = "\uf11a1"
	# CHAR : 󱍠
	md_shield_half = "\uf1360"
	# CHAR : 󰞀
	md_shield_half_full = "\uf0780"
	# CHAR : 󰚊
	md_shield_home = "\uf068a"
	# CHAR : 󰳋
	md_shield_home_outline = "\uf0ccb"
	# CHAR : 󰯄
	md_shield_key = "\uf0bc4"
	# CHAR : 󰯅
	md_shield_key_outline = "\uf0bc5"
	# CHAR : 󰴳
	md_shield_link_variant = "\uf0d33"
	# CHAR : 󰴴
	md_shield_link_variant_outline = "\uf0d34"
	# CHAR : 󰦝
	md_shield_lock = "\uf099d"
	# CHAR : 󱦚
	md_shield_lock_open = "\uf199a"
	# CHAR : 󱦛
	md_shield_lock_open_outline = "\uf199b"
	# CHAR : 󰳌
	md_shield_lock_outline = "\uf0ccc"
	# CHAR : 󱠨
	md_shield_moon = "\uf1828"
	# CHAR : 󱠩
	md_shield_moon_outline = "\uf1829"
	# CHAR : 󰦞
	md_shield_off = "\uf099e"
	# CHAR : 󰦜
	md_shield_off_outline = "\uf099c"
	# CHAR : 󰒙
	md_shield_outline = "\uf0499"
	# CHAR : 󰫚
	md_shield_plus = "\uf0ada"
	# CHAR : 󰫛
	md_shield_plus_outline = "\uf0adb"
	# CHAR : 󰂪
	md_shield_refresh = "\uf00aa"
	# CHAR : 󰇠
	md_shield_refresh_outline = "\uf01e0"
	# CHAR : 󰫜
	md_shield_remove = "\uf0adc"
	# CHAR : 󰫝
	md_shield_remove_outline = "\uf0add"
	# CHAR : 󰶚
	md_shield_search = "\uf0d9a"
	# CHAR : 󱄻
	md_shield_star = "\uf113b"
	# CHAR : 󱄼
	md_shield_star_outline = "\uf113c"
	# CHAR : 󱁝
	md_shield_sun = "\uf105d"
	# CHAR : 󱁞
	md_shield_sun_outline = "\uf105e"
	# CHAR : 󱢾
	md_shield_sword = "\uf18be"
	# CHAR : 󱢿
	md_shield_sword_outline = "\uf18bf"
	# CHAR : 󱆢
	md_shield_sync = "\uf11a2"
	# CHAR : 󱆣
	md_shield_sync_outline = "\uf11a3"
	# CHAR : 󱕅
	md_shimmer = "\uf1545"
	# CHAR : 󰠳
	md_ship_wheel = "\uf0833"
	# CHAR : 󱡎
	md_shipping_pallet = "\uf184e"
	# CHAR : 󱗊
	md_shoe_ballet = "\uf15ca"
	# CHAR : 󱗇
	md_shoe_cleat = "\uf15c7"
	# CHAR : 󰭇
	md_shoe_formal = "\uf0b47"
	# CHAR : 󰭈
	md_shoe_heel = "\uf0b48"
	# CHAR : 󰷺
	md_shoe_print = "\uf0dfa"
	# CHAR : 󱗈
	md_shoe_sneaker = "\uf15c8"
	# CHAR : 󰒚
	md_shopping = "\uf049a"
	# CHAR : 󰒛
	md_shopping_music = "\uf049b"
	# CHAR : 󱇕
	md_shopping_outline = "\uf11d5"
	# CHAR : 󰾄
	md_shopping_search = "\uf0f84"
	# CHAR : 󱩯
	md_shopping_search_outline = "\uf1a6f"
	# CHAR : 󱓹
	md_shore = "\uf14f9"
	# CHAR : 󰜐
	md_shovel = "\uf0710"
	# CHAR : 󰜑
	md_shovel_off = "\uf0711"
	# CHAR : 󰦠
	md_shower = "\uf09a0"
	# CHAR : 󰦡
	md_shower_head = "\uf09a1"
	# CHAR : 󰒜
	md_shredder = "\uf049c"
	# CHAR : 󰒝
	md_shuffle = "\uf049d"
	# CHAR : 󰒞
	md_shuffle_disabled = "\uf049e"
	# CHAR : 󰒟
	md_shuffle_variant = "\uf049f"
	# CHAR : 󱍿
	md_shuriken = "\uf137f"
	# CHAR : 󱣀
	md_sickle = "\uf18c0"
	# CHAR : 󰒠
	md_sigma = "\uf04a0"
	# CHAR : 󰘫
	md_sigma_lower = "\uf062b"
	# CHAR : 󰒡
	md_sign_caution = "\uf04a1"
	# CHAR : 󰞁
	md_sign_direction = "\uf0781"
	# CHAR : 󱀀
	md_sign_direction_minus = "\uf1000"
	# CHAR : 󰿜
	md_sign_direction_plus = "\uf0fdc"
	# CHAR : 󰿝
	md_sign_direction_remove = "\uf0fdd"
	# CHAR : 󱓸
	md_sign_pole = "\uf14f8"
	# CHAR : 󱄘
	md_sign_real_estate = "\uf1118"
	# CHAR : 󰞂
	md_sign_text = "\uf0782"
	# CHAR : 󰒢
	md_signal = "\uf04a2"
	# CHAR : 󰜒
	md_signal_2g = "\uf0712"
	# CHAR : 󰜓
	md_signal_3g = "\uf0713"
	# CHAR : 󰜔
	md_signal_4g = "\uf0714"
	# CHAR : 󰩯
	md_signal_5g = "\uf0a6f"
	# CHAR : 󰢼
	md_signal_cellular_1 = "\uf08bc"
	# CHAR : 󰢽
	md_signal_cellular_2 = "\uf08bd"
	# CHAR : 󰢾
	md_signal_cellular_3 = "\uf08be"
	# CHAR : 󰢿
	md_signal_cellular_outline = "\uf08bf"
	# CHAR : 󰹤
	md_signal_distance_variant = "\uf0e64"
	# CHAR : 󰜕
	md_signal_hspa = "\uf0715"
	# CHAR : 󰜖
	md_signal_hspa_plus = "\uf0716"
	# CHAR : 󰞃
	md_signal_off = "\uf0783"
	# CHAR : 󰘊
	md_signal_variant = "\uf060a"
	# CHAR : 󰷻
	md_signature = "\uf0dfb"
	# CHAR : 󰷼
	md_signature_freehand = "\uf0dfc"
	# CHAR : 󰷽
	md_signature_image = "\uf0dfd"
	# CHAR : 󰷾
	md_signature_text = "\uf0dfe"
	# CHAR : 󰭉
	md_silo = "\uf0b49"
	# CHAR : 󰒣
	md_silverware = "\uf04a3"
	# CHAR : 󰿞
	md_silverware_clean = "\uf0fde"
	# CHAR : 󰒤
	md_silverware_fork = "\uf04a4"
	# CHAR : 󰩰
	md_silverware_fork_knife = "\uf0a70"
	# CHAR : 󰒥
	md_silverware_spoon = "\uf04a5"
	# CHAR : 󰒦
	md_silverware_variant = "\uf04a6"
	# CHAR : 󰒧
	md_sim = "\uf04a7"
	# CHAR : 󰒨
	md_sim_alert = "\uf04a8"
	# CHAR : 󱗓
	md_sim_alert_outline = "\uf15d3"
	# CHAR : 󰒩
	md_sim_off = "\uf04a9"
	# CHAR : 󱗔
	md_sim_off_outline = "\uf15d4"
	# CHAR : 󱗕
	md_sim_outline = "\uf15d5"
	# CHAR : 󱌝
	md_simple_icons = "\uf131d"
	# CHAR : 󰫟
	md_sina_weibo = "\uf0adf"
	# CHAR : 󰥛
	md_sine_wave = "\uf095b"
	# CHAR : 󰒪
	md_sitemap = "\uf04aa"
	# CHAR : 󱦜
	md_sitemap_outline = "\uf199c"
	# CHAR : 󱎥
	md_size_m = "\uf13a5"
	# CHAR : 󱎤
	md_size_s = "\uf13a4"
	# CHAR : 󱎧
	md_size_xl = "\uf13a7"
	# CHAR : 󱎣
	md_size_xs = "\uf13a3"
	# CHAR : 󱎨
	md_size_xxl = "\uf13a8"
	# CHAR : 󱎢
	md_size_xxs = "\uf13a2"
	# CHAR : 󱎩
	md_size_xxxl = "\uf13a9"
	# CHAR : 󰴵
	md_skate = "\uf0d35"
	# CHAR : 󰚙
	md_skate_off = "\uf0699"
	# CHAR : 󱓂
	md_skateboard = "\uf14c2"
	# CHAR : 󰔁
	md_skateboarding = "\uf0501"
	# CHAR : 󰴶
	md_skew_less = "\uf0d36"
	# CHAR : 󰴷
	md_skew_more = "\uf0d37"
	# CHAR : 󱌄
	md_ski = "\uf1304"
	# CHAR : 󱌅
	md_ski_cross_country = "\uf1305"
	# CHAR : 󱌆
	md_ski_water = "\uf1306"
	# CHAR : 󰒫
	md_skip_backward = "\uf04ab"
	# CHAR : 󰼥
	md_skip_backward_outline = "\uf0f25"
	# CHAR : 󰒬
	md_skip_forward = "\uf04ac"
	# CHAR : 󰼦
	md_skip_forward_outline = "\uf0f26"
	# CHAR : 󰒭
	md_skip_next = "\uf04ad"
	# CHAR : 󰙡
	md_skip_next_circle = "\uf0661"
	# CHAR : 󰙢
	md_skip_next_circle_outline = "\uf0662"
	# CHAR : 󰼧
	md_skip_next_outline = "\uf0f27"
	# CHAR : 󰒮
	md_skip_previous = "\uf04ae"
	# CHAR : 󰙣
	md_skip_previous_circle = "\uf0663"
	# CHAR : 󰙤
	md_skip_previous_circle_outline = "\uf0664"
	# CHAR : 󰼨
	md_skip_previous_outline = "\uf0f28"
	# CHAR : 󰚌
	md_skull = "\uf068c"
	# CHAR : 󰯆
	md_skull_crossbones = "\uf0bc6"
	# CHAR : 󰯇
	md_skull_crossbones_outline = "\uf0bc7"
	# CHAR : 󰯈
	md_skull_outline = "\uf0bc8"
	# CHAR : 󱓇
	md_skull_scan = "\uf14c7"
	# CHAR : 󱓈
	md_skull_scan_outline = "\uf14c8"
	# CHAR : 󰒯
	md_skype = "\uf04af"
	# CHAR : 󰒰
	md_skype_business = "\uf04b0"
	# CHAR : 󰒱
	md_slack = "\uf04b1"
	# CHAR : 󰿟
	md_slash_forward = "\uf0fdf"
	# CHAR : 󰿠
	md_slash_forward_box = "\uf0fe0"
	# CHAR : 󰐛
	md_sledding = "\uf041b"
	# CHAR : 󰒲
	md_sleep = "\uf04b2"
	# CHAR : 󰒳
	md_sleep_off = "\uf04b3"
	# CHAR : 󱖥
	md_slide = "\uf15a5"
	# CHAR : 󰷿
	md_slope_downhill = "\uf0dff"
	# CHAR : 󰸀
	md_slope_uphill = "\uf0e00"
	# CHAR : 󱄔
	md_slot_machine = "\uf1114"
	# CHAR : 󱄕
	md_slot_machine_outline = "\uf1115"
	# CHAR : 󱂽
	md_smart_card = "\uf10bd"
	# CHAR : 󱣷
	md_smart_card_off = "\uf18f7"
	# CHAR : 󱣸
	md_smart_card_off_outline = "\uf18f8"
	# CHAR : 󱂾
	md_smart_card_outline = "\uf10be"
	# CHAR : 󱂿
	md_smart_card_reader = "\uf10bf"
	# CHAR : 󱃀
	md_smart_card_reader_outline = "\uf10c0"
	# CHAR : 󰩱
	md_smog = "\uf0a71"
	# CHAR : 󱞙
	md_smoke = "\uf1799"
	# CHAR : 󰎒
	md_smoke_detector = "\uf0392"
	# CHAR : 󱤮
	md_smoke_detector_alert = "\uf192e"
	# CHAR : 󱤯
	md_smoke_detector_alert_outline = "\uf192f"
	# CHAR : 󱠉
	md_smoke_detector_off = "\uf1809"
	# CHAR : 󱠊
	md_smoke_detector_off_outline = "\uf180a"
	# CHAR : 󱠈
	md_smoke_detector_outline = "\uf1808"
	# CHAR : 󱠋
	md_smoke_detector_variant = "\uf180b"
	# CHAR : 󱤰
	md_smoke_detector_variant_alert = "\uf1930"
	# CHAR : 󱠌
	md_smoke_detector_variant_off = "\uf180c"
	# CHAR : 󰒴
	md_smoking = "\uf04b4"
	# CHAR : 󰒵
	md_smoking_off = "\uf04b5"
	# CHAR : 󱐍
	md_smoking_pipe = "\uf140d"
	# CHAR : 󱐨
	md_smoking_pipe_off = "\uf1428"
	# CHAR : 󱙷
	md_snail = "\uf1677"
	# CHAR : 󱔎
	md_snake = "\uf150e"
	# CHAR : 󰒶
	md_snapchat = "\uf04b6"
	# CHAR : 󱌇
	md_snowboard = "\uf1307"
	# CHAR : 󰜗
	md_snowflake = "\uf0717"
	# CHAR : 󰼩
	md_snowflake_alert = "\uf0f29"
	# CHAR : 󱩰
	md_snowflake_check = "\uf1a70"
	# CHAR : 󱋋
	md_snowflake_melt = "\uf12cb"
	# CHAR : 󱓣
	md_snowflake_off = "\uf14e3"
	# CHAR : 󱩱
	md_snowflake_thermometer = "\uf1a71"
	# CHAR : 󰼪
	md_snowflake_variant = "\uf0f2a"
	# CHAR : 󰒷
	md_snowman = "\uf04b7"
	# CHAR : 󰛝
	md_snowmobile = "\uf06dd"
	# CHAR : 󱩲
	md_snowshoeing = "\uf1a72"
	# CHAR : 󰒸
	md_soccer = "\uf04b8"
	# CHAR : 󰠴
	md_soccer_field = "\uf0834"
	# CHAR : 󱕹
	md_social_distance_2_meters = "\uf1579"
	# CHAR : 󱕺
	md_social_distance_6_feet = "\uf157a"
	# CHAR : 󰒹
	md_sofa = "\uf04b9"
	# CHAR : 󱕭
	md_sofa_outline = "\uf156d"
	# CHAR : 󱕮
	md_sofa_single = "\uf156e"
	# CHAR : 󱕯
	md_sofa_single_outline = "\uf156f"
	# CHAR : 󰶛
	md_solar_panel = "\uf0d9b"
	# CHAR : 󰶜
	md_solar_panel_large = "\uf0d9c"
	# CHAR : 󰩲
	md_solar_power = "\uf0a72"
	# CHAR : 󱩳
	md_solar_power_variant = "\uf1a73"
	# CHAR : 󱩴
	md_solar_power_variant_outline = "\uf1a74"
	# CHAR : 󱂒
	md_soldering_iron = "\uf1092"
	# CHAR : 󰚍
	md_solid = "\uf068d"
	# CHAR : 󰐔
	md_sony_playstation = "\uf0414"
	# CHAR : 󰒺
	md_sort = "\uf04ba"
	# CHAR : 󰖽
	md_sort_alphabetical_ascending = "\uf05bd"
	# CHAR : 󱅈
	md_sort_alphabetical_ascending_variant = "\uf1148"
	# CHAR : 󰖿
	md_sort_alphabetical_descending = "\uf05bf"
	# CHAR : 󱅉
	md_sort_alphabetical_descending_variant = "\uf1149"
	# CHAR : 󰒻
	md_sort_alphabetical_variant = "\uf04bb"
	# CHAR : 󰒼
	md_sort_ascending = "\uf04bc"
	# CHAR : 󱎅
	md_sort_bool_ascending = "\uf1385"
	# CHAR : 󱎆
	md_sort_bool_ascending_variant = "\uf1386"
	# CHAR : 󱎇
	md_sort_bool_descending = "\uf1387"
	# CHAR : 󱎈
	md_sort_bool_descending_variant = "\uf1388"
	# CHAR : 󱕇
	md_sort_calendar_ascending = "\uf1547"
	# CHAR : 󱕈
	md_sort_calendar_descending = "\uf1548"
	# CHAR : 󱕉
	md_sort_clock_ascending = "\uf1549"
	# CHAR : 󱕊
	md_sort_clock_ascending_outline = "\uf154a"
	# CHAR : 󱕋
	md_sort_clock_descending = "\uf154b"
	# CHAR : 󱕌
	md_sort_clock_descending_outline = "\uf154c"
	# CHAR : 󰒽
	md_sort_descending = "\uf04bd"
	# CHAR : 󱎉
	md_sort_numeric_ascending = "\uf1389"
	# CHAR : 󰤍
	md_sort_numeric_ascending_variant = "\uf090d"
	# CHAR : 󱎊
	md_sort_numeric_descending = "\uf138a"
	# CHAR : 󰫒
	md_sort_numeric_descending_variant = "\uf0ad2"
	# CHAR : 󰒾
	md_sort_numeric_variant = "\uf04be"
	# CHAR : 󰌼
	md_sort_reverse_variant = "\uf033c"
	# CHAR : 󰒿
	md_sort_variant = "\uf04bf"
	# CHAR : 󰳍
	md_sort_variant_lock = "\uf0ccd"
	# CHAR : 󰳎
	md_sort_variant_lock_open = "\uf0cce"
	# CHAR : 󱪻
	md_sort_variant_off = "\uf1abb"
	# CHAR : 󱅇
	md_sort_variant_remove = "\uf1147"
	# CHAR : 󱟛
	md_soundbar = "\uf17db"
	# CHAR : 󰓀
	md_soundcloud = "\uf04c0"
	# CHAR : 󰘬
	md_source_branch = "\uf062c"
	# CHAR : 󱓏
	md_source_branch_check = "\uf14cf"
	# CHAR : 󱓋
	md_source_branch_minus = "\uf14cb"
	# CHAR : 󱓊
	md_source_branch_plus = "\uf14ca"
	# CHAR : 󱓍
	md_source_branch_refresh = "\uf14cd"
	# CHAR : 󱓌
	md_source_branch_remove = "\uf14cc"
	# CHAR : 󱓎
	md_source_branch_sync = "\uf14ce"
	# CHAR : 󰜘
	md_source_commit = "\uf0718"
	# CHAR : 󰜙
	md_source_commit_end = "\uf0719"
	# CHAR : 󰜚
	md_source_commit_end_local = "\uf071a"
	# CHAR : 󰜛
	md_source_commit_local = "\uf071b"
	# CHAR : 󰜜
	md_source_commit_next_local = "\uf071c"
	# CHAR : 󰜝
	md_source_commit_start = "\uf071d"
	# CHAR : 󰜞
	md_source_commit_start_next_local = "\uf071e"
	# CHAR : 󰓁
	md_source_fork = "\uf04c1"
	# CHAR : 󰘭
	md_source_merge = "\uf062d"
	# CHAR : 󰓂
	md_source_pull = "\uf04c2"
	# CHAR : 󰳏
	md_source_repository = "\uf0ccf"
	# CHAR : 󰳐
	md_source_repository_multiple = "\uf0cd0"
	# CHAR : 󰟮
	md_soy_sauce = "\uf07ee"
	# CHAR : 󱏼
	md_soy_sauce_off = "\uf13fc"
	# CHAR : 󰳑
	md_spa = "\uf0cd1"
	# CHAR : 󰳒
	md_spa_outline = "\uf0cd2"
	# CHAR : 󰯉
	md_space_invaders = "\uf0bc9"
	# CHAR : 󱎃
	md_space_station = "\uf1383"
	# CHAR : 󰹥
	md_spade = "\uf0e65"
	# CHAR : 󰓃
	md_speaker = "\uf04c3"
	# CHAR : 󰦢
	md_speaker_bluetooth = "\uf09a2"
	# CHAR : 󰴸
	md_speaker_multiple = "\uf0d38"
	# CHAR : 󰓄
	md_speaker_off = "\uf04c4"
	# CHAR : 󰜟
	md_speaker_wireless = "\uf071f"
	# CHAR : 󱡅
	md_spear = "\uf1845"
	# CHAR : 󰓅
	md_speedometer = "\uf04c5"
	# CHAR : 󰾅
	md_speedometer_medium = "\uf0f85"
	# CHAR : 󰾆
	md_speedometer_slow = "\uf0f86"
	# CHAR : 󰓆
	md_spellcheck = "\uf04c6"
	# CHAR : 󱥔
	md_sphere = "\uf1954"
	# CHAR : 󱥕
	md_sphere_off = "\uf1955"
	# CHAR : 󱇪
	md_spider = "\uf11ea"
	# CHAR : 󱇫
	md_spider_thread = "\uf11eb"
	# CHAR : 󰯊
	md_spider_web = "\uf0bca"
	# CHAR : 󱓱
	md_spirit_level = "\uf14f1"
	# CHAR : 󱐩
	md_spoon_sugar = "\uf1429"
	# CHAR : 󰓇
	md_spotify = "\uf04c7"
	# CHAR : 󰓈
	md_spotlight = "\uf04c8"
	# CHAR : 󰓉
	md_spotlight_beam = "\uf04c9"
	# CHAR : 󰙥
	md_spray = "\uf0665"
	# CHAR : 󰫠
	md_spray_bottle = "\uf0ae0"
	# CHAR : 󱁟
	md_sprinkler = "\uf105f"
	# CHAR : 󱦝
	md_sprinkler_fire = "\uf199d"
	# CHAR : 󱁠
	md_sprinkler_variant = "\uf1060"
	# CHAR : 󰹦
	md_sprout = "\uf0e66"
	# CHAR : 󰹧
	md_sprout_outline = "\uf0e67"
	# CHAR : 󰝤
	md_square = "\uf0764"
	# CHAR : 󱔀
	md_square_circle = "\uf1500"
	# CHAR : 󰤌
	md_square_edit_outline = "\uf090c"
	# CHAR : 󰨓
	md_square_medium = "\uf0a13"
	# CHAR : 󰨔
	md_square_medium_outline = "\uf0a14"
	# CHAR : 󱋮
	md_square_off = "\uf12ee"
	# CHAR : 󱋯
	md_square_off_outline = "\uf12ef"
	# CHAR : 󱡔
	md_square_opacity = "\uf1854"
	# CHAR : 󰝣
	md_square_outline = "\uf0763"
	# CHAR : 󰞄
	md_square_root = "\uf0784"
	# CHAR : 󰦣
	md_square_root_box = "\uf09a3"
	# CHAR : 󱓻
	md_square_rounded = "\uf14fb"
	# CHAR : 󱨇
	md_square_rounded_badge = "\uf1a07"
	# CHAR : 󱨈
	md_square_rounded_badge_outline = "\uf1a08"
	# CHAR : 󱓼
	md_square_rounded_outline = "\uf14fc"
	# CHAR : 󰨕
	md_square_small = "\uf0a15"
	# CHAR : 󱑻
	md_square_wave = "\uf147b"
	# CHAR : 󰫡
	md_squeegee = "\uf0ae1"
	# CHAR : 󰣀
	md_ssh = "\uf08c0"
	# CHAR : 󰘋
	md_stack_exchange = "\uf060b"
	# CHAR : 󰓌
	md_stack_overflow = "\uf04cc"
	# CHAR : 󰍙
	md_stackpath = "\uf0359"
	# CHAR : 󰿹
	md_stadium = "\uf0ff9"
	# CHAR : 󰜠
	md_stadium_variant = "\uf0720"
	# CHAR : 󰓍
	md_stairs = "\uf04cd"
	# CHAR : 󱎞
	md_stairs_box = "\uf139e"
	# CHAR : 󱊾
	md_stairs_down = "\uf12be"
	# CHAR : 󱊽
	md_stairs_up = "\uf12bd"
	# CHAR : 󰴹
	md_stamper = "\uf0d39"
	# CHAR : 󰟯
	md_standard_definition = "\uf07ef"
	# CHAR : 󰓎
	md_star = "\uf04ce"
	# CHAR : 󰩳
	md_star_box = "\uf0a73"
	# CHAR : 󱊆
	md_star_box_multiple = "\uf1286"
	# CHAR : 󱊇
	md_star_box_multiple_outline = "\uf1287"
	# CHAR : 󰩴
	md_star_box_outline = "\uf0a74"
	# CHAR : 󱕦
	md_star_check = "\uf1566"
	# CHAR : 󱕪
	md_star_check_outline = "\uf156a"
	# CHAR : 󰓏
	md_star_circle = "\uf04cf"
	# CHAR : 󰦤
	md_star_circle_outline = "\uf09a4"
	# CHAR : 󱙨
	md_star_cog = "\uf1668"
	# CHAR : 󱙩
	md_star_cog_outline = "\uf1669"
	# CHAR : 󰥹
	md_star_crescent = "\uf0979"
	# CHAR : 󰥺
	md_star_david = "\uf097a"
	# CHAR : 󰦥
	md_star_face = "\uf09a5"
	# CHAR : 󰫢
	md_star_four_points = "\uf0ae2"
	# CHAR : 󰫣
	md_star_four_points_outline = "\uf0ae3"
	# CHAR : 󰉆
	md_star_half = "\uf0246"
	# CHAR : 󰓐
	md_star_half_full = "\uf04d0"
	# CHAR : 󱕤
	md_star_minus = "\uf1564"
	# CHAR : 󱕨
	md_star_minus_outline = "\uf1568"
	# CHAR : 󰓑
	md_star_off = "\uf04d1"
	# CHAR : 󱕛
	md_star_off_outline = "\uf155b"
	# CHAR : 󰓒
	md_star_outline = "\uf04d2"
	# CHAR : 󱕣
	md_star_plus = "\uf1563"
	# CHAR : 󱕧
	md_star_plus_outline = "\uf1567"
	# CHAR : 󱕥
	md_star_remove = "\uf1565"
	# CHAR : 󱕩
	md_star_remove_outline = "\uf1569"
	# CHAR : 󱙪
	md_star_settings = "\uf166a"
	# CHAR : 󱙫
	md_star_settings_outline = "\uf166b"
	# CHAR : 󱝁
	md_star_shooting = "\uf1741"
	# CHAR : 󱝂
	md_star_shooting_outline = "\uf1742"
	# CHAR : 󰫤
	md_star_three_points = "\uf0ae4"
	# CHAR : 󰫥
	md_star_three_points_outline = "\uf0ae5"
	# CHAR : 󱇯
	md_state_machine = "\uf11ef"
	# CHAR : 󰓓
	md_steam = "\uf04d3"
	# CHAR : 󰓔
	md_steering = "\uf04d4"
	# CHAR : 󰤎
	md_steering_off = "\uf090e"
	# CHAR : 󰓕
	md_step_backward = "\uf04d5"
	# CHAR : 󰓖
	md_step_backward_2 = "\uf04d6"
	# CHAR : 󰓗
	md_step_forward = "\uf04d7"
	# CHAR : 󰓘
	md_step_forward_2 = "\uf04d8"
	# CHAR : 󰓙
	md_stethoscope = "\uf04d9"
	# CHAR : 󱍤
	md_sticker = "\uf1364"
	# CHAR : 󱍥
	md_sticker_alert = "\uf1365"
	# CHAR : 󱍦
	md_sticker_alert_outline = "\uf1366"
	# CHAR : 󱍧
	md_sticker_check = "\uf1367"
	# CHAR : 󱍨
	md_sticker_check_outline = "\uf1368"
	# CHAR : 󰗐
	md_sticker_circle_outline = "\uf05d0"
	# CHAR : 󰞅
	md_sticker_emoji = "\uf0785"
	# CHAR : 󱍩
	md_sticker_minus = "\uf1369"
	# CHAR : 󱍪
	md_sticker_minus_outline = "\uf136a"
	# CHAR : 󱍫
	md_sticker_outline = "\uf136b"
	# CHAR : 󱍬
	md_sticker_plus = "\uf136c"
	# CHAR : 󱍭
	md_sticker_plus_outline = "\uf136d"
	# CHAR : 󱍮
	md_sticker_remove = "\uf136e"
	# CHAR : 󱍯
	md_sticker_remove_outline = "\uf136f"
	# CHAR : 󱞎
	md_sticker_text = "\uf178e"
	# CHAR : 󱞏
	md_sticker_text_outline = "\uf178f"
	# CHAR : 󰓚
	md_stocking = "\uf04da"
	# CHAR : 󱂓
	md_stomach = "\uf1093"
	# CHAR : 󱥝
	md_stool = "\uf195d"
	# CHAR : 󱥞
	md_stool_outline = "\uf195e"
	# CHAR : 󰓛
	md_stop = "\uf04db"
	# CHAR : 󰙦
	md_stop_circle = "\uf0666"
	# CHAR : 󰙧
	md_stop_circle_outline = "\uf0667"
	# CHAR : 󱩵
	md_storage_tank = "\uf1a75"
	# CHAR : 󱩶
	md_storage_tank_outline = "\uf1a76"
	# CHAR : 󰓜
	md_store = "\uf04dc"
	# CHAR : 󰓝
	md_store_24_hour = "\uf04dd"
	# CHAR : 󱣁
	md_store_alert = "\uf18c1"
	# CHAR : 󱣂
	md_store_alert_outline = "\uf18c2"
	# CHAR : 󱣃
	md_store_check = "\uf18c3"
	# CHAR : 󱣄
	md_store_check_outline = "\uf18c4"
	# CHAR : 󱣅
	md_store_clock = "\uf18c5"
	# CHAR : 󱣆
	md_store_clock_outline = "\uf18c6"
	# CHAR : 󱣇
	md_store_cog = "\uf18c7"
	# CHAR : 󱣈
	md_store_cog_outline = "\uf18c8"
	# CHAR : 󱣉
	md_store_edit = "\uf18c9"
	# CHAR : 󱣊
	md_store_edit_outline = "\uf18ca"
	# CHAR : 󱣋
	md_store_marker = "\uf18cb"
	# CHAR : 󱣌
	md_store_marker_outline = "\uf18cc"
	# CHAR : 󱙞
	md_store_minus = "\uf165e"
	# CHAR : 󱣍
	md_store_minus_outline = "\uf18cd"
	# CHAR : 󱣎
	md_store_off = "\uf18ce"
	# CHAR : 󱣏
	md_store_off_outline = "\uf18cf"
	# CHAR : 󱍡
	md_store_outline = "\uf1361"
	# CHAR : 󱙟
	md_store_plus = "\uf165f"
	# CHAR : 󱣐
	md_store_plus_outline = "\uf18d0"
	# CHAR : 󱙠
	md_store_remove = "\uf1660"
	# CHAR : 󱣑
	md_store_remove_outline = "\uf18d1"
	# CHAR : 󱣒
	md_store_search = "\uf18d2"
	# CHAR : 󱣓
	md_store_search_outline = "\uf18d3"
	# CHAR : 󱣔
	md_store_settings = "\uf18d4"
	# CHAR : 󱣕
	md_store_settings_outline = "\uf18d5"
	# CHAR : 󰟇
	md_storefront = "\uf07c7"
	# CHAR : 󱃁
	md_storefront_outline = "\uf10c1"
	# CHAR : 󰓞
	md_stove = "\uf04de"
	# CHAR : 󱇖
	md_strategy = "\uf11d6"
	# CHAR : 󰼫
	md_stretch_to_page = "\uf0f2b"
	# CHAR : 󰼬
	md_stretch_to_page_outline = "\uf0f2c"
	# CHAR : 󱊺
	md_string_lights = "\uf12ba"
	# CHAR : 󱊻
	md_string_lights_off = "\uf12bb"
	# CHAR : 󰘌
	md_subdirectory_arrow_left = "\uf060c"
	# CHAR : 󰘍
	md_subdirectory_arrow_right = "\uf060d"
	# CHAR : 󱕬
	md_submarine = "\uf156c"
	# CHAR : 󰨖
	md_subtitles = "\uf0a16"
	# CHAR : 󰨗
	md_subtitles_outline = "\uf0a17"
	# CHAR : 󰚬
	md_subway = "\uf06ac"
	# CHAR : 󰶝
	md_subway_alert_variant = "\uf0d9d"
	# CHAR : 󰓟
	md_subway_variant = "\uf04df"
	# CHAR : 󰞆
	md_summit = "\uf0786"
	# CHAR : 󱩷
	md_sun_clock = "\uf1a77"
	# CHAR : 󱩸
	md_sun_clock_outline = "\uf1a78"
	# CHAR : 󱦥
	md_sun_compass = "\uf19a5"
	# CHAR : 󱞖
	md_sun_snowflake = "\uf1796"
	# CHAR : 󱩹
	md_sun_snowflake_variant = "\uf1a79"
	# CHAR : 󱣖
	md_sun_thermometer = "\uf18d6"
	# CHAR : 󱣗
	md_sun_thermometer_outline = "\uf18d7"
	# CHAR : 󱟾
	md_sun_wireless = "\uf17fe"
	# CHAR : 󱟿
	md_sun_wireless_outline = "\uf17ff"
	# CHAR : 󰓠
	md_sunglasses = "\uf04e0"
	# CHAR : 󱝆
	md_surfing = "\uf1746"
	# CHAR : 󰗅
	md_surround_sound = "\uf05c5"
	# CHAR : 󰟰
	md_surround_sound_2_0 = "\uf07f0"
	# CHAR : 󱜩
	md_surround_sound_2_1 = "\uf1729"
	# CHAR : 󰟱
	md_surround_sound_3_1 = "\uf07f1"
	# CHAR : 󰟲
	md_surround_sound_5_1 = "\uf07f2"
	# CHAR : 󱜪
	md_surround_sound_5_1_2 = "\uf172a"
	# CHAR : 󰟳
	md_surround_sound_7_1 = "\uf07f3"
	# CHAR : 󰜡
	md_svg = "\uf0721"
	# CHAR : 󰓡
	md_swap_horizontal = "\uf04e1"
	# CHAR : 󰯍
	md_swap_horizontal_bold = "\uf0bcd"
	# CHAR : 󰿡
	md_swap_horizontal_circle = "\uf0fe1"
	# CHAR : 󰿢
	md_swap_horizontal_circle_outline = "\uf0fe2"
	# CHAR : 󰣁
	md_swap_horizontal_variant = "\uf08c1"
	# CHAR : 󰓢
	md_swap_vertical = "\uf04e2"
	# CHAR : 󰯎
	md_swap_vertical_bold = "\uf0bce"
	# CHAR : 󰿣
	md_swap_vertical_circle = "\uf0fe3"
	# CHAR : 󰿤
	md_swap_vertical_circle_outline = "\uf0fe4"
	# CHAR : 󰣂
	md_swap_vertical_variant = "\uf08c2"
	# CHAR : 󰓣
	md_swim = "\uf04e3"
	# CHAR : 󰓤
	md_switch = "\uf04e4"
	# CHAR : 󰓥
	md_sword = "\uf04e5"
	# CHAR : 󰞇
	md_sword_cross = "\uf0787"
	# CHAR : 󱌳
	md_syllabary_hangul = "\uf1333"
	# CHAR : 󱌴
	md_syllabary_hiragana = "\uf1334"
	# CHAR : 󱌵
	md_syllabary_katakana = "\uf1335"
	# CHAR : 󱌶
	md_syllabary_katakana_halfwidth = "\uf1336"
	# CHAR : 󱔁
	md_symbol = "\uf1501"
	# CHAR : 󰫦
	md_symfony = "\uf0ae6"
	# CHAR : 󰓦
	md_sync = "\uf04e6"
	# CHAR : 󰓧
	md_sync_alert = "\uf04e7"
	# CHAR : 󱍸
	md_sync_circle = "\uf1378"
	# CHAR : 󰓨
	md_sync_off = "\uf04e8"
	# CHAR : 󰓩
	md_tab = "\uf04e9"
	# CHAR : 󰭋
	md_tab_minus = "\uf0b4b"
	# CHAR : 󰝜
	md_tab_plus = "\uf075c"
	# CHAR : 󰭌
	md_tab_remove = "\uf0b4c"
	# CHAR : 󱦞
	md_tab_search = "\uf199e"
	# CHAR : 󰓪
	md_tab_unselected = "\uf04ea"
	# CHAR : 󰓫
	md_table = "\uf04eb"
	# CHAR : 󱎹
	md_table_account = "\uf13b9"
	# CHAR : 󱎺
	md_table_alert = "\uf13ba"
	# CHAR : 󱎻
	md_table_arrow_down = "\uf13bb"
	# CHAR : 󱎼
	md_table_arrow_left = "\uf13bc"
	# CHAR : 󱎽
	md_table_arrow_right = "\uf13bd"
	# CHAR : 󱎾
	md_table_arrow_up = "\uf13be"
	# CHAR : 󰨘
	md_table_border = "\uf0a18"
	# CHAR : 󱎿
	md_table_cancel = "\uf13bf"
	# CHAR : 󱁡
	md_table_chair = "\uf1061"
	# CHAR : 󱏀
	md_table_check = "\uf13c0"
	# CHAR : 󱏁
	md_table_clock = "\uf13c1"
	# CHAR : 󱏂
	md_table_cog = "\uf13c2"
	# CHAR : 󰠵
	md_table_column = "\uf0835"
	# CHAR : 󰓬
	md_table_column_plus_after = "\uf04ec"
	# CHAR : 󰓭
	md_table_column_plus_before = "\uf04ed"
	# CHAR : 󰓮
	md_table_column_remove = "\uf04ee"
	# CHAR : 󰓯
	md_table_column_width = "\uf04ef"
	# CHAR : 󰓰
	md_table_edit = "\uf04f0"
	# CHAR : 󱂔
	md_table_eye = "\uf1094"
	# CHAR : 󱏃
	md_table_eye_off = "\uf13c3"
	# CHAR : 󰖼
	md_table_furniture = "\uf05bc"
	# CHAR : 󱈝
	md_table_headers_eye = "\uf121d"
	# CHAR : 󱈞
	md_table_headers_eye_off = "\uf121e"
	# CHAR : 󱏄
	md_table_heart = "\uf13c4"
	# CHAR : 󱏅
	md_table_key = "\uf13c5"
	# CHAR : 󰓱
	md_table_large = "\uf04f1"
	# CHAR : 󰾇
	md_table_large_plus = "\uf0f87"
	# CHAR : 󰾈
	md_table_large_remove = "\uf0f88"
	# CHAR : 󱏆
	md_table_lock = "\uf13c6"
	# CHAR : 󰦦
	md_table_merge_cells = "\uf09a6"
	# CHAR : 󱏇
	md_table_minus = "\uf13c7"
	# CHAR : 󱏈
	md_table_multiple = "\uf13c8"
	# CHAR : 󱏉
	md_table_network = "\uf13c9"
	# CHAR : 󰠶
	md_table_of_contents = "\uf0836"
	# CHAR : 󱏊
	md_table_off = "\uf13ca"
	# CHAR : 󱝃
	md_table_picnic = "\uf1743"
	# CHAR : 󱠼
	md_table_pivot = "\uf183c"
	# CHAR : 󰩵
	md_table_plus = "\uf0a75"
	# CHAR : 󱎠
	md_table_refresh = "\uf13a0"
	# CHAR : 󰩶
	md_table_remove = "\uf0a76"
	# CHAR : 󰠷
	md_table_row = "\uf0837"
	# CHAR : 󰓲
	md_table_row_height = "\uf04f2"
	# CHAR : 󰓳
	md_table_row_plus_after = "\uf04f3"
	# CHAR : 󰓴
	md_table_row_plus_before = "\uf04f4"
	# CHAR : 󰓵
	md_table_row_remove = "\uf04f5"
	# CHAR : 󰤏
	md_table_search = "\uf090f"
	# CHAR : 󰠸
	md_table_settings = "\uf0838"
	# CHAR : 󱐪
	md_table_split_cell = "\uf142a"
	# CHAR : 󱏋
	md_table_star = "\uf13cb"
	# CHAR : 󱎡
	md_table_sync = "\uf13a1"
	# CHAR : 󰹨
	md_table_tennis = "\uf0e68"
	# CHAR : 󰓶
	md_tablet = "\uf04f6"
	# CHAR : 󰓷
	md_tablet_android = "\uf04f7"
	# CHAR : 󰦧
	md_tablet_cellphone = "\uf09a7"
	# CHAR : 󰻎
	md_tablet_dashboard = "\uf0ece"
	# CHAR : 󰝢
	md_taco = "\uf0762"
	# CHAR : 󰓹
	md_tag = "\uf04f9"
	# CHAR : 󱜫
	md_tag_arrow_down = "\uf172b"
	# CHAR : 󱜬
	md_tag_arrow_down_outline = "\uf172c"
	# CHAR : 󱜭
	md_tag_arrow_left = "\uf172d"
	# CHAR : 󱜮
	md_tag_arrow_left_outline = "\uf172e"
	# CHAR : 󱜯
	md_tag_arrow_right = "\uf172f"
	# CHAR : 󱜰
	md_tag_arrow_right_outline = "\uf1730"
	# CHAR : 󱜱
	md_tag_arrow_up = "\uf1731"
	# CHAR : 󱜲
	md_tag_arrow_up_outline = "\uf1732"
	# CHAR : 󱩺
	md_tag_check = "\uf1a7a"
	# CHAR : 󱩻
	md_tag_check_outline = "\uf1a7b"
	# CHAR : 󰓺
	md_tag_faces = "\uf04fa"
	# CHAR : 󰚋
	md_tag_heart = "\uf068b"
	# CHAR : 󰯏
	md_tag_heart_outline = "\uf0bcf"
	# CHAR : 󰤐
	md_tag_minus = "\uf0910"
	# CHAR : 󱈟
	md_tag_minus_outline = "\uf121f"
	# CHAR : 󰓻
	md_tag_multiple = "\uf04fb"
	# CHAR : 󱋷
	md_tag_multiple_outline = "\uf12f7"
	# CHAR : 󱈠
	md_tag_off = "\uf1220"
	# CHAR : 󱈡
	md_tag_off_outline = "\uf1221"
	# CHAR : 󰓼
	md_tag_outline = "\uf04fc"
	# CHAR : 󰜢
	md_tag_plus = "\uf0722"
	# CHAR : 󱈢
	md_tag_plus_outline = "\uf1222"
	# CHAR : 󰜣
	md_tag_remove = "\uf0723"
	# CHAR : 󱈣
	md_tag_remove_outline = "\uf1223"
	# CHAR : 󱤇
	md_tag_search = "\uf1907"
	# CHAR : 󱤈
	md_tag_search_outline = "\uf1908"
	# CHAR : 󱈤
	md_tag_text = "\uf1224"
	# CHAR : 󰓽
	md_tag_text_outline = "\uf04fd"
	# CHAR : 󱏿
	md_tailwind = "\uf13ff"
	# CHAR : 󱪼
	md_tally_mark_1 = "\uf1abc"
	# CHAR : 󱪽
	md_tally_mark_2 = "\uf1abd"
	# CHAR : 󱪾
	md_tally_mark_3 = "\uf1abe"
	# CHAR : 󱪿
	md_tally_mark_4 = "\uf1abf"
	# CHAR : 󱫀
	md_tally_mark_5 = "\uf1ac0"
	# CHAR : 󰓸
	md_tangram = "\uf04f8"
	# CHAR : 󰴺
	md_tank = "\uf0d3a"
	# CHAR : 󰿥
	md_tanker_truck = "\uf0fe5"
	# CHAR : 󱛟
	md_tape_drive = "\uf16df"
	# CHAR : 󰭍
	md_tape_measure = "\uf0b4d"
	# CHAR : 󰓾
	md_target = "\uf04fe"
	# CHAR : 󰯐
	md_target_account = "\uf0bd0"
	# CHAR : 󰩷
	md_target_variant = "\uf0a77"
	# CHAR : 󰓿
	md_taxi = "\uf04ff"
	# CHAR : 󰶞
	md_tea = "\uf0d9e"
	# CHAR : 󰶟
	md_tea_outline = "\uf0d9f"
	# CHAR : 󰔀
	md_teamviewer = "\uf0500"
	# CHAR : 󱣻
	md_teddy_bear = "\uf18fb"
	# CHAR : 󰭎
	md_telescope = "\uf0b4e"
	# CHAR : 󰔂
	md_television = "\uf0502"
	# CHAR : 󱍖
	md_television_ambient_light = "\uf1356"
	# CHAR : 󰠹
	md_television_box = "\uf0839"
	# CHAR : 󰟴
	md_television_classic = "\uf07f4"
	# CHAR : 󰠺
	md_television_classic_off = "\uf083a"
	# CHAR : 󰔃
	md_television_guide = "\uf0503"
	# CHAR : 󰠻
	md_television_off = "\uf083b"
	# CHAR : 󰾉
	md_television_pause = "\uf0f89"
	# CHAR : 󰻏
	md_television_play = "\uf0ecf"
	# CHAR : 󱄐
	md_television_shimmer = "\uf1110"
	# CHAR : 󰾊
	md_television_stop = "\uf0f8a"
	# CHAR : 󰔄
	md_temperature_celsius = "\uf0504"
	# CHAR : 󰔅
	md_temperature_fahrenheit = "\uf0505"
	# CHAR : 󰔆
	md_temperature_kelvin = "\uf0506"
	# CHAR : 󰶠
	md_tennis = "\uf0da0"
	# CHAR : 󰔇
	md_tennis_ball = "\uf0507"
	# CHAR : 󰔈
	md_tent = "\uf0508"
	# CHAR : 󱁢
	md_terraform = "\uf1062"
	# CHAR : 󰙨
	md_test_tube = "\uf0668"
	# CHAR : 󰤑
	md_test_tube_empty = "\uf0911"
	# CHAR : 󰤒
	md_test_tube_off = "\uf0912"
	# CHAR : 󰦨
	md_text = "\uf09a8"
	# CHAR : 󱕰
	md_text_account = "\uf1570"
	# CHAR : 󰈚
	md_text_box = "\uf021a"
	# CHAR : 󰺦
	md_text_box_check = "\uf0ea6"
	# CHAR : 󰺧
	md_text_box_check_outline = "\uf0ea7"
	# CHAR : 󱩼
	md_text_box_edit = "\uf1a7c"
	# CHAR : 󱩽
	md_text_box_edit_outline = "\uf1a7d"
	# CHAR : 󰺨
	md_text_box_minus = "\uf0ea8"
	# CHAR : 󰺩
	md_text_box_minus_outline = "\uf0ea9"
	# CHAR : 󰪷
	md_text_box_multiple = "\uf0ab7"
	# CHAR : 󰪸
	md_text_box_multiple_outline = "\uf0ab8"
	# CHAR : 󰧭
	md_text_box_outline = "\uf09ed"
	# CHAR : 󰺪
	md_text_box_plus = "\uf0eaa"
	# CHAR : 󰺫
	md_text_box_plus_outline = "\uf0eab"
	# CHAR : 󰺬
	md_text_box_remove = "\uf0eac"
	# CHAR : 󰺭
	md_text_box_remove_outline = "\uf0ead"
	# CHAR : 󰺮
	md_text_box_search = "\uf0eae"
	# CHAR : 󰺯
	md_text_box_search_outline = "\uf0eaf"
	# CHAR : 󰦪
	md_text_long = "\uf09aa"
	# CHAR : 󱄽
	md_text_recognition = "\uf113d"
	# CHAR : 󱎸
	md_text_search = "\uf13b8"
	# CHAR : 󱩾
	md_text_search_variant = "\uf1a7e"
	# CHAR : 󰙩
	md_text_shadow = "\uf0669"
	# CHAR : 󰦩
	md_text_short = "\uf09a9"
	# CHAR : 󰔊
	md_text_to_speech = "\uf050a"
	# CHAR : 󰔋
	md_text_to_speech_off = "\uf050b"
	# CHAR : 󰔌
	md_texture = "\uf050c"
	# CHAR : 󰿦
	md_texture_box = "\uf0fe6"
	# CHAR : 󰔍
	md_theater = "\uf050d"
	# CHAR : 󰔎
	md_theme_light_dark = "\uf050e"
	# CHAR : 󰔏
	md_thermometer = "\uf050f"
	# CHAR : 󰸁
	md_thermometer_alert = "\uf0e01"
	# CHAR : 󱢕
	md_thermometer_bluetooth = "\uf1895"
	# CHAR : 󱩿
	md_thermometer_check = "\uf1a7f"
	# CHAR : 󰸂
	md_thermometer_chevron_down = "\uf0e02"
	# CHAR : 󰸃
	md_thermometer_chevron_up = "\uf0e03"
	# CHAR : 󱃂
	md_thermometer_high = "\uf10c2"
	# CHAR : 󰔐
	md_thermometer_lines = "\uf0510"
	# CHAR : 󱃃
	md_thermometer_low = "\uf10c3"
	# CHAR : 󰸄
	md_thermometer_minus = "\uf0e04"
	# CHAR : 󱔱
	md_thermometer_off = "\uf1531"
	# CHAR : 󰸅
	md_thermometer_plus = "\uf0e05"
	# CHAR : 󱪀
	md_thermometer_water = "\uf1a80"
	# CHAR : 󰎓
	md_thermostat = "\uf0393"
	# CHAR : 󰢑
	md_thermostat_box = "\uf0891"
	# CHAR : 󰟶
	md_thought_bubble = "\uf07f6"
	# CHAR : 󰟷
	md_thought_bubble_outline = "\uf07f7"
	# CHAR : 󰔑
	md_thumb_down = "\uf0511"
	# CHAR : 󰔒
	md_thumb_down_outline = "\uf0512"
	# CHAR : 󰔓
	md_thumb_up = "\uf0513"
	# CHAR : 󰔔
	md_thumb_up_outline = "\uf0514"
	# CHAR : 󰔕
	md_thumbs_up_down = "\uf0515"
	# CHAR : 󱤔
	md_thumbs_up_down_outline = "\uf1914"
	# CHAR : 󰔖
	md_ticket = "\uf0516"
	# CHAR : 󰔗
	md_ticket_account = "\uf0517"
	# CHAR : 󰔘
	md_ticket_confirmation = "\uf0518"
	# CHAR : 󱎪
	md_ticket_confirmation_outline = "\uf13aa"
	# CHAR : 󰤓
	md_ticket_outline = "\uf0913"
	# CHAR : 󰜤
	md_ticket_percent = "\uf0724"
	# CHAR : 󱐫
	md_ticket_percent_outline = "\uf142b"
	# CHAR : 󰔙
	md_tie = "\uf0519"
	# CHAR : 󰜥
	md_tilde = "\uf0725"
	# CHAR : 󱣳
	md_tilde_off = "\uf18f3"
	# CHAR : 󰔚
	md_timelapse = "\uf051a"
	# CHAR : 󰯑
	md_timeline = "\uf0bd1"
	# CHAR : 󰾕
	md_timeline_alert = "\uf0f95"
	# CHAR : 󰾘
	md_timeline_alert_outline = "\uf0f98"
	# CHAR : 󱔲
	md_timeline_check = "\uf1532"
	# CHAR : 󱔳
	md_timeline_check_outline = "\uf1533"
	# CHAR : 󱇻
	md_timeline_clock = "\uf11fb"
	# CHAR : 󱇼
	md_timeline_clock_outline = "\uf11fc"
	# CHAR : 󰾙
	md_timeline_help = "\uf0f99"
	# CHAR : 󰾚
	md_timeline_help_outline = "\uf0f9a"
	# CHAR : 󱔴
	md_timeline_minus = "\uf1534"
	# CHAR : 󱔵
	md_timeline_minus_outline = "\uf1535"
	# CHAR : 󰯒
	md_timeline_outline = "\uf0bd2"
	# CHAR : 󰾖
	md_timeline_plus = "\uf0f96"
	# CHAR : 󰾗
	md_timeline_plus_outline = "\uf0f97"
	# CHAR : 󱔶
	md_timeline_remove = "\uf1536"
	# CHAR : 󱔷
	md_timeline_remove_outline = "\uf1537"
	# CHAR : 󰯓
	md_timeline_text = "\uf0bd3"
	# CHAR : 󰯔
	md_timeline_text_outline = "\uf0bd4"
	# CHAR : 󱎫
	md_timer = "\uf13ab"
	# CHAR : 󰔜
	md_timer_10 = "\uf051c"
	# CHAR : 󰔝
	md_timer_3 = "\uf051d"
	# CHAR : 󱫌
	md_timer_alert = "\uf1acc"
	# CHAR : 󱫍
	md_timer_alert_outline = "\uf1acd"
	# CHAR : 󱫎
	md_timer_cancel = "\uf1ace"
	# CHAR : 󱫏
	md_timer_cancel_outline = "\uf1acf"
	# CHAR : 󱫐
	md_timer_check = "\uf1ad0"
	# CHAR : 󱫑
	md_timer_check_outline = "\uf1ad1"
	# CHAR : 󱤥
	md_timer_cog = "\uf1925"
	# CHAR : 󱤦
	md_timer_cog_outline = "\uf1926"
	# CHAR : 󱫒
	md_timer_edit = "\uf1ad2"
	# CHAR : 󱫓
	md_timer_edit_outline = "\uf1ad3"
	# CHAR : 󱫔
	md_timer_lock = "\uf1ad4"
	# CHAR : 󱫕
	md_timer_lock_open = "\uf1ad5"
	# CHAR : 󱫖
	md_timer_lock_open_outline = "\uf1ad6"
	# CHAR : 󱫗
	md_timer_lock_outline = "\uf1ad7"
	# CHAR : 󱫘
	md_timer_marker = "\uf1ad8"
	# CHAR : 󱫙
	md_timer_marker_outline = "\uf1ad9"
	# CHAR : 󱫚
	md_timer_minus = "\uf1ada"
	# CHAR : 󱫛
	md_timer_minus_outline = "\uf1adb"
	# CHAR : 󱫜
	md_timer_music = "\uf1adc"
	# CHAR : 󱫝
	md_timer_music_outline = "\uf1add"
	# CHAR : 󱎬
	md_timer_off = "\uf13ac"
	# CHAR : 󰔞
	md_timer_off_outline = "\uf051e"
	# CHAR : 󰔛
	md_timer_outline = "\uf051b"
	# CHAR : 󱫞
	md_timer_pause = "\uf1ade"
	# CHAR : 󱫟
	md_timer_pause_outline = "\uf1adf"
	# CHAR : 󱫠
	md_timer_play = "\uf1ae0"
	# CHAR : 󱫡
	md_timer_play_outline = "\uf1ae1"
	# CHAR : 󱫢
	md_timer_plus = "\uf1ae2"
	# CHAR : 󱫣
	md_timer_plus_outline = "\uf1ae3"
	# CHAR : 󱫤
	md_timer_refresh = "\uf1ae4"
	# CHAR : 󱫥
	md_timer_refresh_outline = "\uf1ae5"
	# CHAR : 󱫦
	md_timer_remove = "\uf1ae6"
	# CHAR : 󱫧
	md_timer_remove_outline = "\uf1ae7"
	# CHAR : 󰔟
	md_timer_sand = "\uf051f"
	# CHAR : 󱦟
	md_timer_sand_complete = "\uf199f"
	# CHAR : 󰚭
	md_timer_sand_empty = "\uf06ad"
	# CHAR : 󰞌
	md_timer_sand_full = "\uf078c"
	# CHAR : 󱦠
	md_timer_sand_paused = "\uf19a0"
	# CHAR : 󱤣
	md_timer_settings = "\uf1923"
	# CHAR : 󱤤
	md_timer_settings_outline = "\uf1924"
	# CHAR : 󱫨
	md_timer_star = "\uf1ae8"
	# CHAR : 󱫩
	md_timer_star_outline = "\uf1ae9"
	# CHAR : 󱫪
	md_timer_stop = "\uf1aea"
	# CHAR : 󱫫
	md_timer_stop_outline = "\uf1aeb"
	# CHAR : 󱫬
	md_timer_sync = "\uf1aec"
	# CHAR : 󱫭
	md_timer_sync_outline = "\uf1aed"
	# CHAR : 󰔠
	md_timetable = "\uf0520"
	# CHAR : 󱢖
	md_tire = "\uf1896"
	# CHAR : 󱁣
	md_toaster = "\uf1063"
	# CHAR : 󱆷
	md_toaster_off = "\uf11b7"
	# CHAR : 󰳓
	md_toaster_oven = "\uf0cd3"
	# CHAR : 󰔡
	md_toggle_switch = "\uf0521"
	# CHAR : 󰔢
	md_toggle_switch_off = "\uf0522"
	# CHAR : 󰨙
	md_toggle_switch_off_outline = "\uf0a19"
	# CHAR : 󰨚
	md_toggle_switch_outline = "\uf0a1a"
	# CHAR : 󱨥
	md_toggle_switch_variant = "\uf1a25"
	# CHAR : 󱨦
	md_toggle_switch_variant_off = "\uf1a26"
	# CHAR : 󰦫
	md_toilet = "\uf09ab"
	# CHAR : 󰦬
	md_toolbox = "\uf09ac"
	# CHAR : 󰦭
	md_toolbox_outline = "\uf09ad"
	# CHAR : 󱁤
	md_tools = "\uf1064"
	# CHAR : 󰔣
	md_tooltip = "\uf0523"
	# CHAR : 󰀌
	md_tooltip_account = "\uf000c"
	# CHAR : 󱠻
	md_tooltip_cellphone = "\uf183b"
	# CHAR : 󱕜
	md_tooltip_check = "\uf155c"
	# CHAR : 󱕝
	md_tooltip_check_outline = "\uf155d"
	# CHAR : 󰔤
	md_tooltip_edit = "\uf0524"
	# CHAR : 󱋅
	md_tooltip_edit_outline = "\uf12c5"
	# CHAR : 󰔥
	md_tooltip_image = "\uf0525"
	# CHAR : 󰯕
	md_tooltip_image_outline = "\uf0bd5"
	# CHAR : 󱕞
	md_tooltip_minus = "\uf155e"
	# CHAR : 󱕟
	md_tooltip_minus_outline = "\uf155f"
	# CHAR : 󰔦
	md_tooltip_outline = "\uf0526"
	# CHAR : 󰯖
	md_tooltip_plus = "\uf0bd6"
	# CHAR : 󰔧
	md_tooltip_plus_outline = "\uf0527"
	# CHAR : 󱕠
	md_tooltip_remove = "\uf1560"
	# CHAR : 󱕡
	md_tooltip_remove_outline = "\uf1561"
	# CHAR : 󰔨
	md_tooltip_text = "\uf0528"
	# CHAR : 󰯗
	md_tooltip_text_outline = "\uf0bd7"
	# CHAR : 󰣃
	md_tooth = "\uf08c3"
	# CHAR : 󰔩
	md_tooth_outline = "\uf0529"
	# CHAR : 󱄩
	md_toothbrush = "\uf1129"
	# CHAR : 󱄬
	md_toothbrush_electric = "\uf112c"
	# CHAR : 󱄪
	md_toothbrush_paste = "\uf112a"
	# CHAR : 󱘆
	md_torch = "\uf1606"
	# CHAR : 󰴻
	md_tortoise = "\uf0d3b"
	# CHAR : 󱊸
	md_toslink = "\uf12b8"
	# CHAR : 󰦮
	md_tournament = "\uf09ae"
	# CHAR : 󰠼
	md_tow_truck = "\uf083c"
	# CHAR : 󰚁
	md_tower_beach = "\uf0681"
	# CHAR : 󰚂
	md_tower_fire = "\uf0682"
	# CHAR : 󱡵
	md_town_hall = "\uf1875"
	# CHAR : 󱊈
	md_toy_brick = "\uf1288"
	# CHAR : 󱊉
	md_toy_brick_marker = "\uf1289"
	# CHAR : 󱊊
	md_toy_brick_marker_outline = "\uf128a"
	# CHAR : 󱊋
	md_toy_brick_minus = "\uf128b"
	# CHAR : 󱊌
	md_toy_brick_minus_outline = "\uf128c"
	# CHAR : 󱊍
	md_toy_brick_outline = "\uf128d"
	# CHAR : 󱊎
	md_toy_brick_plus = "\uf128e"
	# CHAR : 󱊏
	md_toy_brick_plus_outline = "\uf128f"
	# CHAR : 󱊐
	md_toy_brick_remove = "\uf1290"
	# CHAR : 󱊑
	md_toy_brick_remove_outline = "\uf1291"
	# CHAR : 󱊒
	md_toy_brick_search = "\uf1292"
	# CHAR : 󱊓
	md_toy_brick_search_outline = "\uf1293"
	# CHAR : 󰤔
	md_track_light = "\uf0914"
	# CHAR : 󰟸
	md_trackpad = "\uf07f8"
	# CHAR : 󰤳
	md_trackpad_lock = "\uf0933"
	# CHAR : 󰢒
	md_tractor = "\uf0892"
	# CHAR : 󱓄
	md_tractor_variant = "\uf14c4"
	# CHAR : 󰩸
	md_trademark = "\uf0a78"
	# CHAR : 󱍼
	md_traffic_cone = "\uf137c"
	# CHAR : 󰔫
	md_traffic_light = "\uf052b"
	# CHAR : 󱠪
	md_traffic_light_outline = "\uf182a"
	# CHAR : 󰔬
	md_train = "\uf052c"
	# CHAR : 󰯘
	md_train_car = "\uf0bd8"
	# CHAR : 󱜳
	md_train_car_passenger = "\uf1733"
	# CHAR : 󱜴
	md_train_car_passenger_door = "\uf1734"
	# CHAR : 󱜵
	md_train_car_passenger_door_open = "\uf1735"
	# CHAR : 󱜶
	md_train_car_passenger_variant = "\uf1736"
	# CHAR : 󰣄
	md_train_variant = "\uf08c4"
	# CHAR : 󰔭
	md_tram = "\uf052d"
	# CHAR : 󰿧
	md_tram_side = "\uf0fe7"
	# CHAR : 󰔮
	md_transcribe = "\uf052e"
	# CHAR : 󰔯
	md_transcribe_close = "\uf052f"
	# CHAR : 󱁥
	md_transfer = "\uf1065"
	# CHAR : 󰶡
	md_transfer_down = "\uf0da1"
	# CHAR : 󰶢
	md_transfer_left = "\uf0da2"
	# CHAR : 󰔰
	md_transfer_right = "\uf0530"
	# CHAR : 󰶣
	md_transfer_up = "\uf0da3"
	# CHAR : 󰴼
	md_transit_connection = "\uf0d3c"
	# CHAR : 󱕆
	md_transit_connection_horizontal = "\uf1546"
	# CHAR : 󰴽
	md_transit_connection_variant = "\uf0d3d"
	# CHAR : 󰾋
	md_transit_detour = "\uf0f8b"
	# CHAR : 󱔕
	md_transit_skip = "\uf1515"
	# CHAR : 󰚮
	md_transit_transfer = "\uf06ae"
	# CHAR : 󰤕
	md_transition = "\uf0915"
	# CHAR : 󰤖
	md_transition_masked = "\uf0916"
	# CHAR : 󰗊
	md_translate = "\uf05ca"
	# CHAR : 󰸆
	md_translate_off = "\uf0e06"
	# CHAR : 󰴾
	md_transmission_tower = "\uf0d3e"
	# CHAR : 󱤬
	md_transmission_tower_export = "\uf192c"
	# CHAR : 󱤭
	md_transmission_tower_import = "\uf192d"
	# CHAR : 󱧝
	md_transmission_tower_off = "\uf19dd"
	# CHAR : 󰩹
	md_trash_can = "\uf0a79"
	# CHAR : 󰩺
	md_trash_can_outline = "\uf0a7a"
	# CHAR : 󱊔
	md_tray = "\uf1294"
	# CHAR : 󱊕
	md_tray_alert = "\uf1295"
	# CHAR : 󰄠
	md_tray_arrow_down = "\uf0120"
	# CHAR : 󰄝
	md_tray_arrow_up = "\uf011d"
	# CHAR : 󱊖
	md_tray_full = "\uf1296"
	# CHAR : 󱊗
	md_tray_minus = "\uf1297"
	# CHAR : 󱊘
	md_tray_plus = "\uf1298"
	# CHAR : 󱊙
	md_tray_remove = "\uf1299"
	# CHAR : 󰜦
	md_treasure_chest = "\uf0726"
	# CHAR : 󰔱
	md_tree = "\uf0531"
	# CHAR : 󰹩
	md_tree_outline = "\uf0e69"
	# CHAR : 󰔲
	md_trello = "\uf0532"
	# CHAR : 󰔳
	md_trending_down = "\uf0533"
	# CHAR : 󰔴
	md_trending_neutral = "\uf0534"
	# CHAR : 󰔵
	md_trending_up = "\uf0535"
	# CHAR : 󰔶
	md_triangle = "\uf0536"
	# CHAR : 󰔷
	md_triangle_outline = "\uf0537"
	# CHAR : 󱨉
	md_triangle_small_down = "\uf1a09"
	# CHAR : 󱨊
	md_triangle_small_up = "\uf1a0a"
	# CHAR : 󱑼
	md_triangle_wave = "\uf147c"
	# CHAR : 󰯙
	md_triforce = "\uf0bd9"
	# CHAR : 󰔸
	md_trophy = "\uf0538"
	# CHAR : 󰔹
	md_trophy_award = "\uf0539"
	# CHAR : 󰶤
	md_trophy_broken = "\uf0da4"
	# CHAR : 󰔺
	md_trophy_outline = "\uf053a"
	# CHAR : 󰔻
	md_trophy_variant = "\uf053b"
	# CHAR : 󰔼
	md_trophy_variant_outline = "\uf053c"
	# CHAR : 󰔽
	md_truck = "\uf053d"
	# CHAR : 󱧞
	md_truck_alert = "\uf19de"
	# CHAR : 󱧟
	md_truck_alert_outline = "\uf19df"
	# CHAR : 󱣘
	md_truck_cargo_container = "\uf18d8"
	# CHAR : 󰳔
	md_truck_check = "\uf0cd4"
	# CHAR : 󱊚
	md_truck_check_outline = "\uf129a"
	# CHAR : 󰔾
	md_truck_delivery = "\uf053e"
	# CHAR : 󱊛
	md_truck_delivery_outline = "\uf129b"
	# CHAR : 󰞈
	md_truck_fast = "\uf0788"
	# CHAR : 󱊜
	md_truck_fast_outline = "\uf129c"
	# CHAR : 󱢑
	md_truck_flatbed = "\uf1891"
	# CHAR : 󱦮
	md_truck_minus = "\uf19ae"
	# CHAR : 󱦽
	md_truck_minus_outline = "\uf19bd"
	# CHAR : 󱊝
	md_truck_outline = "\uf129d"
	# CHAR : 󱦭
	md_truck_plus = "\uf19ad"
	# CHAR : 󱦼
	md_truck_plus_outline = "\uf19bc"
	# CHAR : 󱦯
	md_truck_remove = "\uf19af"
	# CHAR : 󱦾
	md_truck_remove_outline = "\uf19be"
	# CHAR : 󱦦
	md_truck_snowflake = "\uf19a6"
	# CHAR : 󰜧
	md_truck_trailer = "\uf0727"
	# CHAR : 󱂖
	md_trumpet = "\uf1096"
	# CHAR : 󰩻
	md_tshirt_crew = "\uf0a7b"
	# CHAR : 󰔿
	md_tshirt_crew_outline = "\uf053f"
	# CHAR : 󰩼
	md_tshirt_v = "\uf0a7c"
	# CHAR : 󰕀
	md_tshirt_v_outline = "\uf0540"
	# CHAR : 󱪁
	md_tsunami = "\uf1a81"
	# CHAR : 󰤗
	md_tumble_dryer = "\uf0917"
	# CHAR : 󱆺
	md_tumble_dryer_alert = "\uf11ba"
	# CHAR : 󱆻
	md_tumble_dryer_off = "\uf11bb"
	# CHAR : 󰘮
	md_tune = "\uf062e"
	# CHAR : 󱕂
	md_tune_variant = "\uf1542"
	# CHAR : 󰙪
	md_tune_vertical = "\uf066a"
	# CHAR : 󱕃
	md_tune_vertical_variant = "\uf1543"
	# CHAR : 󱠽
	md_tunnel = "\uf183d"
	# CHAR : 󱠾
	md_tunnel_outline = "\uf183e"
	# CHAR : 󱪂
	md_turbine = "\uf1a82"
	# CHAR : 󱜛
	md_turkey = "\uf171b"
	# CHAR : 󰳕
	md_turnstile = "\uf0cd5"
	# CHAR : 󰳖
	md_turnstile_outline = "\uf0cd6"
	# CHAR : 󰳗
	md_turtle = "\uf0cd7"
	# CHAR : 󰕃
	md_twitch = "\uf0543"
	# CHAR : 󰕄
	md_twitter = "\uf0544"
	# CHAR : 󰦯
	md_two_factor_authentication = "\uf09af"
	# CHAR : 󰼭
	md_typewriter = "\uf0f2d"
	# CHAR : 󰯚
	md_ubisoft = "\uf0bda"
	# CHAR : 󰕈
	md_ubuntu = "\uf0548"
	# CHAR : 󱃄
	md_ufo = "\uf10c4"
	# CHAR : 󱃅
	md_ufo_outline = "\uf10c5"
	# CHAR : 󰟹
	md_ultra_high_definition = "\uf07f9"
	# CHAR : 󰕉
	md_umbraco = "\uf0549"
	# CHAR : 󰕊
	md_umbrella = "\uf054a"
	# CHAR : 󱢊
	md_umbrella_beach = "\uf188a"
	# CHAR : 󱢋
	md_umbrella_beach_outline = "\uf188b"
	# CHAR : 󰦰
	md_umbrella_closed = "\uf09b0"
	# CHAR : 󱏢
	md_umbrella_closed_outline = "\uf13e2"
	# CHAR : 󱏡
	md_umbrella_closed_variant = "\uf13e1"
	# CHAR : 󰕋
	md_umbrella_outline = "\uf054b"
	# CHAR : 󰕌
	md_undo = "\uf054c"
	# CHAR : 󰕍
	md_undo_variant = "\uf054d"
	# CHAR : 󰕎
	md_unfold_less_horizontal = "\uf054e"
	# CHAR : 󰝠
	md_unfold_less_vertical = "\uf0760"
	# CHAR : 󰕏
	md_unfold_more_horizontal = "\uf054f"
	# CHAR : 󰝡
	md_unfold_more_vertical = "\uf0761"
	# CHAR : 󰕐
	md_ungroup = "\uf0550"
	# CHAR : 󰻐
	md_unicode = "\uf0ed0"
	# CHAR : 󱗂
	md_unicorn = "\uf15c2"
	# CHAR : 󱗃
	md_unicorn_variant = "\uf15c3"
	# CHAR : 󱗥
	md_unicycle = "\uf15e5"
	# CHAR : 󰚯
	md_unity = "\uf06af"
	# CHAR : 󰦱
	md_unreal = "\uf09b1"
	# CHAR : 󰚰
	md_update = "\uf06b0"
	# CHAR : 󰕒
	md_upload = "\uf0552"
	# CHAR : 󱍳
	md_upload_lock = "\uf1373"
	# CHAR : 󱍴
	md_upload_lock_outline = "\uf1374"
	# CHAR : 󰠽
	md_upload_multiple = "\uf083d"
	# CHAR : 󰛶
	md_upload_network = "\uf06f6"
	# CHAR : 󰳘
	md_upload_network_outline = "\uf0cd8"
	# CHAR : 󱃆
	md_upload_off = "\uf10c6"
	# CHAR : 󱃇
	md_upload_off_outline = "\uf10c7"
	# CHAR : 󰸇
	md_upload_outline = "\uf0e07"
	# CHAR : 󰕓
	md_usb = "\uf0553"
	# CHAR : 󱊞
	md_usb_flash_drive = "\uf129e"
	# CHAR : 󱊟
	md_usb_flash_drive_outline = "\uf129f"
	# CHAR : 󱇰
	md_usb_port = "\uf11f0"
	# CHAR : 󱦡
	md_vacuum = "\uf19a1"
	# CHAR : 󱦢
	md_vacuum_outline = "\uf19a2"
	# CHAR : 󱁦
	md_valve = "\uf1066"
	# CHAR : 󱁧
	md_valve_closed = "\uf1067"
	# CHAR : 󱁨
	md_valve_open = "\uf1068"
	# CHAR : 󰟺
	md_van_passenger = "\uf07fa"
	# CHAR : 󰟻
	md_van_utility = "\uf07fb"
	# CHAR : 󰟼
	md_vanish = "\uf07fc"
	# CHAR : 󱕔
	md_vanish_quarter = "\uf1554"
	# CHAR : 󱇡
	md_vanity_light = "\uf11e1"
	# CHAR : 󰫧
	md_variable = "\uf0ae7"
	# CHAR : 󱄑
	md_variable_box = "\uf1111"
	# CHAR : 󰕔
	md_vector_arrange_above = "\uf0554"
	# CHAR : 󰕕
	md_vector_arrange_below = "\uf0555"
	# CHAR : 󰫨
	md_vector_bezier = "\uf0ae8"
	# CHAR : 󰕖
	md_vector_circle = "\uf0556"
	# CHAR : 󰕗
	md_vector_circle_variant = "\uf0557"
	# CHAR : 󰕘
	md_vector_combine = "\uf0558"
	# CHAR : 󰕙
	md_vector_curve = "\uf0559"
	# CHAR : 󰕚
	md_vector_difference = "\uf055a"
	# CHAR : 󰕛
	md_vector_difference_ab = "\uf055b"
	# CHAR : 󰕜
	md_vector_difference_ba = "\uf055c"
	# CHAR : 󰢓
	md_vector_ellipse = "\uf0893"
	# CHAR : 󰕝
	md_vector_intersection = "\uf055d"
	# CHAR : 󰕞
	md_vector_line = "\uf055e"
	# CHAR : 󰿨
	md_vector_link = "\uf0fe8"
	# CHAR : 󰕟
	md_vector_point = "\uf055f"
	# CHAR : 󰕠
	md_vector_polygon = "\uf0560"
	# CHAR : 󱡖
	md_vector_polygon_variant = "\uf1856"
	# CHAR : 󰕡
	md_vector_polyline = "\uf0561"
	# CHAR : 󱈥
	md_vector_polyline_edit = "\uf1225"
	# CHAR : 󱈦
	md_vector_polyline_minus = "\uf1226"
	# CHAR : 󱈧
	md_vector_polyline_plus = "\uf1227"
	# CHAR : 󱈨
	md_vector_polyline_remove = "\uf1228"
	# CHAR : 󰝊
	md_vector_radius = "\uf074a"
	# CHAR : 󰗆
	md_vector_rectangle = "\uf05c6"
	# CHAR : 󰕢
	md_vector_selection = "\uf0562"
	# CHAR : 󰀁
	md_vector_square = "\uf0001"
	# CHAR : 󱡗
	md_vector_square_close = "\uf1857"
	# CHAR : 󱣙
	md_vector_square_edit = "\uf18d9"
	# CHAR : 󱣚
	md_vector_square_minus = "\uf18da"
	# CHAR : 󱡘
	md_vector_square_open = "\uf1858"
	# CHAR : 󱣛
	md_vector_square_plus = "\uf18db"
	# CHAR : 󱣜
	md_vector_square_remove = "\uf18dc"
	# CHAR : 󰕣
	md_vector_triangle = "\uf0563"
	# CHAR : 󰕤
	md_vector_union = "\uf0564"
	# CHAR : 󰨛
	md_vhs = "\uf0a1b"
	# CHAR : 󰕦
	md_vibrate = "\uf0566"
	# CHAR : 󰳙
	md_vibrate_off = "\uf0cd9"
	# CHAR : 󰕧
	md_video = "\uf0567"
	# CHAR : 󱨜
	md_video_2d = "\uf1a1c"
	# CHAR : 󰟽
	md_video_3d = "\uf07fd"
	# CHAR : 󱏙
	md_video_3d_off = "\uf13d9"
	# CHAR : 󰻑
	md_video_3d_variant = "\uf0ed1"
	# CHAR : 󰠾
	md_video_4k_box = "\uf083e"
	# CHAR : 󰤙
	md_video_account = "\uf0919"
	# CHAR : 󰃽
	md_video_box = "\uf00fd"
	# CHAR : 󰃾
	md_video_box_off = "\uf00fe"
	# CHAR : 󱁩
	md_video_check = "\uf1069"
	# CHAR : 󱁪
	md_video_check_outline = "\uf106a"
	# CHAR : 󱔮
	md_video_high_definition = "\uf152e"
	# CHAR : 󰤚
	md_video_image = "\uf091a"
	# CHAR : 󰠿
	md_video_input_antenna = "\uf083f"
	# CHAR : 󰡀
	md_video_input_component = "\uf0840"
	# CHAR : 󰡁
	md_video_input_hdmi = "\uf0841"
	# CHAR : 󰾌
	md_video_input_scart = "\uf0f8c"
	# CHAR : 󰡂
	md_video_input_svideo = "\uf0842"
	# CHAR : 󱦩
	md_video_marker = "\uf19a9"
	# CHAR : 󱦪
	md_video_marker_outline = "\uf19aa"
	# CHAR : 󰦲
	md_video_minus = "\uf09b2"
	# CHAR : 󰊺
	md_video_minus_outline = "\uf02ba"
	# CHAR : 󰕨
	md_video_off = "\uf0568"
	# CHAR : 󰯛
	md_video_off_outline = "\uf0bdb"
	# CHAR : 󰯜
	md_video_outline = "\uf0bdc"
	# CHAR : 󰦳
	md_video_plus = "\uf09b3"
	# CHAR : 󰇓
	md_video_plus_outline = "\uf01d3"
	# CHAR : 󰤛
	md_video_stabilization = "\uf091b"
	# CHAR : 󰕩
	md_video_switch = "\uf0569"
	# CHAR : 󰞐
	md_video_switch_outline = "\uf0790"
	# CHAR : 󰨜
	md_video_vintage = "\uf0a1c"
	# CHAR : 󰻒
	md_video_wireless = "\uf0ed2"
	# CHAR : 󰻓
	md_video_wireless_outline = "\uf0ed3"
	# CHAR : 󰕪
	md_view_agenda = "\uf056a"
	# CHAR : 󱇘
	md_view_agenda_outline = "\uf11d8"
	# CHAR : 󰕫
	md_view_array = "\uf056b"
	# CHAR : 󱒅
	md_view_array_outline = "\uf1485"
	# CHAR : 󰕬
	md_view_carousel = "\uf056c"
	# CHAR : 󱒆
	md_view_carousel_outline = "\uf1486"
	# CHAR : 󰕭
	md_view_column = "\uf056d"
	# CHAR : 󱒇
	md_view_column_outline = "\uf1487"
	# CHAR : 󰹪
	md_view_comfy = "\uf0e6a"
	# CHAR : 󱒈
	md_view_comfy_outline = "\uf1488"
	# CHAR : 󰹫
	md_view_compact = "\uf0e6b"
	# CHAR : 󰹬
	md_view_compact_outline = "\uf0e6c"
	# CHAR : 󰕮
	md_view_dashboard = "\uf056e"
	# CHAR : 󱥇
	md_view_dashboard_edit = "\uf1947"
	# CHAR : 󱥈
	md_view_dashboard_edit_outline = "\uf1948"
	# CHAR : 󰨝
	md_view_dashboard_outline = "\uf0a1d"
	# CHAR : 󰡃
	md_view_dashboard_variant = "\uf0843"
	# CHAR : 󱒉
	md_view_dashboard_variant_outline = "\uf1489"
	# CHAR : 󰕯
	md_view_day = "\uf056f"
	# CHAR : 󱒊
	md_view_day_outline = "\uf148a"
	# CHAR : 󱢈
	md_view_gallery = "\uf1888"
	# CHAR : 󱢉
	md_view_gallery_outline = "\uf1889"
	# CHAR : 󰕰
	md_view_grid = "\uf0570"
	# CHAR : 󱇙
	md_view_grid_outline = "\uf11d9"
	# CHAR : 󰾍
	md_view_grid_plus = "\uf0f8d"
	# CHAR : 󱇚
	md_view_grid_plus_outline = "\uf11da"
	# CHAR : 󰕱
	md_view_headline = "\uf0571"
	# CHAR : 󰕲
	md_view_list = "\uf0572"
	# CHAR : 󱒋
	md_view_list_outline = "\uf148b"
	# CHAR : 󰕳
	md_view_module = "\uf0573"
	# CHAR : 󱒌
	md_view_module_outline = "\uf148c"
	# CHAR : 󰜨
	md_view_parallel = "\uf0728"
	# CHAR : 󱒍
	md_view_parallel_outline = "\uf148d"
	# CHAR : 󰕴
	md_view_quilt = "\uf0574"
	# CHAR : 󱒎
	md_view_quilt_outline = "\uf148e"
	# CHAR : 󰜩
	md_view_sequential = "\uf0729"
	# CHAR : 󱒏
	md_view_sequential_outline = "\uf148f"
	# CHAR : 󰯋
	md_view_split_horizontal = "\uf0bcb"
	# CHAR : 󰯌
	md_view_split_vertical = "\uf0bcc"
	# CHAR : 󰕵
	md_view_stream = "\uf0575"
	# CHAR : 󱒐
	md_view_stream_outline = "\uf1490"
	# CHAR : 󰕶
	md_view_week = "\uf0576"
	# CHAR : 󱒑
	md_view_week_outline = "\uf1491"
	# CHAR : 󰕷
	md_vimeo = "\uf0577"
	# CHAR : 󰘏
	md_violin = "\uf060f"
	# CHAR : 󰢔
	md_virtual_reality = "\uf0894"
	# CHAR : 󱎶
	md_virus = "\uf13b6"
	# CHAR : 󱣡
	md_virus_off = "\uf18e1"
	# CHAR : 󱣢
	md_virus_off_outline = "\uf18e2"
	# CHAR : 󱎷
	md_virus_outline = "\uf13b7"
	# CHAR : 󰕼
	md_vlc = "\uf057c"
	# CHAR : 󰕽
	md_voicemail = "\uf057d"
	# CHAR : 󱪃
	md_volcano = "\uf1a83"
	# CHAR : 󱪄
	md_volcano_outline = "\uf1a84"
	# CHAR : 󰦴
	md_volleyball = "\uf09b4"
	# CHAR : 󰕾
	md_volume_high = "\uf057e"
	# CHAR : 󰕿
	md_volume_low = "\uf057f"
	# CHAR : 󰖀
	md_volume_medium = "\uf0580"
	# CHAR : 󰝞
	md_volume_minus = "\uf075e"
	# CHAR : 󰝟
	md_volume_mute = "\uf075f"
	# CHAR : 󰖁
	md_volume_off = "\uf0581"
	# CHAR : 󰝝
	md_volume_plus = "\uf075d"
	# CHAR : 󱄠
	md_volume_source = "\uf1120"
	# CHAR : 󰸈
	md_volume_variant_off = "\uf0e08"
	# CHAR : 󱄡
	md_volume_vibrate = "\uf1121"
	# CHAR : 󰨟
	md_vote = "\uf0a1f"
	# CHAR : 󰨠
	md_vote_outline = "\uf0a20"
	# CHAR : 󰖂
	md_vpn = "\uf0582"
	# CHAR : 󰡄
	md_vuejs = "\uf0844"
	# CHAR : 󰹭
	md_vuetify = "\uf0e6d"
	# CHAR : 󰖃
	md_walk = "\uf0583"
	# CHAR : 󰟾
	md_wall = "\uf07fe"
	# CHAR : 󱨑
	md_wall_fire = "\uf1a11"
	# CHAR : 󰤜
	md_wall_sconce = "\uf091c"
	# CHAR : 󰤝
	md_wall_sconce_flat = "\uf091d"
	# CHAR : 󱟉
	md_wall_sconce_flat_outline = "\uf17c9"
	# CHAR : 󰐜
	md_wall_sconce_flat_variant = "\uf041c"
	# CHAR : 󱟊
	md_wall_sconce_flat_variant_outline = "\uf17ca"
	# CHAR : 󱟋
	md_wall_sconce_outline = "\uf17cb"
	# CHAR : 󰝈
	md_wall_sconce_round = "\uf0748"
	# CHAR : 󱟌
	md_wall_sconce_round_outline = "\uf17cc"
	# CHAR : 󰤞
	md_wall_sconce_round_variant = "\uf091e"
	# CHAR : 󱟍
	md_wall_sconce_round_variant_outline = "\uf17cd"
	# CHAR : 󰖄
	md_wallet = "\uf0584"
	# CHAR : 󰖅
	md_wallet_giftcard = "\uf0585"
	# CHAR : 󰖆
	md_wallet_membership = "\uf0586"
	# CHAR : 󰯝
	md_wallet_outline = "\uf0bdd"
	# CHAR : 󰾎
	md_wallet_plus = "\uf0f8e"
	# CHAR : 󰾏
	md_wallet_plus_outline = "\uf0f8f"
	# CHAR : 󰖇
	md_wallet_travel = "\uf0587"
	# CHAR : 󰸉
	md_wallpaper = "\uf0e09"
	# CHAR : 󰖈
	md_wan = "\uf0588"
	# CHAR : 󰾐
	md_wardrobe = "\uf0f90"
	# CHAR : 󰾑
	md_wardrobe_outline = "\uf0f91"
	# CHAR : 󰾁
	md_warehouse = "\uf0f81"
	# CHAR : 󰜪
	md_washing_machine = "\uf072a"
	# CHAR : 󱆼
	md_washing_machine_alert = "\uf11bc"
	# CHAR : 󱆽
	md_washing_machine_off = "\uf11bd"
	# CHAR : 󰖉
	md_watch = "\uf0589"
	# CHAR : 󰖊
	md_watch_export = "\uf058a"
	# CHAR : 󰢕
	md_watch_export_variant = "\uf0895"
	# CHAR : 󰖋
	md_watch_import = "\uf058b"
	# CHAR : 󰢖
	md_watch_import_variant = "\uf0896"
	# CHAR : 󰢗
	md_watch_variant = "\uf0897"
	# CHAR : 󰚱
	md_watch_vibrate = "\uf06b1"
	# CHAR : 󰳚
	md_watch_vibrate_off = "\uf0cda"
	# CHAR : 󰖌
	md_water = "\uf058c"
	# CHAR : 󱔂
	md_water_alert = "\uf1502"
	# CHAR : 󱔃
	md_water_alert_outline = "\uf1503"
	# CHAR : 󰾒
	md_water_boiler = "\uf0f92"
	# CHAR : 󱆳
	md_water_boiler_alert = "\uf11b3"
	# CHAR : 󱆴
	md_water_boiler_off = "\uf11b4"
	# CHAR : 󱔄
	md_water_check = "\uf1504"
	# CHAR : 󱔅
	md_water_check_outline = "\uf1505"
	# CHAR : 󱠆
	md_water_circle = "\uf1806"
	# CHAR : 󱔆
	md_water_minus = "\uf1506"
	# CHAR : 󱔇
	md_water_minus_outline = "\uf1507"
	# CHAR : 󰖍
	md_water_off = "\uf058d"
	# CHAR : 󱔈
	md_water_off_outline = "\uf1508"
	# CHAR : 󱡕
	md_water_opacity = "\uf1855"
	# CHAR : 󰸊
	md_water_outline = "\uf0e0a"
	# CHAR : 󰖎
	md_water_percent = "\uf058e"
	# CHAR : 󱔉
	md_water_percent_alert = "\uf1509"
	# CHAR : 󱔊
	md_water_plus = "\uf150a"
	# CHAR : 󱔋
	md_water_plus_outline = "\uf150b"
	# CHAR : 󱊠
	md_water_polo = "\uf12a0"
	# CHAR : 󰖏
	md_water_pump = "\uf058f"
	# CHAR : 󰾓
	md_water_pump_off = "\uf0f93"
	# CHAR : 󱔌
	md_water_remove = "\uf150c"
	# CHAR : 󱔍
	md_water_remove_outline = "\uf150d"
	# CHAR : 󱟆
	md_water_sync = "\uf17c6"
	# CHAR : 󱪅
	md_water_thermometer = "\uf1a85"
	# CHAR : 󱪆
	md_water_thermometer_outline = "\uf1a86"
	# CHAR : 󱁫
	md_water_well = "\uf106b"
	# CHAR : 󱁬
	md_water_well_outline = "\uf106c"
	# CHAR : 󱡉
	md_waterfall = "\uf1849"
	# CHAR : 󱒁
	md_watering_can = "\uf1481"
	# CHAR : 󱒂
	md_watering_can_outline = "\uf1482"
	# CHAR : 󰘒
	md_watermark = "\uf0612"
	# CHAR : 󰼮
	md_wave = "\uf0f2e"
	# CHAR : 󱑽
	md_waveform = "\uf147d"
	# CHAR : 󰞍
	md_waves = "\uf078d"
	# CHAR : 󱡙
	md_waves_arrow_left = "\uf1859"
	# CHAR : 󱡚
	md_waves_arrow_right = "\uf185a"
	# CHAR : 󱡛
	md_waves_arrow_up = "\uf185b"
	# CHAR : 󰯞
	md_waze = "\uf0bde"
	# CHAR : 󰖐
	md_weather_cloudy = "\uf0590"
	# CHAR : 󰼯
	md_weather_cloudy_alert = "\uf0f2f"
	# CHAR : 󰹮
	md_weather_cloudy_arrow_right = "\uf0e6e"
	# CHAR : 󱣶
	md_weather_cloudy_clock = "\uf18f6"
	# CHAR : 󰖑
	md_weather_fog = "\uf0591"
	# CHAR : 󰖒
	md_weather_hail = "\uf0592"
	# CHAR : 󰼰
	md_weather_hazy = "\uf0f30"
	# CHAR : 󰢘
	md_weather_hurricane = "\uf0898"
	# CHAR : 󰖓
	md_weather_lightning = "\uf0593"
	# CHAR : 󰙾
	md_weather_lightning_rainy = "\uf067e"
	# CHAR : 󰖔
	md_weather_night = "\uf0594"
	# CHAR : 󰼱
	md_weather_night_partly_cloudy = "\uf0f31"
	# CHAR : 󰖕
	md_weather_partly_cloudy = "\uf0595"
	# CHAR : 󰼲
	md_weather_partly_lightning = "\uf0f32"
	# CHAR : 󰼳
	md_weather_partly_rainy = "\uf0f33"
	# CHAR : 󰼴
	md_weather_partly_snowy = "\uf0f34"
	# CHAR : 󰼵
	md_weather_partly_snowy_rainy = "\uf0f35"
	# CHAR : 󰖖
	md_weather_pouring = "\uf0596"
	# CHAR : 󰖗
	md_weather_rainy = "\uf0597"
	# CHAR : 󰖘
	md_weather_snowy = "\uf0598"
	# CHAR : 󰼶
	md_weather_snowy_heavy = "\uf0f36"
	# CHAR : 󰙿
	md_weather_snowy_rainy = "\uf067f"
	# CHAR : 󰖙
	md_weather_sunny = "\uf0599"
	# CHAR : 󰼷
	md_weather_sunny_alert = "\uf0f37"
	# CHAR : 󱓤
	md_weather_sunny_off = "\uf14e4"
	# CHAR : 󰖚
	md_weather_sunset = "\uf059a"
	# CHAR : 󰖛
	md_weather_sunset_down = "\uf059b"
	# CHAR : 󰖜
	md_weather_sunset_up = "\uf059c"
	# CHAR : 󰼸
	md_weather_tornado = "\uf0f38"
	# CHAR : 󰖝
	md_weather_windy = "\uf059d"
	# CHAR : 󰖞
	md_weather_windy_variant = "\uf059e"
	# CHAR : 󰖟
	md_web = "\uf059f"
	# CHAR : 󰾔
	md_web_box = "\uf0f94"
	# CHAR : 󱞐
	md_web_cancel = "\uf1790"
	# CHAR : 󰞉
	md_web_check = "\uf0789"
	# CHAR : 󱉊
	md_web_clock = "\uf124a"
	# CHAR : 󱂠
	md_web_minus = "\uf10a0"
	# CHAR : 󰪎
	md_web_off = "\uf0a8e"
	# CHAR : 󰀳
	md_web_plus = "\uf0033"
	# CHAR : 󱞑
	md_web_refresh = "\uf1791"
	# CHAR : 󰕑
	md_web_remove = "\uf0551"
	# CHAR : 󱞒
	md_web_sync = "\uf1792"
	# CHAR : 󰖠
	md_webcam = "\uf05a0"
	# CHAR : 󱜷
	md_webcam_off = "\uf1737"
	# CHAR : 󰘯
	md_webhook = "\uf062f"
	# CHAR : 󰜫
	md_webpack = "\uf072b"
	# CHAR : 󱉈
	md_webrtc = "\uf1248"
	# CHAR : 󰘑
	md_wechat = "\uf0611"
	# CHAR : 󰖡
	md_weight = "\uf05a1"
	# CHAR : 󰴿
	md_weight_gram = "\uf0d3f"
	# CHAR : 󰖢
	md_weight_kilogram = "\uf05a2"
	# CHAR : 󱅝
	md_weight_lifter = "\uf115d"
	# CHAR : 󰦵
	md_weight_pound = "\uf09b5"
	# CHAR : 󰖣
	md_whatsapp = "\uf05a3"
	# CHAR : 󱓲
	md_wheel_barrow = "\uf14f2"
	# CHAR : 󱪇
	md_wheelchair = "\uf1a87"
	# CHAR : 󰖤
	md_wheelchair_accessibility = "\uf05a4"
	# CHAR : 󰦶
	md_whistle = "\uf09b6"
	# CHAR : 󱊼
	md_whistle_outline = "\uf12bc"
	# CHAR : 󰖥
	md_white_balance_auto = "\uf05a5"
	# CHAR : 󰖦
	md_white_balance_incandescent = "\uf05a6"
	# CHAR : 󰖧
	md_white_balance_iridescent = "\uf05a7"
	# CHAR : 󰖨
	md_white_balance_sunny = "\uf05a8"
	# CHAR : 󰜬
	md_widgets = "\uf072c"
	# CHAR : 󱍕
	md_widgets_outline = "\uf1355"
	# CHAR : 󰖩
	md_wifi = "\uf05a9"
	# CHAR : 󱚵
	md_wifi_alert = "\uf16b5"
	# CHAR : 󱚶
	md_wifi_arrow_down = "\uf16b6"
	# CHAR : 󱚷
	md_wifi_arrow_left = "\uf16b7"
	# CHAR : 󱚸
	md_wifi_arrow_left_right = "\uf16b8"
	# CHAR : 󱚹
	md_wifi_arrow_right = "\uf16b9"
	# CHAR : 󱚺
	md_wifi_arrow_up = "\uf16ba"
	# CHAR : 󱚻
	md_wifi_arrow_up_down = "\uf16bb"
	# CHAR : 󱚼
	md_wifi_cancel = "\uf16bc"
	# CHAR : 󱚽
	md_wifi_check = "\uf16bd"
	# CHAR : 󱚾
	md_wifi_cog = "\uf16be"
	# CHAR : 󱚿
	md_wifi_lock = "\uf16bf"
	# CHAR : 󱛀
	md_wifi_lock_open = "\uf16c0"
	# CHAR : 󱛁
	md_wifi_marker = "\uf16c1"
	# CHAR : 󱛂
	md_wifi_minus = "\uf16c2"
	# CHAR : 󰖪
	md_wifi_off = "\uf05aa"
	# CHAR : 󱛃
	md_wifi_plus = "\uf16c3"
	# CHAR : 󱛄
	md_wifi_refresh = "\uf16c4"
	# CHAR : 󱛅
	md_wifi_remove = "\uf16c5"
	# CHAR : 󱛆
	md_wifi_settings = "\uf16c6"
	# CHAR : 󰸋
	md_wifi_star = "\uf0e0b"
	# CHAR : 󰤟
	md_wifi_strength_1 = "\uf091f"
	# CHAR : 󰤠
	md_wifi_strength_1_alert = "\uf0920"
	# CHAR : 󰤡
	md_wifi_strength_1_lock = "\uf0921"
	# CHAR : 󱛋
	md_wifi_strength_1_lock_open = "\uf16cb"
	# CHAR : 󰤢
	md_wifi_strength_2 = "\uf0922"
	# CHAR : 󰤣
	md_wifi_strength_2_alert = "\uf0923"
	# CHAR : 󰤤
	md_wifi_strength_2_lock = "\uf0924"
	# CHAR : 󱛌
	md_wifi_strength_2_lock_open = "\uf16cc"
	# CHAR : 󰤥
	md_wifi_strength_3 = "\uf0925"
	# CHAR : 󰤦
	md_wifi_strength_3_alert = "\uf0926"
	# CHAR : 󰤧
	md_wifi_strength_3_lock = "\uf0927"
	# CHAR : 󱛍
	md_wifi_strength_3_lock_open = "\uf16cd"
	# CHAR : 󰤨
	md_wifi_strength_4 = "\uf0928"
	# CHAR : 󰤩
	md_wifi_strength_4_alert = "\uf0929"
	# CHAR : 󰤪
	md_wifi_strength_4_lock = "\uf092a"
	# CHAR : 󱛎
	md_wifi_strength_4_lock_open = "\uf16ce"
	# CHAR : 󰤫
	md_wifi_strength_alert_outline = "\uf092b"
	# CHAR : 󱛏
	md_wifi_strength_lock_open_outline = "\uf16cf"
	# CHAR : 󰤬
	md_wifi_strength_lock_outline = "\uf092c"
	# CHAR : 󰤭
	md_wifi_strength_off = "\uf092d"
	# CHAR : 󰤮
	md_wifi_strength_off_outline = "\uf092e"
	# CHAR : 󰤯
	md_wifi_strength_outline = "\uf092f"
	# CHAR : 󱛇
	md_wifi_sync = "\uf16c7"
	# CHAR : 󰖬
	md_wikipedia = "\uf05ac"
	# CHAR : 󱪈
	md_wind_power = "\uf1a88"
	# CHAR : 󱪉
	md_wind_power_outline = "\uf1a89"
	# CHAR : 󰶥
	md_wind_turbine = "\uf0da5"
	# CHAR : 󱦫
	md_wind_turbine_alert = "\uf19ab"
	# CHAR : 󱦬
	md_wind_turbine_check = "\uf19ac"
	# CHAR : 󰖭
	md_window_close = "\uf05ad"
	# CHAR : 󰖮
	md_window_closed = "\uf05ae"
	# CHAR : 󱇛
	md_window_closed_variant = "\uf11db"
	# CHAR : 󰖯
	md_window_maximize = "\uf05af"
	# CHAR : 󰖰
	md_window_minimize = "\uf05b0"
	# CHAR : 󰖱
	md_window_open = "\uf05b1"
	# CHAR : 󱇜
	md_window_open_variant = "\uf11dc"
	# CHAR : 󰖲
	md_window_restore = "\uf05b2"
	# CHAR : 󱄜
	md_window_shutter = "\uf111c"
	# CHAR : 󱄝
	md_window_shutter_alert = "\uf111d"
	# CHAR : 󱪊
	md_window_shutter_cog = "\uf1a8a"
	# CHAR : 󱄞
	md_window_shutter_open = "\uf111e"
	# CHAR : 󱪋
	md_window_shutter_settings = "\uf1a8b"
	# CHAR : 󱗺
	md_windsock = "\uf15fa"
	# CHAR : 󰫩
	md_wiper = "\uf0ae9"
	# CHAR : 󰶦
	md_wiper_wash = "\uf0da6"
	# CHAR : 󱣟
	md_wiper_wash_alert = "\uf18df"
	# CHAR : 󱑷
	md_wizard_hat = "\uf1477"
	# CHAR : 󰖴
	md_wordpress = "\uf05b4"
	# CHAR : 󰖶
	md_wrap = "\uf05b6"
	# CHAR : 󰯟
	md_wrap_disabled = "\uf0bdf"
	# CHAR : 󰖷
	md_wrench = "\uf05b7"
	# CHAR : 󱦣
	md_wrench_clock = "\uf19a3"
	# CHAR : 󰯠
	md_wrench_outline = "\uf0be0"
	# CHAR : 󰡅
	md_xamarin = "\uf0845"
	# CHAR : 󰗀
	md_xml = "\uf05c0"
	# CHAR : 󰟿
	md_xmpp = "\uf07ff"
	# CHAR : 󰭏
	md_yahoo = "\uf0b4f"
	# CHAR : 󰗁
	md_yeast = "\uf05c1"
	# CHAR : 󰚀
	md_yin_yang = "\uf0680"
	# CHAR : 󱅼
	md_yoga = "\uf117c"
	# CHAR : 󰗃
	md_youtube = "\uf05c3"
	# CHAR : 󰡈
	md_youtube_gaming = "\uf0848"
	# CHAR : 󰡇
	md_youtube_studio = "\uf0847"
	# CHAR : 󰵀
	md_youtube_subscription = "\uf0d40"
	# CHAR : 󰑈
	md_youtube_tv = "\uf0448"
	# CHAR : 󱔖
	md_yurt = "\uf1516"
	# CHAR : 󰫪
	md_z_wave = "\uf0aea"
	# CHAR : 󰫫
	md_zend = "\uf0aeb"
	# CHAR : 󰵁
	md_zigbee = "\uf0d41"
	# CHAR : 󰗄
	md_zip_box = "\uf05c4"
	# CHAR : 󰿺
	md_zip_box_outline = "\uf0ffa"
	# CHAR : 󰨣
	md_zip_disk = "\uf0a23"
	# CHAR : 󰩽
	md_zodiac_aquarius = "\uf0a7d"
	# CHAR : 󰩾
	md_zodiac_aries = "\uf0a7e"
	# CHAR : 󰩿
	md_zodiac_cancer = "\uf0a7f"
	# CHAR : 󰪀
	md_zodiac_capricorn = "\uf0a80"
	# CHAR : 󰪁
	md_zodiac_gemini = "\uf0a81"
	# CHAR : 󰪂
	md_zodiac_leo = "\uf0a82"
	# CHAR : 󰪃
	md_zodiac_libra = "\uf0a83"
	# CHAR : 󰪄
	md_zodiac_pisces = "\uf0a84"
	# CHAR : 󰪅
	md_zodiac_sagittarius = "\uf0a85"
	# CHAR : 󰪆
	md_zodiac_scorpio = "\uf0a86"
	# CHAR : 󰪇
	md_zodiac_taurus = "\uf0a87"
	# CHAR : 󰪈
	md_zodiac_virgo = "\uf0a88"